---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2010-03-15;66
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20100508&codiceRedaz=010G0089&dataVigenza=20251104
dataGU: 20100508
codiceRedaz: 010G0089
dataVigenza: 20251104
---

# Codice dell'ordinamento militare. (10G0089)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87 e 117, secondo comma, lettera d), della Costituzione;

Vistala legge 28 novembre 2005, n. 246 e, in particolare, l'articolo 14:

comma 14, cosi' come sostituito dall'articolo 4, comma 1, lettera a), della legge 18 giugno 2009, n. 69, con il quale e' stata conferita al Governo la delega ad adottare, con le modalita' di cui all'articolo 20 della legge 15 marzo 1997, n. 59, decreti legislativi che individuano le disposizioni legislative statali, pubblicate anteriormente al 1° gennaio 1970, anche se modificate con provvedimenti successivi, delle quali si ritiene indispensabile la permanenza in vigore, secondo i principi e criteri direttivi fissati nello stesso comma 14, dalla lettera a) alla lettera h);

comma 15, con cui si stabilisce che i decreti legislativi di cui al citato comma 14, provvedono, altresi', alla semplificazione o al riassetto della materia che ne e' oggetto, nel rispetto dei principi e criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, anche al fine di armonizzare le disposizioni mantenute in vigore con quelle pubblicate successivamente alla data del 1° gennaio 1970;

comma 22, con cui si stabiliscono i termini per l'acquisizione del prescritto parere da parte della Commissione parlamentare per la semplificazione;

Visto il decreto legislativo 30 luglio 1999, n. 300, recante riforma dell'organizzazione del Governo, a norma dell'articolo 11 della legge 15 marzo 1997, n. 59 e, in particolare, gli articoli da 20 a 22;

Visto il concerto reso dal Ministro per i rapporti con il Parlamento, dal Ministro per i rapporti con le Regioni, dal Ministro per le pari opportunita', dal Ministro per la pubblica amministrazione e l'innovazione, dal Ministro per l'attuazione del programma di Governo, dal Ministro degli affari esteri, dal Ministro dell'interno, dal Ministro della giustizia, dal Ministro dell'economia e delle finanze, dal Ministro dello sviluppo economico, dal Ministro delle politiche agricole alimentari e forestali, dal Ministro dell'ambiente e della tutela del territorio e del mare, dal Ministro delle infrastrutture e dei trasporti, dal Ministro del lavoro e delle politiche sociali, dal Ministro della salute e dal Ministro per i beni e le attivita' culturali;

VistI i pareri resi dal Sottosegretario di Stato con delega per la famiglia, la droga e il servizio civile e dal Sottosegretario di Stato e Capo del Dipartimento della protezione civile della Presidenza del Consiglio dei Ministri;

Visti altresi', i pareri resi dal Ministro per le riforme per il federalismo, dal Ministro per le politiche europee, dal Ministro della gioventu', dal Ministro del turismo, dal Ministro dell'istruzione, dell'universita' e della ricerca;

Vista la richiesta di parere inviata in data 30 giugno 2009 alle Conferenze Stato Regioni e Unificata;

Visto il parere reso dal Consiglio della magistratura militare nella seduta del 7 luglio 2009;

Vista la deliberazione preliminare del Consiglio dei ministri, adottata nella riunione dell'11 dicembre 2009;

Udito il parere del Consiglio di Stato espresso dalla Commissione speciale nell'Adunanza del 10 febbraio 2010;

Acquisita la proposta di parere della Commissione bicamerale per la semplificazione, per la seduta del 24 febbraio 2010;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 12 marzo 2010;

Sulla proposta del Ministro della difesa e del Ministro per la semplificazione normativa;

Emana il seguente decreto legislativo:

## LIBRO PRIMO ORGANIZZAZIONE E FUNZIONI TITOLO I DISPOSIZIONI PRELIMINARI

### Art. 1. - Oggetto e ambito di applicazione

1. Il presente decreto, con la denominazione di <<codice dell'ordinamento militare>>, e le altre disposizioni da esso espressamente richiamate, disciplinano l'organizzazione, le funzioni e l'attivita' della difesa e sicurezza militare e delle Forze armate. Ai fini del presente decreto per <<codice>> si intende il codice di cui al presente comma.

2. Nulla e' innovato dal presente codice per quanto concerne le disposizioni vigenti proprie del Corpo della guardia di finanza, del Sistema di informazione per la sicurezza della Repubblica, dell'Amministrazione della pubblica sicurezza, delle Forze di polizia a ordinamento civile e del Corpo nazionale dei vigili del fuoco.

3. Le norme regolamentari disciplinanti la medesima materia del codice sono raccolte in un testo unico organico, d'ora innanzi denominato <<regolamento>>, emanato ai sensi dell'articolo 20 della legge 15 marzo 1997, n. 59; il regolamento e' modificato secondo le procedure previste dall'articolo 17 della legge 23 agosto 1988, n. 400, nel rispetto delle ulteriori modalita' individuate dal codice.

4. Nella materia di cui al comma 1, rimane ferma la disciplina introdotta dalle leggi di autorizzazione alla ratifica di trattati internazionali.

5. Nella materia di cui al comma 1, lo Stato esercita la potesta' legislativa esclusiva ai sensi dell'articolo 117, comma 2, lettera d), della Costituzione, che costituisce anche limite all'esercizio delle attribuzioni delle regioni e delle province autonome di Trento e Bolzano sul governo del territorio.

6. Se non e' diversamente disposto, ai provvedimenti e ai procedimenti previsti dal codice e dal regolamento si applicano la legge 7 agosto 1990, n. 241, il decreto del Presidente della Repubblica 28 dicembre 2000, n. 445, e il decreto legislativo 30 giugno 2003, n. 196.

## TITOLO II CONSIGLIO SUPREMO DI DIFESA

### Art. 2. - Attribuzioni del Consiglio supremo di difesa

1. Il Consiglio supremo di difesa, nel presente titolo denominato <<Consiglio>>, esamina i problemi generali politici e tecnici attinenti alla difesa nazionale e determina i criteri e fissa le direttive per l'organizzazione e il coordinamento delle attivita' che comunque la riguardano.

### Art. 3. - Componenti di diritto

1. Il Consiglio e' presieduto dal Presidente della Repubblica ed e' composto:

- a) dal Presidente del Consiglio dei ministri, con funzioni di vice-presidente;
- b) dal Ministro degli affari esteri;
- c) dal Ministro dell'interno;
- d) dal Ministro dell'economia e delle finanze;
- e) dal Ministro della difesa;
- f) dal Ministro dello sviluppo economico;
- g) dal Capo di stato maggiore della difesa.

2. Il segretario del Consiglio, nominato dal Consiglio stesso e scelto al di fuori dei suoi componenti, partecipa alle sedute.

### Art. 4. - Componenti eventuali

1. Il Presidente puo' convocare riunioni del Consiglio con la partecipazione, a suo invito, dei Ministri non indicati nell'articolo 3.

2. Possono altresi' essere convocati alle riunioni del Consiglio, se il presidente lo ritiene opportuno, i Capi di stato maggiore dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, i presidenti degli organi e istituti indicati nell'articolo 5, nonche' persone di particolare competenza nel campo scientifico, industriale ed economico ed esperti in problemi militari, ivi compresi i rappresentanti qualificati del Corpo volontari della liberta' e delle formazioni partigiane.

### Art. 5. - Organi ausiliari

1. Il Consiglio, nello svolgimento delle sue attribuzioni, puo' avvalersi del Comitato interministeriale per la programmazione economica, del Consiglio nazionale delle ricerche, dell'Istituto centrale di statistica, degli organi consultivi delle Forze armate e dello Stato.

### Art. 6. - Segretario del Consiglio

1. Il segretario del Consiglio raccoglie ed elabora, secondo le direttive del Consiglio, tutti gli elementi relativi alle questioni da sottoporre al Consiglio stesso, coordina le relative deliberazioni e ne predispone l'attuazione da parte degli organi competenti.

2. A tale scopo il segretario del Consiglio puo' chiedere direttamente ad amministrazioni pubbliche, enti e imprese, tutti gli elementi e i dati necessari per lo studio e la trattazione delle questioni da sottoporre al Consiglio.

### Art. 7. - Ufficio di segreteria

1. L'Ufficio di segreteria, istituito presso il Consiglio, coadiuva il segretario del Consiglio nello svolgimento delle funzioni indicate nell'articolo 6.

2. L'Ufficio di segreteria e' costituito da personale comandato, militare e civile, delle amministrazioni dello Stato.

3. Il numero massimo dei componenti l'Ufficio di segreteria e' determinato con decreto del Presidente del Consiglio dei ministri, di concerto con i Ministri dell'economia e delle finanze e della difesa.

### Art. 8. - Riunioni

1. Il Consiglio si riunisce almeno due volte all'anno.

2. E' inoltre convocato, tutte le volte che se ne ravvisi la necessita', dal Presidente della Repubblica, di propria iniziativa o su proposta del Presidente del Consiglio dei ministri.

### Art. 9. - Regolamento di organizzazione e funzionamento

1. Le norme necessarie per l'attuazione di quanto previsto dal presente titolo sono contenute nel regolamento.

## TITOLO III AMMINISTRAZIONE DELLA DIFESA CAPO I MINISTRO DELLA DIFESA

### Art. 10. - Attribuzioni del Ministro della difesa

1. Il Ministro della difesa, preposto all'amministrazione militare e civile della difesa e massimo organo gerarchico e disciplinare:

- a) attua le deliberazioni in materia di difesa e sicurezza adottate dal Governo, sottoposte all'esame del Consiglio supremo di difesa e approvate dal Parlamento;
- b) emana le direttive in merito alla politica militare, all'attivita' informativa e di sicurezza e all'attivita' tecnico-amministrativa;
- c) partecipa direttamente o tramite un suo delegato a tutti gli organismi internazionali ed europei competenti in materia di difesa e sicurezza militare o le cui deliberazioni comportino effetti sulla difesa nazionale;
- d) approva la pianificazione generale e operativa interforze con i conseguenti programmi tecnico-finanziari, nonche' la pianificazione relativa all'area industriale, pubblica e privata, di interesse della Difesa.

2. Il Ministro della difesa, inoltre, propone al Presidente del Consiglio dei ministri, la relazione annuale da presentare al Parlamento, in ordine allo stato della disciplina militare e allo stato dell'organizzazione delle Forze armate, in relazione agli obiettivi di ristrutturazione, riferendo, in particolare:

- a) sul livello di operativita' delle singole Forze armate;
- b) sul grado di integrazione del personale militare volontario femminile;
- c) sull'attivita' per il sostegno alla ricollocazione professionale dei volontari congedati, svolta dall'esistente struttura ministeriale;
- d) sul conseguimento degli obiettivi di reclutamento dei volontari necessari ad assicurare l'operativita' delle Forze armate;
- e) sullo stato dei reclutamenti nelle carriere iniziali delle Forze di polizia a ordinamento civile e militare e del Corpo militare della Croce rossa.

3. Il Ministro della difesa, altresi', puo' sopprimere o riorganizzare, con proprio decreto, emanato su proposta del Capo di stato maggiore della difesa, enti e organismi nell'ambito del processo di ristrutturazione delle Forze armate, fermo restando il disposto dell'articolo 177.

### Art. 11. - Attribuzioni in materia di armamenti

1. Il Ministro della difesa, in materia di controllo dell'esportazione, importazione e transito dei materiali di armamento, esercita le competenze e attribuzioni previste dalla legge 9 luglio 1990, n. 185 e dal regolamento di attuazione ((...)).

### Art. 12. - Relazioni al Parlamento

1. Il Ministro della difesa, in sede di presentazione annuale dello stato di previsione del Ministero, illustra al Parlamento:

- a) l'evoluzione del quadro strategico e le implicazioni militari della situazione delle alleanze;
- b) l'evoluzione degli impegni operativi interforze, con riguardo alla capacita' operativa e alla preparazione delle Forze armate e al loro necessario adeguamento;
- c) la nota aggiuntiva allo stato di previsione della spesa;
- d) gli altri elementi di cui all'articolo 548.

2. Il Ministro della difesa presenta annualmente, entro il 31 gennaio, una relazione al Parlamento sullo stato di avanzamento del processo di ristrutturazione, nonche' sulla necessita' di apportarvi correttivi nei limiti degli stanziamenti di bilancio e delle dotazioni organiche di personale previste dalle vigenti disposizioni. Il Ministro della difesa evidenzia altresi', nella medesima relazione, le modalita' attraverso le quali il processo di ristrutturazione attua il principio del coordinamento tra le Forze armate.

### Art. 13. - Attribuzioni ulteriori

1. Il Ministro della difesa, oltre a quanto previsto negli articoli 10, 11 e 12, esercita le competenze:

- a) in materia di ordinamento giudiziario, di cui al capo VI del presente titolo;
- b) attribuite in via generale ai Ministri in materia di organizzazione dei rispettivi dicasteri, e in particolare quelle di cui al decreto legislativo 30 marzo 2001, n. 165;
- c) previste dalla legge, dal presente codice e dal regolamento.

### Art. 14. - Uffici di diretta collaborazione con il Ministro e organismo indipendente di valutazione della performance

1. Il Ministro della difesa, nell'ambito di quanto previsto dall'articolo 14, comma 2, del decreto legislativo 30 marzo 2001, n. 165, si avvale:

- a) per l'esercizio delle funzioni indicate negli articoli 10, 11, 12 e 13, di uffici di diretta collaborazione, aventi esclusive competenze di supporto e di raccordo con l'amministrazione;
- b) ai sensi dell'articolo 8, comma 1, ultimo periodo, del decreto legislativo 30 luglio 1999, n. 286, del supporto dell'organismo indipendente di valutazione della performance.

2. Il Ministro della difesa puo' essere coadiuvato da un portavoce, anche esterno all'amministrazione, con compiti di diretta collaborazione ai fini dei rapporti di carattere politico-istituzionale con gli organi di informazione. Si applica, in tal caso, l'articolo 7 della legge 7 giugno 2000, n. 150.

3. Gli uffici e l'organismo indipendente di valutazione della performance di cui al presente articolo sono disciplinati con il regolamento.

## CAPO II - MINISTERO DELLA DIFESA

### SEZIONE I - AMMINISTRAZIONE CENTRALE E PERIFERICA

#### Art. 15. - Attribuzioni del Ministero della difesa

1. Al Ministero della difesa sono attribuite le funzioni e i compiti spettanti allo Stato in materia di difesa e sicurezza militare dello Stato, politica militare e partecipazione a missioni a supporto della pace, partecipazione a organismi internazionali di settore, pianificazione generale e operativa delle Forze armate e interforze, pianificazione relativa all'area industriale di interesse della Difesa.

2. Il Ministero della difesa esercita in particolare le funzioni e i compiti ((di seguito indicati:)) difesa e sicurezza dello Stato, del territorio nazionale e delle vie di comunicazione marittime e aree, pianificazione generale operativa delle Forze armate e Interforze con i conseguenti programmi tecnico finanziari; partecipazione a missioni anche multinazionali per interventi a supporto della pace; partecipazione agli organismi internazionali ed europei competenti in materia di difesa e sicurezza militare o le cui deliberazioni comportino effetti sulla difesa nazionale e attuazione delle decisioni da questi adottate; rapporti con le autorita' militari degli altri Stati; informativa al Parlamento sull'evoluzione del quadro strategico e degli impegni operativi; classificazione, organizzazione e funzionamento degli enti dell'area operativa; interventi di tutela ambientale, concorso nelle attivita' di protezione civile su disposizione del Governo, concorso alla salvaguardia delle libere istituzioni e il bene della collettivita' nazionale nei casi di pubbliche calamita'; ((...)) politica degli armamenti e relativi programmi di cooperazione internazionale; conseguimento degli obiettivi di efficienza fissati per lo strumento militare; bilancio e affari finanziari; ispezioni amministrative; affari giuridici, economici, contenzioso, disciplinari e sociali del personale militare e civile; armamenti terrestri, navali e aeronautici; telecomunicazioni, informatica e tecnologie avanzate; lavori e demanio; commissariato e servizi generali; leva e reclutamento; sanita' militare; attivita' di ricerca e sviluppo, approvvigionamento dei materiali e dei sistemi d'arma; programmi di studio nel settore delle nuove tecnologie per lo sviluppo dei programmi d'armamento; pianificazione dell'area industriale pubblica e privata; classificazione, organizzazione e funzionamento degli enti dell'area tecnico industriale.

((

2-bis. La ripartizione delle funzioni e dei compiti, di cui al comma 2, tra le aree e gli uffici individuati dall'articolo 16, comma 1, lettere b), c), d) ed e), e' attuata con regolamento, emanato ai sensi dell'articolo 17, comma 4-bis, della legge 23 agosto 1988, n. 400, sentite, per le materie di competenza, le organizzazioni sindacali rappresentative, apportando, con regolamento emanato ai sensi dell'articolo 17, comma 2 della medesima legge 23 agosto 1988, n. 400, anche eventuali, conseguenti abrogazioni di disposizioni del presente codice, secondo criteri che assicurano nell'ambito delle aree:

- a) la individuazione dei compiti e delle funzioni attinenti alle attribuzioni di comando nei riguardi del personale rispetto ai rimanenti compiti e funzioni riguardanti il personale medesimo;
- b) la standardizzazione organizzativa, per settori omogenei, anche attraverso le necessarie semplificazioni e armonizzazioni procedimentali;
- c) l'unicita' decisionale;
- d) le procedure di coordinamento delle attivita' fra le aree;
- e) l'attribuzione di funzioni e compiti tecnico-amministrativi al personale civile di livello dirigenziale e non dirigenziale appartenente ai ruoli del Ministero della difesa;
- f) la predisposizione di meccanismi per la verifica dell'effettivo livello di fruibilita' dei servizi erogati al personale.

))

3. Il Ministero della difesa svolge i compiti di cui agli articoli 21 e 22.

#### Art. 16. - Ordinamento

1. L'organizzazione del Ministero della difesa e' articolata nelle seguenti componenti:

- a) uffici di diretta collaborazione del Ministro della difesa;
- b) area tecnico-operativa;
- c) area tecnico-amministrativa;
- d) area tecnico-industriale;
- e) tre uffici centrali;
- f) Servizio assistenza spirituale;
- g) Ufficio per la tutela della cultura e della memoria della difesa;
- h) Circolo ufficiali delle Forze armate.

2. L'area tecnico-operativa e' disciplinata nel capo III del presente titolo; l'area tecnico-amministrativa, ((articolata nella Direzione nazionale degli armamenti, nelle)) direzioni generali secondo quanto previsto dal regolamento, coordinate da un segretario generale, ((e negli uffici centrali, e' disciplinata)) nel capo IV del presente titolo e nel regolamento; l'area tecnico-industriale e' disciplinata nel capo V del presente titolo; l'Ufficio per la tutela della cultura e della memoria della difesa e' disciplinato dal presente capo, dal capo VI del titolo II del libro secondo, dal capo II del titolo III del libro terzo e dal regolamento.

#### Art. 17. - (( (Assistenza spirituale). ))

((

1. L'assistenza spirituale ai militari cattolici, di cui all'articolo 11, comma 2, dell'accordo, con protocollo addizionale, firmato a Roma il 18 febbraio 1984, che apporta modificazioni al Concordato lateranense dell'11 febbraio 1929, tra la Repubblica italiana e la Santa Sede, ratificato e reso esecutivo con la legge 25 marzo 1985, n. 121, e' assicurata da cappellani militari, nominati dal Ministro della difesa su designazione dell'Ordinario militare, in base alle disposizioni stabilite dal presente codice e, in particolare, dal titolo III del libro quinto.

2. Le autorita' militari garantiscono ai cappellani militari la piena liberta' nell'esercizio del loro ministero, riconoscendo la dignita' e la natura peculiare del loro servizio, e assicurano la disponibilita' dei luoghi e dei mezzi necessari per l'assolvimento delle loro funzioni))

#### Art. 18. - ((capo dell'Ufficio per la tutela della cultura e della memoria della difesa))

1. Il ((capo dell'Ufficio per la tutela della cultura e della memoria della difesa)) esercita le sue funzioni alla dirette dipendenze del Ministro della difesa, che ha il potere di nomina e di tutela dello stesso ((capo dell'Ufficio)), oltre che di decisione in ordine ai dissensi tra il ((capo dell'Ufficio)) e le altre amministrazioni con cui deve raccordarsi al fine dell'espletamento delle sue funzioni.

2. Le competenze e le funzioni del ((capo dell'Ufficio per la tutela della cultura e della memoria della difesa)) sono disciplinati nel libro II, titolo II, capo VI, sezione III del presente codice.

#### Art. 19. - Circolo ufficiali delle Forze armate d'Italia

1. Il Circolo ufficiali delle Forze armate d'Italia ha sede a Roma ed e', a tutti gli effetti, inserito nell'ambito degli uffici di organizzazione del Ministero della difesa.

2. Le attivita' sociali e di rappresentanza espletate dal Circolo ufficiali delle Forze armate d'Italia non sono considerate commerciali ai sensi dell'articolo 4, comma 5, del decreto del Presidente della Repubblica 26 ottobre 1972, n. 633.

3. Gli ufficiali in servizio delle Forze armate e del Corpo della guardia di finanza sono iscritti di diritto al Circolo, e sono tenuti al pagamento obbligatorio della quota mensile.

4. Al Circolo e' destinato personale militare e civile nell'ambito delle dotazioni organiche del Ministero della difesa, il quale subentra in tutti i rapporti di lavoro in essere a tempo indeterminato del Circolo. Per il funzionamento sono utilizzate le risorse derivanti dalle quote obbligatoriamente versate mensilmente dagli ufficiali, l'ammontare delle quali e' stabilito annualmente dal Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, nonche' gli eventuali contributi finanziari e strumentali forniti dal Ministero della difesa nell'ambito degli stanziamenti ordinari di bilancio.

5. Gli organi, l'organizzazione e il funzionamento del Circolo sono disciplinati dal regolamento.

#### Art. 20. - Enti vigilati

1. Sono posti sotto la vigilanza del Ministero della difesa:

- a) l'Agenzia industrie difesa;
- b) la Difesa servizi spa;
- c) l'Unione nazionale ufficiali in congedo d'Italia;
- d) l'Opera nazionale per i figli degli aviatori;
- e) l'Unione italiana tiro a segno;
- f) la Lega navale italiana;
- g) l'Associazione italiana della Croce rossa, per le componenti ausiliarie delle Forze armate;
- h) la Cassa di previdenza delle Forze armate.

2. L'organizzazione, i compiti e le funzioni dell'Agenzia industrie difesa e della Difesa servizi spa sono rispettivamente disciplinati nell'articolo 48 e nell'articolo 535.

3. Nel regolamento sono disciplinati gli enti di cui alle lettere c), d), e), f), g) e h), del comma 1; la disciplina relativa alle componenti ausiliarie delle Forze armate dell'Associazione italiana della Croce rossa e' contenuta negli articoli 196, 197 e da 1626 a 1760. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 21. - Servizio di assistenza al volo

1. Ai sensi dell'articolo 7, paragrafo 5, del regolamento (CE) n. 550/2004, i servizi di controllo del traffico aereo regolari e pianificati sono forniti al traffico aereo generale sotto la responsabilita' dell'Aeronautica militare sugli aeroporti e negli spazi aerei di competenza, quale fornitore di servizi di navigazione aerea in via primaria a movimenti di aeromobili diversi dal traffico aereo generale.

2. Per assicurare una corretta fornitura dei servizi di cui al comma 1, l'Aeronautica militare, avvalendosi degli atti di intesa previsti dall'articolo 1, comma 3, del decreto legge 8 settembre 2004, n. 237, convertito, con modificazioni, dalla legge 9 novembre 2004, n. 265, applica e garantisce il rispetto dei requisiti di qualita' e sicurezza, stabiliti dal decreto legislativo 30 maggio 2008, n. 118, nella formazione, nell'addestramento e nell'impiego del personale militare preposto alle funzioni di controllo del traffico aereo generale.

3. L'Ente nazionale per l'aviazione civile rilascia la licenza di studente o controllore del traffico aereo al personale militare impiegato nello svolgimento delle funzioni di controllore o studente controllore presso fornitori di servizi di navigazione aerea di cui al comma 1, previa dimostrazione da parte dell'Aeronautica militare della rispondenza dei requisiti in possesso di detto personale a quelli prescritti dal decreto legislativo 30 maggio 2008, n. 118.

4. In relazione a urgenti necessita' per la difesa nazionale, il servizio di assistenza al volo per il traffico aereo generale, di cui alla legge 23 maggio 1980, n. 242, puo' essere assunto dal Ministero della difesa con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, di concerto con i Ministri della difesa e delle infrastrutture e dei trasporti, sentite le commissioni competenti dei due rami del Parlamento e, in caso di particolare urgenza, informati i Presidenti delle Camere.

5. Con decorrenza dalla data del predetto decreto, il personale addetto al servizio di assistenza al volo e' considerato, a ogni effetto, personale militare in congedo richiamato in servizio, salvo il mantenimento, se piu' favorevole, del proprio trattamento economico. Esso non puo' essere destinato a un diverso servizio.

6. Con il decreto di cui al comma 4 sono adottate le norme per l'attribuzione dei gradi militari in relazione alle funzioni svolte.

#### Art. 22.

Servizio di distruzione delle scorte di mine antipersona, armi chimiche e degli esplosivi non contrassegnati, nonche' di bonifica da ordigni esplosivi residuati bellici

1. Il Ministero della difesa esercita le seguenti competenze:

- a) in materia di distruzione delle scorte di mine antipersona: 1) provvede a distruggere l'arsenale di mine antipersona in dotazione o stoccaggio presso le Forze armate, fatta eccezione per una quantita' limitata e comunque non superiore alle ottomila unita' e rinnovabile tramite importazione fino a una quantita' non superiore al numero sopra indicato, in deroga a quanto disposto dall'articolo 1, comma 2 della legge 29 ottobre 1997, n. 374, destinata esclusivamente all'addestramento in operazioni di sminamento e alla ricerca di nuove tecnologie a scopo di sminamento e di distruzione delle mine; 2) provvede, altresi', a distruggere le mine antipersona consegnate dalle aziende produttrici e dagli altri detentori, ai sensi dell'articolo 3 della legge 29 ottobre 1997, n. 374;
- b) in materia di armi chimiche: 1) comunica al Ministero degli affari esteri, ai fini delle dichiarazioni iniziali e successive all'Organizzazione, prescritte dall'articolo III della Convenzione sulla proibizione dello sviluppo, produzione, immagazzinaggio e uso di armi chimiche e sulla loro distruzione, con annessi, fatta a Parigi il 13 gennaio 1993, e dalla parte IV dell'annesso sulle verifiche alla convenzione, i dati e le informazioni ivi specificamente indicati, relativi alle armi chimiche obsolete ovvero abbandonate gia' raccolte nel centro di stoccaggio in attesa di distruzione e a tutte le armi chimiche obsolete rinvenute in aree sotto il suo diretto controllo, nonche' quelli relativi ai composti chimici della tabella I, contenuta nell'<<annesso sui composti chimici>> alla convenzione, detenuti per le attivita' non proibite dalla convenzione e, in particolare, per l'addestramento delle squadre di difesa nucleare, biologica, chimica (NBC) e per le esigenze di collaudo e sperimentazione dei materiali per la difesa NBC; 2) provvede, attraverso il Centro tecnico logistico interforze NBC, al recupero, immagazzinaggio e distruzione delle armi chimiche di cui al punto 1 della presente lettera, secondo le procedure, le modalita' e le scadenze previste nelle disposizioni della convenzione e del citato annesso, e fornisce, su richiesta delle autorita' competenti e nell'ambito della propria competenza, concorso alla identificazione, al recupero, all'immagazzinamento e alla distruzione delle armi chimiche, incluse quelle obsolete e abbandonate, rinvenute sul territorio nazionale;
- c) in materia di distruzione degli esplosivi non contrassegnati, ai sensi della legge 20 dicembre 2000, n. 420: 1) procede alla distruzione degli esplosivi non contrassegnati; 2) definisce con proprio provvedimento i profili procedurali nonche' gli enti, stabilimenti o reparti incaricati di svolgere l'attivita' di distruzione.
- c-bis) in materia di bonifiche da ordigni esplosivi residuati bellici, con le risorse umane, finanziarie e strumentali a legislazione vigente: 1) provvede all'organizzazione del servizio e alla formazione del personale specializzato; 2) esercita le funzioni di vigilanza sulle attivita' di ricerca e scoprimento di ordigni che, a scopo precauzionale, possono essere eseguiti su iniziativa e a spese dei soggetti interessati, mediante ditte che impiegano personale specializzato ai sensi del numero 1), e, a tal fine, emana le prescrizioni tecniche e sorveglia l'esecuzione dell'attivita' ((, anche ai sensi degli articoli 91, comma 2-bis e 104, comma 4-bis, del decreto legislativo 9 aprile 2008, n. 81 e dell'articolo 1, comma 2, della legge 1° ottobre 2012, n. 177)); 3) segnala alle competenti sedi INAIL il personale incaricato di effettuare i lavori di bonifica ai sensi del numero 2); 4) esegue direttamente o mediante appalto alle ditte di cui al numero 2) le attivita' di ricerca, individuazione e scoprimento di ordigni sulle aree che ha in uso; 5) svolge l'attivita' di disinnesco, brillamento, quando ne ricorrono le condizioni, e rimozione degli ordigni bellici rinvenuti, attraverso personale specializzato di Forza armata; 6) svolge l'attivita' di cui al numero n. 5) sotto il coordinamento dei prefetti competenti per territorio, cui e' rimessa l'adozione di ogni provvedimento utile a tutela della pubblica incolumita'.

2. Con il decreto interministeriale di cui all'articolo 6 della legge 29 ottobre 1997, n. 374:

- a) e' stabilita la disciplina della distruzione delle scorte di mine antipersona con modalita' che tengano presenti anche le esigenze di tutela ambientale;
- b) e' individuato, altresi', l'ufficio competente nell'ambito dell'amministrazione del Ministero della difesa;
- c) e' istituito un registro ove riportare i quantitativi e i tipi di mine antipersona in possesso delle Forze armate, nonche' di quelle consegnate ai sensi del comma 1, e le date e le modalita' della loro distruzione, e annotare, altresi', le denunce fatte ai sensi dell'articolo 4, della legge 29 ottobre 1997, n. 374.

3. Con il decreto interministeriale di cui all'articolo 4, comma 3, della legge 20 dicembre 2000, n. 420, e' definita la disciplina relativa alle attivita' procedurali e le modalita' di distruzione degli esplosivi non contrassegnati.

### SEZIONE II - ORGANI CONSULTIVI E ((COMMISSIONI DI ELEVATA SPECIALIZZAZIONE TECNICA))

#### Art. 23.

((ARTICOLO ABROGATO DALLA L. 31 DICEMBRE 2012, N. 244)) ((18a))

------------- AGGIORNAMENTO (18a) La L. 31 dicembre 2012, n. 244 ha disposto (con l'art. 5, comma 1) che "Il Consiglio superiore delle Forze armate e' soppresso a decorrere dal sesto mese successivo alla data di entrata in vigore della presente legge".

#### Art. 24. - (( Organi consultivi ))

((

1. Presso il Ministero della difesa operano:

- a) il Comitato unico di garanzia per le pari opportunita', la valorizzazione del benessere di chi lavora e contro le discriminazioni, istituito ai sensi dell'articolo 57, comma 01, del decreto legislativo 30 marzo 2001, n. 165;
- b) il Consiglio interforze sulla prospettiva di genere, quale organo di consulenza del Capo di Stato maggiore della difesa, disciplinato nel regolamento in conformita' alle vigenti disposizioni internazionali.

2. L'attivita' degli organismi di cui al comma 1 e' svolta senza nuovi maggiori oneri per la finanza pubblica, attraverso le strutture esistenti e il personale in servizio a cui comunque non spetta alcuna indennita' o emolumento aggiuntivo, compresi gettoni di presenza. Ai componenti dell'organismo di cui al comma 1, lettera b), non e' corrisposta alcuna forma di rimborso spese.

))

#### Art. 24-bis. - Commissione interministeriale per l'espressione del parere sulle cause degli incidenti accorsi agli aeromobili di Stato e delle raccomandazioni ai fini di prevenzione

1. Presso il Ministero della difesa - Ispettorato per la sicurezza del volo - opera la Commissione interministeriale sugli incidenti accorsi agli aeromobili di Stato avente i seguenti compiti:

- a) esprimere il parere tecnico-amministrativo sulle responsabilita' conseguenti a incidenti di volo occorsi agli aeromobili militari, della Polizia di Stato, del Corpo nazionale dei vigili del fuoco e del Corpo forestale dello Stato;
- b) emettere il giudizio conclusivo sulle cause dei predetti incidenti e le conseguenti raccomandazioni ai fini di prevenzione.

2. La composizione e le modalita' di funzionamento della commissione interministeriale di cui al comma 1, presieduta dall'Ispettore per la sicurezza del volo, sono definiti ((...)) con decreto del Ministro della difesa, adottato di concerto con gli altri Ministri interessati.

3. Ai componenti della commissione interministeriale ((, nominati per la durata di un biennio con decreto del Ministro della difesa su designazione degli altri Ministri interessati,)) non e' dovuto alcun compenso, compresi gettoni di presenza e rimborsi spese.

## CAPO III - AREA TECNICO OPERATIVA

### SEZIONE I - CAPO DI STATO MAGGIORE DELLA DIFESA

#### Art. 25. - Configurazione della carica di Capo di stato maggiore della difesa

1. Il Capo di stato maggiore della difesa e' scelto tra gli ufficiali di grado non inferiore a quello di generale di corpo d'armata dell'Esercito italiano, di ammiraglio di squadra della Marina militare e di generale di squadra aerea dell'Aeronautica militare, in servizio permanente ovvero richiamati ai sensi dell'articolo 1094, comma 4, ed e' nominato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa.

2. Il Capo di stato maggiore della difesa:

- a) dipende direttamente dal Ministro della difesa, di cui e' l'alto consigliere tecnico-militare e al quale risponde dell'esecuzione delle direttive ricevute;
- b) e' gerarchicamente sovraordinato: 1) ai Capi di stato maggiore di Forza armata; 1-bis) al Comandante del Comando operativo di vertice interforze; 2) al Comandante generale dell'Arma dei carabinieri, limitatamente ai compiti militari devoluti alla stessa Arma; ((3) al Segretario generale della difesa e al Direttore nazionale degli armamenti in relazione alle funzioni agli stessi affidate;))
- c) svolge i compiti previsti dal codice, dal regolamento e dalla legge.

3. Il Capo di stato maggiore della difesa, in caso di assenza, impedimento, o vacanza della carica e' sostituito dal piu' anziano in carica tra i Capi di stato maggiore di Forza armata, senza tener conto, ai fini dell'attribuzione della suddetta anzianita', di eventuali periodi espletati nella funzione vicaria.

#### Art. 26. - Attribuzioni del Capo di stato maggiore della difesa

1. Il Capo di stato maggiore della difesa, in base alle direttive impartite dal Ministro della difesa:

- a) e' responsabile della pianificazione, della predisposizione e dell'impiego delle Forze armate nel loro complesso; predispone, sentiti i Capi di stato maggiore di Forza armata ((, il Comandante del Comando operativo di vertice interforze)) e il Comandante generale dell'Arma dei carabinieri, in relazione ai compiti militari dell'Arma, la pianificazione generale finanziaria e quella operativa interforze e definisce i conseguenti programmi tecnico-finanziari;
- a-bis) provvede, per le esigenze dei comandi direttamente dipendenti e degli enti interforze di cui all'articolo 93 del regolamento, all'impiego operativo e alla diretta amministrazione dei correlati fondi del settore funzionamento volti ad assicurare l'efficienza dei mezzi, dei materiali e delle infrastrutture, anche avvalendosi delle competenti direzioni generali, nei limiti degli stanziamenti approvati dal Ministro;
- b) assicura i rapporti con le corrispondenti autorita' militari degli altri Stati;
- c) adotta le misure organizzative conseguenti all'adozione dei provvedimenti di cui all'articolo 10, comma 3;

2. Il Capo di stato maggiore della difesa dirige, coordina e controlla l'attivita' di polizia militare, avvalendosi del Comando generale dell'Arma dei carabinieri per l'elaborazione delle disposizioni di carattere tecnico.

3. Le ulteriori specifiche attribuzioni del Capo di stato maggiore della difesa in campo nazionale, internazionale e tecnico-scientifico sono disciplinate nel regolamento.

#### Art. 27. - Ordinamento dello Stato maggiore della difesa

1. Il Capo di stato maggiore della difesa, per l'esercizio delle sue attribuzioni:

- a) dispone di uno Stato maggiore il cui ordinamento e' fissato nel regolamento;
- b) si avvale del Comando operativo di vertice interforze di cui all'articolo 29;

2. Sono unificate presso lo Stato maggiore della difesa le attribuzioni e le attivita' generali concernenti la pianificazione, la predisposizione e l'impiego delle Forze armate, nonche' le attivita' svolte nell'ambito delle strutture centrali di Forza armata suscettibili di accorpamento interforze.

3. Dipendono direttamente dal Capo di stato maggiore della difesa gli altri comandi ed enti interforze indicati nel regolamento.

### SEZIONE II - ORGANISMI INTERFORZE

#### Art. 28. - Comitato dei Capi di stato maggiore delle Forze armate

1. Il Comitato dei Capi di stato maggiore delle Forze armate e' organo di consulenza del Capo di stato maggiore della difesa. E' presieduto dal Capo di stato maggiore della difesa, e ne fanno parte, altresi', il Segretario generale della difesa, ((il Direttore nazionale degli armamenti,)) i Capi di stato maggiore di Forza armata, il Comandante del Comando operativo di vertice interforze e il Comandante generale dell'Arma dei carabinieri.

2. Le determinazioni adottate dal Capo di stato maggiore della difesa, che ne assume la piena responsabilita', costituiscono disposizioni per i Capi di stato maggiore di Forza armata, per il Comandante del Comando operativo di vertice interforze, per il Comandante generale dell'Arma dei carabinieri, limitatamente ai compiti militari dell'Arma, ((per il Direttore nazionale degli armamenti)) e per il Segretario generale della difesa.

3. Le disposizioni regolanti il funzionamento dell'organo sono contenute nel regolamento.

#### Art. 29. - Comando operativo di vertice interforze

1. Il Comando operativo di vertice interforze ((...)) svolge funzioni di pianificazione e di direzione delle operazioni nonche' delle esercitazioni interforze e multinazionali, assicurando le necessarie forme di ((coordinamento dei)) Comandi operativi di componente delle Forze armate.

1-bis. Il comandante del Comando operativo di vertice interforze ((dipende dal Capo di stato maggiore della difesa ed)) e' nominato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa sentito il Capo di stato maggiore della difesa, tra gli ufficiali con il grado di generale di corpo d'armata, ammiraglio di squadra o generale di quadra aerea in servizio permanente effettivo.

2. Le norme disciplinanti l'ordinamento del Comando operativo di vertice interforze sono stabilite nel regolamento.

#### Art. 30. - Reparto informazioni e sicurezza dello Stato maggiore della difesa

1. Il Reparto informazioni e sicurezza dello Stato maggiore della difesa svolge i compiti previsti dall'articolo 8 della legge 3 agosto 2007, n. 124.

#### Art. 31. - Comandi regione militare interforze

1. Con uno o piu' decreti del Ministro della difesa possono essere costituiti Comandi regione militare interforze cui devolvere le funzioni territoriali e presidiarie svolte dai Comandi ((e unita' dell'Esercito deputate per il territorio)), dai Comandi marittimi della Marina militare e dai Comandi di regione aerea.

### SEZIONE III - CAPI DI STATO MAGGIORE DI FORZA ARMATA E COMANDANTE GENERALE DELL'ARMA DEI CARABINIERI

#### Art. 32. - Configurazione delle cariche di Capo di stato maggiore di Forza armata e del Comandante generale dell'Arma dei carabinieri

1. I Capi di stato maggiore dell'Esercito italiano, della Marina militare e dell'Aeronautica militare sono ufficiali della rispettiva Forza armata che all'atto della nomina rivestono grado di generale di corpo d'armata, ammiraglio di squadra, generale di squadra aerea in servizio permanente; il Comandante generale dell'Arma dei carabinieri all'atto della nomina riveste il grado di generale di corpo d'armata in servizio permanente. I citati vertici militari:

- a) sono nominati con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa, sentito il Capo di stato maggiore della difesa;
- b) dipendono dal Capo di stato maggiore della difesa; il Comandante generale, limitatamente ai compiti militari dell'Arma dei carabinieri;
- c) nell'ambito della rispettiva Forza armata hanno rango gerarchico sovraordinato nei riguardi di tutti gli ufficiali generali e ammiragli.

2. I Capi di stato maggiore e il Comandante generale dell'Arma dei carabinieri, in caso di assenza, impedimento o vacanza della carica, sono sostituiti dall'ufficiale generale o ammiraglio designato alla funzione vicaria. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dagli avvisi di rettifica pubblicati in G.U. 01/06/2010, n. 126 e in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 33. - Attribuzioni del Capo di stato maggiore di Forza armata e del Comandante generale dell'Arma dei carabinieri

1. Il Capo di stato maggiore di Forza armata e, per i compiti militari dell'Arma, il Comandante generale dell'Arma dei carabinieri:

- a) propongono al Capo di stato maggiore della difesa il programma relativo alle rispettive Forze armate ai fini della predisposizione della pianificazione generale interforze, ai sensi dell'articolo 26;
- b) sono responsabili dell'organizzazione e dell'approntamento delle rispettive Forze armate, avvalendosi anche delle competenti direzioni generali ((coordinate dal Segretario generale e delle direzioni della Direzione nazionale degli armamenti));
- c) esercitano la funzione di comando delle rispettive Forze armate;
- d) adottano, per quanto di rispettiva competenza, i provvedimenti organizzativi conseguenti all'adozione dei decreti di cui all'articolo 10, comma 3, previo parere del Capo di Stato maggiore della difesa.
- d-bis) determinano i profili di impiego del personale militare della rispettiva Forza armata, in riferimento a ciascun ruolo, al fine di evitare duplicazioni di compiti e funzioni, ferme restando le attribuzioni del Capo di stato maggiore della difesa.

2. Le ulteriori specifiche attribuzioni dei Capi di stato maggiore di Forza armata sono indicate nel regolamento.

3. Le ulteriori attribuzioni del Comandante generale dell'Arma dei carabinieri sono disciplinate nel titolo IV, capo V, sezione II, del presente libro.

#### Art. 34. - Ordinamento dello Stato maggiore di Forza armata e del Comando generale dell'Arma dei carabinieri

1. I Capi di stato maggiore di Forza armata e il Comandante generale dell'Arma dei carabinieri per l'esercizio delle relative attribuzioni:

- a) dispongono, rispettivamente, degli Stati maggiori di Forza armata, disciplinati nel regolamento, e del Comando generale, di cui all'articolo 170;
- b) si avvalgono di Comandi di vertice e Ispettorati, indicati per ogni singola Forza armata nel titolo IV del presente libro.

2. Fatto salvo quanto disposto nell'articolo 29, rientra nelle competenze degli Stati maggiori di Forza armata e del Comando generale dell'Arma dei carabinieri l'esercizio delle attribuzioni e delle attivita' relative all'impiego e al governo del proprio personale, all'addestramento, alla logistica e alle predisposizioni di approntamento e mobilitazione di Forza armata.

### SEZIONE IV - UFFICI DEGLI ADDETTI DELLE FORZE ARMATE IN SERVIZIO ALL'ESTERO

#### Art. 35. - Addetti delle Forze armate in servizio all'estero

1. Il personale delle Forze armate, da destinare in qualita' di addetto, addetto aggiunto e assistente presso le rappresentanze diplomatiche italiane all'estero e' nominato con decreto del Ministro della difesa, sentito il Ministro degli affari esteri; con la stessa procedura il medesimo personale militare puo' essere accreditato per piu' Stati o per piu' Forze armate.

2. La costituzione dell'ufficio dell'addetto militare, di cui al comma 1, e' preceduta dalla preventiva designazione, a opera di decreti del Ministro della difesa, di concerto con i Ministri degli affari esteri e dell'economia e finanze, delle sedi diplomatiche italiane all'estero.

#### Art. 36. - Uffici degli addetti delle Forze armate in servizio all'estero

1. L'addetto dispone di un ufficio, del quale fa parte, oltre agli eventuali addetti aggiunti e assistenti, il personale ((militare e civile)) assegnato dal Ministero della difesa ((nei limiti dei posti di organico di cui al comma 2 e dei connessi oneri)).

2. I posti d'organico dell'ufficio di cui al comma 1 sono determinati con decreto del Ministro della difesa, di concerto con i Ministri degli affari esteri e dell'economia e finanze.

#### Art. 37. - Sicurezza degli uffici degli addetti militari all'estero

1. La sicurezza degli uffici degli addetti militari all'estero e' assicurata dall'Arma dei carabinieri ai sensi dell'articolo 158.

#### Art. 38. - Gestione del danaro e del materiale

1. Gli uffici degli addetti militari costituiscono distaccamenti dell'ufficio amministrazioni speciali del Ministero della difesa per quanto attiene alla gestione del denaro e del materiale.

2. La gestione del denaro comprende:

- a) spese per il personale;
- b) spese per il funzionamento.

3. La gestione del materiale comprende la custodia, la conservazione e la manutenzione dei beni mobili assegnati per l'uso.

#### Art. 39. - Personale

1. Il personale in servizio all'estero ha diritto ogni anno a una licenza ordinaria di trenta giorni lavorativi, nonche' a quattro giornate di riposo da fruire nell'anno solare ai sensi e alle condizioni previste dalla legge 23 dicembre 1977, n. 937. Le ferie del personale civile del Ministero della difesa in servizio all'estero sono regolate secondo le disposizioni vigenti per il territorio nazionale. Le disposizioni di cui al presente comma si applicano anche al personale di cui all' articolo 1808.

2. Per il personale in servizio nelle sedi disagiate e in quelle particolarmente disagiate, stabilite per il personale del Ministero degli affari esteri ai sensi del comma 1 dell'articolo 144 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, il periodo di licenza ordinaria o di ferie di cui al comma 1 e' rispettivamente aumentato di sette e di dieci giorni lavorativi.

3. Al personale di cui ai commi 1, primo e secondo periodo, e 2 si applicano le stesse norme sul trattamento economico per congedi ordinari o ferie e per rimborso delle relative spese di viaggio vigenti per il personale del Ministero degli affari esteri in servizio all'estero, compreso il periodo di tempo corrispondente ai giorni di viaggio per andata e ritorno dall'Italia, stabilito per il personale del Ministero medesimo ai sensi del comma 3 dell'articolo 180 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18.

((

4. Al personale di cui al comma 2 del presente articolo si applicano le norme che regolano, per il personale del Ministero degli affari esteri, il computo, ai fini del trattamento di quiescenza, del servizio previsto nelle sedi disagiate e particolarmente disagiate.

))

5. ((COMMA ABROGATO DAL D. LGS. 31 DICEMBRE 2012, N. 248)).

6. ((COMMA ABROGATO DAL D. LGS. 31 DICEMBRE 2012, N. 248)).

7. ((COMMA ABROGATO DAL D. LGS. 31 DICEMBRE 2012, N. 248)).

8. ((COMMA ABROGATO DAL D. LGS. 31 DICEMBRE 2012, N. 248)).

## CAPO IV - AREA TECNICO AMMINISTRATIVA

### SEZIONE I - ((DIRETTORE NAZIONALE DEGLI ARMAMENTI))

#### Art. 40. - (( (Configurazione della carica di Direttore nazionale degli armamenti). ))

((

1. Il Direttore nazionale degli armamenti e' scelto tra gli ufficiali in servizio permanente con il grado di generale di corpo d'armata, o grado corrispondente, delle Forze armate, ovvero tra i dirigenti civili di prima fascia del ruolo dei dirigenti del Ministero della difesa o delle altre amministrazioni dello Stato o anche tra personale estraneo alle stesse, se il Segretario generale della difesa e' un generale di corpo d'armata, o grado corrispondente, delle Forze armate. E' nominato ai sensi dell'articolo 19, comma 3, del decreto legislativo 30 marzo 2001, n. 165, con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa, sentito il Capo di stato maggiore della difesa.

2. Il Direttore nazionale degli armamenti dipende dal Ministro della difesa e, per le attribuzioni tecnico-operative connesse all'efficientamento tecnologico e capacitivo dei sistemi destinati allo strumento militare, dal Capo di stato maggiore della difesa. In caso di assenza, impedimento o vacanza della carica e' sostituito dal Vice Direttore nazionale degli armamenti.

3. Le ulteriori attribuzioni del Direttore nazionale degli armamenti sono disciplinate dal regolamento.

))

#### Art. 41. - ((Attribuzioni del Direttore nazionale degli armamenti))

1. Il ((Direttore nazionale degli armamenti)):

- a) predispone, d'intesa con il Capo di stato maggiore della difesa, le proposte di pianificazione annuale e pluriennale generale finanziaria relative all'area industriale, pubblica e privata, di interesse della Difesa;
- b) e' responsabile, nel quadro della pianificazione generale dello strumento militare, dell'organizzazione e del funzionamento dell'area tecnico-industriale ((, nonche' delle attivita' di innovazione e ricerca tecnologica e di sviluppo, produzione e approvvigionamento dei sistemi d'arma));
- c) ((LETTERA ABROGATA DAL D.L. 22 GIUGNO 2023, N. 75));
- d) puo' delegare competenze ((...)) nell'area tecnico-industriale in materia di armamenti a un funzionario civile della Difesa oppure a un dirigente proveniente dal settore privato, assunto con contratto a tempo determinato, e nominato ai sensi dell'articolo 19 decreto legislativo 30 marzo 2001, n. 165, previa designazione del ((Direttore nazionale degli armamenti)) medesimo.

2. Le ulteriori specifiche attribuzioni del ((Direttore nazionale degli armamenti)) in campo nazionale, internazionale e tecnico-scientifico sono disciplinate nel regolamento.

#### Art. 42. - ((Organi di supporto del Direttore nazionale degli armamenti))

1. Il ((Direttore nazionale degli armamenti)) per l'esercizio delle sue attribuzioni:

- a) ha alle sue dipendenze i direttori generali del Ministero ((facenti parte della Direzione nazionale degli armamenti));
- b) si avvale di un Vice direttore nazionale degli armamenti, scelto tra gli ufficiali in servizio permanente con il grado di generale di corpo d'armata, o grado corrispondente, delle Forze armate, se il Direttore nazionale degli armamenti riveste la qualifica dirigenziale civile, ovvero tra i dirigenti civili di prima fascia del ruolo dei dirigenti del Ministero della difesa o delle altre amministrazioni dello Stato, se il Direttore nazionale degli armamenti e' un generale di corpo d'armata, o grado corrispondente, delle Forze armate. Il Vice direttore nazionale degli armamenti e' nominato su proposta del Ministro della Difesa, sentito il Direttore nazionale degli armamenti, ai sensi dall'articolo 19 del decreto legislativo 30 marzo 2001, n. 165;
- c) dispone ((della Direzione nazionale degli armamenti, disciplinata)) nella sezione II, del presente capo, e nel regolamento. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### SEZIONE II - ((DIREZIONE NAZIONALE DEGLI ARMAMENTI))

#### Art. 43. - Competenze della Direzione nazionale degli armamenti

1. Sono unificate presso la Direzione nazionale degli armamenti le attribuzioni e le attivita' concernenti la politica industriale e tecnologica, l'innovazione ((e la ricerca tecnologica)) e lo sviluppo, nonche' le attribuzioni e le attivita' analoghe svolte da uffici del Ministero della difesa, ivi compresi quelli posti alle dirette dipendenze del Ministro.

2. Le competenze e l'ordinamento della Direzione nazionale degli armamenti sono disciplinati dal regolamento.

#### Art. 44. - Registro nazionale delle imprese

1. Presso ((la Direzione nazionale degli armamenti)), e' istituito il registro nazionale delle imprese e consorzi di imprese operanti nel settore della progettazione, produzione, importazione, esportazione, trasferimento intracomunitario, intermediazione, manutenzione e lavorazioni comunque connesse di materiale di armamento, precisate e suddivise secondo le funzioni per le quali l'iscrizione puo' essere accettata. Copie di tale registro nazionale e dei suoi aggiornamenti sono trasmesse, per i fini della legge 9 luglio 1990, n. 185, ai Ministeri degli affari esteri, dell'interno, dell'economia e delle finanze e dello sviluppo economico.

2. Solo agli iscritti al registro nazionale possono essere rilasciate le autorizzazioni a iniziare trattative contrattuali e a effettuare operazioni di esportazione, importazione, transito, trasferimento intracomunitario e intermediazione di materiale di armamento.

3. L'iscrizione al registro di cui al comma 1 tiene luogo dell'autorizzazione di cui all'articolo 28, comma 2, del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, fermi restando i requisiti indicati all'articolo 9 della legge 18 aprile 1975, n. 110.

4. Le domande di iscrizione al registro nazionale sono corredate della documentazione necessaria a comprovare l'esistenza dei requisiti richiesti, secondo le modalita' indicate nel regolamento, su cui per tale parte e' acquisito il concerto del Ministro degli affari esteri e del Ministro dello sviluppo economico. Le domande sono presentate dalle imprese e dai consorzi di imprese che vi hanno interesse purche' in possesso dei seguenti requisiti soggettivi:

- a) per le imprese individuali e per le societa' di persone, la cittadinanza italiana dell'imprenditore o del legale rappresentante, ovvero la residenza in Italia dei suddetti, purche' cittadini di Paesi legati all'Italia da un trattato per la collaborazione giudiziaria;
- b) per le societa' di capitali, purche' legalmente costituite in Italia e ivi esercitanti attivita' concernenti materiali soggetti al controllo di cui alla legge 9 luglio 1990, n. 185, la residenza in Italia dei soggetti titolari dei poteri di rappresentanza ai predetti fini, purche' cittadini italiani o di Paesi legati all'Italia da un trattato per la collaborazione giudiziaria;
- c) per i consorzi di imprese costituiti con la partecipazione di una o piu' imprese iscritte al registro nazionale, l'assenza di condizioni ostative di cui al comma 8 per le imprese partecipanti e il possesso dei requisiti soggettivi di cui alla lettera b) per il legale rappresentante del consorzio.

5. Sono iscritti d'ufficio al registro nazionale i consorzi industriali promossi a seguito di specifiche intese intergovernative o comunque autorizzati dai competenti organi dello Stato italiano.

6. Gli iscritti al registro nazionale comunicano al Ministero della difesa ogni variazione dei soggetti di cui al comma 4, lettere a) e b), e al comma 5, il trasferimento della sede, la istituzione di nuove sedi, la trasformazione o l'estinzione dell'impresa.

7. Non sono iscrivibili o, se iscritte, decadono dalla iscrizione:

- a) le imprese dichiarate fallite;
- b) le imprese cui si applicano le norme di sospensione, decadenza e non iscrivibilita' stabilite dalla legge 31 maggio 1965, n. 575;
- c) le imprese i cui rappresentanti indicati al comma 4, lettere a) e b), sono stati definitivamente riconosciuti come appartenuti o appartenenti ad associazioni segrete ai sensi dell'articolo 1 della legge 25 gennaio 1982, n. 17, o sono stati condannati ai sensi della legge 20 giugno 1952, n. 645, del testo unico delle leggi di pubblica sicurezza approvato con regio decreto 18 giugno 1931, n. 773, della legge 18 aprile 1975, n. 110, nonche' della legge 9 luglio 1990, n. 185;
- d) le imprese i cui legali rappresentanti sono stati condannati, con sentenza passata in giudicato, per reati di commercio illegale di materiali di armamento;
- e) le imprese che, in violazione del divieto di cui all'articolo 22 della legge 9 luglio 1990, n. 185, assumono con le funzioni ivi elencate, ex dipendenti delle amministrazioni dello Stato prima di tre anni dalla cessazione del loro servizio attivo.

8. Il verificarsi delle condizioni di cui al comma 7, lettere a), b), c) e d), determina la sospensione o la cancellazione dal registro nazionale, disposta con decreto del Ministro della difesa, da comunicare ai Ministeri di cui al comma 1.

9. Se e' rimosso l'impedimento alla iscrizione, l'impresa puo' ottenere l'iscrizione stessa o, se cancellata, la reiscrizione nel registro nazionale.

10. In pendenza dell'accertamento definitivo degli impedimenti di cui al comma 8, l'impresa o il consorzio possono esercitare le normali attivita' nei limiti delle autorizzazioni concesse e in corso di validita', a eccezione di quelle oggetto di contestazione. A essi non possono essere rilasciate nuove autorizzazioni.

11. La Commissione per la tenuta del registro nazionale di cui al comma 1, insediata presso il Ministero della difesa, presieduta da un magistrato del Consiglio di Stato, e composta da un rappresentante del Ministero degli affari esteri, del Ministero dell'interno, del Ministero dell'economia e delle finanze, del Ministero della difesa e del Ministero dello sviluppo economico, svolge le seguenti funzioni:

- a) delibera sulla base dei requisiti di cui al comma 4 in merito alla iscrizione o reiscrizione al registro;
- b) provvede alla revisione triennale del registro;
- c) fa rapporto all'autorita' giudiziaria ai fini dell'applicazione delle sanzioni per illeciti relativi al registro;
- d) formula un parere al Ministro per la cancellazione e la sospensione dal registro.

12. Le modalita' per l'iscrizione al registro e le norme relative al funzionamento della commissione, sono disciplinate nel regolamento.

13. Per l'iscrizione nel registro nazionale gli interessati sono tenuti a versare un contributo annuo nella misura e con le modalita' stabiliti con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, pubblicato nella Gazzetta Ufficiale entro il 31 ottobre dell'anno precedente a quello il cui contributo si riferisce.

13-bis. Per lo svolgimento delle sue attivita' istituzionali e per l'iscrizione al registro nazionale, l'Agenzia industrie difesa e' esentata dall'obbligo di munirsi delle licenze previste dagli articoli 28, 46 e 47 del testo unico delle leggi di pubblica sicurezza, di cui al regio decreto 18 giugno 1931, n. 773. L'Agenzia industrie difesa assicura l'annotazione delle operazioni svolte con operatori economici e con altri soggetti privati negli appositi registri previsti dagli articoli 35 e 55 del citato testo unico di cui al regio decreto n. 773 del 1931, anche allo scopo di consentire le previste verifiche da parte degli ufficiali e agenti di pubblica sicurezza secondo le modalita' stabilite dalle disposizioni vigenti.

### ((SEZIONE IIBIS)) ((SEGRETARIO GENERALE DELLA DIFESA))

#### Art. 44-bis. - (( (Configurazione della carica di Segretario generale della difesa). ))

((

1. Il Segretario generale della difesa e' scelto tra i dirigenti civili di prima fascia del ruolo dei dirigenti del Ministero della difesa o delle altre amministrazioni dello Stato o anche tra personale estraneo alle stesse, ovvero tra gli ufficiali in servizio permanente con il grado di generale di corpo d'armata, o grado corrispondente, delle Forze armate, se il Direttore nazionale degli armamenti riveste la qualifica dirigenziale civile. E' nominato ai sensi dell'articolo 19, comma 3, del decreto legislativo 30 marzo 2001, n. 165, con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa, sentito il Capo di stato maggiore della difesa.

2. Il Segretario generale assicura l'espletamento delle funzioni di cui all'articolo 6 del decreto legislativo 30 luglio 1999, n. 300, dipende direttamente dal Ministro della difesa e, limitatamente alle funzioni tecnico-operative, dal Capo di stato maggiore della difesa. In caso di assenza, impedimento o vacanza della carica e' sostituito dal Vice segretario generale.

3. Le ulteriori attribuzioni del Segretario generale della difesa sono disciplinate dal regolamento.

))

#### Art. 44-ter. - (Organi di supporto del Segretario generale della difesa)

1. Il Segretario generale della difesa per l'esercizio delle sue attribuzioni si avvale:

- a) di un Vice segretario generale scelto tra i dirigenti civili di prima fascia del ruolo dei dirigenti del Ministero della difesa o delle altre amministrazioni dello Stato, se il Segretario generale e' un generale di corpo d'armata, o grado corrispondente, delle Forze armate, ((ovvero tra gli ufficiali)) in servizio permanente con il grado di generale di corpo d'armata, o grado corrispondente, delle Forze armate, se il Segretario generale riveste la qualifica dirigenziale civile. Il Vice segretario generale e' nominato su proposta del Ministro della difesa, sentito il Segretario generale, ai sensi dell'articolo 19 del decreto legislativo 30 marzo 2001, n. 165;
- b) del Segretariato generale della difesa, disciplinato dal regolamento.

## CAPO V - AREA TECNICO INDUSTRIALE

### Art. 45. - Stabilimenti e arsenali militari

1. Gli stabilimenti e gli arsenali militari, organi di produzione e di lavoro a carattere industriale del Ministero della difesa, per il supporto tecnico e logistico delle Forze armate, assolvono di massima, nei limiti e con le modalita' stabilite dalle norme del codice e del regolamento, i seguenti compiti:

- a) produzione di mezzi e materiali;
- b) riparazioni, manutenzioni e trasformazioni di mezzi e materiali non eseguibili presso gli organi logistici di forza armata;
- c) conferimento di commesse esterne, con tutte le conseguenti attivita' di controllo e collaudo;
- d) studio ed esperienze; realizzazione di prototipi;
- e) analisi, studio e controllo in materia di costi e prezzi anche ai fini di un'azione calmieratrice dei prezzi di mercato;
- f) formazione e aggiornamento ai diversi livelli e per specialita' del personale tecnico dipendente dal Ministero della difesa.

2. Gli stabilimenti e arsenali militari, inoltre, concorrono allo studio, nel rispettivo settore, dello sviluppo di attivita' industriali di particolare interesse militare e della loro eventuale conversione ai fini della produzione bellica.

((

2-bis. Gli arsenali e gli stabilimenti militari adibiti allo svolgimento di attivita' di manutenzione sui mezzi e sugli equipaggiamenti delle Forze armate possono concorrere, all'occorrenza, anche all'espletamento degli interventi manutentivi sui mezzi e sugli equipaggiamenti delle Forze di polizia a ordinamento civile e militare, con contestuale ristoro dei relativi oneri da parte delle amministrazioni che intendono avvalersi di detti servizi manutentivi e fatte salve le prioritarie esigenze delle Forze armate.

))

3. Con decreto del Ministro della difesa sono stabiliti:

- a) tipo, finalita', compiti specifici di cui al presente articolo, numero e dislocazione, in relazione alle esigenze delle Forze armate e del progresso scientifico e tecnico;
- b) l'ordinamento e la ripartizione interna dei compiti di ciascuno stabilimento e arsenale militare e delle rispettive sezioni staccate.

### Art. 46. - Direzione e struttura organizzativa degli stabilimenti e degli arsenali militari

1. Gli enti di cui all'articolo 45 sono retti, a seconda della loro potenzialita', da ufficiali generali o ufficiali superiori, il cui incarico e' conferito con decreto ministeriale.

2. Gli stabilimenti e arsenali militari e le sezioni staccate di tali enti sono strutturati sulla base di una Direzione e di uno o piu' servizi.

3. In caso di vacanza, assenza o impedimento del direttore, la reggenza della carica e' affidata al vice direttore.

4. Al funzionamento degli stabilimenti e degli arsenali militari provvede personale militare e civile.

5. La ripartizione delle dipendenze degli enti di cui al presente articolo e' individuata nell'articolo 47.

### Art. 47. - Classificazione degli enti

1. Gli enti dell'area tecnico-industriale e i centri tecnici dell'area tecnico-operativa del Ministero della difesa si distinguono in:

- a) enti gestiti dall'Agenzia industrie difesa, denominati unita';
- b) enti dipendenti ((dalla Direzione nazionale degli armamenti));
- c) enti dipendenti dai Comandi e dagli Ispettorati logistici di Forza armata.

2. Alla indicazione degli enti da ricomprendere nelle categorie definite dal comma 1 si provvede con decreto del Ministro della difesa.

3. Gli enti dipendenti ((dalla Direzione nazionale degli armamenti)) sono disciplinati nel regolamento.

### Art. 48. - Agenzia industrie difesa

1. L'Agenzia industrie difesa, istituita, nelle forme disciplinate dagli articoli 8 e 9 del decreto legislativo 30 luglio 1999, n. 300, con personalita' giuridica di diritto pubblico, e' posta sotto la vigilanza del Ministro della difesa, ((per il conseguimento dei suoi specifici obiettivi e missioni, nonche' per lo svolgimento dei compiti permanenti cosi' come previsto dall'articolo 12)), comma 1, lettera r), della legge 15 marzo 1997, n. 59. Scopo dell'Agenzia e' quello di gestire unitariamente le attivita' delle unita' produttive e industriali della difesa indicate con uno o piu' decreti del Ministro della difesa. L'Agenzia utilizza le risorse finanziarie materiali e umane delle unita' dalla stessa amministrate nella misura stabilita dal regolamento di cui al comma 2.

2. Le norme concernenti l'organizzazione e il funzionamento dell'Agenzia sono definite nel regolamento, nel rispetto dell'obiettivo dell'economica gestione e dei principi che regolano la concorrenza e il mercato in quanto applicabili.

### Art. 49. - Enti dipendenti dai comandi e dagli ispettorati logistici di Forza armata

1. La responsabilita' della manutenzione e della sperimentazione dei beni funzionali all'impiego dello strumento militare e' affidata ai competenti comandi o ispettorati di Forza armata.

2. Gli enti, di cui al presente articolo, hanno autonomia gestionale nell'ambito dei programmi di lavoro disposti annualmente dagli organi di cui al comma 1, attendono ai compiti relativi alle attivita' amministrativo-contabili, secondo quanto previsto dalle norme di contabilita' generale dello Stato e sono altresi' obbligati a provvedere alla tenuta di una contabilita' analitica industriale.

3. I direttori degli enti, al fine di ottimizzare i procedimenti connessi all'attuazione dei programmi di lavoro annuali, provvedono autonomamente sia alle necessarie acquisizioni di beni e servizi sia alla gestione delle risorse disponibili, per il pieno raggiungimento degli obiettivi individuati dai programmi medesimi.

4. Prima dell'inizio dell'esercizio finanziario, gli enti di cui al presente articolo ricevono il programma di lavoro annuale con l'indicazione delle risorse finanziarie stanziate sui pertinenti capitoli di bilancio.

### Art. 50. - Personale degli enti dipendenti dai comandi e dagli ispettorati logistici di Forza armata

1. Il direttore dell'ente (( ... )) e' scelto tra il personale militare con grado non inferiore a colonnello o gradi equipollenti. Il direttore, individuato in relazione alle esperienze maturate nel settore tecnico-industriale, ricopre l'incarico per un periodo di quattro anni, rinnovabile anche per un periodo di tempo inferiore, compatibilmente con le esigenze di impiego della Forza armata di appartenenza e sempre che l'attivita' svolta risulti adeguata agli obiettivi prefissati.

2. Il direttore:

- a) formula proposte ai fini della predisposizione dei programmi di lavoro;
- b) cura l'attuazione dei programmi stessi, anche mediante l'affidamento della gestione di singoli progetti a personale dipendente appositamente incaricato, determinando le risorse occorrenti alla realizzazione di ciascun progetto;
- c) esercita i poteri di spesa nei limiti degli stanziamenti assegnati;
- d) determina, informandone le organizzazioni sindacali maggiormente rappresentative sul piano nazionale, i criteri generali di organizzazione degli uffici, e definisce, ai sensi delle prescrizioni del contratto collettivo nazionale di lavoro del comparto del personale dipendente dei Ministeri, l'orario di servizio e l'articolazione dell'orario contrattuale di lavoro in relazione alle esigenze funzionali della struttura organizzativa cui e' preposto;
- e) individua i responsabili dei procedimenti curati dall'ente adottando le conseguenti attivita' di verifica e controllo.

3. Il direttore e' responsabile dei risultati dell'attivita' svolta, con particolare riferimento alla corretta gestione delle risorse pubbliche e al raggiungimento degli obiettivi indicati nei programmi di lavoro. A tal fine, si avvale di un apposito sistema informativo-statistico per il controllo interno di gestione dell'ente, con rilevazioni periodiche dei costi, delle attivita' e dei relativi risultati.

4. Ferme le vigenti dotazioni organiche, il vice direttore dell'ente dell'area tecnico-industriale, nominato con decreto del Ministro della difesa, e' scelto nell'ambito dei funzionari civili della Difesa in possesso di esperienza nel settore tecnico-industriale e di adeguata qualifica funzionale o dirigenziale; l'incarico puo' anche essere conferito a personale dell'Amministrazione pubblica ovvero estraneo alla stessa se in possesso di analoga esperienza e con precedenti incarichi di dirigenza aziendale.

5. Il vice direttore coadiuva il direttore nell'esplicazione dei suoi compiti e lo sostituisce in caso di assenza o impedimento in tutte le sue attribuzioni; dirige i servizi posti alle proprie dipendenze; ha la reggenza dell'ente in caso di vacanza; provvede a gestire i singoli progetti affidatigli dal direttore.

### Art. 51. - Norme comuni agli enti dell'area tecnico-industriale

1. Con uno o piu' decreti il Ministro della difesa provvede:

- a) di concerto con i Ministri della pubblica amministrazione e innovazione e dell'economia e delle finanze, sentite le organizzazioni sindacali maggiormente rappresentative, alla riorganizzazione connessa all'espletamento delle attivita' di competenza di ciascun ente di cui all'articolo 47, comma 1, lettere b) e c), nonche' alla definizione di specifici settori d'intervento degli enti di cui all'articolo 47, comma 1, lettera b), eventualmente procedendo ad accorpamenti, trasformazioni, concentrazioni di processi produttivi e riconversioni industriali, con ricorso anche a una unica gestione se l'autonomia di singole strutture non risulta funzionalmente utile e conveniente;
- b) di concerto con i Ministri della pubblica amministrazione e innovazione e dell'economia e delle finanze, alla indicazione degli enti di cui all'articolo 47, comma 1, lettera b), che, in relazione agli obiettivi di produttivita' ed economicita', sono da dismettere, anche ai sensi dell'articolo 4, comma 3, lettera c), della legge 15 marzo 1997, n. 59, ovvero da trasformare, sentite le organizzazioni sindacali maggiormente rappresentative, in aziende a ordinamento autonomo, ai sensi e nel termine dell'articolo 12, comma 1, lettera g) della legge 15 marzo 1997, n. 59, come modificato dall'articolo 7, comma 1, lettera i), della legge 15 maggio 1997, n. 127. Il relativo ordinamento e' definito, per ciascuna azienda, sentite le organizzazioni sindacali maggiormente rappresentative.

2. Relativamente agli aspetti del personale dipendente degli enti di cui all'articolo 47, correlati alle procedure di ristrutturazione di cui al presente articolo, si applicano le disposizioni previste dal capo I del titolo II del libro V del presente codice.

## CAPO VI - GIUSTIZIA MILITARE

### SEZIONE I - ORDINAMENTO GIUDIZIARIO MILITARE

#### Art. 52. - Magistrati militari

1. I magistrati militari sono distinti secondo le funzioni esercitate e sono equiparati ai corrispondenti magistrati ordinari.

2. Le funzioni giudicanti sono:

- a) di primo grado (giudice presso il Tribunale militare e presso l'Ufficio militare di sorveglianza);
- b) di secondo grado (giudice presso la Corte militare di appello);
- c) semidirettive di primo grado (presidente di sezione presso il Tribunale militare);
- d) semidirettive di secondo grado (presidente di sezione della Corte militare di appello);
- e) direttive di primo grado (presidente del Tribunale militare);
- f) direttive elevate di primo grado (presidente del Tribunale militare di sorveglianza);
- g) direttive di secondo grado (presidente della Corte militare di appello).

3. Le funzioni requirenti sono:

- a) di primo grado (sostituto procuratore militare);
- b) di secondo grado (sostituto procuratore generale militare presso la Corte militare di appello);
- c) di legittimita' (sostituto procuratore generale militare presso la Procura generale militare presso la Corte di Cassazione);
- d) semidirettive di secondo grado (avvocato generale militare presso la Corte militare di appello);
- e) direttive di primo grado (procuratore militare della Repubblica presso il Tribunale militare);
- f) direttive di secondo grado (procuratore generale militare presso la Corte militare di appello);
- g) direttive superiori requirenti di legittimita' (procuratore generale militare presso la Corte di Cassazione).

4. Lo stato giuridico, le garanzie d'indipendenza, l'avanzamento e il trattamento economico dei magistrati militari sono regolati dalle disposizioni in vigore per i magistrati ordinari, in quanto applicabili. Ai fini dell'anzianita', e' valutato anche il servizio prestato presso altre magistrature.

#### Art. 53. - Requisiti e criteri per il conferimento delle funzioni

1. Per il conferimento delle funzioni di cui all'articolo 52, commi 2, lettera a) e 3, lettera a) e' richiesta almeno la delibera di conferimento delle funzioni giurisdizionali al termine del periodo di tirocinio.

2. Per il conferimento delle funzioni di cui all'articolo 52, commi 2, lettere b) e c), e (( 3, lettere b) e c-bis) )) e' richiesto il conseguimento almeno della seconda valutazione di professionalita'.

3. Per il conferimento delle funzioni di cui all'articolo 52, commi 2, lettera e) e 3, lettera e) e' richiesto il conseguimento almeno della terza valutazione di professionalita'.

4. Per il conferimento delle funzioni di cui all'articolo 52, commi 2, lettere d) ed f), e 3, lettere c) e d), e' richiesto il conseguimento almeno della quarta valutazione di professionalita'.

5. Per il conferimento delle funzioni di cui all'articolo 52, commi 2, lettera g) e 3, lettera f) e' richiesto il conseguimento almeno della quinta valutazione di professionalita'.

6. Per il conferimento delle funzioni di cui all'articolo 52, comma 3, lettera g), e' richiesto il conseguimento almeno della sesta valutazione di professionalita'; il magistrato, alla data della vacanza del posto da coprire, deve avere esercitato, per almeno quattro anni, funzioni direttive giudicanti o requirenti di primo o di secondo grado o funzioni requirenti di legittimita'.

#### Art. 54. - Tribunale militare

1. Il Tribunale militare e' formato:

- a) da un magistrato militare in possesso dei requisiti previsti dall'articolo 53, comma 3, che lo presiede;
- b) da piu' magistrati militari in possesso dei requisiti previsti dall'articolo 53, comma 1, e da almeno un magistrato militare in possesso dei requisiti previsti dall'articolo 53, comma 2.

2. Il Tribunale militare giudica con l'intervento:

- a) del presidente del Tribunale militare o del presidente di sezione del Tribunale militare che lo presiedono; in caso di impedimento del presidente giudica con l'intervento di un magistrato militare in possesso dei requisiti previsti dall'articolo 53, comma 2, con funzioni di presidente;
- b) di un magistrato militare in possesso dei requisiti previsti dal comma 1, lettera b), con funzioni di giudice;
- c) di un militare dell'Esercito italiano, della Marina militare, dell'Aeronautica militare, dell' Arma dei Carabinieri o della Guardia di finanza di grado pari a quello dell'imputato e comunque non inferiore al grado di ufficiale, estratto a sorte, con funzioni di giudice. Nessun ufficiale puo' esimersi dall'assumere ed esercitare le funzioni di giudice. Non possono comunque essere destinati a tali funzioni: 1) gli ufficiali che svolgono incarichi di Ministro o Sottosegretario di Stato; 2) il Capo di stato maggiore della difesa; 3) il Segretario generale della difesa ((e il Direttore nazionale degli armamenti)); 4) i Capi di stato maggiore delle Forze armate e i Comandanti generali dell'Arma dei carabinieri e della Guardia di finanza; 5) il Direttore generale per il personale militare.

3. L'estrazione a sorte dei giudici di cui al comma 2, lettera c), si effettua tra gli ufficiali, aventi il grado richiesto, che prestano servizio nella circoscrizione del Tribunale militare.

4. Le estrazioni a sorte, previo avviso affisso in apposito albo, sono effettuate, nell'aula di udienza aperta al pubblico, dal presidente, alla presenza del pubblico ministero, con l'assistenza di un ausiliario, che redige verbale.

5. I giudici estratti a sorte durano in funzione due mesi e proseguono nell'esercizio delle funzioni sino alla conclusione dei dibattimenti in corso.

6. L'estrazione a sorte avviene ogni sei mesi, distintamente per ognuno dei bimestri successivi. Sono estratti, per ogni giudice, due supplenti.

#### Art. 55. - Circoscrizioni territoriali

1. I Tribunali militari e le Procure militari sono tre e hanno sede in Verona, Roma e Napoli.

2. Il Tribunale militare e la Procura militare di Verona hanno competenza in ordine ai reati militari commessi nelle regioni Valle d'Aosta, Piemonte, Liguria, Lombardia, Trentino Alto-Adige, Veneto, Friuli Venezia-Giulia, Emilia- Romagna.

3. Il Tribunale militare e la Procura militare di Roma hanno competenza in ordine ai reati militari commessi nelle regioni Toscana, Umbria, Marche, Lazio, Abruzzo e Sardegna.

4. Il Tribunale militare e la Procura militare di Napoli hanno competenza in ordine ai reati militari commessi nelle regioni Molise, Campania, Puglia, Basilicata, Calabria e Sicilia.

#### Art. 56. - Tribunale e Ufficio militare di sorveglianza

1. Il Tribunale militare di sorveglianza, con sede in Roma e giurisdizione su tutto il territorio nazionale, si compone di tutti i magistrati militari di sorveglianza e di esperti nominati dal Consiglio della magistratura militare, su proposta motivata del presidente del Tribunale militare di sorveglianza.

2. I provvedimenti del Tribunale militare di sorveglianza sono adottati:

- a) da un collegio composto dal presidente, magistrato militare in possesso dei requisiti di cui all'articolo 53, comma 4, o, in sua assenza o impedimento, dal magistrato militare di sorveglianza che lo segue per anzianita' nel ruolo;
- b) da un magistrato militare di sorveglianza almeno in possesso dei requisiti di cui all'articolo 53, comma 1;
- c) da due fra gli esperti di cui al comma 1.

3. L'Ufficio militare di sorveglianza ha sede in Roma e ha giurisdizione su tutto il territorio nazionale; al suddetto Ufficio sono assegnati magistrati militari di sorveglianza, in possesso almeno dei requisiti di cui all'articolo 53, comma 1;

4. I magistrati militari che esercitano le funzioni di sorveglianza non devono essere adibiti ad altre funzioni giudiziarie.

5. Con decreto del presidente della Corte militare d'appello puo' essere temporaneamente destinato a esercitare le funzioni del magistrato militare di sorveglianza mancante o impedito un magistrato militare, in possesso almeno dei requisiti di cui all'articolo 53, comma 1.

#### Art. 57. - Corte militare di appello

1. La Corte militare d'appello, con sede in Roma, giudica sull'appello proposto avverso i provvedimenti emessi dai Tribunali militari.

2. La Corte militare d'appello e' formata:

- a) da un magistrato militare in possesso dei requisiti di cui all'articolo 53, comma 5, che la presiede;
- b) da magistrati militari in possesso dei requisiti di cui all'articolo 53, comma 4;
- c) da magistrati militari in possesso dei requisiti di cui all'articolo 53, comma 2.

3. Le sezioni della Corte sono formate:

- a) da un magistrato militare in possesso almeno dei requisiti di cui all'articolo 53, comma 4, che la presiede;
- b) da magistrati militari in possesso almeno dei requisiti di cui all'articolo 53, comma 2.

4. La Corte militare d'appello giudica con l'intervento:

- a) del presidente della Corte militare di appello o della sezione o, in caso di impedimento, di un magistrato militare almeno in possesso dei requisiti di cui all'articolo 53, comma 2, con funzioni di presidente;
- b) di due magistrati militari in possesso almeno dei requisiti di cui all'articolo 53, comma 2, con funzioni di giudice;
- c) di due militari dell'Esercito italiano, della Marina militare, dell'Aeronautica militare, dell'Arma dei Carabinieri o della Guardia di finanza, di grado pari a quello dell'imputato e, comunque, non inferiore a tenente colonnello, estratti a sorte, con funzioni di giudice. Nessun ufficiale puo' esimersi dall'assumere ed esercitare le funzioni di giudice. Non possono comunque essere destinati a tali funzioni: 1) gli ufficiali che svolgono incarichi di Ministro o Sottosegretario di Stato; 2) il Capo di stato maggiore della difesa; 3) il Segretario generale della difesa ((e il Direttore nazionale degli armamenti)); 4) i Capi di stato maggiore delle Forze armate e i Comandanti generali dell'Arma dei carabinieri e della Guardia di finanza; 5) il Direttore generale per il personale militare.

5. Le estrazioni a sorte e la durata in funzione dei giudici appartenenti alle Forze armate sono regolate dalle norme stabilite per i Tribunali militari.

#### Art. 58. - Uffici del pubblico ministero

1. La Procura generale militare presso la Corte di Cassazione e' composta:

- a) dal procuratore generale militare della Repubblica, magistrato militare con funzioni direttive superiori requirenti di legittimita', scelto tra i magistrati in possesso dei requisiti di cui all'articolo 53, comma 6;
- b) da due sostituti procuratori generali militari, magistrati militari in possesso dei requisiti di cui all'articolo 53, comma 4.

2. La Procura generale militare presso la Corte militare di appello e' composta:

- a) da un procuratore generale militare della Repubblica, magistrato militare in possesso dei requisiti di cui all'articolo 53, comma 5;
- b) da un avvocato generale militare, magistrato militare in possesso dei requisiti di cui all'articolo 53, comma 4;
- c) da sostituti procuratori generali militari, magistrati militari in possesso dei requisiti di cui all'articolo 53, comma 2.

3. La Procura militare presso il Tribunale militare e' composta:

- a) da un procuratore militare della Repubblica, magistrato militare in possesso dei requisiti di cui all'articolo 53, comma 3;
- a-bis) da un procuratore militare aggiunto della Repubblica, magistrato militare in possesso dei requisiti di cui all'articolo 53, comma 2;
- b) da sostituti procuratori militari della Repubblica, magistrati militari in possesso dei requisiti di cui all'articolo 53, comma 1.

#### Art. 59. - Ruolo organico dei magistrati militari

1. Il ruolo organico dei magistrati militari e' fissato in cinquantotto unita'.

2. Alla formazione delle piante organiche degli uffici giudiziari militari si provvede con decreto del Ministro della difesa, su proposta del Consiglio della magistratura militare.

### SEZIONE II - CONSIGLIO DELLA MAGISTRATURA MILITARE

#### Art. 60. - Composizione del Consiglio della magistratura militare

1. Il Consiglio della magistratura militare ha sede in Roma ed e' composto da:

- a) il primo presidente della Corte di Cassazione, che lo presiede;
- b) il procuratore generale militare presso la Corte di Cassazione;
- c) ((quattro)) componenti eletti dai magistrati militari;
- d) un componente estraneo alla magistratura militare, scelto d'intesa tra i Presidenti delle due Camere, fra professori ordinari di universita' in materie giuridiche e avvocati con almeno quindici anni di esercizio professionale, che assume le funzioni di vice presidente del Consiglio. Quest'ultimo componente non puo' esercitare attivita' professionale suscettibile di interferire con le funzioni della magistratura militare ne' puo' esercitare attivita' professionale nell'interesse o per conto, ovvero contro l'amministrazione militare.

((

2. Nel corso del mandato, i magistrati militari componenti elettivi del Consiglio della magistratura militare rimangono in ruolo e, se fuori ruolo al momento della loro elezione, sono ricollocati in ruolo, eventualmente anche in soprannumero, nella sede di provenienza e nelle funzioni precedentemente esercitate.

))

3. L'attivita' e l'attuazione delle deliberazioni del Consiglio sono promosse dal presidente, sostituito, in caso di impedimento, dal vice presidente.

#### Art. 61. - Principi generali in materia di attribuzioni e funzionamento del Consiglio della magistratura militare

1. Il Consiglio ha, per i magistrati militari, le stesse attribuzioni previste per il Consiglio superiore della magistratura, ivi comprese quelle concernenti i procedimenti disciplinari, sostituiti al Ministro della giustizia e al procuratore generale presso la Corte di Cassazione, rispettivamente, il Ministro della difesa e il procuratore generale militare presso la Corte di Cassazione.

2. Le deliberazioni del Consiglio sono adottate a maggioranza e per la loro validita' e' necessaria la presenza di almeno ((quattro componenti, di cui due elettivi)). A parita' di voti prevale il voto del presidente.

3. Il Consiglio dura in carica quattro anni.

#### Art. 62. - Attribuzioni generali del Consiglio della magistratura militare

1. Il Consiglio della magistratura militare delibera:

- a) sulle assunzioni della magistratura militare, sull'assegnazione di sedi e di funzioni, sui trasferimenti, sulle promozioni e su ogni altro provvedimento di stato riguardante i magistrati militari;
- b) sulle sanzioni disciplinari a carico dei magistrati militari, in esito a procedimenti promossi dal Ministro della difesa o dal procuratore generale militare presso la Corte di Cassazione;
- c) sul conferimento ai magistrati militari di incarichi extragiudiziari;
- d) su ogni altra materia a esso attribuita dalla legge.

2. Tutti i provvedimenti riguardanti i magistrati militari sono adottati, in conformita' delle deliberazioni del Consiglio, con decreto del Ministro della difesa, fatta salva l'applicazione dell'articolo 1, lettera f), della legge 12 gennaio 1991, n. 13.

3. Il Consiglio, inoltre:

- a) esprime pareri e puo' far proposte al Ministro della difesa sulle modificazioni delle circoscrizioni giudiziarie militari e su tutte le materie riguardanti l'organizzazione o il funzionamento dei servizi relativi alla giustizia militare;
- b) da' pareri su disegni di legge concernenti le materie di cui ai commi 1 e 3 e su ogni altro oggetto concernente tali materie;
- c) verifica i titoli di ammissione dei magistrati eletti e decide sui reclami e sui ricorsi relativi alla eleggibilita' e alle operazioni elettorali. Verifica i requisiti di ammissione del componente scelto dai Presidenti delle due Camere e, se ne ravvisa la mancanza, ne da' comunicazione ai Presidenti stessi, salvi i provvedimenti interni di competenza del Consiglio;
- d) disciplina con regolamento interno il proprio funzionamento.

4. Sulle materie di competenza del Consiglio, il Ministro della difesa puo' avanzare proposte o proporre osservazioni.

5. Il Ministro della difesa puo' intervenire alle adunanze del Consiglio se ne e' richiesto dal presidente o se lo ritiene opportuno per fare comunicazioni o per dare chiarimenti. Egli, tuttavia, non puo' essere presente alle deliberazioni.

#### Art. 63. - Attribuzioni del Consiglio in materia di assunzioni nella magistratura militare

1. Il Consiglio della magistratura militare provvede alle assunzioni dei magistrati militari avvalendosi di commissioni da esso nominate. Le commissioni esaminatrici dei concorsi per uditore giudiziario militare formano le graduatorie, che sono pubblicate nel Bollettino ufficiale del Ministero della difesa e comunicate agli interessati. Delle commissioni di concorso possono far parte anche magistrati componenti del Consiglio.

2. Il Consiglio, esaminati gli atti e gli eventuali reclami proposti dal Ministro della difesa e dagli interessati entro trenta giorni, rispettivamente, dalla pubblicazione o dalla comunicazione predette, approva o modifica la graduatoria.

#### Art. 64. - Attribuzioni del Consiglio in materia di conferimento di uffici direttivi e valutazione per la nomina

1. Sul conferimento degli uffici direttivi e sulla valutazione per la nomina alle funzioni di legittimita' il Consiglio della magistratura militare delibera su proposta di una commissione, nominata all'inizio del quadriennio e ((rinnovata nella sua composizione dopo un biennio, formata da cinque dei suoi componenti, di cui tre elettivi)).

2. Per il conferimento degli uffici direttivi la proposta e' formulata dalla commissione di concerto con il Ministro della difesa.

((

2-bis. I componenti eletti non possono proporre domanda per un ufficio direttivo o semidirettivo nel periodo del loro mandato elettivo e comunque prima che sia trascorso un anno dal giorno in cui hanno cessato di far parte del Consiglio della magistratura militare.

))

#### Art. 65. - Attribuzioni del Consiglio in materia di ispezioni

1. Il Consiglio della magistratura militare, per accertare l'efficienza e la regolarita' dei servizi e per esigenze relative all'esercizio delle funzioni a esso attribuite, dispone ispezioni negli Uffici giudiziari militari.

2. L'incarico ispettivo e' conferito, di volta in volta, con durata determinata, a uno o piu' componenti del Consiglio. Esso e' incompatibile con l'esercizio delle funzioni giudiziarie presso l'organo giudiziario sottoposto all'ispezione.

3. Il magistrato militare che ha eseguito l'ispezione non partecipa alle deliberazioni del Consiglio su illeciti disciplinari rilevati nell'ispezione.

4. Il Ministro della difesa puo' in ogni tempo disporre ispezioni negli uffici giudiziari militari, richiedendo al Consiglio la nomina di ispettori.

#### Art. 66. - Attribuzioni del presidente e del vice presidente

1. Il presidente del Consiglio della magistratura militare:

- a) indice le elezioni dei componenti elettivi, alle quali partecipano tutti i magistrati con esclusione solo di quelli sospesi dalle funzioni;
- b) convoca il Consiglio di sua iniziativa o a richiesta di almeno tre componenti, entro quindici giorni dalla richiesta;
- c) comunica al Ministro della difesa le date di convocazione e l'ordine del giorno delle sedute del Consiglio;
- d) esercita le altre attribuzioni indicate dalla legge.

2. Il vice presidente sostituisce il presidente in caso di assenza o impedimento.

#### Art. 67. - Disposizioni in materia di procedimento disciplinare

1. Il procedimento disciplinare nei confronti dei magistrati militari e' regolato dalle norme in vigore per i magistrati ordinari. Il procuratore generale militare presso la Corte di Cassazione esercita le funzioni di pubblico ministero e non partecipa alle deliberazioni.

2. L'azione disciplinare nei confronti dei giudici militari appartenenti alle Forze armate e' esercitata dal Ministro della difesa o dal procuratore generale militare presso la Corte di Cassazione. Si applicano a questi ultimi le disposizioni del comma 1 e dell'articolo 61, comma 1.

#### Art. 68. - Stato giuridico del componente non togato

1. Per quanto concerne lo stato giuridico del componente non togato del Consiglio si osservano, in quanto applicabili, le disposizioni della legge 24 marzo 1958, n. 195. Il trattamento economico di tale componente e' stabilito con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, avuto riguardo alle incompatibilita', ai carichi di lavoro e alle indennita' dei componenti del Consiglio superiore della magistratura eletti dal Parlamento.

#### Art. 69. - Elezioni del Consiglio della magistratura militare

1. All'elezione dei componenti di cui all'articolo 60, comma 1, lettera c), che si svolge in un'unica tornata, partecipano tutti i magistrati militari, con voto diretto, personale e segreto.

2. Non sono eleggibili e non possono votare esclusivamente i magistrati sospesi dalle funzioni. Ciascun elettore puo' votare per un solo componente. I voti espressi in eccedenza sono nulli.

3. Per l'elezione dei componenti di cui alla citata lettera c) e' istituito presso il Consiglio della magistratura militare l'ufficio elettorale presieduto dal procuratore generale presso la Corte militare di appello e composto dai due magistrati militari in possesso dei requisiti di cui all'articolo 53, commi 1 e 2, piu' anziani in ruolo.

4. Le elezioni sono indette con decreto del presidente del Consiglio della magistratura militare da pubblicarsi nella Gazzetta Ufficiale almeno trenta giorni prima della data stabilita. Esse si tengono in due giorni consecutivi, di cui uno festivo, dalle ore 9 alle ore 16.

5. Le schede elettorali sono preventivamente firmate dai componenti dell'ufficio elettorale e sono riconsegnate chiuse dall'elettore.

6. Ultimate le votazioni, l'ufficio elettorale procede immediatamente allo spoglio delle schede e proclama eletti i magistrati che hanno riportato il maggior numero di voti. A parita' di voti e' eletto il piu' anziano di eta'.

7. L'ufficio elettorale decide a maggioranza sulle contestazioni sorte durante le operazioni di voto, nonche' su quelle relative alla validita' delle schede, dandone atto nel verbale delle operazioni elettorali.

8. I reclami relativi alle operazioni elettorali sono proposti al Consiglio della magistratura militare e devono pervenire all'ufficio di segreteria entro il quindicesimo giorno successivo alla proclamazione dei risultati. Essi non hanno effetto sospensivo. Il Consiglio decide nella sua prima seduta.

9. I componenti eletti, che nel corso del quadriennio di durata del Consiglio della magistratura militare perdono i requisiti di eleggibilita' o cessano dal servizio per qualsiasi causa, sono sostituiti, per il restante periodo, dai magistrati che seguono gli eletti per il maggior numero di suffragi ottenuti.

#### Art. 70. - Inizio del funzionamento e cessazione del mandato del Consiglio

1. La durata del Consiglio della magistratura militare si computa dal giorno dell'insediamento.

2. Il Consiglio scade al termine del quadriennio. Tuttavia, fino a quando non e' insediato il nuovo Consiglio, continua a funzionare quello precedente.

#### Art. 71. - Ufficio di segreteria del Consiglio

1. Presso il Consiglio della magistratura militare e' costituito un ufficio di segreteria il cui organico e' determinato con decreto del Presidente della Repubblica su proposta del Ministero della difesa.

2. Presso l'ufficio di segreteria sono custoditi i documenti personali riguardanti i magistrati militari.

3. I magistrati militari componenti dell'ufficio di segreteria continuano a esercitare le loro funzioni giudiziarie. Se richiesti, assistono alle riunioni del Consiglio.

#### Art. 72. - Applicabilita' di norme previste per il Consiglio superiore della magistratura

1. Per tutto cio' che non e' diversamente regolato dal presente codice, si osservano, in quanto applicabili, le norme previste per il Consiglio superiore della magistratura, in particolare sostituiti al Ministro e al Ministero della giustizia, rispettivamente il Ministro e il Ministero della difesa.

### SEZIONE III - DISCIPLINA DEL CONCORSO IN MAGISTRATURA MILITARE

#### Art. 73. - Concorsi

1. Alla magistratura militare si accede mediante concorso pubblico per titoli per la nomina a magistrato militare, al quale possono partecipare soltanto i magistrati ordinari che non hanno superato il quarantesimo anno di eta', salve le elevazioni previste dall'ordinamento. Le modalita' della domanda di ammissione, il termine per la sua presentazione, i casi di esclusione dal concorso, i criteri di valutazione dei titoli da parte della commissione esaminatrice, nonche' le modalita' di approvazione della relativa graduatoria e di nomina dei vincitori sono stabilite con apposito decreto del Ministro della difesa, previa delibera del Consiglio della magistratura militare.

2. Entro due mesi dal termine di conclusione del concorso per titoli riservato ai magistrati ordinari, nel perdurare di vacanze organiche, il Ministro della difesa, su delibera del Consiglio della magistratura militare, provvede a bandire con decreto il successivo concorso pubblico per esami tra i soggetti di cui alle lettere h), i) e l), dell'articolo 2, comma 1, del decreto legislativo 5 aprile 2006, n. 160. Con lo stesso decreto del Ministro della difesa sono individuati:

- a) i punti a disposizione nella valutazione delle prove e i criteri di assegnazione da parte dei membri della commissione degli stessi punti, per ciascuna prova scritta e orale;
- b) le ulteriori norme utili allo svolgimento del concorso.

#### Art. 74. - Concorso per esami

1. Il concorso per esami di cui all'articolo 73, comma 2, ha luogo in Roma.

2. La commissione esaminatrice e' nominata dal Ministro della difesa, su proposta del Consiglio della magistratura militare, ed e' composta da cinque membri scelti fra magistrati, sia ordinari sia militari e professori delle facolta' di giurisprudenza. Con lo stesso decreto possono essere nominati, altresi', membri supplenti. Le funzioni di segretario sono esercitate da un funzionario di cancelleria, appartenente ai ruoli del Ministero della difesa.

3. L'esame consiste:

- a) in una prova scritta su ciascuna delle seguenti materie: 1) diritto penale militare; 2) diritto penale; 3) diritto civile;
- b) in una prova orale su ciascuna delle materie indicate alla lettera a) e inoltre sulle seguenti materie: 1) procedura penale e procedura penale militare; 2) diritto romano; 3) diritto amministrativo; 4) diritto costituzionale.

4. Per essere ammessi alla prova orale occorre avere riportato non meno di sei decimi in ciascuna materia della prova scritta.

5. Sono dichiarati idonei coloro che hanno riportato una media non inferiore a sette decimi nell'insieme delle prove scritte e orali e non meno di sei decimi in ciascuna materia della prova scritta e della prova orale.

6. Non sono ammessi al concorso coloro che in due concorsi precedenti non sono stati dichiarati idonei.

7. La commissione procede alla classifica dei concorrenti secondo il numero totale dei voti riportati.

8. A parita' di voti sono preferiti nell'ordine seguente:

- a) gli insigniti di medaglia al valore militare;
- b) i mutilati o invalidi di guerra, riconosciuti idonei al servizio;
- c) i feriti in combattimento e i mutilati e invalidi di guerra, riconosciuti idonei al servizio;
- d) gli insigniti di croce di guerra o di altra attestazione speciale di merito di guerra;
- e) gli orfani di guerra e i figli degli invalidi di guerra;
- f) coloro che hanno prestato servizio militare come combattenti;
- g) coloro che hanno prestato lodevole servizio, a qualunque titolo, presso l'amministrazione militare;
- h) i piu' anziani di eta'.

9. I primi classificati, entro i limiti dei posti messi a concorso, sono assunti in servizio con decreto ministeriale, a titolo di prova, con la qualifica di magistrati militari in tirocinio.

10. Le ulteriori norme utili per lo svolgimento del concorso sono stabilite, volta per volta, con lo stesso decreto ministeriale che indice il concorso.

#### Art. 75. - Tirocinio e nomina

1. I magistrati militari di cui all'articolo 74 sono destinati, con decreto ministeriale, agli uffici giudiziari militari per compiervi il prescritto tirocinio, che non puo' essere inferiore a sei mesi.

2. Trascorso positivamente il periodo minimo di prova, il Consiglio della magistratura militare delibera in ordine alla nomina a magistrato militare e al conferimento delle funzioni giudiziarie militari, sulla base dei pareri formulati dai capi degli uffici dove i magistrati militari hanno prestato il tirocinio.

### SEZIONE IV - ORDINAMENTO PENITENZIARIO MILITARE

#### Art. 76. - Applicabilita' delle disposizioni dell'ordinamento penitenziario comune

1. Per gli stabilimenti militari di pena e per l'espiazione delle pene detentive militari, se non e' espressamente o diversamente previsto dalle disposizioni del presente codice o da altre norme penali militari, si applicano le disposizioni dell'ordinamento penitenziario comune, sostituite, se necessario, le autorita' competenti ordinarie con quelle militari.

#### Art. 77. - Disposizioni interne di servizio per gli stabilimenti militari di pena

1. Il Ministro della difesa, con proprio decreto, stabilisce le norme interne di servizio per gli stabilimenti militari di pena.

2. Con il citato decreto, oltre alle modalita' di trattamento e alla disciplina del personale detenuto, sono, in ogni caso, regolamentate le seguenti materie:

- a) gli orari di apertura e chiusura degli stabilimenti militari di pena;
- b) gli orari relativi all'organizzazione della vita quotidiana della popolazione detenuta;
- c) le modalita' relative allo svolgimento dei vari servizi predisposti per i detenuti;
- d) gli orari di permanenza nei locali comuni;
- e) gli orari, i turni e le modalita' di permanenza all'aperto;
- f) i tempi e le modalita' particolari per i colloqui, la corrispondenza e le comunicazioni anche telefoniche;
- g) le affissioni consentite e le relative modalita';
- h) i giochi consentiti;
- i) l'importo della retribuzione dovuta ai detenuti militari assegnati al lavoro.

3. Ferme restando le attribuzioni del Tribunale e dell'Ufficio militare di sorveglianza, le materie non disciplinate dal citato decreto del Ministro della difesa o quelle che necessitano, per l'esecuzione, di specifiche direttive, sono demandate alla competenza di ciascun comandante degli stabilimenti militari di pena, secondo le modalita' indicate nello stesso decreto del Ministro della difesa.

#### Art. 78. - Stabilimenti militari di pena

1. Gli stabilimenti militari di pena si distinguono in:

- a) carceri giudiziarie militari;
- b) reclusori militari.

#### Art. 79. - Visite dei parlamentari

1. Per le visite dei parlamentari negli stabilimenti militari di pena si applicano le speciali disposizioni previste dal titolo III del libro II.

#### Art. 80. - Detenuti custoditi nelle carceri giudiziarie militari

1. Nelle carceri giudiziarie militari sono custoditi i militari detenuti in attesa di giudizio, a disposizione dell'autorita' giudiziaria militare od ordinaria.

2. Resta fermo quanto disposto dall' articolo 79, comma 2, della legge 1° aprile 1981, n. 121.

#### Art. 81. - Separazione dei detenuti secondo il grado

1. Nelle carceri giudiziarie militari, gli ufficiali sono tenuti separati dai sottufficiali e questi ultimi dai graduati e militari di truppa.

2. Gli ufficiali sono tenuti separati fra loro, secondo il grado che rivestono.

#### Art. 82. - Reclusori militari

1. I reclusori militari sono istituiti per custodirvi i militari che espiano la pena della reclusione militare o, a loro richiesta, le pene detentive comuni; resta fermo quanto disposto dall'articolo 79, comma 1, della legge 1° aprile 1981, n. 121.

2. Gli ufficiali che non hanno perduto il grado per effetto della condanna scontano la pena della reclusione militare in locali diversi da quelli destinati agli altri militari.

#### Art. 83. - Degradazione

1. Se la condanna pronunciata dal giudice militare a carico di militari detenuti in un carcere giudiziario militare importa la degradazione, il procuratore militare competente da' comunicazione della sentenza al Ministero della giustizia, perche' venga indicato in quale stabilimento di pena il condannato deve essere tradotto.

2. Se la condanna che importa la degradazione e' stata pronunciata da un giudice diverso da quello militare, il magistrato competente per l'esecuzione trasmette al comandante del carcere giudiziario militare, nel quale il condannato si trova detenuto, l'ordine di scarcerazione e quello di traduzione allo stabilimento al quale il condannato e' assegnato.

3. Immediatamente prima di effettuare la traduzione allo stabilimento a cui il condannato e' stato assegnato, il procuratore militare della Repubblica competente o, nel caso previsto dal comma 2, il magistrato competente per l'esecuzione, richiede all'autorita' amministrativa militare competente l'esecuzione della degradazione.

#### Art. 84. - Esercizio e pratiche di culto negli stabilimenti militari di pena

1. Per l'esercizio e le pratiche di culto negli stabilimenti militari di pena si applicano i principi dell'ordinamento penitenziario comune e, in quanto compatibili, le relative disposizioni regolamentari di esecuzione.

2. In ogni stabilimento militare di pena e' istituito un oratorio per il culto cattolico, il cui esercizio e' affidato alle cure di un cappellano militare.

#### Art. 85. - Lavoro dei militari detenuti

1. I detenuti militari in espiazione di pena sono occupati giornalmente con istruzioni civili e militari, e assegnati, a seconda delle loro attitudini, ai lavori organizzati a tal fine dal comando degli stabilimenti militari di pena.

2. Ai detenuti militari compete una retribuzione nella misura stabilita dal decreto del Ministro della difesa di cui all'articolo 77. Sulla specifica materia e' necessario il concerto con il Ministro dell'economia e delle finanze.

3. Gli ufficiali e sottufficiali detenuti sono di norma adibiti a lavori d'ufficio o ad altri lavori per i quali hanno particolare attitudine.

4. All'eventuale indennizzo da corrispondersi ai militari detenuti nel caso di infortunio sul lavoro, si provvede in virtu' delle disposizioni di legge o regolamentari vigenti al momento del fatto.

#### Art. 86. - Cassa militare delle ammende

1. Presso il Comando degli stabilimenti militari di pena e' istituita una cassa militare delle ammende, nella quale sono versate le somme dovute secondo le disposizioni della legge penale militare.

2. Le somme come sopra versate sono destinate, in relazione ai condannati militari, a scopi analoghi a quelli indicati nelle disposizioni di ordinamento penitenziario comune.

3. Il funzionamento della predetta cassa, la gestione dei fondi relativi e le loro erogazioni sono disciplinate con il decreto del Ministro della difesa di cui all'articolo 77. Sulla specifica materia e' necessario il concerto con il Ministro dell'economia e delle finanze.

## TITOLO IV FORZE ARMATE CAPO I DISPOSIZIONI COMUNI

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 87. - Definizione

1. Le Forze armate sono al servizio della Repubblica.

2. L'ordinamento e l'attivita' delle Forze armate, conformi agli articoli 11 e 52 della Costituzione, sono disciplinati dal codice e dal regolamento.

3. Le Forze armate sono organizzate su base obbligatoria e su base professionale, secondo quanto previsto dal presente codice.

#### Art. 88. - Principi in materia di organizzazione

1. Lo strumento militare e' volto a consentire la permanente disponibilita' di strutture di comando e controllo di Forza armata e interforze, facilmente integrabili in complessi multinazionali, ((e di unita' terrestri, navali, aeree, cibernetiche e aero-spaziali)) di intervento rapido, ((preposte alla difesa del territorio nazionale, delle vie di comunicazione marittime e aeree, delle infrastrutture spaziali e dello spazio cibernetico in ambito militare)); e' finalizzato, altresi', alla partecipazione a missioni anche multinazionali per interventi a supporto della pace.

2. Le predisposizioni di mobilitazione, occorrenti ai fini di cui al comma 1, sono limitate al completamento dei comandi, enti e unita' in vita.

#### Art. 89. - Compiti delle Forze armate

1. Compito prioritario delle Forze armate e' la difesa dello Stato.

2. Le Forze armate hanno altresi' il compito di operare al fine della realizzazione della pace e della sicurezza, in conformita' alle regole del diritto internazionale e alle determinazioni delle organizzazioni internazionali delle quali l'Italia fa parte.

3. Le Forze armate concorrono alla salvaguardia delle libere istituzioni e svolgono compiti specifici in circostanze di pubblica calamita' e in altri casi di straordinaria necessita' e urgenza.

4. In caso di conflitti armati e nel corso delle operazioni di mantenimento e ristabilimento della pace e della sicurezza internazionale i comandanti delle Forze armate vigilano, in concorso, se previsto, con gli organismi internazionali competenti, sull'osservanza delle norme di diritto internazionale umanitario.

#### Art. 90. - Funzioni di polizia militare

1. La polizia militare e' costituita dal complesso delle attivita' volte a garantire le condizioni generali di ordine e sicurezza delle Forze Armate sul territorio nazionale e all'estero. A tale scopo gli organi di polizia militare vigilano sull'osservanza delle leggi, dei regolamenti e delle disposizioni dell'autorita' militare attinenti all'attivita' da loro svolta. Gli organi di polizia militare esercitano, inoltre, un'azione di contrasto, di natura tecnico-militare, delle attivita' dirette a ledere il regolare svolgimento dei compiti delle Forze armate.

2. Le funzioni di polizia militare, svolte in via esclusiva dall'Arma dei carabinieri per l'Esercito italiano, la Marina militare e l'Aeronautica militare, fermo restando quanto previsto dall'articolo 132, comma 1, lettera a), sono disciplinate con decreto del Ministro della difesa e sono esercitate sulla base delle disposizioni impartite dal Capo di stato maggiore della difesa, nonche' nel rispetto delle competenze dei Comandanti responsabili.

#### Art. 91. - Funzioni di polizia giudiziaria militare

1. Le Forze armate esercitano le funzioni di polizia giudiziaria militare secondo le disposizioni dettate dai codici penali militari di pace e di guerra e dal presente codice.

#### Art. 92. - Compiti ulteriori delle Forze armate

1. Le Forze armate, oltre ai compiti istituzionali propri e fermo restando l'intervento prestato anche ai sensi dell'articolo 11 della legge 24 febbraio 1992, n. 225, in occasione di calamita' naturali di cui alla predetta legge e in altri casi di straordinaria necessita' e urgenza, forniscono a richiesta e compatibilmente con le capacita' tecniche del personale e dei mezzi in dotazione, il proprio contributo nei campi della pubblica utilita' e della tutela ambientale. (51)

2. Il contributo di cui al comma 1 e' fornito per le seguenti attivita':

- a) consulenza ad amministrazioni ed enti in tema di pianificazione e intervento delle Forze armate in situazioni di emergenza nazionale;
- b) contributo di personale e mezzi alle amministrazioni istituzionalmente preposte alla salvaguardia della vita umana in terra e in mare;
- c) ripristino della viabilita' principale e secondaria;
- d) pianificazione, svolgimento di corsi e di attivita' addestrative in tema di cooperazione civile-militare;
- e) trasporti con mezzi militari;
- f) campagna antincendi boschivi e interventi antincendi anche al di fuori di detta campagna, e anche attraverso la disponibilita', in dipendenza delle proprie esigenze, di risorse, mezzi e personale delle Forze armate, in caso di riconosciuta e urgente necessita', su richiesta delle regioni interessate, giusta quanto previsto dall'articolo 7, comma 3, lettera c), legge 21 novembre 2000, n. 353, in materia di incendi boschivi;
- g) emissioni di dati meteorologici;
- h) emissioni bollettini periodici relativi a rischio - valanghe;
- i) rilevamento nucleare, biologico e chimico ed effettuazione dei relativi interventi di bonifica;
- l) svolgimento di operazioni a contrasto dell'inquinamento marino da idrocarburi e da altri agenti;
- m) rilevamento idrooceanografico e aereofotogrammetrico di zone di interesse e produzione del relativo supporto cartografico, nonche' scambio di informazioni, elaborati e dati di natura geotopografica e geodetica;
- n) intervento in emergenze idriche nelle isole minori delle regioni a statuto ordinario;
- o) interventi in camera iperbarica per barotraumatizzati e ossigenoterapia;
- p) interventi sull'ambiente marino a tutela della fauna, della flora e del monitoraggio delle acque, attivita' di ricerca ambientale marina e scambio di informazioni e dati in materia di climatologia;
- q) demolizione di opere abusive e ripristino dello stato dei luoghi, secondo quanto previsto dagli articoli 41 del decreto del Presidente della Repubblica 6 giugno 2001, n. 380, e 61 del decreto del Presidente della Repubblica 30 maggio 2002, n. 115.

3. Con decreto del Ministro della difesa, di concerto con il Ministro dell'ambiente, della tutela del territorio e del mare e del Dipartimento nazionale della protezione civile, sentiti i Ministri interessati, sono determinate le modalita' per il perseguimento delle finalita' di cui al comma 1.

4. Le Forze armate, nell'ambito delle proprie attribuzioni, svolgono i compiti ulteriori previsti dalla legge e, in particolare, quelli di cui all'articolo 15 del regio decreto 30 gennaio 1941, n. 12 e dall'articolo 12 della ((legge 3 agosto 2007, n. 124, nonche' quelli di cui all'articolo 5, comma 5, del decreto-legge 14 giugno 2021, n. 82, convertito, con modificazioni, dalla legge 4 agosto 2021, n. 109)).

--------------- AGGIORNAMENTO (51) Il D.Lgs. 2 gennaio 2018, n. 1 ha disposto (con l'art. 47, comma 1, lettera h)) che "Tutti i riferimenti alla legge 24 febbraio 1992, n. 225 e ai relativi articoli, contenuti in altre disposizioni, si intendono riferiti al presente decreto e ai corrispondenti articoli. In particolare: [...] h) l'articolo 11 della legge n. 225 del 1992, citato nell'articolo 92, comma 1, e nell'articolo 137, comma 1, del decreto legislativo 15 marzo 2010 n. 66, deve intendersi riferito all'articolo 13 del presente decreto".

#### Art. 92-bis. - (( (Iniziative per la diffusione dei valori e della cultura militare fra i giovani). ))

((

1. Nell'ambito delle iniziative per la diffusione dei valori e della cultura della pace e della solidarieta' internazionale tra le giovani generazioni, le Forze armate organizzano corsi di formazione a carattere teorico-pratico, tendenti a rafforzare la conoscenza e la condivisione dei valori che da esse promanano e che sono alla base della presenza dei militari italiani di tutte le componenti operative nelle missioni internazionali. I corsi, di durata non superiore a tre settimane, si svolgono presso reparti delle Forze armate, secondo le priorita' stabilite dal decreto di cui al comma 5, e sono intesi a fornire le conoscenze di base riguardanti il dovere costituzionale di difesa della Patria, le attivita' prioritarie delle Forze armate, in particolare nelle missioni internazionali di pace a salvaguardia degli interessi nazionali, di contrasto al terrorismo internazionale e di soccorso alle popolazioni locali, nonche' quelle di concorso alla protezione dei beni culturali, paesaggistici e ambientali e alla salvaguardia delle libere istituzioni, in circostanze di pubblica calamita' e in altri casi di straordinaria necessita' e urgenza. Dell'attivazione dei corsi e' data notizia mediante pubblicazione di apposito avviso nella Gazzetta Ufficiale - 4ª serie speciale "Concorsi ed esami" -, e nel sito istituzionale del Ministero della difesa.

2. Possono presentare la domanda di partecipazione ai corsi di cui al comma 1 i cittadini italiani, senza distinzione di sesso, in possesso dei seguenti requisiti: eta' non inferiore a diciotto anni compiuti e non superiore a trenta anni compiuti; godimento dei diritti civili e politici; idoneita' all'attivita' sportiva agonistica; esito negativo agli accertamenti diagnostici per l'abuso di alcool, per l'uso, anche saltuario od occasionale, di sostanze stupefacenti, nonche' per l'utilizzo di sostanze psicotrope a scopo non terapeutico; assenza di sentenze penali di condanna ovvero di procedimenti penali in corso per delitti non colposi, di procedimenti disciplinari conclusi con il licenziamento dal lavoro alle dipendenze di pubbliche amministrazioni, di provvedimenti di proscioglimento da arruolamenti, d'autorita' o d'ufficio, esclusi i proscioglimenti per inidoneita' psico-fisica; requisiti morali e di condotta previsti dall'articolo 35, comma 6, del decreto legislativo 30 marzo 2001, n. 165. Alla domanda di partecipazione gli aspiranti devono allegare la certificazione relativa all'idoneita' all'attivita' sportiva agonistica e all'esito negativo degli accertamenti diagnostici di cui al primo periodo del presente comma, nonche' la scheda vaccinale rilasciate da struttura sanitaria pubblica o convenzionata con il Servizio sanitario nazionale. Nella medesima domanda gli aspiranti possono indicare la preferenza per uno o piu' reparti tra quelli individuati annualmente per lo svolgimento dei corsi, nei quali sono prioritariamente destinati, in relazione alle disponibilita'. I giovani sono ammessi ai corsi nel limite dei posti disponibili e previo superamento di apposita visita medica.

3. I giovani ammessi ai corsi assumono lo stato di militari, contraendo una speciale ferma volontaria di durata pari alla durata del corso, e sono tenuti all'osservanza delle disposizioni previste dagli ordinamenti di Forza armata. Durante i corsi i frequentatori fruiscono, a titolo gratuito, degli alloggi di servizio collettivi e della mensa.

4. Al termine dei corsi, ai frequentatori e' rilasciato un attestato di frequenza, che costituisce titolo per l'iscrizione all'associazione d'arma di riferimento del reparto di Forza armata presso il quale si e' svolto il corso, nonche', previa intesa con il Ministero dell'istruzione, dell'universita' e della ricerca, per il riconoscimento di crediti formativi nei segmenti scolastici in cui sia possibile farvi ricorso. All'attestato di frequenza non puo' essere attribuito alcun valore o punteggio utile nei concorsi per il reclutamento del personale delle Forze armate.

5. Con decreto del Ministro della difesa, sentita la Presidenza del Consiglio dei Ministri, sono stabiliti:

- a) gli eventuali ulteriori requisiti e i titoli preferenziali per l'ammissione ai corsi, individuati tra i seguenti: abilitazioni e brevetti attestanti specifiche capacita' tecniche o sportive; residenza nei territori di dislocazione ovvero in aree tipiche di reclutamento dei reparti presso i quali i corsi sono svolti; titolo di studio; parentela o affinita', entro il secondo grado, con il personale delle Forze armate deceduto o divenuto permanentemente inabile al servizio per infermita' o lesioni riportate in servizio, con le vittime del terrorismo, della criminalita' organizzata e del dovere; ordine cronologico di presentazione delle domande;
- b) le modalita' di attivazione, organizzazione e svolgimento dei corsi, le cause di allontanamento dagli stessi, il cui accertamento e' demandato al giudizio insindacabile del comandante del corso, nonche' le eventuali ulteriori modalita' per l'attivazione di corsi, anche di durata minore, cui sia possibile l'ammissione di giovani con disabilita', in possesso dei requisiti di cui al comma 2, esclusa l'idoneita' all'attivita' sportiva agonistica;
- c) la somma che i frequentatori versano, a titolo di cauzione, commisurata al controvalore dei materiali di vestiario ed equipaggiamento forniti dall'Amministrazione; tale somma e', in tutto o in parte, incamerata in via definitiva se i frequentatori trattengono, a domanda, al termine dei corsi, ovvero danneggiano i citati materiali. In tali casi, la quota parte della cauzione trattenuta e' versata in Tesoreria per la successiva riassegnazione, in deroga ai vigenti limiti, al fondo del Ministero della difesa istituito ai sensi dell'articolo 2, comma 616, della legge 24 dicembre 2007, n. 244, in aggiunta alla dotazione dello stesso come determinata ai sensi del comma 617 del medesimo articolo 2.

))

#### Art. 93. - Impiego particolare di contingenti di personale militare delle Forze armate

1. In relazione alle specifiche ed eccezionali esigenze di cui all'articolo 18 della legge 26 marzo 2001, n. 128, possono essere utilizzati contingenti di personale militare delle Forze armate, ai sensi e con le modalita' previste dal medesimo articolo 18 e dall'articolo 19, della legge n. 128 del 2001.

#### Art. 94. - Direzioni di amministrazione delle Forze armate

1. Le Direzioni di amministrazione delle Forze armate:

- a) assicurano il finanziamento degli enti amministrativamente dipendenti, attraverso la disponibilita' dei fondi accreditati dall'amministrazione centrale sulle apposite contabilita' speciali, e la resa dei conti relativi;
- b) svolgono le funzioni di natura giuridico-amministrativa a esse devolute in relazione all'ordinamento delle singole Forze armate;
- c) esercitano l'azione di controllo amministrativo nei confronti degli enti della rispettiva giurisdizione sia in sede ispettiva, sia in sede di revisione degli atti di gestione per conto anche dell'Ufficio centrale del bilancio presso il Ministero della difesa;
- d) eseguono le operazioni per la chiusura a pareggio delle contabilita' speciali, relativamente a ciascun anno finanziario.

2. La Direzione di amministrazione interforze, con le attribuzioni e i compiti indicati nel comma 1, ha competenza sugli enti a carattere interforze ((...)).

#### Art. 95. - Bande musicali

1. Le bande musicali delle Forze armate sono complessi organici destinati a partecipare alle celebrazioni piu' importanti della vita delle rispettive istituzioni e a rappresentare le Forze armate di appartenenza, in occasione di manifestazioni pubbliche, organizzate anche a livello internazionale.

2. Su richiesta di enti o comitati, puo' essere autorizzata la partecipazione della banda a manifestazioni indette in occasione di particolari solennita', nonche' ad attivita' concertistiche per la diffusione della cultura musicale, anche in collegamento con associazioni culturali e con enti pubblici o privati, nazionali e stranieri.

3. Le bande musicali sono poste alle dipendenze amministrative e disciplinari:

- a) del Comando ((militare della Capitale)), quella dell'Esercito italiano;
- b) del Comando marittimo Capitale, quella della Marina militare;
- c) del Comando dell'Aeronautica militare di Roma, quella dell'Aeronautica militare;
- d) del Comando della Legione allievi carabinieri di Roma, quella dell'Arma dei carabinieri 4 L'impiego delle bande e' disposto rispettivamente da: a) lo Stato maggiore dell'Esercito italiano; b) lo Stato maggiore della Marina militare; c) lo Stato maggiore dell'Aeronautica militare; d) il Comando generale dell'Arma dei carabinieri. 5. Fermi i compiti di istituto e le funzioni di rappresentanza militare di Forza armata e compatibilmente con essi, le bande musicali svolgono attivita' artistica e culturale in tutto il territorio nazionale secondo una opportuna programmazione annuale dei concerti coordinata dallo Stato maggiore della difesa, in relazione anche alle richieste degli enti locali. 6. L'organizzazione strumentale e le modalita' d'impiego delle bande musicali militari sono disciplinate nel regolamento.

### SEZIONE II - BANDIERE E ONORIFICENZE

#### Art. 96. - Bandiera della Repubblica italiana

1. La bandiera della Repubblica e' il simbolo della Patria.

2. La bandiera da combattimento affidata a una unita' militare e', inoltre, il simbolo dell'onore dell'unita' stessa nonche' delle sue tradizioni, della sua storia, del ricordo dei suoi caduti, e va difesa fino all'estremo sacrificio.

3. Alla bandiera vanno tributati i massimi onori.

4. Le modalita' di uso ed esposizione delle bandiere militari, fatto salvo quanto previsto dall'art. 1, legge 5 febbraio 1998, n. 22, sono disciplinate con determinazioni del Capo di stato maggiore della difesa.

#### Art. 97. - Concessione della bandiera per le Forze armate e per i corpi ausiliari

1. Per tutti gli enti dell'Esercito italiano, dell'Aeronautica militare, dell'Arma dei Carabinieri, e per i reparti a terra della Marina militare, gia' concessionari di bandiera o stendardo, e' adottata una bandiera, avente le caratteristiche indicate con decreto del Ministro della difesa.

2. Per i Corpi dell'arma di cavalleria e i reparti a cavallo, in luogo della bandiera di cui al comma 1 e' adottato uno stendardo, la cui composizione e caratteristiche, analoghe a quelle della bandiera, sono indicate con decreto del Ministro della difesa.

3. ((COMMA SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)).

4. Al Corpo militare della Croce rossa italiana e al Corpo delle infermiere volontarie della Croce rossa italiana e' concesso l'uso della bandiera nazionale.

5. Al Corpo speciale volontario ausiliario dell'Associazione dei Cavalieri italiani del sovrano militare ordine di Malta e' concesso l'uso della bandiera nazionale.

#### Art. 98. - Concessione di una bandiera navale per la Marina militare e per la Marina mercantile

1. La bandiera navale istituita per la Marina militare e per la Marina mercantile e' conforme ai modelli indicati, rispettivamente, con decreto del Ministro della difesa e con quello delle infrastrutture e dei trasporti.

2. A ogni nave della Marina militare, escluse le unita' ausiliarie e quelle di uso locale, all'infuori della dotazione normale di bandiere, sono consegnate una bandiera nazionale, che prende il nome di Bandiera di combattimento, e uno stendardo.

3. La Bandiera di combattimento deve alzarsi sempre in combattimento e, se le condizioni di tempo e di navigazione lo consiglino, allorquando e' presente a bordo il Presidente della Repubblica e nelle grandi solennita'; lo stendardo, in combattimento, e' posto su apposito sostegno nell'interno della torre, del ponte o della camera di comando.

4. Le ulteriori disposizioni circa il confezionamento, la consegna, la custodia, il deposito e l'uso della bandiere di cui al comma 3 sono stabilite con determinazione del Capo di stato maggiore della Marina militare.

#### Art. 99. - Concessione di ricompense alle Forze armate

1. Il conferimento alla bandiera della croce di cavaliere all'Ordine militare d'Italia, la concessione ai reparti di ricompense al valore militare, nonche' al valore e al merito di Forza armata, sono disciplinati dal libro IV, titolo VIII, capo V, sezioni da I a VII del presente codice.

## CAPO II - ESERCITO ITALIANO

### Art. 100. - Istituzione e funzioni dell'Esercito italiano

1. L'Esercito italiano costituisce la componente operativa terrestre della difesa militare dello Stato.

### Art. 101. - (( (Organizzazione generale dell'Esercito italiano).))

((

1. Per l'assolvimento dei compiti stabiliti dalla legge l'Esercito italiano e' organizzato in comandi, enti e unita' titolari di capacita' operative, di supporto, logistiche, formative, addestrative, infrastrutturali e territoriali.

2. Le funzioni, l'ordinamento, le sedi, le dipendenze e l'articolazione delle strutture ordinative di cui al comma 1, sono stabiliti con determinazione del Capo di Stato maggiore dell'Esercito.

))

### Art. 102. - (( (Organizzazione operativa dell'Esercito italiano) ))

((

1. L'organizzazione operativa dell'Esercito italiano e' posta alle dirette dipendenze del Capo di stato maggiore dell'Esercito.

2. Le funzioni, l'ordinamento, le sedi, le dipendenze e le articolazioni di comandi, enti e strutture dell'organizzazione di cui al comma 1, sono definiti con determinazione del Capo di stato maggiore dell'Esercito.

))

### Art. 103. - (( (Organizzazione territoriale dell'Esercito italiano).))

((

1. L'attribuzione delle funzioni nei settori del reclutamento e delle forze di completamento, del demanio e delle servitu' militari, della leva e del collocamento al lavoro dei militari volontari congedati e' effettuata con determinazione del Capo di stato maggiore dell'Esercito, con cui sono altresi' individuati i Comandi, le unita' e i reparti competenti per territorio o presidio.

2. L'articolazione, le sedi, l'ordinamento e le competenze dei comandi, reparti e unita' di cui al comma 1, sono stabiliti con determinazione del Capo di stato maggiore dell'Esercito.

3. In ciascuna delle regioni amministrative tipiche di reclutamento, con priorita' alle regioni amministrative dell'arco alpino, e' assicurata, senza nuovi o maggiori oneri a carico dello Stato, la presenza di almeno un reparto alpino.

))

### Art. 104. - (( (Organizzazione formativa e addestrativa dell'Esercito italiano).))

((

1. L'organizzazione formativa e addestrativa dell'Esercito italiano fa capo al Comando per la formazione, specializzazione e dottrina dell'Esercito e comprende:

- a) i seguenti istituti di formazione: 1) Comando per la formazione e Scuola di applicazione; 2) Accademia militare; 3) Scuola sottufficiali dell'Esercito; 4) Scuola militare "Nunziatella"; 5) Scuola militare "Teulie'";
- b) la Scuola lingue estere dell'Esercito;
- c) il Centro di simulazione e validazione dell'Esercito;
- d) gli altri Enti di formazione e specializzazione individuati dagli ordinamenti di Forza armata.

2. Le funzioni, l'ordinamento, le sedi, le dipendenze e l'articolazione del comando, degli istituti, delle scuole, dei centri e degli enti di cui al comma 1, nonche' dei comandi, unita' e reparti dipendenti, sono definiti con determinazione del Capo di stato maggiore dell'Esercito.))

------------- AGGIORNAMENTO (24) Il D.P.R. 6 agosto 2013, n. 115 ha disposto (con l'art. 3, comma 1, lettera a)) che "a fare data dall'adozione del decreto di soppressione del Raggruppamento unita' addestrative per la formazione dei volontari dell'Esercito italiano di cui all'articolo 2, comma 1, lettera d), all'articolo 104, al comma 1, lettera a), il numero 6) e' soppresso".

### Art. 105. - (( (Organizzazione logistica dell'Esercito italiano).))

((

1. L'organizzazione logistica dell'Esercito italiano fa capo al Comando logistico dell'Esercito da cui dipendono:

- a) i comandi trasporti e materiali, commissariato, sanita' e veterinaria, e tecnico;
- b) i poli di mantenimento e di rifornimento;
- c) il Centro polifunzionale di sperimentazione;
- d) il Centro tecnico logistico interforze NBC;
- e) il Policlinico militare di Roma;
- f) il Centro militare di veterinaria.

2. Le funzioni, l'ordinamento, le sedi, le dipendenze e l'articolazione del Comando di cui al comma 1, nonche' dei comandi, unita' e reparti dipendenti, sono definiti con determinazione del Capo di stato maggiore dell'Esercito.

))

### Art. 106. - Direzione di amministrazione dell'Esercito italiano

1. La Direzione di amministrazione e' posta alle dipendenze del ((Centro di responsabilita' amministrativa)) dell'Esercito italiano, e svolge le competenze di cui all'articolo 94, su tutti gli enti dell'Esercito italiano, anche mediante delega, secondo gli ordinamenti di Forza armata.

### Art. 107. - (( (Organizzazione per le infrastrutture dell'Esercito italiano).))

((

1. Le attribuzioni nei settori demaniale, infrastrutturale e del mantenimento del patrimonio immobiliare dell'Esercito italiano fanno capo al dipartimento delle infrastrutture presso lo Stato maggiore dell'Esercito che le espleta avvalendosi dei comandi e delle unita' intermedie e periferiche dotate di adeguata struttura tecnica competente nelle specifiche materie.

2. Le funzioni, l'ordinamento, le sedi, le dipendenze e l'articolazione del dipartimento di cui al comma 1, nonche' dei comandi, unita' e reparti dipendenti, sono definiti con determinazione del Capo di stato maggiore dell'Esercito.

))

### Art. 108. - (Armi e Corpi dell'Esercito italiano).

1. L'Esercito italiano si compone di strutture organizzative a vari livelli ordinativi, cui sono conferite una o piu' funzioni operative, formative, addestrative, di sostegno logistico e di gestione amministrativa dello strumento militare terrestre.

2. Il personale militare dell'Esercito italiano, adibito a una o piu' funzioni tecnico-operative o tecnico-logistiche, e' assegnato ai fini dello stato giuridico e dell'impiego alle seguenti armi o corpi:

- a) Arma di fanteria;
- b) Arma di cavalleria;
- c) Arma di artiglieria;
- d) Arma del genio;
- e) Arma delle trasmissioni;
- f) Arma dei trasporti e materiali;
- g) Corpo degli ingegneri;
- h) Corpo sanitario;
- i) Corpo di commissariato.

3. Nel regolamento sono stabilite le specialita' delle ((Armi e dei Corpi)).

### Art. 109. - Corpo degli ingegneri dell'Esercito italiano

1. Il Corpo degli ingegneri dell'Esercito italiano:

- a) presiede agli studi scientifici e tecnici dei mezzi occorrenti all'Esercito italiano, nonche' alla realizzazione e alla sperimentazione tecnica dei relativi prototipi;
- b) provvede all'elaborazione delle condizioni tecniche dei progetti di capitolati d'onere e all'elaborazione dei progetti di regolamentazione tecnica per la conservazione, la manutenzione, l'uso e la riparazione dei materiali dell'Esercito italiano;
- c) sovraintende al controllo della produzione e fissa le direttive tecniche per il collaudo dei materiali da approvvigionare.
- c-bis) svolge attivita' di progettazione, costruzione, manutenzione e collaudo di immobili e infrastrutture dell'Esercito.

## CAPO III - MARINA MILITARE

### SEZIONE I - DISPOSIZIONI PER LA MARINA MILITARE

#### Art. 110. - Istituzione e funzioni della Marina militare

1. La Marina militare costituisce la componente operativa marittima della difesa militare dello Stato.

#### Art. 111. - Competenze particolari della Marina militare

1. Rientrano nelle competenze della Marina militare, secondo quanto previsto dalla legislazione vigente:

- a) la vigilanza a tutela degli interessi nazionali e delle vie di comunicazione marittime al di la' del limite esterno del mare territoriale e l'esercizio delle funzioni di polizia dell'alto mare demandate alle navi da guerra negli spazi marittimi internazionali dagli articoli 200 e 1235, primo comma, numero 4, del codice della navigazione e dalla legge 2 dicembre 1994, n. 689, nonche' di quelle relative alla salvaguardia dalle minacce agli spazi marittimi internazionali, ivi compreso il contrasto alla pirateria;
- b) il concorso ai fini di prevenzione e di contrasto del traffico dei migranti via mare, nelle acque internazionali, ai sensi dell'articolo 12, comma 9-bis, del decreto legislativo 25 luglio 1998, n. 286, oltre che nell'ambito della cooperazione operativa tra gli Stati membri dell'Unione Europea coordinata dall'Agenzia istituita con il regolamento UE n. 2007/2004 del 26 ottobre 2004, gestendo il necessario dispositivo di sorveglianza marittima integrata;
- c) il concorso al contrasto al traffico di sostanze stupefacenti, ai sensi dell'articolo 99 del decreto del Presidente della Repubblica 9 ottobre 1990, n. 309;
- d) il servizio di rifornimento idrico delle isole minori.

((1-bis. La Marina militare promuove le attivita' per la valorizzazione delle potenzialita' e della competitivita' del settore della subacquea nazionale, per la promozione delle connesse attivita' di ricerca e tecnico-scientifiche nonche' per il potenziamento delle innovazioni e della relativa proprieta' intellettuale. A tale fine, con decreto del Ministro della difesa, di concerto con i Ministri delle imprese e del made in Italy e dell'universita' e della ricerca, e' istituito e disciplinato il Polo nazionale della subacquea))

#### Art. 112. - Organizzazione operativa della Marina militare

1. Il Comando in capo della Squadra navale e' il vertice dell'organizzazione operativa della Marina militare, dipende direttamente dal Capo di Stato maggiore della Marina militare ed e' retto da un ammiraglio di squadra ((nominato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa, sentito il Capo di stato maggiore della difesa)).

2. Dal Comando di cui al comma 1 dipendono direttamente le unita' navali, i comandi operativi che le raggruppano e i reparti delle forze operative, individuati con determinazione del Capo di stato maggiore della Marina militare, che, con medesimo atto, ne determina anche l'articolazione, le sedi, l'ordinamento e le funzioni.

3. COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 7.

#### Art. 113. - Organizzazione logistica della Marina militare

1. L'organizzazione logistica della Marina militare fa capo al Comando logistico della Marina militare e ai Reparti dello Stato maggiore della Marina titolari delle componenti specialistiche di Forza armata. Dal Comando logistico della Marina militare, che dipende direttamente dal Capo di stato maggiore, dipendono per le funzioni logistiche i Comandi marittimi di cui all'articolo 124.

2. Fatte salve le prerogative e le attribuzioni delle componenti specialistiche di Forza armata, il Comando logistico della Marina militare assicura il supporto tecnico e logistico generale allo strumento marittimo, ai comandi, agli enti e al personale, nonche', quale organo direttivo centrale del Servizio dei fari e del segnalamento marittimo di cui all' articolo 114, attraverso la dipendente Direzione dei fari e del segnalamento marittimo, svolge le funzioni previste nel capo IV, titolo III, libro primo del regolamento.

3. Il Comando in capo della Squadra navale esercita funzioni logistiche di supporto diretto ai comandi dipendenti, ai fini dell'approntamento e del mantenimento in efficienza dello strumento operativo.

4. L'Ispettorato di sanita' della Marina militare, alle dipendenze del Capo di stato maggiore della Marina, esercita funzioni di indirizzo nell'ambito della logistica sanitaria.

4-bis. ((L'Ente circoli di cui all'articolo 131-bis rientra nell'organizzazione logistica della Marina militare ed e' posto alle dirette dipendenze del Capo di stato maggiore della Marina militare)).

5. Le sedi, l'ordinamento e le funzioni dei comandi e degli enti dell'organizzazione logistica di cui al presente articolo, sono individuati con determinazione del Capo di stato maggiore della Marina militare.

#### Art. 114. - Servizio dei fari e del segnalamento marittimo della Marina militare

1. Il servizio dei fari e del segnalamento marittimo gestisce la segnaletica marittima, fissa e galleggiante, dislocata lungo le coste continentali e insulari e nei porti di interesse nazionale previsti dalle vigenti disposizioni.

2. Il servizio presiede al funzionamento degli ausili alla navigazione ((di cui all'articolo 169 del regolamento)), con esclusione degli altri tipi di radioassistenze, dei sistemi di comunicazione marittima e degli impianti di controllo del traffico che la legislazione vigente assegna ad altri dicasteri o enti.

3. Ferma la competenza del Ministero delle infrastrutture e dei trasporti in ordine alla costruzione, modifica e manutenzione straordinaria dei manufatti e delle infrastrutture del servizio, il servizio dei fari e del segnalamento marittimo provvede, altresi':

- a) all'acquisizione, installazione e manutenzione degli impianti di segnalamento ottico acustico e radioelettrico;
- b) all'acquisizione e gestione dei mezzi navali e terrestri necessari all'espletamento del servizio;
- c) al minuto mantenimento e all'ordinaria manutenzione dei manufatti e delle infrastrutture del servizio.

4. Il servizio dei fari e del segnalamento marittimo e' articolato nei seguenti organi facenti parte dell'organizzazione periferica della Marina militare:

- a) ufficio tecnico dei fari e del segnalamento marittimo;
- b) comandi di zona dei fari;
- c) reggenze dei segnalamenti.

5. Al servizio dei fari e del segnalamento marittimo sono assegnati:

- a) ufficiali, sottufficiali, graduati e militari di truppa della Marina militare nei contingenti determinati dal Capo di stato maggiore della Marina militare nell'ambito della propria competenza istituzionale;
- b) gli appartenenti a qualifiche del personale tecnico civile del servizio dei fari e del segnalamento marittimo del Ministero della difesa;
- c) gli appartenenti ad altre qualifiche del personale civile del Ministero della difesa previste dall'organico per l'assolvimento dei diversi compiti di istituto del predetto servizio.

6. In aggiunta al personale di cui al comma 5, all'ispettorato e' assegnato, per lo svolgimento di compiti attinenti al settore delle infrastrutture, un ufficiale superiore dell'Arma del genio dell'Esercito italiano compreso nel rispettivo ruolo organico.

7. Il regolamento disciplina il funzionamento del servizio dei fari e del segnalamento marittimo

#### Art. 115. - Vigilanza in mare

1. La Marina militare espleta:

- a) il servizio di vigilanza, ai sensi all'articolo 2, lettera c), legge 31 dicembre 1982, n. 979, che in caso di necessita' puo' integrare quello di vigilanza e di soccorso in mare svolto dal Corpo delle capitanerie di porto. Il servizio e' svolto in base alle direttive emanate d'intesa fra il Ministro delle infrastrutture e dei trasporti e il Ministro della difesa, sentite, se occorre, le altre amministrazioni interessate. La Marina militare provvede all'equipaggiamento e alla condotta dei mezzi;
- b) la sorveglianza per la prevenzione degli inquinamenti delle acque marine da idrocarburi e dalle altre sostanze nocive nell'ambiente marino e l'accertamento delle infrazioni alle relative norme, ai sensi degli articoli 23, legge 31 dicembre 1982, n. 979, e 12, decreto legislativo 6 novembre 2007, n. 202.

2. Le spese di gestione e manutenzione dei mezzi destinati al servizio di vigilanza di cui al comma 1, lettera a), conseguenti alla realizzazione del programma di costruzione e acquisto dei mezzi di cui all'articolo 6, legge 31 dicembre 1982, n. 979, sono a carico del Ministero della difesa.

3. Ai comandanti delle unita' di vigilanza di cui al comma 1, lettera a) del presente articolo, e' riconosciuta la qualifica di ufficiali di polizia giudiziaria ai sensi dell'articolo 57, comma 3 , del codice di procedura penale.

#### Art. 116. - Organizzazione formativa della Marina militare

((

1. L'organizzazione formativa di Forza armata fa capo al Comando Scuole della Marina militare, da cui dipendono:

- a) l'Accademia navale;
- b) la Scuola navale militare "Francesco Morosini";
- c) l'Istituto di Studi Militari Marittimi;
- d) le Scuole sottufficiali e volontari della Marina militare;
- e) il Centro di selezione della Marina militare.

))

((2. Le sedi, l'ordinamento e le funzioni dei comandi e degli enti di cui al comma 1, sono definiti con determinazione del Capo di stato maggiore della Marina.))

------------- AGGIORNAMENTO (24) Il D.P.R. 6 agosto 2013, n. 115 ha disposto (con l'art. 3, comma 1, lettera a)) che "a fare data dall'adozione del decreto di soppressione del Centro addestramento e formazione del personale volontario della Marina militare di cui all'articolo 2, comma 1, lettera f), all'articolo 116, al comma 1, la lettera e) e' soppressa".

#### Art. 117. - Servizio idrografico della Marina militare

1. L'Istituto idrografico della Marina militare, posto alle dipendenze del Capo di stato maggiore della Marina militare, ha sede in Genova ed e' retto da un ufficiale ammiraglio del Corpo di stato maggiore.

2. Nel regolamento e' disciplinato l'ordinamento dell'Istituto idrografico.

#### Art. 118. - (( (Corpi della Marina militare).))

((

1. L'organizzazione della Marina militare e' suddivisa in:

- a) Corpo di stato maggiore;
- b) Corpo del genio della Marina;
- c) Corpo sanitario militare marittimo;
- d) Corpo di commissariato militare marittimo;
- e) Corpo delle capitanerie di porto;
- f) Corpo degli equipaggi militari marittimi.

2. Il Corpo del genio della Marina e' articolato nelle seguenti specialita':

- a) genio navale;
- b) armi navali;
- c) infrastrutture.

3. Il Corpo delle capitanerie di porto e' trattato nella sezione II del presente capo. Il Corpo degli equipaggi militari marittimi e' costituito dai sottufficiali, graduati e militari di truppa della Marina militare, esclusi gli appartenenti al Corpo delle capitanerie di porto.

4. Per gli ufficiali appartenenti ai corpi di cui al comma 1, possono essere utilizzate le seguenti denominazioni:

a) per il Corpo di stato maggiore: ufficiali di vascello

b) per il Corpo del genio della Marina: 1) per la specialita' genio navale: ufficiali G.N.; 2) per la specialita' armi navali: ufficiali A.N.; 3) per la specialita' infrastrutture: ufficiali INFR.;

c) per il Corpo sanitario militare marittimo: ufficiali di Sanita';

d) per il Corpo di commissariato militare marittimo: ufficiali commissari;

e) per il Corpo delle capitanerie di porto: ufficiali C.P.;

f) per il Corpo degli equipaggi militari marittimi: ufficiali C.S.))

((37))

----------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica decorre dal 1° gennaio 2017.

#### Art. 119. - Corpo di stato maggiore

1. Rientra nelle competenze degli ufficiali del Corpo di stato maggiore:

- a) coprire le cariche prescritte dall'ordinamento del Ministero della difesa;
- b) armare, guidare, comandare, disarmare le navi dello Stato, e assumerne la responsabilita' e la custodia nei porti militari e negli arsenali;
- c) comandare le forze navali comunque costituite;
- d) comandare i comandi marittimi, comandare i depositi e distaccamenti della Marina militare; comandare e dirigere gli istituti e le scuole della Marina militare; comandare le stazioni elicotteri/aeromobili e i gruppi di volo della Marina militare;
- e) dirigere a bordo ed eventualmente a terra i servizi delle artiglierie e delle armi subacquee e provvedere a bordo alle relative sistemazioni e al munizionamento in concorso con gli ufficiali ((del Corpo del genio della marina, specialita' armi navali)), e amministrare il relativo materiale; dirigere a bordo ed eventualmente a terra i reparti, le componenti, le sezioni elicotteri e aeree della Marina militare; ((37))
- f) dirigere a bordo e a terra i servizi delle comunicazioni;
- g) dirigere il servizio idrografico, quello dei fari e del segnalamento marittimo, e ogni altro servizio attinente alla nautica, e amministrarne il materiale;
- h) dirigere e compiere gli studi per la preparazione bellica delle forze marittime;
- i) eseguire le ispezioni generali e quelle sul funzionamento dei servizi di propria competenza;
- l) adempiere gli incarichi di addetti per la Marina militare all'estero;
- m) LETTERA SOPPRESSA DAL D.LGS. 24 FEBBRAIO 2012, N. 20.

----------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica decorre dal 1° gennaio 2017.

#### Art. 120.

(Corpo del genio ((della Marina)) ). ((37))

1. Rientra nelle competenze del Corpo del genio ((della Marina, specialita' genio navale)): ((37))

- a) progettare le navi dello Stato in base ai programmi stabiliti dagli organi competenti ((...)), nonche', con il personale in possesso dei previsti titoli e requisiti professionali, progettare, seguire e controllare la costruzione dei materiali inerenti l'impiego degli aeromobili di cui agli articoli 126 e 127, inclusi i relativi allestimenti, armamenti, collaudi, servizi tecnici e interventi di mantenimento; ((37))
- b) seguire e controllare la costruzione o il raddobbo delle navi dello Stato, delle macchine, degli impianti e degli attrezzi relativi ((...)); ((37))
- c) coprire le cariche prescritte dall'ordinamento del Ministero della difesa, compresi gli incarichi di addetti aggiunti e assistenti per la Marina militare all'estero;
- d) imbarcare sulle navi per esercitare funzioni inerenti al proprio servizio per la direzione e l'esercizio degli apparati del sistema nave;
- e) dirigere gli arsenali e gli stabilimenti della Marina militare((...)); ((37))
- f) vigilare i beni e servizi, ovvero materiali e lavori, di competenza ((...)) che sono eseguiti dall'industria privata per conto della Marina militare; ((37))
- g) provvedere a ogni altro servizio tecnico relativo alle costruzioni navali, agli immobili e alle infrastrutture occorrenti alla Marina militare; ((37))
- h) eseguire le ispezioni generali e quelle sul funzionamento dei servizi di propria competenza.

((1-bis. Rientra nelle competenze del Corpo del genio della Marina, specialita' armi navali:

a) progettare il sistema di combattimento delle navi dello Stato, studiare l'armamento delle navi di nuova costruzione e provvedere all'acquisto e alla sistemazione dei relativi impianti, in base ai programmi stabiliti dagli organi competenti; studiare e provvedere le nuove armi e i materiali d'armamento; provvedere a tutti i servizi del munizionamento e degli esplosivi, secondo quanto stabilito all'articolo 119; provvedere a ogni altro servizio tecnico relativo ai servizi di cui alla presente lettera;

b) coprire le cariche prescritte dall'ordinamento del Ministero della difesa, compresi gli incarichi di addetti aggiunti e assistenti per la Marina militare all'estero;

c) imbarcare sulle navi per esercitare funzioni inerenti al proprio servizio;

d) dirigere i lavori di costruzione, di montamento, di riparazione e modifica del materiale di cui alla lettera a) nonche', con il personale in possesso dei previsti titoli e requisiti professionali, progettare, seguire e controllare la costruzione dei materiali inerenti all'impiego degli aeromobili di cui agli articoli 126 e 127, inclusi i relativi allestimenti, armamenti, collaudi, servizi tecnici e interventi di mantenimento;

e) dirigere gli arsenali e gli stabilimenti della Marina militare per i servizi di cui alla lettera a);

f) vigilare i beni e servizi, ovvero materiali e lavori, di competenza che sono eseguiti dall'industria privata per conto della Marina militare;

g) eseguire le ispezioni generali e quelle sul funzionamento dei servizi di propria competenza.))

((37))

((1-ter. Rientra nelle competenze del Corpo del genio della Marina, specialita' infrastrutture:

a) progettare gli immobili o le infrastrutture dello Stato in base ai programmi stabiliti dagli organi competenti ovvero secondo le disposizioni dello Stato maggiore della Marina;

b) dirigere, seguire e controllare la costruzione o il mantenimento e il collaudo degli immobili e delle infrastrutture in base ai programmi stabiliti dagli organi competenti ovvero secondo le disposizioni dello Stato maggiore della Marina;

c) coprire le cariche prescritte dall'ordinamento del Ministero della difesa, compresi gli incarichi di addetti aggiunti e assistenti per la Marina militare all'estero;

d) dirigere le direzioni e sezioni del genio militare per la Marina militare ovvero le articolazioni del settore infrastrutture in ambito interforze;

e) vigilare i beni e servizi, ovvero materiali e lavori, di competenza che sono eseguiti dall'industria privata per conto della Marina militare.

f) eseguire le ispezioni generali e quelle sul funzionamento dei servizi di propria competenza.))

((37))

----------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, lettera c)) che al comma 1, lettera g), del presente articolo, le parole «, agli immobili e alle infrastrutture alla Marina militare» sono soppresse". Ha inoltre disposto(con l'art. 2, comma 1, alinea) che le presenti modifiche decorrono dal 1° gennaio 2017.

#### Art. 121.

((ARTICOLO ABROGATO DAL D.LGS. 26 APRILE 2016, N. 91))

#### Art. 122. - Corpo sanitario militare marittimo

1. Rientra nelle competenze degli ufficiali medici del Corpo sanitario militare marittimo:

- a) il Servizio medico chirurgico occorrente alla Marina militare sia a terra sia a bordo;
- b) coprire le cariche previste dall'ordinamento del Ministero della difesa;
- c) l'amministrazione del materiale ospedaliero sia a terra sia a bordo;
- d) eseguire le visite mediche disciplinari e quelle medico-legali;
- e) eseguire le ispezioni di carattere tecnico-sanitario agli stabilimenti di cura alla Marina militare ed effettuare ogni altro Servizio sanitario per la Marina militare.

#### Art. 123. - Corpo di commissariato militare marittimo

1. Rientrano nelle competenze del Corpo di commissariato militare marittimo:

- a) la direzione della gestione amministrativa-logistica per quanto concerne: 1) il vettovagliamento; 2) il casermaggio, il vestiario e l'equipaggiamento; 3) i combustibili e i lubrificanti; 4) gli automezzi e gli altri materiali ordinari e speciali; 5) il coordinamento e il controllo dell'attivita' di movimentazione e trasporto di uomini, mezzi e materiali; 6) le attivita' di programmazione e contrattuali, mediante procedure accentrate o delegate o decentrate; 7) attivita' di studio, ricerca, sviluppo ed elaborazione della normativa tecnica per gli approvvigionamenti; 8) i collaudi, il controllo di qualita', la distribuzione, l'uso, la conservazione, la manutenzione, il recupero e la cessione di materiali;
- b) la gestione dei fondi necessari per il funzionamento degli enti, la predisposizione delle variazioni di bilancio e di cassa, la somministrazione dei fondi occorrenti e l'ordinazione delle conseguenti spese, l'assegnazione e variazione del fondo scorta per unita' navali ed enti a terra;
- c) l'amministrazione e l'erogazione al personale militare e civile dei trattamenti economici previsti dalle disposizioni vigenti;
- d) il controllo interno di legittimita' e di merito con funzioni anche ispettive, la valorizzazione e analisi delle rendicontazioni economico finanziarie;
- e) l'attivita' di consulenza giuridica nei settori: 1) amministrativo; 2) disciplinare; 3) legale, sia a bordo sia a terra, e nell'ambito di operazioni fuori area relativamente all'applicazione del diritto internazionale; 4) normativo, nella redazione degli atti di interesse della Forza armata;
- f) la gestione del contenzioso;
- g) la formazione e qualificazione del personale nell'ambito dei settori di competenza;
- h) l'assolvimento degli incarichi previsti dall'ordinamento del Ministero della difesa;
- i) l'assolvimento degli incarichi amministrativi e logistici previsti dal codice e dal regolamento, a bordo delle unita' navali e presso gli enti a terra, nonche' quelli previsti ai fini dell'avanzamento dal libro IV, titolo VII, capo VIII del presente codice.

#### Art. 124. - Organizzazione territoriale periferica della Marina militare

((

1. Hanno giurisdizione sul litorale dello Stato, per i servizi della Marina militare, i Comandi marittimi che dipendono, per le funzioni territoriali, dal Capo di stato maggiore della Marina.

))

2. ((I Comandi marittimi)) della Marina militare adottano gli opportuni provvedimenti, ricorrendo anche, se necessario, all'impiego di personale militare all'uopo addestrato, in situazioni di necessita', se la interruzione o la sospensione del servizio di segnalamento di cui all'articolo 114, puo' compromettere la sicurezza della navigazione, e deve, comunque, essere garantita la continuita' dell'attivita' operativa.

((

3. Le sedi, le aree di giurisdizione, l'ordinamento e le funzioni dei Comandi marittimi sono individuati con determinazione del Capo di stato maggiore della Marina militare.

))

#### Art. 125. - Aviazione antisommergibile della Marina militare

1. L'Aviazione <<antisommergibile>> di cui all'articolo 152 fa parte organicamente dell'Aeronautica militare, e dipende, per l'impiego, dalla Marina militare.

2. I reparti dell'Aviazione <<antisommergibile>> sono costituiti:

- a) da personale dell'Aeronautica militare;
- b) da ufficiali della Marina militare in possesso del brevetto militare di pilota rilasciato dall'Aeronautica militare e abilitati al pilotaggio dei velivoli <<antisommergibile>> in dotazione ai reparti;
- c) da ufficiali della Marina militare in possesso del brevetto di osservatore dall'aeroplano;
- d) da personale del Corpo degli equipaggi militari marittimi delle categorie radaristi e radiotelegrafisti in possesso del brevetto di <<specialista aeronautico>> rilasciato dall'Aeronautica militare.

3. Il numero dei piloti, degli osservatori e degli specialisti della Marina militare e' stabilito con il decreto del Ministro della difesa.

4. Il generale ispettore dell'aviazione per la Marina militare, di cui all'articolo 141, e il personale dei reparti dell'Aviazione <<antisommergibile>> sono compresi negli organici delle rispettive Armi o Corpi.

5. Agli ufficiali della Marina militare piloti e ai sottufficiali, graduati e comuni della Marina militare in possesso del brevetto di specialista aeronautico, in servizio presso i gruppi aerei <<antisommergibile>>, sono estese le norme che regolano l'attivita' di volo del personale dell'Aeronautica militare.

#### Art. 126. - Reparti elicotteri della Marina militare

1. I reparti elicotteri, istituiti presso la Marina militare, integrano i servizi e l'efficacia dei relativi mezzi di impiego.

2. I reparti elicotteri della Marina militare sono organicamente inseriti nei comandi e nelle unita' individuati con determinazione del Capo di stato maggiore della Marina militare.

#### Art. 127. - Utilizzo da parte della Marina militare di aerei imbarcati

1. Per integrare le capacita' di difesa delle proprie unita' navali, la Marina militare puo' utilizzare aerei imbarcati. Tali aerei, facenti organicamente parte della Marina militare, devono possedere le caratteristiche dell'impiego specialistico di Forza armata.

2. Per l'acquisizione degli aerei e per la loro immatricolazione, nonche' per il relativo supporto tecnico-logistico, la Marina militare si avvale delle competenti Direzioni generali del Ministero della difesa.

3. Rimangono ferme le competenze dell'Aeronautica militare in materia di organizzazione, direzione, coordinamento e controllo di tutti i mezzi della difesa aerea nell'area di interesse nazionale, ivi compresi gli aerei imbarcati quando chiamati a concorrere alla difesa del territorio.

#### Art. 128. - Attivita' di pilotaggio

1. Il pilotaggio degli aerei imbarcati e' affidato al personale della Marina militare che, compreso negli organici e nei contingenti dei rispettivi ruoli, e' in possesso dei previsti brevetti e delle prescritte abilitazioni militari.

2. I brevetti e le abilitazioni sono conferiti sulla base delle norme vigenti.

3. Con determinazione del Capo di stato maggiore della difesa, sentiti i Capi di stato maggiore dell'Aeronautica militare e della Marina militare, al pilotaggio degli aerei imbarcati puo' essere destinato anche personale dell'Aeronautica militare.

#### Art. 129. - Studi e approvvigionamento della Marina militare

1. La Marina militare si avvale per gli studi, le sperimentazioni e i collaudi riguardanti gli aerei destinati all'imbarco, degli organismi tecnici dell'Aeronautica militare e delle competenti Direzioni generali del Ministero della difesa.

2. La scelta dei mezzi aerei avviene in conformita' alle procedure in vigore per l'approvvigionamento degli armamenti e dei materiali destinati alla Difesa.

3. In allegato allo stato di previsione del Ministero della difesa e' presentata annualmente una relazione sullo stato di attuazione degli studi e del programma di acquisizione, con la quantificazione delle relative incidenze finanziarie.

#### Art. 130.

Istituto per le telecomunicazioni e l'elettronica della Marina militare <<Giancarlo Vallauri>>

1. Alla direzione dell'Istituto per le telecomunicazioni e l'elettronica della Marina militare <<Giancarlo Vallauri>> e' preposto un ufficiale di grado non inferiore a capitano di vascello del ((Corpo del genio della Marina, specialita' armi navali)). All'Istituto sono inoltre destinati ufficiali, sottufficiali, graduati, militari di truppa e dipendenti civili, secondo apposite tabelle stabilite dallo Stato maggiore della Marina militare. Il personale di cui al presente comma e' compreso nei rispettivi organici. ((37))

2. Sono compiti dell'Istituto:

- a) lo studio dei problemi scientifici e tecnici inerenti alle apparecchiature e ai sistemi che interessano la Marina militare nel campo delle telecomunicazioni e dell'elettronica, nonche' la compilazione delle specifiche tecniche degli apparati e delle relative installazioni e la loro omologazione;
- b) la valutazione di studi e progetti di nuove apparecchiature e nuovi sistemi nel campo dell'elettronica ai fini del loro eventuale sviluppo, nonche' il controllo, il collaudo e le prove dei prototipi e di particolari apparecchiature, sistemi e componenti elettronici ai fini della loro omologazione;
- c) l'esecuzione di studi, ricerche e sperimentazioni, anche in correlazione con altri enti delle Forze armate, istituti di ricerca e sviluppo nazionali e stranieri, nonche' con le industrie, al fine di contribuire al progresso scientifico e tecnico nella realizzazione delle apparecchiature e dei sistemi che rientrano nel campo della propria attivita';
- d) la comunicazione e le antenne; scoperta e contromisure; misura controllo strumenti. 4. Per l'assolvimento di tali compiti, l'Istituto dispone di impianti a terra costituiti da laboratori, officine e magazzini.

--------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica si applica a decorrere dal 1° gennaio 2017.

#### Art. 131. - Direzione di amministrazione della Marina militare

1. La Direzione di amministrazione della Marina militare e' posta alle dipendenze dell'Ufficio generale del Centro di responsabilita' amministrativa della Marina militare.

2. La Direzione di amministrazione di cui al comma 1, svolge le competenze di cui all'articolo 94.

3. Per l'assolvimento dei propri compiti e funzioni si avvale anche di una o piu' dipendenti sezioni, distaccate in altre sedi.

4. I compiti e le funzioni delle sezioni sono definiti con determinazione del Capo di stato maggiore della Marina militare, ai sensi dell'articolo 94.

#### Art. 131-bis. - (Ente circoli della Marina militare)

1. L'Ente circoli della Marina militare e' preposto alla direzione e all'amministrazione dei circoli ufficiali e sottufficiali della Marina militare nel rispetto della vigente normativa amministrativo-contabile e del relativo statuto, approvato con decreto del Presidente della Repubblica 1° gennaio 1949, n. 83, e successive modificazioni.

2. ((Gli ufficiali e i sottufficiali della Marina militare sono soci ordinari, iscritti di diritto ai circoli, e)) versano una quota mensile di importo determinato con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

### SEZIONE II - CORPO DELLE CAPITANERIE DI PORTO

#### Art. 132. - Istituzione e funzioni militari del Corpo delle capitanerie di porto

1. Il Corpo delle capitanerie di porto dipende dalla Marina militare, ai sensi dell'articolo 118 ed esercita, in tale ambito, le seguenti competenze:

- a) concorre alla difesa marittima e costiera, ai servizi ausiliari e logistici della Forza armata, all'applicazione delle norme del diritto internazionale marittimo e all'esercizio della polizia militare;
- b) presiede i consigli di leva marittima e ne fa parte; adempie alle operazioni per la formazione del contingente di leva; arruola e avvia gli iscritti sotto le armi; tiene i ruoli e le matricole degli uomini in congedo illimitato; compie le operazioni inerenti alla mobilitazione della Forza armata;
- c) adempie ogni altra attivita' a supporto della Forza armata in coerenza con le disposizioni del presente codice e della normativa in esso richiamata.

2. Il Corpo delle capitanerie di porto - Guardia costiera concorre, in particolare, nell'ambito della Forza armata, allo svolgimento delle seguenti attivita':

- a) assicurare la difesa dello Stato mediante: 1) la protezione delle unita' navali e delle installazioni di interesse militare; 2) il pattugliamento e la sorveglianza della fascia costiera; 3) il supporto logistico alle forze navali nazionali e Nato nei sorgitori dove non e' presente un'Autorita' della Marina militare; 4) l'esercizio della funzione di presidio militare su delega ((dei Comandi marittimi)); 5) la partecipazione di uomini e mezzi sia alle attivita' presso i centri di addestramento della Marina militare sia alle esercitazioni aeronavali; 6) il supporto ai nuclei operatori subacquei, compatibilmente con le primarie esigenze di servizio;
- b) realizzare la pace e la sicurezza internazionale mediante: 1) la partecipazione alle missioni di embargo disposte dagli organismi internazionali preposti, attraverso il controllo e le ispezioni di unita' mercantili; 2) la partecipazione al dispositivo navale di sorveglianza delle coste e delle acque interne di Paesi terzi a seguito di accordi internazionali; 3) lo svolgimento di operazioni di interdizione di carattere internazionale e di peace building nel settore della riorganizzazione dei servizi portuali e dei trasporti marittimi; 4) l'attivita' di formazione e di addestramento degli equipaggi appartenenti a marine estere;
- c) supportare l'organo cartografico di Stato (IIMM) per quanto concerne la documentazione nautica;
- d) svolgere i servizi militari attinenti al personale marittimo, alla difesa dei porti, delle installazioni militari e del naviglio mercantile indicati nel regolamento, nonche' gli altri compiti assegnati alla Marina militare.

3. Gli uffici periferici del Corpo delle capitanerie di porto - Guardia costiera dipendono, quanto ai servizi attinenti alla Marina militare, dai Comandi ((marittimi competenti per territorio)).

#### Art. 133. - (( (Comandante generale del Corpo delle capitanerie di porto). ))

((

1. Il Comandante generale del Corpo delle capitanerie di porto, e' nominato tra gli ufficiali in servizio permanente effettivo appartenenti al Corpo delle capitanerie di porto con il grado di ammiraglio ispettore, con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa, sentito il Capo di stato maggiore della difesa, e del Ministro delle infrastrutture e dei trasporti.

2. Al Comandante generale del Corpo delle capitanerie di porto, a decorrere dalla data di assunzione dell'incarico, e' conferito il grado di ammiraglio ispettore capo in sovrannumero rispetto alle dotazioni organiche e, in deroga a quanto previsto dall'articolo 1078, senza determinare vacanza organica nel grado inferiore. Rimane in carica per almeno due anni e, ove raggiunto dal limite di eta', e' richiamato in servizio d'autorita' fino al termine del mandato.

3. Il Comandante generale del Corpo delle capitanerie di porto, nella qualita' di Capo di corpo, dipende dal Capo di stato maggiore della Marina militare per gli aspetti tecnico-militari attinenti al Corpo.

))

#### Art. 134. - Esercizio di funzioni dipendenti dal Ministero delle infrastrutture e dei trasporti

1. Il Corpo delle capitanerie di porto - Guardia costiera:

- a) esercita le competenze relative alle materie del Ministero delle infrastrutture e dei trasporti per cui la legge e altre disposizioni normative prevedono la diretta attribuzione allo stesso;
- b) svolge, in regime di avvalimento, le attivita' a esso conferite nei settori riconducibili al competente Dipartimento per i trasporti, la navigazione e i sistemi informativi e statistici del Ministero delle infrastrutture e dei trasporti.

2. Nell'ambito delle funzioni di cui al comma 1, il Corpo delle capitanerie di porto - Guardia costiera, attraverso le proprie articolazioni periferiche:

- a) svolge la funzione generale di Autorita' marittima ai sensi del codice della navigazione;
- b) ferme restando le attribuzioni in materia di coordinamento generale dei servizi di soccorso marittimo, di cui all'articolo 3, comma 1, lettera a), del decreto del Presidente della Repubblica 28 settembre 1994, n. 662, e' competente per l'esercizio delle funzioni di ricerca e salvataggio in mare, ai sensi degli articoli 69, 70 e 830 del codice della navigazione, di disciplina, monitoraggio e controllo del traffico navale, di sicurezza della navigazione e del trasporto marittimo, nonche' delle relative attivita' di vigilanza e controllo, ai sensi del codice della navigazione, della legge 28 dicembre 1989, n. 422 e delle altre leggi speciali.

3. Il Corpo delle capitanerie di porto - Guardia costiera esercita ulteriori funzioni relativamente alle seguenti materie:

- a) comando dei porti ed esercizio delle funzioni di Autorita' di sicurezza in materia di prevenzione da minacce, ai sensi del decreto legislativo 6 novembre 2007, n. 203;
- b) polizia nei porti e in corso di navigazione;
- c) sicurezza generale nei porti e nelle relative adiacenze, ai sensi dell'articolo 81 del codice della navigazione e, nei termini previsti dall'articolo 82 del predetto codice, sulle navi in porto e in corso di navigazione nel mare territoriale;
- d) polizia marittima;
- e) demanio marittimo ed esercizio dei relativi poteri di polizia amministrativa;
- f) personale marittimo;
- g) regime amministrativo della nave;
- h) diporto nautico;
- i) soccorso e polizia di sicurezza della navigazione nei laghi e nelle acque interne;
- l) autorita' portuale nei porti in cui non e' istituita un'Autorita' portuale;
- m) servizi tecnico - nautici;
- n) sicurezza delle attivita' lavorative nei porti e a bordo di navi, ai sensi del decreto legislativo 9 aprile 2008, n. 81 ((, ed esercizio delle potesta' organizzative e dei poteri di vigilanza in materia di sicurezza dei luoghi di lavoro nell'ambito delle proprie strutture e dei propri mezzi operativi));
- o) attivita' ispettiva in funzione di Port State Control Flag State, rispettivamente ai sensi delle direttive 2009/16/CE, 2009/15/CE e 106/2001/CE e successive modifiche;
- p) indagini e inchieste sui sinistri marittimi al fine di individuarne cause, circostanze e responsabilita' in linea con la previsione del codice della navigazione e del relativo regolamento di esecuzione, nonche' ai sensi del decreto legislativo 2 febbraio 2001, n. 28;
- q) responsabilita' civile per i danni dovuti a inquinamenti da combustibile delle navi;
- r) altre materie previste dal codice della navigazione e dalle altre leggi speciali che demandano al Corpo specifiche funzioni.

#### Art. 135. - Esercizio di funzioni dipendenti dal Ministero dell'ambiente, della tutela del territorio e del mare

1. Il Corpo delle capitanerie di porto - Guardia costiera dipende funzionalmente dal Ministero dell'ambiente, della tutela del territorio e del mare, ai sensi dell'articolo 8 della legge 8 luglio 1986, n. 349, e dell'articolo 3 della legge 28 gennaio 1994, n. 84, esercitando funzioni di vigilanza e controllo in materia di tutela dell'ambiente marino e costiero.

2. In dipendenza delle attribuzioni di cui al comma 1, e fermo restando quanto previsto dall'articolo 12 del decreto legislativo 6 novembre 2007, n. 202, il Corpo delle capitanerie di porto - Guardia costiera esercita, in particolare, le sottoelencate funzioni:

- a) nelle zone sottoposte alla giurisdizione nazionale svolge, in via prevalente, le attivita' di controllo relative all'esatta applicazione delle norme del diritto italiano, del diritto dell'Unione europea e dei trattati internazionali in vigore per l'Italia in materia di prevenzione e repressione di tutti i tipi di inquinamento marino, ivi compresi l'inquinamento da navi e da acque di zavorra, l'inquinamento da immersione di rifiuti, l'inquinamento da attivita' di esplorazione e di sfruttamento dei fondi marini e l'inquinamento di origine atmosferica, nonche' in materia di protezione dei mammiferi e della biodiversita';
- b) nelle acque di giurisdizione e di interesse nazionale esercita, per fini di tutela ambientale e di sicurezza della navigazione, ai sensi della legge 7 marzo 2001, n. 51, il controllo del traffico marittimo;
- c) provvede, ai sensi degli articoli 135, 2° comma, e 195, 5° comma, del decreto legislativo 3 aprile 2006, n. 152, alla sorveglianza e all'accertamento delle violazioni in materia di tutela delle acque dall'inquinamento e di gestione delle risorse idriche se dalle stesse possono derivare danni o situazioni di pericolo per l'ambiente marino e costiero, nonche' alla sorveglianza e all'accertamento degli illeciti in violazione della normativa in materia di rifiuti e alla repressione dei traffici illeciti e degli smaltimenti illegali dei rifiuti;
- d) esercita, ai sensi dell'articolo 19 della legge 6 dicembre 1991, n. 394, la sorveglianza nelle aree marine protette e sulle aree di reperimento;
- e) ai sensi dell'articolo 296, comma 9, del decreto legislativo 3 aprile 2006, n. 152, in relazione al tenore di zolfo dei combustibili per uso marittimo, accerta le violazione e irroga le sanzioni di cui ai commi da 5 a 8 del predetto articolo;
- f) per le attivita' di cui agli articoli 11 e 12 della legge 31 dicembre 1982, n. 979, attraverso la sua organizzazione periferica a livello di compartimento marittimo, opera, ai sensi della legge 16 luglio 1998, n. 239, articolo 7, sulla base di direttive vincolanti, generali e specifiche, del Ministero dell'ambiente, della tutela del territorio e del mare; in forza della medesima disposizione normativa per altri interventi e attivita' in materia di tutela e difesa del mare, il Ministero dell'ambiente, della tutela del territorio e del mare puo' avvalersi anche del Corpo delle capitanerie di porto, sulla base di specifiche convenzioni.

#### Art. 136. - Esercizio di funzioni dipendenti dal Ministero delle politiche agricole, alimentari e forestali

1. Il Corpo delle capitanerie di porto - Guardia costiera dipende funzionalmente dal Ministero delle politiche agricole, alimentari e forestali, ai sensi del decreto legislativo 26 maggio 2004, n. 153, per l'esercizio delle funzioni delegate in materia di pesca marittima.

2. In dipendenza delle attribuzioni di cui al comma 1, il Corpo delle capitanerie di porto - Guardia costiera esercita, in particolare, le sottoelencate funzioni:

- a) direzione, vigilanza e controllo sulla filiera della pesca, ai sensi dell'articolo 21 della legge 14 luglio 1965, n. 963;
- b) attivita' amministrativa in materia di pesca marittima sulla base di direttive impartite dal Ministero delle politiche agricole, alimentari e forestali, ai sensi dell'articolo 7, comma 1, del decreto legislativo 26 maggio 2004, n. 153;
- c) in base a quanto disposto dall'articolo 7, comma 2, del citato decreto legislativo 26 maggio 2004, n. 153, centro di controllo nazionale della pesca, sulla base degli indirizzi concertati con le Regioni e in aderenza ai principi generali di cui all'articolo 118 della Costituzione;
- d) vigilanza e controllo sull'esatto adempimento delle norme relative alle provvidenze in materia di pesca previste dalla normativa nazionale e comunitaria;
- e) verifica della corretta applicazione delle norme sul commercio di prodotti ittici e biologici marini;
- f) partecipazione, mediante personale specializzato, alle attivita' di verifica sull'esatto adempimento della normativa comunitaria in materia di pesca, in base alla pianificazione, e alle discendenti fasi operative, disposte dai competenti organi comunitari.

#### Art. 137. - Esercizio di funzioni dipendenti da altri Ministeri

1. Il Corpo delle capitanerie di porto - Guardia costiera svolge, nell'ambito delle attribuzioni di polizia giudiziaria previste dall'articolo 1235 del codice della navigazione e da altre leggi speciali, nonche' ai sensi dell'articolo 57, comma 3, del codice di procedura penale, le sottoelencate funzioni, riconducibili nelle piu' generali competenze di altri ministeri:

- a) esercita l'attivita' di polizia stradale, ai sensi dell'articolo 12, comma 3, lettera f), del decreto legislativo 30 aprile 1992, n. 285;
- b) presta, ai sensi dell'articolo 11 della legge 24 febbraio 1992, n. 225, nell'ambito della struttura permanente presso il Dipartimento della protezione civile, la necessaria collaborazione operativa per la pianificazione e la gestione delle emergenze in mare; ((51))
- c) concorre nell'attivita' di contrasto al traffico di sostanze stupefacenti o psicotrope, nei termini stabiliti dagli articoli 5 e 99 del decreto del Presidente della Repubblica 9 ottobre 1990, n. 309;
- d) concorre nell'attivita' di contrasto all'immigrazione illegale, ai sensi dell'articolo 11, comma 1, lettera d), della legge 30 luglio 2002, n. 189;
- e) concorre alla vigilanza finalizzata all'individuazione e alla salvaguardia dei beni del patrimonio storico, artistico e archeologico, con particolare riguardo ai reperti archeologici sommersi;
- f) attua le competenze a esso demandate in materia di disciplina del collocamento della gente di mare.

--------------- AGGIORNAMENTO (51) Il D.Lgs. 2 gennaio 2018, n. 1 ha disposto (con l'art. 47, comma 1, lettera h)) che "Tutti i riferimenti alla legge 24 febbraio 1992, n. 225 e ai relativi articoli, contenuti in altre disposizioni, si intendono riferiti al presente decreto e ai corrispondenti articoli. In particolare: [...] h) l'articolo 11 della legge n. 225 del 1992, citato nell'articolo 92, comma 1, e nell'articolo 137, comma 1, del decreto legislativo 15 marzo 2010 n. 66, deve intendersi riferito all'articolo 13 del presente decreto".

#### Art. 138. - Profili organizzativi e funzionali

1. L'esercizio a livello centrale e periferico, da parte del Corpo delle capitanerie di porto, delle competenze di cui agli articoli 134, 135, 136 e 137, avviene mediante le proprie risorse umane e strumentali.

2. Il Corpo delle capitanerie di porto e' soggetto alle misure organizzative e funzionali adottate ai sensi dell'articolo 26 del decreto-legge 30 dicembre 2008, n. 207, convertito, con modificazioni, dalla legge 22 febbraio 2009, n. 14, nel rispetto dei principi e criteri direttivi che vi sono enunciati. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 01/06/2010, n. 126 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

## CAPO IV - AERONAUTICA MILITARE

### Art. 139. - Istituzione e funzioni dell'Aeronautica militare

1. L'Aeronautica militare, quale complesso delle forze militari aeree, delle basi aeree, delle scuole, dei servizi ed enti aeronautici, costituisce la componente operativa aerea della difesa militare dello Stato.

### Art. 140. - Ispettorato per la sicurezza del volo

1. L'Ispettorato per la sicurezza del volo dipende direttamente dal Capo di stato maggiore dell'Aeronautica militare e coordina l'investigazione, al fine della prevenzione, sulle cause degli incidenti di volo degli aeromobili di cui all'articolo 748 del codice della navigazione.

2. L'Ispettorato e' articolato in uffici, le cui competenze sono stabilite con determinazione del Capo di stato maggiore dell'Aeronautica militare.

### Art. 141. - Ispettorato dell'Aviazione per la Marina militare

1. L'ispettore dell'Aviazione per la Marina militare, ufficiale generale del ruolo naviganti normale dell'Aeronautica, sovrintende, per conto dello Stato maggiore dell'Aeronautica militare, alle attivita' tecniche e logistiche dei reparti di aviazione antisommergibile di cui all'articolo 125 e del relativo addestramento tecnico professionale.

2. Le attribuzioni dell'Ispettore dell'Aviazione per la Marina militare sono definite con determinazione del Capo di stato maggiore dell'Aeronautica militare, sentito il Capo di stato maggiore della Marina militare.

### Art. 142. - Comando della squadra aerea

1. Il Comando della squadra aerea, retto da un generale di squadra aerea e posto alle dirette dipendenze del Capo di stato maggiore dell'Aeronautica militare, esercita le attribuzioni in materia di addestramento, predisposizione e approntamento operativo dei reparti, affinche' gli stessi acquisiscano e mantengano i previsti livelli di prontezza operativa.

((

1-bis. Il Comandante della squadra aerea e' nominato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa, sentito il Capo di stato maggiore della difesa.

))

2. L'articolazione del Comando, le sedi, l'ordinamento e le funzioni delle unita' e dei reparti dipendenti sono stabiliti con determinazione del Capo di stato maggiore dell'Aeronautica militare.

### Art. 143. - (( (Comando e controllo operativo delle Forze aeree).))

((

1. Il Comando della squadra aerea esercita, altresi', le funzioni di comando e controllo connesse con le operazioni o esercitazioni aeree d'interesse della Forza armata; il relativo Comandante espleta la funzione di Comandante operativo delle Forze aeree e designa, quando previsto, il Comandante operativo delle Forze aeree interalleate.

2. Il Comando della squadra aerea si integra con il relativo comando interalleato.

))

### Art. 144. - Articolazione territoriale dell'Aeronautica militare

1. Sono posti alle dipendenze del Capo di stato maggiore dell'Aeronautica militare i comandi di regione aerea, retti da ufficiali generali; il Capo di stato maggiore ne disciplina le funzioni territoriali e i compiti di collegamento con gli enti e le amministrazioni locali.

2. L'articolazione dei comandi, le sedi, l'ordinamento e le funzioni delle unita' e dei reparti dipendenti, sono stabiliti con determinazione del Capo di stato maggiore dell'Aeronautica militare.

### Art. 145. - Comando logistico dell'Aeronautica militare

1. Il Comando logistico, posto alle dirette dipendenze del Capo di stato maggiore dell'Aeronautica militare, costituisce il vertice della struttura tecnica, logistica e amministrativa della Forza armata, e garantisce il supporto necessario a consentire la massima operativita' della stessa.

2. L'articolazione e i compiti del Comando, le sedi, l'ordinamento e le funzioni degli enti dipendenti, sono stabiliti con determinazione del Capo di stato maggiore dell'Aeronautica militare.

### Art. 146. - Comando delle scuole dell'Aeronautica militare

1. Il Comando delle scuole dell'Aeronautica militare, retto da un generale di squadra e posto alle dipendenze del Capo di stato maggiore dell'Aeronautica militare, esercita le attribuzioni in materia di reclutamento, selezione, formazione, qualificazione specialistica basica del personale dell'Aeronautica militare appartenente a tutte le categorie, nonche' l'addestramento iniziale al volo del personale navigante anche di altre Forze armate o di polizia, finalizzato al conseguimento del brevetto di pilota o navigatore militare.

2. Dal Comando delle scuole dipendono:

- a) l'Istituto di scienze militari aeronautiche;
- b) l'Accademia aeronautica;
- c) la Scuola marescialli dell'Aeronautica militare;
- d) la Scuola specialisti dell'Aeronautica militare;
- e) la Scuola volontari ((...)) dell'Aeronautica militare;
- f) la Scuola militare aeronautica "Giulio Douhet".

((

3. Le sedi, l'ordinamento e le funzioni dei comandi e degli enti di cui al comma 1, sono definiti con determinazione del Capo di stato maggiore dell'Aeronautica.

))

### Art. 147. - Ruoli e Corpi dell'Aeronautica militare

1. L'Aeronautica militare si compone dei seguenti elementi:

- a) Arma aeronautica, articolata in ruoli, naviganti e armi, e specialita';
- b) Corpo del genio aeronautico;
- c) Corpo di commissariato aeronautico;
- d) Corpo sanitario aeronautico.

2. Gli articoli 148, 149 e 150 stabiliscono, rispettivamente, la ripartizione e le attribuzioni degli elementi di cui al comma 1, lettere b), c) e d).

### Art. 148. - Corpo del genio aeronautico

1. Il Corpo del genio aeronautico e' costituito dagli ufficiali del genio aeronautico ed esercita funzioni tecniche inerenti:

- a) alla progettazione, alla costruzione, all'allestimento e all'armamento dei materiali aeronautici di qualsiasi specie, compresi gli immobili dell'Aeronautica militare;
- b) al collaudo e alla manutenzione del materiale aeronautico e degli stessi immobili dell'Aeronautica militare;
- c) disimpegna ogni altro servizio tecnico inerente all'impiego degli aeromobili militari ed esercita vigilanza tecnica sul materiale aeronautico dell'aviazione civile.

2. Il genio aeronautico presiede al funzionamento tecnico e amministrativo:

- a) delle direzioni delle costruzioni aeronautiche e dei dipendenti uffici distaccati di sorveglianza;
- b) delle direzioni del demanio aeronautico dei comandi di zona aerea e dei comandi dell'Aeronautica militare;
- c) di impianti sperimentali e stabilimenti vari.

### Art. 149. - Corpo di commissariato aeronautico

1. Il Corpo di commissariato aeronautico:

- a) esercita funzioni direttive, ispettive, logistiche, tecniche, amministrative e contabili per i servizi del contante, del vettovagliamento, del vestiario ed equipaggiamento, del casermaggio nonche' degli altri materiali ordinari;
- b) svolge attivita' di studio, ricerca e sviluppo tecnico nei settori di specifico interesse e assolve funzioni in materia giuridica, economica e finanziaria; ricopre incarichi previsti dagli ordinamenti.

2. Il Corpo di commissariato aeronautico presiede al funzionamento tecnico e amministrativo:

- a) delle direzioni di commissariato aeronautico, dei comandi di zona aerea e dei comandi dell'Aeronautica militare;
- b) di magazzini e stabilimenti vari.

### Art. 150. - Corpo sanitario aeronautico

1. Il Corpo sanitario aeronautico, costituito dagli ufficiali medici ((dell'Aeronautica)), esercita funzioni direttive e tecnico-professionali intese:

- a) ad accertare la idoneita' psico-fisica, attraverso servizi generali e speciali, del personale dell'Aeronautica militare, l'idoneita' al volo ((e ai servizi di navigazione aerea)) del personale militare e di altre pubbliche amministrazioni, nonche' l'idoneita' psico-fisica e la persistenza di tale idoneita' degli aspiranti al conseguimento di licenze e attestati aeronautici;
- b) a curare l'integrita' fisica e tutelare l'igiene del personale dell'Aeronautica militare, provvedendo, a tali fini, all'allestimento e ai rifornimenti dei servizi e dei materiali occorrenti;
- c) allo svolgimento delle pratiche medico-legali interessanti il personale dell'Aeronautica militare.

2. Il Corpo sanitario aeronautico presiede al funzionamento tecnico e amministrativo:

- a) degli istituti ((di medicina aerospaziale)) dell'Aeronautica militare;
- b) dei servizi sanitari ordinativamente costituiti;
- c) di magazzini e stabilimenti vari.

3. Per le infermita' di carattere generale, si provvede altresi' al servizio sanitario dell'Aeronautica militare, con gli stabilimenti sanitari dell'Esercito italiano e della Marina militare, previ accordi con gli stati maggiori interessati.

### Art. 151. - Unita' e comandi di volo dell'Aeronautica militare

1. I reparti di volo si distinguono, secondo il livello ordinativo, in:

- a) squadriglia, unita' organica fondamentale;
- b) gruppo;
- c) stormo;
- d) brigata aerea;
- e) divisione aerea;
- f) squadra aerea.

2. La squadra, la divisione e la brigata costituiscono le grandi unita' aeree.

3. Le sedi, l'ordinamento e le funzioni delle unita' e dei reparti di cui al comma 1 sono stabiliti con determinazione del Capo di stato maggiore dell'Aeronautica militare.

### Art. 152. - Aviazione antisommergibile dell'Aeronautica militare

1. L'aviazione antisommergibile e' costituita dal complesso degli aerei e degli equipaggi, dei mezzi e del personale tecnico a terra, specificamente destinati a condurre azioni aeree nella lotta contro i sommergibili.

2. I comandanti dei gruppi e delle squadriglie <<antisommergibile>> sono ufficiali dei ruoli naviganti dell'Arma aeronautica. Il pilotaggio di ciascun aereo e' affidato a ufficiali dei ruoli naviganti dell'Arma aeronautica e a ufficiali di Marina piloti; le funzioni di primo pilota e il comando dell'aereo sono affidati al piu' elevato in grado o piu' anziano di detti ufficiali.

### Art. 153. - (( (Reparti elicotteri delle altre Forze armate). ))

((

1. L'Aeronautica militare provvede, anche nel campo degli elicotteri, al controllo della circolazione aerea e alla determinazione delle procedure e norme inerenti a tale circolazione, nonche' all'organizzazione, funzionamento ed esercizio del soccorso aereo e del trasporto aereo, salva la facolta' da parte delle altre Forze armate di utilizzare gli elicotteri di cui dispongono per esigenze contingenti di soccorso e di trasporto riguardanti le proprie unita'.

2. All'Aeronautica militare competono, inoltre:

- a) la direzione e il coordinamento dell'impiego degli elicotteri in quelle attivita' militari che comportino il concorso di elicotteri di piu' Forze armate;
- b) il rilascio dei brevetti militari di pilota o pilota osservatore di elicottero e di specialista di elicottero o delle abilitazioni all'esercizio del volo sui vari tipi di elicotteri, nonche', ricorrendone le circostanze, il ritiro dei brevetti o la sospensione temporanea dall'attivita' di volo dei titolari degli stessi.

))

### Art. 154. - Direzione di amministrazione dell'Aeronautica militare

1. La Direzione di amministrazione ((e' posta alle dipendenze dell'Ufficio generale centro di responsabilita' amministrativa dell'Aeronautica militare e)) assolve i seguenti compiti:

- a) assicura il finanziamento degli enti attraverso la disponibilita' dei fondi accreditati dall'amministrazione centrale sulle apposite contabilita' speciali e la resa dei relativi conti;
- b) svolge le funzioni di natura giuridico amministrativa devolute in relazione all'ordinamento di Forza armata;
- c) esercita l'azione di controllo amministrativo nei confronti degli enti sia in sede ispettiva sia in sede di revisione degli atti di gestione anche per conto dell'Ufficio centrale del bilancio presso il Ministero della difesa.

## CAPO V - ARMA DEI CARABINIERI

### SEZIONE I - COMPITI E ATTRIBUZIONI

#### Art. 155. - Istituzione e funzioni dell'Arma dei carabinieri

1. L'Arma dei carabinieri ha collocazione autonoma nell'ambito del Ministero della difesa, con rango di Forza armata ed e' forza militare di polizia a competenza generale e in servizio permanente di pubblica sicurezza, con le speciali prerogative conferite dalla normativa vigente. ((Ai sensi dell'articolo 3 della legge 14 maggio 2010, n. 84, e' la Forza di polizia italiana a statuto militare per la Forza di gendarmeria europea (EUROGENDFOR).))

#### Art. 156. - Compiti militari dell'Arma dei carabinieri

1. L'Arma dei carabinieri, sulla base delle direttive del Capo di stato maggiore della difesa:

- a) concorre all'attuazione delle predisposizioni di mobilitazione delle Forze armate di cui all'articolo 88;
- b) concorre alla difesa integrata del territorio nazionale; il concorso e' definito dai Capi di stato maggiore di Forza Armata, responsabili dell'approntamento e dell'impiego dei rispettivi dispositivi di difesa, in accordo con il Comandante generale dell'Arma dei carabinieri;
- c) partecipa alle operazioni militari all'estero.

2. Nell'ambito delle operazioni di cui al comma 1, lettera c), l'Arma dei carabinieri:

- a) partecipa anche a operazioni per il mantenimento e il ristabilimento della pace e della sicurezza internazionale, al fine, in particolare, di realizzare condizioni di sicurezza e ordinata convivenza nelle aree d'intervento;
- b) concorre ad assicurare il contributo nazionale alle attivita' promosse dalla comunita' internazionale o derivanti da accordi internazionali, volte alla ricostituzione e al ripristino dell'operativita' dei corpi di polizia locali nelle aree di presenza delle Forze armate, assolvendo compiti di addestramento, consulenza, assistenza e osservazione.

3. I compiti connessi con la partecipazione alle operazioni militari e le esigenze di carattere militare, di cui al presente articolo, sono assolti sulla base delle direttive e dei rapporti di dipendenza operativi stabiliti dal Capo di stato maggiore della difesa e limitatamente al concorso alla difesa integrata del territorio.

4. Nell'ambito dei compiti militari, l'Arma dei carabinieri:

- a) concorre alla tutela del bene della collettivita' nazionale in casi di pubbliche calamita';
- b) fornisce all'autorita' individuata dal Presidente del Consiglio dei ministri, nell'esercizio delle funzioni di cui all'articolo 1 della legge 3 agosto 2007, n. 124, elementi informativi necessari per il rilascio delle abilitazioni di sicurezza agli appartenenti alle Forze armate, al personale civile dell'Amministrazione della difesa, nonche' alle persone fisiche e giuridiche per lo svolgimento di attivita' produttive attinenti alla sicurezza militare dello Stato.

#### Art. 157. - Funzioni di polizia giudiziaria militare dell'Arma dei carabinieri

1. L'Arma dei carabinieri esercita le funzioni di polizia giudiziaria militare, secondo quanto stabilito dall'articolo 91, ferme restando le attribuzioni e le qualifiche dei Comandanti di corpo, di distaccamento o di posto delle varie Forze armate.

#### Art. 158. - Sicurezza delle rappresentanze diplomatiche e consolari e degli uffici degli addetti militari all'estero

1. L'Arma dei carabinieri assicura i servizi di sicurezza delle rappresentanze diplomatiche e consolari, nonche' degli uffici degli addetti militari all'estero.

2. Concorre, inoltre, ad affrontare particolari situazioni di emergenza o di crisi, locali o internazionali, che dovessero mettere in pericolo la sicurezza delle suddette rappresentanze, assicurando la disponibilita' di personale appartenente a reparti speciali.

3. L'impiego del personale di cui al comma 2 e' disposto sulla base delle direttive del Capo di stato maggiore della difesa.

#### Art. 159. - Compiti d'istituto dell'Arma dei carabinieri

1. L'Arma dei carabinieri, quale Forza militare di polizia ai sensi dell'articolo 155:

- a) assicura il mantenimento dell'ordine pubblico, della sicurezza dei cittadini, della loro incolumita' e della tutela della proprieta', ai sensi della legislazione vigente;
- b) svolge le funzioni di struttura operativa del servizio nazionale di protezione civile, ai sensi della legge 24 febbraio 1992, n. 225;
- c) espleta gli altri compiti previsti dalla normativa vigente.

#### Art. 160. - Speciali compiti dell'Arma dei carabinieri

1. L'Arma dei carabinieri provvede, altresi':

- a) ai servizi presso la Presidenza della Repubblica;
- b) alle scorte d'onore;
- c) ai servizi presso gli uffici giudiziari.

#### Art. 161. - ((Funzioni di polizia giudiziaria, di sicurezza pubblica e di polizia forestale, ambientale e agroalimentare dell'Arma dei carabinieri))

1. L'Arma dei carabinieri esercita, ai sensi della normativa vigente:

- a) funzioni di polizia giudiziaria;
- b) funzioni di sicurezza pubblica.

((1-bis. L'Arma dei carabinieri esercita altresi' le funzioni di polizia forestale, ambientale e agroalimentare ai sensi del decreto legislativo 19 agosto 2016, n. 177, fermi restando gli specifici compiti attribuiti in materia dalla normativa vigente ad altre amministrazioni dello Stato))

#### Art. 161-bis. - ((Personale ispettivo con compiti di polizia ambientale))

((

1. Per le esigenze connesse all'esercizio delle funzioni di polizia ambientale dell'Arma dei carabinieri, con decreto del Ministro della difesa e del Ministro dell'ambiente e della sicurezza energetica, di concerto con il Ministro dell'interno, sono stabiliti le competenze del personale ispettivo e i criteri generali per lo svolgimento delle attivita' ispettive, prevedendo il principio della rotazione del medesimo personale nell'esecuzione delle visite nei singoli siti o impianti, al fine di garantire la terzieta' dell'intervento ispettivo.

2. In relazione alle attivita' di cui al comma 1, con determinazione del Comandante generale dell'Arma dei carabinieri sono individuati:

a) il personale incaricato degli interventi ispettivi svolti ai sensi della vigente normativa internazionale, dell'Unione europea, nazionale e regionale in materia ambientale;

b) i requisiti che il predetto personale deve possedere nonche' le relative attivita' di formazione e aggiornamento))

#### Art. 161-ter. - (( (Personale ispettivo con compiti di polizia agroalimentare). ))

((

1. Per le esigenze connesse all'esercizio delle funzioni di polizia agroalimentare dell'Arma dei carabinieri, con decreto del Ministro della difesa e del Ministro dell'agricoltura, della sovranita' alimentare e delle foreste, di concerto con il Ministro dell'interno, sono stabilite le competenze del personale ispettivo e i criteri generali per lo svolgimento delle attivita' ispettive, prevedendo il principio della rotazione del medesimo personale nell'esecuzione delle visite nei singoli siti, al fine di garantire la terzieta' dell'intervento ispettivo.

2. In relazione alle attivita' di cui al comma 1, con determinazione del Comandante generale dell'Arma dei carabinieri sono individuati:

- a) il personale incaricato degli interventi ispettivi svolti ai sensi della vigente normativa internazionale, dell'Unione europea, nazionale e regionale in materia agroalimentare;
- b) i requisiti che il predetto personale deve possedere, nonche' le relative attivita' di formazione e aggiornamento.

))

### SEZIONE II - ORDINAMENTO

#### Art. 162. - Dipendenze dell'Arma dei carabinieri

1. L'Arma dei carabinieri dipende:

- a) tramite il Comandante generale, dal Capo di stato maggiore della difesa per quanto attiene ai compiti militari;
- b) funzionalmente dal Ministro dell'interno, per quanto attiene ai compiti di tutela dell'ordine e della sicurezza pubblica.

2. Per gli aspetti tecnico-amministrativi, l'Arma dei carabinieri fa capo:

- a) al Ministero della difesa per quanto concerne il personale, l'amministrazione e le attivita' logistiche;
- b) al Ministero dell'interno per l'accasermamento e il casermaggio connessi con l'assolvimento dei compiti indicati al comma 1, lettera b), nonche' per l'utilizzazione delle risorse finanziarie finalizzate al potenziamento delle Forze di polizia.

3. I reparti dell'Arma costituiti nell'ambito di dicasteri, organi o autorita' nazionali per l'assolvimento di compiti specifici dipendono funzionalmente dai titolari dei dicasteri, organi e autorita' ((, fermo restando quanto previsto dal comma 2-bis dell'articolo 174-bis)). I reparti e gli uffici dell'Arma costituiti nell'ambito interforze, dei comandi e degli organismi alleati in Italia e all'estero ovvero delle Forze armate, dipendono, tramite i relativi comandanti, rispettivamente dal Capo di stato maggiore della difesa e dai Capi di stato maggiore di Forza armata.

#### Art. 163. - Comandante generale dell'Arma dei carabinieri

1. Il Comandante generale e' componente, oltre che degli organismi collegiali previsti dal codice e dal regolamento:

- a) del Comitato nazionale dell'ordine e della sicurezza pubblica, ai sensi dell'articolo 18 della legge 1° aprile 1981, n. 121;
- b) del Consiglio generale per la lotta alla criminalita' organizzata, ai sensi dell'articolo 1 del decreto-legge 29 ottobre 1991, n. 345, convertito, con modificazioni, dall'articolo 1 della legge 30 dicembre 1991, n. 410.

#### Art. 164. - Attribuzioni del Comandante generale dell'Arma dei carabinieri in campo operativo, addestrativo e tecnico logistico

1. Il Comandante generale e' organo centrale di sicurezza dell'Arma dei carabinieri e sulla base delle direttive del Capo di stato maggiore della difesa:

- a) individua i reparti e il personale da impiegare per l'assolvimento dei compiti connessi con le funzioni di polizia militare e la partecipazione a operazioni militari in Italia e all'estero, e ne assicura la disponibilita', nonche' l'autonomia logistica, fermo restando l'assolvimento degli altri compiti istituzionali previsti dal codice, ed e' responsabile del relativo addestramento e approntamento;
- b) formula le proposte di competenza per la pianificazione operativa;
- c) determina, relativamente all'Arma dei carabinieri, le modalita' attuative della mobilitazione e l'entita' delle relative scorte;
- d) concorda con la Direzione generale competente la designazione del personale civile, ferme restando le attribuzioni del Segretario generale della difesa;
- e) assicura, per l'esecuzione di operazioni ed esercitazioni, nazionali e multinazionali, la disponibilita' quantitativa e qualitativa delle forze stabilite dal Capo di stato maggiore della difesa, individuando i relativi reparti; in tale quadro, definisce l'attivita' addestrativa ed esercita, anche avvalendosi dei comandi dipendenti, le funzioni, se delegate, di comando operativo per le operazioni e le esercitazioni dell'Arma dei carabinieri;
- f) e' responsabile dell'organizzazione e dell'approntamento delle unita' e dei reparti dell'Arma anche per l'assolvimento degli impegni derivanti da accordi e trattati internazionali;
- g) dispone il concorso dell'Arma dei carabinieri alla difesa integrata del territorio nazionale;
- h) promuove lo svolgimento di percorsi di formazione presso altre scuole delle amministrazioni statali, nonche' presso soggetti pubblici e privati, e di periodi di studio presso amministrazioni e istituzioni dei Paesi dell'Unione europea e organizzazioni internazionali.

2. Il Comandante generale:

- a) fermo restando quanto disposto dall'articolo 177, determina l'ordinamento, le circoscrizioni territoriali, gli organici e le modalita' di funzionamento dei comandi, reparti, unita', istituti ed enti vari, emanando le relative disposizioni nei settori di attivita' tecnico-operativa;
- b) determina l'istituzione o la soppressione di posti fissi o stazioni temporanee;
- c) approva i programmi e impartisce le disposizioni riguardanti l'addestramento e il perfezionamento della preparazione professionale del personale dell'Arma;
- d) approva le pubblicazioni dell'Arma dei carabinieri.

3. Il Comandante generale, nel settore tecnico-logistico:

- a) determina le politiche di impiego, di gestione e di mantenimento del parco, le dotazioni e le scorte, la regolamentazione tecnica;
- b) sentito, su iniziativa del Capo di stato maggiore della difesa, il Comitato dei Capi di stato maggiore delle Forze armate, determina: 1) le linee di pianificazione e programmazione tecnica; 2) i programmi, le ricerche, gli studi e le sperimentazioni; 3) l'adozione di nuovi materiali specifici per le esigenze dell'Arma.

4. Allo scopo di assicurare efficienza, economicita', speditezza e rispondenza al pubblico interesse delle attivita' istituzionali dell'Arma dei carabinieri, il Comandante generale adotta misure di razionalizzazione dell'organizzazione, della gestione e del funzionamento del sostegno tecnico, logistico e amministrativo tese al recupero di personale da destinare al servizio d'istituto e al miglioramento del supporto dei reparti, prevedendo anche l'affidamento di servizi a terzi, nei limiti degli ordinari stanziamenti di bilancio.

5. Al fine di pervenire all'attuazione dei necessari adeguamenti delle procedure tecniche, logistiche e amministrative in relazione alle specifiche esigenze dell'Arma dei carabinieri, il Ministro della difesa stabilisce con proprio decreto i settori nei quali il Comandante generale, d'intesa con il Segretariato generale della difesa, e' autorizzato a procedere alla revisione delle relative discipline di carattere amministrativo.

#### Art. 165. - Attribuzioni del Comandante generale in materia di reclutamento, stato, avanzamento e impiego

1. Il Comandante generale, ferme le altre competenze e attribuzioni in materia di impiego, reclutamento, stato, avanzamento e disciplina del personale, previste dal codice, propone al Capo di stato maggiore della difesa le destinazioni dei generali di corpo d'armata e, per le esigenze in ambito Difesa:

- a) i generali di grado non inferiore a generale di divisione da destinare agli incarichi di direzione degli uffici di livello dirigenziale generale, fermo restando quanto previsto dall'articolo 89 del regolamento;
- b) gli ufficiali da destinare all'impiego in ambito internazionale, in incarichi interforze e in altri dicasteri.

2. Il Comandante generale determina le destinazioni degli ufficiali dipendenti, previo nulla osta del Ministro dell'interno per quelli trasferiti da o per l'organizzazione territoriale e gli organismi interforze di polizia, dandone preventiva comunicazione al Capo di stato maggiore della difesa per i generali di divisione e di brigata.

3. Il Comandante generale e' presidente della commissione superiore e vice presidente della commissione di vertice per l'avanzamento degli ufficiali dei carabinieri, indica al Capo di stato maggiore della difesa gli ufficiali generali da proporre al Ministro della difesa quali componenti delle commissioni di vertice e superiore d'avanzamento, e propone al Ministro della difesa gli ufficiali da designare quali componenti della commissione ordinaria d'avanzamento.

4. Il Comandante generale ((esprime in maniera motivata il)) parere sulla concessione delle ricompense al valore e al merito dell'Arma dei carabinieri.

5. Il Comandante generale puo' ordinare direttamente l'inchiesta formale nei confronti del personale dipendente e designa i componenti della commissione di disciplina per il personale nei cui confronti ha ordinato l'inchiesta formale.

#### Art. 166. - Attribuzioni del Comandante generale in campo finanziario e amministrativo

1. Il Comandante generale svolge le funzioni di capo ente programmatore, di direttore generale titolare di centro di responsabilita' amministrativa e, ai fini del decentramento amministrativo, di comandante militare territoriale sull'intero territorio nazionale.

2. Il Comandante generale propone, quale capo di ente programmatore, al Capo di stato maggiore della difesa, l'allocazione degli stanziamenti sui capitoli di bilancio dell'Arma dei carabinieri e ne detiene l'impiego operativo.

3. Il Comandante generale provvede, quale direttore generale titolare di centro di responsabilita' amministrativa, nell'ambito delle risorse assegnate dal Ministro della difesa, all'amministrazione dei capitoli di bilancio dell'Arma dei carabinieri, esercitando i poteri di spesa e le connesse funzioni in materia contrattuale e di gestione amministrativo-contabile, e definendo i limiti di valore delle spese che gli ufficiali di livello dirigenziale sottordinati possono impegnare.

4. Il Comandante generale si avvale, quale comandante militare territoriale per gli enti dipendenti dal Comando generale, della direzione di amministrazione di cui all'articolo 171.

#### Art. 167. - Attribuzioni del Comandante generale in campo internazionale

1. Il Comandante generale dell'Arma dei carabinieri provvede, su delega del Capo di stato maggiore della difesa e in conformita' agli indirizzi del Ministro della difesa, informandone, salvo il caso in cui si tratti di materie esclusivamente militari, previamente il Ministro dell'interno, alla predisposizione e alla gestione dei protocolli di intesa e degli accordi tecnici internazionali finalizzati allo scambio di esperienze con paritetici organismi esteri, nei settori organizzativo, addestrativo, tecnico-scientifico e logistico di specifico interesse dell'Arma dei carabinieri.

#### Art. 168. - Attribuzioni del Vice comandante generale

1. Il Vice comandante generale e' il generale di corpo d'armata in servizio permanente effettivo piu' anziano in ruolo ((tra quelli che si trovano ad almeno un anno dal limite di eta' per la cessazione dal servizio permanente)) ed e' nominato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della difesa. Il decreto di nomina e' predisposto dal Comandante generale e trasmesso dal Capo di stato maggiore della difesa.

2. Rimane in carica con mandato della durata ((di un anno, senza possibilita' di proroga o rinnovo. Se, al termine del mandato di un anno, non e' presente in ruolo alcun generale di corpo d'armata che si trova ad almeno un anno dal limite di eta' per la cessazione dal servizio permanente, il Vice comandante generale in carica e' confermato nell'incarico sino a un massimo di due anni e comunque non oltre la data di cessazione dal servizio permanente. Il Vice comandante generale)) e' gerarchicamente preminente rispetto agli altri generali di corpo d'armata dell'Arma dei carabinieri.

3. Il Ministro della difesa ha facolta' di escludere il generale di corpo d'armata ((di cui al comma 1)) e proporre la nomina di quello che lo segue in ordine di anzianita' ((tra quelli che si trovano ad almeno un anno dal limite di eta' per la cessazione dal servizio permanente)).

4. Il Vice comandante generale esercita le funzioni vicarie in caso di assenza o di impedimento del Comandante generale e lo coadiuva, assolvendo le funzioni e i compiti delegati; presiede la commissione ordinaria di avanzamento degli ufficiali dei carabinieri e su delega del Comandante generale effettua ispezioni agli Alti Comandi dell'Arma.

#### Art. 169. - Articolazione dell'Arma dei carabinieri

1. La struttura organizzativa dell'Arma dei carabinieri e' articolata in:

- a) Comando generale;
- b) organizzazione addestrativa;
- c) organizzazione territoriale;
- c-bis) organizzazione per la tutela forestale, ambientale e agroalimentare;
- d) organizzazione mobile e speciale;
- e) reparti per esigenze specifiche.

#### Art. 170. - Comando generale dell'Arma dei carabinieri

1. Il Comando generale e' la struttura mediante la quale il Comandante generale dirige, coordina e controlla le attivita' dell'Arma. In particolare:

- a) assicura l'analisi dei fenomeni criminosi e il raccordo delle attivita' operative condotte dai reparti dell'Arma;
- b) mantiene, per tutto cio' che non attiene ai compiti militari, i rapporti con i ministeri e con gli altri organi centrali della pubblica amministrazione nonche', nei casi previsti dalle norme in vigore, con gli organismi internazionali, fermi restando i rapporti di dipendenza funzionale dal Ministro dell'interno.

2. Il Comando generale e' costituito dallo Stato maggiore, direzioni, reparti e uffici, disciplinati con determinazione del Comandante generale.

#### Art. 171. - Direzione di amministrazione dell'Arma dei carabinieri

1. La Direzione di amministrazione e' posta alle dipendenze del Comando generale dell'Arma dei carabinieri e ha competenza territoriale nazionale per gli enti dipendenti dal medesimo Comando generale.

#### Art. 172. - Organizzazione addestrativa dell'Arma dei carabinieri

1. L'organizzazione addestrativa provvede, secondo gli obiettivi definiti dal Comando generale, alla formazione, all'aggiornamento e alla specializzazione del personale dell'Arma dei carabinieri. Essa comprende:

- a) il Comando delle scuole dell'Arma dei carabinieri, retto da generale di corpo d'armata che assicura univocita' di indirizzo addestrativo e didattico, persegue l'elevazione del livello professionale del personale ed esercita il comando sugli istituti d'istruzione dell'Arma dei carabinieri;
- b) l'Accademia dell'Arma dei carabinieri;
- c) la Scuola ufficiali;
- d) la Scuola marescialli;
- e) la Scuola brigadieri;
- f) le scuole carabinieri;
- g) istituti e centri di perfezionamento e specializzazione.

#### Art. 173. - (( (Organizzazione territoriale dell'Arma dei carabinieri). ))

((

1. L'organizzazione territoriale, componente fondamentale dell'Arma, comprende:

- a) Comandi interregionali, retti da generale di corpo d'armata, che esercitano funzioni di alta direzione, di coordinamento e di controllo nei confronti dei comandi legionali, nonche' assicurano la gestione della disciplina e l'attivita' ispettiva tecnico-logistica;
- b) Comandi legionali, con competenza sul territorio di una o piu' regioni amministrative, retti da generale di divisione o di brigata, cui risale la responsabilita' della gestione del personale e competono le funzioni di direzione, di coordinamento e di controllo delle attivita' dei comandi provinciali, nonche' assicurano attraverso i propri organi, il sostegno tecnico, logistico e amministrativo di tutti i reparti dell'Arma dislocati nell'area di competenza, anche se appartenenti ad altre organizzazioni;
- c) Comandi provinciali, retti da generale di brigata o da colonnello, cui sono attribuite, le funzioni di direzione, di coordinamento e di controllo dei reparti dipendenti, e la responsabilita' dell'analisi e del raccordo delle attivita' operative e di contrasto della criminalita' condotte nella provincia anche da reparti di altre organizzazioni dell'Arma;
- d) Comandi a livello infraprovinciale, retti da ufficiale e differentemente strutturati in rapporto alla loro estensione e rilevanza operativa, cui compete prioritariamente la responsabilita' della direzione e del coordinamento delle attivita' di controllo del territorio e di contrasto delle manifestazioni di criminalita' a rilevanza locale, nonche' l'assolvimento dei compiti militari;
- e) Comandi di stazione, peculiari articolazioni di base dell'Arma dei carabinieri a livello locale, cui compete la responsabilita' diretta del controllo del territorio e delle connesse attivita' istituzionali, nonche' l'assolvimento dei compiti militari. Sono retti, di massima e in relazione alla rilevanza dell'impegno operativo, da luogotenente, maresciallo maggiore o maresciallo capo.

2. L'organizzazione territoriale, struttura essenziale per il controllo del territorio, costituisce riferimento per i reparti delle altre organizzazioni dell'Arma nell'espletamento delle attivita' di rispettiva competenza.

))

#### Art. 174. - Organizzazione mobile e speciale dell'Arma dei carabinieri

1. L'organizzazione mobile e speciale comprende reparti dedicati, in via prioritaria o esclusiva, all'espletamento, nell'ambito delle competenze attribuite all'Arma dei carabinieri, di compiti particolari o che svolgono attivita' di elevata specializzazione, a integrazione, a sostegno o con il supporto dell'organizzazione territoriale.

2. L'organizzazione di cui al comma 1 si articola in:

- a) ((Comando unita' mobili e specializzate, retto da generale di corpo d'armata, che esercita funzioni di alta direzione, di coordinamento e di controllo nei confronti dei comandi di divisione dipendenti));
- b) Comandi, retti da generale di divisione o di brigata, che esercitano funzioni di direzione, di coordinamento e di controllo dei reparti alle dirette dipendenze.

#### Art. 174-bis. - (Organizzazione per la tutela forestale, ambientale e agroalimentare)

1. L'organizzazione forestale, ambientale e agroalimentare comprende reparti dedicati, in via prioritaria o esclusiva, all'espletamento, nell'ambito delle competenze attribuite all'Arma dei carabinieri, di compiti particolari o che svolgono attivita' di elevata specializzazione in materia di tutela dell'ambiente, del territorio e delle acque, nonche' nel campo della sicurezza e dei controlli nel settore agroalimentare, a sostegno o con il supporto dell'organizzazione territoriale.

2. L'organizzazione di cui al comma 1, si articola in:

- a) Comando unita' forestali, ambientali e agroalimentari, che, ferme restando la dipendenza dell'Arma dei carabinieri dal Capo di stato maggiore della difesa, ((tramite il Comandante generale)), per i compiti militari, e la dipendenza funzionale dal Ministro dell'interno, per i compiti di tutela dell'ordine e della sicurezza pubblica, ai sensi dell'articolo 162, comma 1, dipende funzionalmente dal Ministro dell'agricoltura, della sovranita' alimentare e delle foreste, fatta salva la dipendenza funzionale dal Ministro dell'ambiente e della sicurezza energetica del Comando per la tutela ambientale e la sicurezza energetica. Il Ministro dell'ambiente e della sicurezza energetica si avvale altresi' del Comando unita' forestali, ambientali e agroalimentari per lo svolgimento delle specifiche funzioni espressamente riconducibili alle attribuzioni del relativo Ministero. Il Comando unita' forestali, ambientali e agroalimentari e' retto da un generale di corpo d'armata che esercita funzioni di alta direzione, di coordinamento e di controllo nei confronti dei comandi dipendenti, collocato in soprannumero rispetto all'organico. L'incarico di vicecomandante del Comando e' attribuito al generale di divisione in servizio permanente effettivo del ruolo forestale;
- b) Comandi, retti da generale di divisione o di brigata, che esercitano funzioni di direzione, di coordinamento e di controllo dei reparti dipendenti.

2-bis. I reparti istituiti con decreto del Ministro dell'ambiente dell'11 novembre 1986, registrato alla Corte dei conti in data 24 novembre 1986, registro n. 1, foglio n. 1, e con decreto del Ministro della difesa dell'8 giugno 2001, pubblicato nella Gazzetta Ufficiale 11 settembre 2001, n. 211, Supplemento ordinario, sono posti alle dipendenze del Comando di cui al comma 2, lettera a). I medesimi reparti assumono rispettivamente la denominazione di Comando carabinieri per la tutela ambientale e la sicurezza energetica e Comando carabinieri per la tutela agroalimentare.

2-ter. Dal Comando di cui al comma 2, lettera a), dipendono anche il Comando carabinieri per la tutela forestale e dei parchi e il Comando carabinieri per la tutela della biodiversita'.

2-quater. Il Ministro ((dell'agricoltura)), della sovranita' alimentare e delle foreste, di concerto con il Ministro dell'ambiente e della sicurezza energetica e con il Ministro dell'economia e delle finanze, definisce gli obiettivi strategici generali del Comando di cui al comma 2, lettera a), nelle materie riconducibili alle attribuzioni dei Ministeri ((dell'agricoltura)), della sovranita' alimentare e delle foreste e dell'ambiente e della sicurezza energetica.

#### Art. 175. - Reparti e unita' dell'Arma dei carabinieri per esigenze specifiche

1. Costituiscono reparti e unita' per esigenze specifiche:

- a) il Reggimento corazzieri;
- b) i reparti per le esigenze degli organi costituzionali;
- c) i reparti e gli uffici presso gli organi della Difesa, dell'Esercito italiano, della Marina militare, dell'Aeronautica militare, i comandi e gli organismi internazionali in Italia e all'estero;
- d) i reparti di volo, i reparti a cavallo e le unita' navali;
- e) le unita' paracadutiste ed eliportate;
- f) il gruppo di intervento speciale;
- g) la banda dell'Arma dei carabinieri;
- h) le unita' presso dicasteri vari.

2. L'Arma, inoltre, concorre con proprio personale all'attivita' degli organismi interforze secondo le norme che ne regolano la composizione e il funzionamento.

#### Art. 176. - Organi di polizia militare dell'Arma dei carabinieri

1. Alle funzioni di polizia militare, incluse quelle di assistenza ai comandi e alle unita' militari, provvedono, nell'ambito definito dall'articolo 90, i reparti territoriali, gli uffici, i comandi e i reparti costituiti presso gli organi centrali della difesa, presso le Forze armate, gli organismi NATO e gli altri organismi internazionali in Italia e all'estero, nonche' le altre unita' appositamente individuate.

#### Art. 177. - Procedure per l'istituzione e la soppressione di reparti dell'Arma dei carabinieri

1. Il Comandante generale istituisce o sopprime comandi territoriali di livello non superiore a comando provinciale con propria determinazione, previo assenso del Ministro della difesa, che si pronuncia di concerto con il Ministro dell'interno.

2. Salvo quanto previsto dall'articolo 11 della legge 31 marzo 2000, n. 78, l'istituzione o la soppressione di comandi diversi da quelli di cui al comma 1, nei limiti delle dotazioni di personale previste dalle disposizioni vigenti, e' disposta dal Comandante generale, previo consenso del Capo di stato maggiore della difesa, con l'assenso del Ministro della difesa, di concerto con il Ministro dell'interno se si tratti di comandi che svolgono servizi o attivita' di pubblica sicurezza e ordine pubblico.

#### Art. 178. - Qualifiche di polizia giudiziaria

1. Agli appartenenti ai ruoli degli ufficiali, esclusi gli ufficiali generali, degli ispettori e dei sovrintendenti e' attribuita la qualifica di ufficiale di polizia giudiziaria.

2. Agli appartenenti al ruolo degli appuntati e carabinieri e' attribuita la qualifica di agente di polizia giudiziaria.

3. Gli appuntati, limitatamente al periodo in cui hanno l'effettivo comando di una stazione dell'Arma, sono ufficiali di polizia giudiziaria.

4. Gli appartenenti all'Arma dei carabinieri, in base alle qualifiche di polizia giudiziaria loro attribuite, adempiono verso l'autorita' giudiziaria agli obblighi di legge che loro incombono, osservate le disposizioni che regolano i propri rapporti interni di dipendenza gerarchica.

#### Art. 179. - Qualifiche di pubblica sicurezza

1. Gli ufficiali dei carabinieri hanno la qualifica di ufficiali di pubblica sicurezza, ai sensi della normativa vigente.

2. Agli appartenenti ai ruoli degli ispettori, dei sovrintendenti e degli appuntati e carabinieri e' attribuita la qualifica di agente di pubblica sicurezza.

((

3. I luogotenenti e i marescialli maggiori, oltre quanto gia' specificato, sono sostituti ufficiali di pubblica sicurezza e sostituiscono i superiori gerarchici in caso di assenza o impedimento di questi, assumendo anche la qualifica di ufficiale di pubblica sicurezza.

))

#### Art. 179-bis. - (( (Sospensione delle qualifiche di polizia giudiziaria e di pubblica sicurezza).))

((

1. La sospensione dall'impiego comporta la sospensione delle qualifiche di ufficiale e agente di polizia giudiziaria e di pubblica sicurezza, che sono ripristinate all'atto della riassunzione in servizio.

2. Il provvedimento medico legale di temporanea non idoneita' al servizio per patologia o infermita' di carattere neuro-psichico comporta la sospensione delle qualifiche di ufficiale e agente di polizia giudiziaria e di pubblica sicurezza, che sono ripristinate all'atto della riacquisizione dell'idoneita' al servizio.

))

#### Art. 180. - Disposizioni ulteriori in tema di organizzazione e servizio dell'Arma dei carabinieri

1. Nel regolamento sono disciplinate le relazioni dell'Arma dei carabinieri con le altre autorita' militari e civili.

2. Il Ministro della difesa, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, adotta, di concerto con il Ministro dell'interno limitatamente alle parti relative ai compiti di tutela dell'ordine e della sicurezza pubblica, il regolamento generale dell'Arma dei carabinieri che stabilisce:

- a) l'organizzazione e il funzionamento delle strutture e dei mezzi dell'Arma dei carabinieri;
- b) l'organizzazione e l'esecuzione del servizio istituzionale.

## TITOLO V SANITA' MILITARE CAPO I DISPOSIZIONI GENERALI

### Art. 181. - Istituzione e funzioni del Servizio sanitario militare

1. ((Il Servizio sanitario militare, di seguito denominato: "Sanita' militare" provvede:))

- a) all'accertamento dell'idoneita' dei cittadini al servizio militare;
- b) all'accertamento dell'idoneita' dei militari al servizio incondizionato;
- c) alla tutela della salute dei militari;
- d) ai rifornimenti e allestimenti dei materiali tecnici e di servizio generale che occorrono per i bisogni in tempo di pace, di guerra o di grave crisi internazionale;
- e) a ogni altro adempimento previsto dal presente codice, dal regolamento o dalla legge.

### Art. 182. - Rapporti con la legislazione in materia sanitaria e di igiene pubblica

1. Sono di competenza della Sanita' militare le funzioni amministrative concernenti:

- a) l'organizzazione sanitaria militare;
- b) le attivita' indicate nell'articolo 181;
- c) le attivita' di cui all'articolo 2, comma 1, del decreto legislativo 6 novembre 2007, n. 193.

2. Relativamente alle funzioni di igiene, sanita' pubblica e polizia veterinaria, di cui all'articolo 32 della legge 23 dicembre 1978, n. 833, sono fatte salve in materia di ordinanze, di accertamenti preventivi, di istruttoria o di esecuzione dei relativi provvedimenti, le attivita' di istituto delle Forze armate che, nel quadro delle suddette misure sanitarie, ricadono sotto la responsabilita' delle competenti autorita'.

3. La Sanita' militare applica le disposizioni delle leggi concernenti la tutela dell'igiene e della sanita' pubblica, ivi comprese quelle relative alla manipolazione, preparazione e distribuzione di alimenti e bevande, ((nonche' della sanita' pubblica veterinaria,)) compatibilmente con le particolari esigenze connesse all'utilizzo dello strumento militare.

### Art. 183. - Rapporti con il servizio sanitario nazionale

1. Per far fronte alle esigenze della Sanita' militare che non possono essere soddisfatte con il proprio personale, il Ministero della difesa puo' stipulare convenzioni, nei limiti di stanziamento di bilancio, con le aziende sanitarie locali, con gli enti e gli istituti di cui agli articoli 39, 40, 41 e 42 della legge 23 dicembre 1978, n. 833, nonche' con i policlinici a gestione diretta, per prestazioni professionali rese dal personale delle stesse aziende, nei limiti di orario previsto per il predetto personale.

2. Analoghe convenzioni possono essere stipulate con medici civili, generici o specialisti, se le esigenze della Sanita' militare non possono essere soddisfatte con il personale medico militare o con quello delle unita' sanitarie locali e degli enti e istituti di cui al comma l.

3. Il Ministero della difesa puo', sempre che ricorrano le condizioni di cui al comma 2, stipulare convenzioni anche con laureati in medicina veterinaria, chimica, psicologia e biologia, estranei all'Amministrazione dello Stato.

4. Le convenzioni con i medici civili sono stipulate con l'osservanza dei contenuti normativi ed economici previsti dagli accordi collettivi nazionali che disciplinano i rapporti fra servizio sanitario nazionale e medici.

5. I compensi da corrispondere ai laureati, di cui al comma 3, sono stabiliti annualmente con decreto del Ministro della difesa, emanato di concerto con il Ministro dell'economia e delle finanze.

6. Con decreto del Ministro della salute e del Ministro della difesa sono individuate:

- a) d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome, e nel rispetto delle indicazioni degli strumenti di programmazione regionale, tenuto conto della localizzazione e della disponibilita' di risorse delle altre strutture sanitarie pubbliche esistenti, le strutture sanitarie militari accreditabili, nonche' le specifiche categorie destinatarie e le prestazioni ai fini della stipula degli accordi contrattuali previsti dall'articolo 8-quinquies del decreto legislativo 30 dicembre 1992, n. 502; gli accordi contrattuali sono stipulati tra le predette strutture sanitarie militari e le regioni nel rispetto della reciproca autonomia;
- b) le categorie destinatarie e le tipologie delle prestazioni erogate dalle strutture sanitarie militari.

### Art. 184. - Tutela della salute e sicurezza nei luoghi di lavoro per le Forze armate

1. La normativa in materia di tutela della salute e della sicurezza nei luoghi di lavoro, di cui al decreto legislativo 9 aprile 2008, n. 81, si applica alle Forze armate nei limiti di compatibilita' con gli speciali compiti e attivita' da esse svolti, tenuto conto delle insopprimibili esigenze connesse all'utilizzo dello strumento militare, come valutate dai competenti organismi militari sanitari e tecnici.

2. I limiti di compatibilita' e le esigenze connesse all'utilizzo dello strumento militare sono individuati nel regolamento, in questa parte emanato nel rispetto delle procedure previste dall'art. 3, comma 2, 1° periodo del decreto legislativo 9 aprile 2008, n. 81.

### Art. 185. - Sicurezza nucleare e protezione sanitaria per l'amministrazione della difesa

1. Ai sensi dell'articolo 162 del decreto legislativo 17 marzo 1995, n. 230, la materia della sicurezza nucleare e protezione sanitaria si applica all'Amministrazione della difesa, al fine di garantire la protezione della popolazione e dei lavoratori contro i rischi derivanti dalle radiazioni ionizzanti; la disciplina applicativa e' contenuta nel regolamento, ove sono indicate le particolari esigenze connesse ai compiti istituzionali delle Forze armate in tempo di pace. ((67))

2. Sono escluse dall'ambito di applicazione del decreto legislativo 6 febbraio 2007, n. 52, le sorgenti sigillate ad alta attivita' detenute per attivita' svolte nell'ambito del Ministero della difesa.

------------ AGGIORNAMENTO (67) Il D.Lgs. 31 luglio 2020, n. 101 ha disposto (con l'art. 242, comma 1) che i rinvii alle disposizioni del decreto legislativo 17 marzo 1995, n. 230 contenuti nel comma 1 del presente articolo s'intendono riferiti alle corrispondenti disposizioni del suindicato D.Lgs..

### Art. 186. - Altre disposizioni in materia di tutela dei lavoratori

1. Le disposizioni sancite dal decreto legislativo 26 novembre 1999, n. 532, dalla legge 22 febbraio 2001, n. 36 e dal decreto legislativo 19 agosto 2005, n. 187, si applicano alle Forze armate, nei limiti di compatibilita' con gli speciali compiti e attivita' da esse svolti, tenuto conto delle insopprimibili esigenze connesse all'utilizzo dello strumento militare.

2. I limiti di compatibilita' e le esigenze connesse all'utilizzo dello strumento militare di cui al comma 1, sono valutati dai competenti organismi militari sanitari e tecnici.

### Art. 187. - Disposizioni tecniche attuative

1. Con decreto del Ministro della difesa sono emanate le disposizioni tecniche attuative dell'ordinamento della Sanita' militare e dei servizi sanitari militari delle singole Forze armate.

((

1-bis. Forme di razionale coordinamento coerenti con i criteri interforze tra il Servizio sanitario militare e il Servizio sanitario del Corpo della Guardia di finanza possono essere assicurate, senza nuovi maggiori oneri per la finanza pubblica, mediante la stipula di apposite convenzioni fra il Comando generale della Guardia di finanza e lo Stato maggiore della difesa.

))

## CAPO II - ORGANIZZAZIONE

### SEZIONE I - ORGANI DELLA SANITA' MILITARE

#### Art. 188. - Organi centrali

1. Sono organi centrali della Sanita' militare:

- a) La struttura organizzativa della Sanita' militare costituita nell'ambito ((dell'Area tecnico-operativa del Ministero della difesa));
- b) il Collegio ((medico-legale));
- c) gli organi direttivi delle Forze armate di cui all'articolo 191.

#### Art. 189. - ((1. Il Collegio medico-legale esprime pareri medico-legali ed esegue le visite dirette ordinate o richieste dal Ministero della difesa, dalle sezioni giurisdizionali e di controllo della Corte dei conti, dagli organi della giustizia amministrativa e dalle amministrazioni statali, anche in occasione del ricorso straordinario al Presidente della Repubblica.))

((2. Il Collegio medico-legale e' articolato in sezioni, fino a un massimo di cinque, di cui non piu' di due distaccate presso la Corte dei conti, secondo la struttura ordinativa organica definita dallo Stato maggiore della difesa.)) ((3. Del Collegio medico-legale fanno parte ufficiali medici delle Forze armate con particolare qualificazione professionale nelle branche mediche di interesse del Collegio e possono esservi assegnati ufficiali medici o funzionari medici delle Forze di polizia a ordinamento militare o civile con corrispondente qualificazione.)) 4. ((COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 7)). 5. ((COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 7)). 6. ((COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 7)). 7. In presenza di vacanze organiche nei ruoli degli ufficiali medici in servizio permanente effettivo delle Forze armate ((, i membri del Collegio possono essere scelti, fino a un quarto dell'organico, fra docenti universitari o specializzati, preferibilmente competenti in medicina legale)), mediante convenzione annuale, approvata con decreto del Ministro della difesa, dalla quale devono risultare le modalita' delle prestazioni e il relativo compenso, la cui misura massima mensile e' determinata con decreto del Ministro della difesa, di cui al comma 9. 8. I componenti del Collegio medico-legale sono: a) nominati con decreto del Ministro della difesa, garantendo un'adeguata rappresentanza di tutte le Forze armate e le Forze di polizia a ordinamento militare e civile; b) designati dai rispettivi vertici delle Forze armate o delle Forze di polizia; c) sostituiti, se occorre, da ufficiali medici della stessa Forza armata o di polizia, designati, volta per volta, dai rispettivi vertici. 9. Il presidente del Collegio medico-legale puo' richiedere l'intervento, con parere consultivo e senza diritto al voto, di medici estranei al collegio, scelti tra specialisti civili, docenti universitari. Ai predetti consulenti e' corrisposto un gettone di presenza, la cui misura e' fissata con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, per ciascuna giornata di adunanza del collegio tenuta con il loro intervento. ((9-bis. L'interessato puo' essere assistito durante tutta l'attivita' davanti al Collegio medico-legale, senza oneri per l'Amministrazione, da un medico di fiducia che non integra la composizione del citato Collegio.)) ((10. Per le esigenze di funzionamento del Collegio medico-legale i competenti Ministeri dispongono l'assegnazione di personale adeguato nelle qualifiche e nel numero per l'espletamento delle attivita'.)) 11. Il Collegio medico-legale: a) dipende direttamente dallo Stato maggiore della difesa ((...)); b) per le esigenze connesse agli accertamenti sanitari da espletare, puo' avvalersi del personale medico e delle attivita' di laboratorio e di diagnostica del Policlinico militare di Roma, ovvero di ogni altra struttura sanitaria militare. ((b-bis) le spese per i locali, gli arredi e per l'approvvigionamento di quanto necessario al funzionamento delle sezioni distaccate sono a carico della Corte dei conti.)) ((medico-legale))

#### Art. 190.

Sezioni del collegio ((medico-legale)) ((

1. Il collegio medico-legale e' articolato in sezioni e, a richiesta del presidente o di almeno tre membri, si pronuncia in seduta plenaria. Ogni sezione e' composta da un presidente e da quattro membri effettivi. Le sezioni possono essere integrate temporaneamente dai membri aggiunti di cui al comma 7 dell'articolo 189. A ciascuna sezione del Collegio medico-legale deve essere assegnato almeno uno specialista in medicina legale e delle assicurazioni.

((

2. Per la validita' delle adunanze del Collegio medico-legale occorre la presenza di almeno la meta' dei componenti, oltre il presidente, nelle sedute plenarie, e di due membri effettivi, oltre il presidente, nelle sedute di sezione.

))

3. Le sezioni del collegio medico legale hanno facolta' di chiamare a visita diretta gli interessati se lo ritengono opportuno e si esprimono in merito a: ((a) pareri e visite dirette richieste o ordinate dagli organi o dalle amministrazioni di cui all'articolo 189, comma 1;)) b) pareri circa la concessione dei distintivi ai mutilati di guerra e ai feriti e mutilati in servizio di cui alle sezioni XI e XII del capo III del titolo VIII del libro IV del regolamento; c) ((LETTERA SOPPRESSA DAL D.LGS. 28 GENNAIO 2014, N. 7)).

#### Art. 191. - (Organi direttivi).

1. Secondo l'ordinamento di ciascuna Forza armata sono individuati organi direttivi che esercitano le attribuzioni in materia di:

- a) attuazione delle disposizioni tecniche di cui all'articolo 187;
- b) organizzazione e coordinamento delle attivita' dei servizi svolti dagli enti sanitari di ciascuna Forza armata.

2. ((Il Capo di ciascun organo direttivo di cui al comma 1 e' nominato)) dal rispettivo Capo di stato maggiore di Forza armata o dal Comandante generale dell'Arma dei carabinieri.

((

3. Il Capo dell'organo direttivo di cui al comma 1, per l'espletamento delle sue attribuzioni, si avvale della struttura ordinativa costituita e organizzata secondo l'ordinamento di ciascuna Forza armata. Nell'ambito di tale struttura ordinativa possono essere istituite una o piu' commissioni mediche di secondo grado di Forza armata. Ciascuna Commissione e' presieduta dal Capo dell'organo direttivo di cui al comma 1 o da un suo delegato.

))

((

4. Della Commissione fanno parte, in qualita' di membri, due ufficiali superiori medici, nominati dal Capo dell'organo direttivo di cui al comma 1; detti membri sono scelti fra gli ufficiali in servizio presso l'organo di direzione o presso altre strutture sanitarie militari della stessa Forza armata.

))

((

4-bis. La Commissione medica di secondo grado di Forza armata esamina le istanze o i ricorsi presentati dagli interessati avverso i giudizi di prima istanza espressi dagli organi sanitari di Forza armata diversi dalle commissioni mediche di cui all'articolo 193. I giudizi della commissione sono definitivi.

))

#### Art. 192. - Commissioni mediche interforze

1. Le Commissioni mediche interforze, di prima e di seconda istanza, nel presente titolo denominate <<Commissioni>>, esprimono i giudizi sanitari previsti dall'articolo 198.

2. Le Commissioni hanno una competenza territoriale definita con determinazione del Capo di Stato maggiore della difesa.

#### Art. 193. - Commissioni mediche ospedaliere interforze di prima istanza

1. Le Commissioni, oltre ai compiti di cui all'articolo 192, effettuano gli accertamenti medico-legali in materia di:

- a) provvidenze a favore di categorie di dipendenti pubblici e delle vittime del terrorismo, della criminalita', del dovere, di incidenti causati da attivita' istituzionale delle Forze armate, di ordigni bellici in tempo di pace e dell'esposizione a materiale bellico di cui alle disposizioni contenute nel libro VII, titolo III, capo IV, sezioni III e IV del presente codice;
- b) benefici in favore dei militari di leva, volontari e di carriera, appartenenti alle Forze armate e alle Forze di polizia a ordinamento militare e civile, infortunati o caduti in servizio e dei loro superstiti, di cui all'articolo 1895 e all'articolo 1896;
- c) impiego del personale delle Forze di polizia invalido per causa di servizio, ai sensi del decreto del Presidente della Repubblica 25 ottobre 1981, n. 738;
- d) transito nell'impiego civile di cui all'articolo 930;
- e) indennizzo a favore dei soggetti danneggiati da complicanze di tipo irreversibile a causa di vaccinazioni obbligatorie, trasfusioni e somministrazione di emoderivati, di cui alla legge 25 febbraio 1992, n. 210.

((

2. Le Commissioni mediche ospedaliere sono costituite presso i Dipartimenti militari di medicina legale.

))

3. La Commissione e' composta da tre ufficiali medici, di cui almeno uno, preferibilmente, specialista in medicina legale e delle assicurazioni. Assume le funzioni di presidente ((il direttore del Dipartimento militare di medicina legale)) o l'ufficiale superiore medico da lui delegato o, in loro assenza, l'ufficiale superiore medico piu' elevato in grado o, a parita' di grado, con maggiore anzianita' di servizio.

4. La Commissione, quando si pronuncia su infermita' o lesioni di militari appartenenti a Forze armate diverse o di appartenenti a Forze di polizia a ordinamento militare o civile, e' composta di due ufficiali medici, di cui uno con funzioni di presidente, identificato con le modalita' indicate al comma 3 e di un ufficiale medico o funzionario medico della Forza armata o di polizia di appartenenza.

5. La Commissione chiamata a pronunciarsi ai fini della concessione dei benefici previsti dal libro VII, titolo III, capo IV, sezioni III e IV, e' integrata da due ufficiali medici dell'Arma dei carabinieri nominati dal Comando generale, allorquando il relativo procedimento si riferisca ai superstiti del personale dell'Arma vittima del dovere e agli stessi militari.

((

5-bis. A richiesta del presidente puo' intervenire ai lavori della Commissione, con parere consultivo e senza diritto di voto, un ufficiale superiore o un funzionario designato dal comandante del Corpo o capo dell'ufficio, cui appartiene l'interessato.

))

#### Art. 194.

Commissione ((medica)) interforze di seconda istanza ((

01. Per l'esame dei ricorsi avverso i giudizi sanitari di prima istanza limitatamente all'accertamento della idoneita' al servizio di cui all'articolo 19, comma 4, del decreto del Presidente della Repubblica 29 ottobre 2001, n. 461, senza nuovi o maggiori oneri per la finanza pubblica, sono istituite una o piu' Commissioni mediche interforze di seconda istanza.

((

1. La Commissione di cui al comma 01 assume la struttura ordinativa organica definita dallo Stato maggiore della difesa ed e' composta da un presidente e due ufficiali superiori medici, in qualita' di membri.

))

((

2. La Commissione di cui al comma 01:

- a) esamina i ricorsi presentati nel termine di dieci giorni dalla comunicazione del verbale della commissione medica di prima istanza;
- b) e' composta assicurando la presenza nel collegio di un ufficiale medico o funzionario medico della Forza armata o di polizia a ordinamento militare o civile di appartenenza del ricorrente.

))

3. A richiesta del presidente puo' intervenire ai lavori della Commissione ((di cui al comma 01)), con parere consultivo e senza diritto a voto, un ufficiale superiore o un funzionario designato dal comandante del corpo o capo dell'ufficio, cui appartiene l'interessato.

#### Art. 195. - Strutture sanitarie interforze

1. Le strutture sanitarie militari deputate alla diagnosi, cura e alle attivita' di medicina legale sono:

- a) il Policlinico militare, con sede in Roma, struttura polispecialistica che svolge anche attivita' ((di sperimentazione clinica, di formazione e di ricerca in ambito sanitario e veterinario));
- b) i Centri ospedalieri militari, aventi competenze nella diagnostica terapeutica per il ricovero e la cura del personale militare;
- c) i Dipartimenti militari di medicina legale, aventi competenza medico-legale.

#### Art. 195-bis. - ((Istituti di medicina aerospaziale dell'Aeronautica militare))

((

1. Gli Istituti di medicina aerospaziale dell'Aeronautica militare sono posti alle dipendenze del Capo dell'organo direttivo sanitario dell'Aeronautica militare ai sensi dell'articolo 191 e svolgono le seguenti attivita':

- a) accertamento dell'idoneita' al volo e ai servizi di navigazione aerea del personale delle Forze armate, delle Forze di polizia a ordinamento militare e civile, del Corpo dei vigili del fuoco, nonche' degli aspiranti al conseguimento di licenze e attestati aeronautici;
- b) effettuazione dei controlli ordinari e straordinari sul mantenimento dell'idoneita' al volo ed ai servizi di navigazione aerea del personale di cui alla lettera a), nonche' dei titolari di licenze e attestati aeronautici;
- c) accertamenti sanitari o medico-legali disposti dall'organo direttivo sanitario dell'Aeronautica militare ovvero previsti nella normativa vigente.

2. Gli Istituti di medicina aerospaziale possono esprimere altresi', secondo le indicazioni delle Forze armate, delle Forze di polizia a ordinamento militare o civile, e del Corpo dei vigili del fuoco, i giudizi di idoneita' al servizio militare o al servizio d'istituto per il personale sottoposto all'accertamento dell'idoneita' di cui al comma 1, lettera a). In tali casi, ai fini dell'espressione del giudizio, sono preventivamente acquisite anche le valutazioni di un ufficiale medico o funzionario medico della Forza armata o di polizia a ordinamento militare o civile di appartenenza dell'interessato, ovvero, del Corpo dei vigili del fuoco.

3. Con direttiva tecnica dell'organo direttivo sanitario dell'Aeronautica militare sono stabilite la periodicita' e le modalita' tecniche con le quali il personale delle Forze armate deve essere sottoposto alle visite mediche per l'accertamento del mantenimento dell'idoneita' al volo e ai servizi di navigazione aerea.

))

#### Art. 195-ter. - ((Commissione sanitaria d'appello))

((

1. La Commissione sanitaria d'appello, posta alle dipendenze dell'organo direttivo sanitario dell'Aeronautica militare, esamina i ricorsi presentati dal personale delle Forze armate, delle Forze di polizia ad ordinamento militare e civile, del Corpo dei vigili del fuoco, nonche' dagli iscritti al fondo di previdenza del personale di volo dipendente dalle aziende di navigazione aerea avverso i giudizi sanitari di prima istanza espressi dagli Istituti di medicina aerospaziale dell'Aeronautica militare in sede di selezione e certificazione dell'idoneita' al volo e ai servizi di navigazione aerea di cui all'articolo 195-bis, comma 1, lettere a) e b), ferme restando le competenze della Commissione medica d'appello di cui all'articolo 38 del decreto del Presidente della Repubblica 18 novembre 1988, n. 566 e all'articolo 11 del decreto del Presidente della Repubblica 28 marzo 2013, n. 44. I ricorsi devono essere presentati nel termine di 30 giorni dalla comunicazione del verbale dell'Istituto di medicina aerospaziale dell'Aeronautica militare.

2. La Commissione sanitaria d'appello e' presieduta dal Capo dell'organo direttivo sanitario dell'Aeronautica militare e ne fanno parte due ufficiali superiori medici nominati dal Capo dell'organo direttivo.

3. Secondo le indicazioni delle Forze armate, delle Forze di polizia ad ordinamento militare o civile e del Corpo dei vigili del fuoco la Commissione sanitaria di appello puo' pronunciarsi, altresi', sui ricorsi presentati dal personale avverso i giudizi di idoneita' al servizio militare e al servizio di istituto espressi dall'organo di cui all'articolo 195-bis.

4. La Commissione sanitaria d'appello visita e giudica collegialmente, redigendo apposito verbale di visita nel quale formula un giudizio definitivo.

5. Allorche' esprime i giudizi di cui al comma 3, la Commissione sanitaria di appello e' composta assicurando la presenza nel collegio, in qualita' di membro, di un ufficiale medico o funzionario medico della Forza armata o di polizia a ordinamento militare o civile di appartenenza del ricorrente, ovvero, del Corpo dei vigili del fuoco. La Commissione, quando esamina i ricorsi degli iscritti al fondo di previdenza del personale di volo dipendente dalle aziende di navigazione aerea, e' integrata da un medico designato dall'Ente Nazionale per l'Aviazione Civile.

6. L'interessato puo' essere assistito durante la visita, senza oneri per l'Amministrazione, da un medico di fiducia che non integra la composizione della Commissione.

7. La Commissione sanitaria d'appello, per esigenze legate alla complessita' dell'accertamento sanitario, puo' richiedere la partecipazione alla visita, per un parere consultivo e senza diritto al voto, di un medico specialista appartenente al Corpo sanitario aeronautico che non ha partecipato all'emissione del giudizio sanitario di prima istanza.

))

### SEZIONE II - COMPONENTI AUSILIARIE DELLE FORZE ARMATE DELLA CROCE ROSSA ITALIANA

#### Art. 196. - Compiti in tempo di guerra, di grave crisi internazionale o di conflitto armato

1. L'Associazione italiana della Croce rossa in tempo di guerra, di grave crisi internazionale o di conflitto armato:

- a) contribuisce, in conformita' a quanto previsto dalle convenzioni di Ginevra del 12 agosto 1949, rese esecutive dalla legge 27 ottobre 1951, n. 1739, allo sgombero e alla cura dei feriti e dei malati di guerra nonche' delle vittime dei conflitti armati e allo svolgimento dei compiti di carattere sanitario e assistenziale connessi all'attivita' di difesa civile;
- b) disimpegna il servizio di ricerca e di assistenza dei prigionieri di guerra, degli internati e dei dispersi.

2. Dichiarato lo stato di guerra o di grave crisi internazionale:

- a) l'organizzazione dei servizi di cui al comma 1 e' determinata con decreto del Ministro della difesa, tenuto conto della competenza degli organi del Servizio sanitario nazionale;
- b) le autorita' di vertice dei corpi della Croce rossa italiana ausiliari delle Forze armate ((continuano a dipendere)) direttamente dal presidente nazionale, il quale assume tutti i poteri, diventando l'unico rappresentante dell'Associazione.

#### Art. 197. - Organizzazione dei servizi umanitari

1. In conformita' alla normativa emanata per l'assolvimento dei compiti umanitari commessi da convenzioni e risoluzioni internazionali:

- a) il Ministro della difesa esercita i relativi poteri e facolta' nei riguardi del Corpo militare della Croce rossa italiana e del Corpo delle infermiere volontarie ausiliarie delle Forze armate dello Stato;
- b) l'Associazione italiana della Croce rossa e' tenuta ad attendere in via ordinaria secondo le direttive e sotto la vigilanza del Ministero della difesa, alla preparazione del personale, dei materiali e delle strutture di pertinenza dei corpi suddetti, al fine di assicurare costantemente l'efficienza dei relativi servizi in qualsiasi circostanza.

((

2. Per la formazione delle infermiere volontarie, del personale del Corpo militare e del personale volontario per il soccorso, la Croce rossa italiana puo' stipulare convenzioni con le regioni, ferma restando la possibilita' di formazione attraverso strutture clinico-sanitarie militari o proprie strutture formative ordinate allo scopo specifico.

))

3. Il diploma di infermiera volontaria della Croce rossa italiana e' valido nell'ambito dei servizi resi nell'assolvimento dei compiti propri dell'istituzione e per le Forze armate ((. . . )).

4. L'organizzazione e il funzionamento dei servizi della Croce rossa italiana ausiliari delle Forze armate sono sovvenzionati dallo Stato e sono disciplinati dal regolamento.

5. ((COMMA ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20)).

## CAPO III - ATTRIBUZIONI E SERVIZI

### SEZIONE I - ATTIVITA' DELLE COMMISSIONI MEDICHE INTERFORZE

#### Art. 198. - Accertamento dell'idoneita' al servizio e delle infermita' da causa di servizio

1. La Commissione di cui all'articolo 193 territorialmente competente in relazione all'ufficio di ultima assegnazione del dipendente ovvero, se il dipendente e' pensionato o deceduto, alla residenza rispettivamente del pensionato o dell'avente diritto, effettua la diagnosi dell'infermita' o lesione, comprensiva possibilmente anche dell'esplicitazione eziopatogenetica, nonche' del momento della conoscibilita' della patologia. Per coloro che risiedono all'estero la visita e' effettuata, per delega della Commissione, da un collegio di due medici nominati dalla locale autorita' consolare ovvero dal medico fiduciario dell'autorita' stessa.

((

1-bis. Per il dipendente residente al di fuori della regione amministrativa ove hanno sede le competenti commissioni mediche, se le condizioni di salute ne rendono oggettivamente impossibile o molto disagevole lo spostamento, la commissione territorialmente competente puo' delegare la visita due medici, di cui almeno uno ufficiale superiore, appartenenti alle infermerie di cui all'articolo 199 o ai servizi sanitari appositamente individuati ed organizzati presso enti o comandi superiori.

))

2. La Commissione, per esigenze legate alla complessita' dell'accertamento sanitario, puo' richiedere la partecipazione alla visita, con voto consultivo, di un medico specialista.

3. L'interessato puo' essere assistito durante la visita, senza oneri per l'amministrazione, da un medico di fiducia, che non integra la composizione della Commissione.

4. La Commissione, entro trenta giorni dalla ricezione degli atti dall'Amministrazione, effettua la visita per il tramite di almeno un componente e redige processo verbale, firmato da tutti i membri. Dal verbale risultano le generalita' del dipendente, la qualifica e la firma dei componenti della commissione, il giudizio diagnostico, gli accertamenti e gli elementi valutati a fini diagnostici, la determinazione della data di conoscibilita' o stabilizzazione dell'infermita' da cui derivi una menomazione ascrivibile a categoria di compenso, nonche' l'indicazione della categoria stessa, il giudizio di idoneita' al servizio o altre forme di inabilita', le eventuali dichiarazioni a verbale del medico designato dall'interessato, i motivi di dissenso del componente eventualmente dissenziente e il voto consultivo del medico specialista.

5. Il verbale e' trasmesso all'Amministrazione competente entro quindici giorni dalla conclusiva visita. In caso di accertamento conseguente alla trasmissione di certificazione medica ai sensi dell'articolo 8, comma 1 del decreto del Presidente della Repubblica 29 ottobre 2001, n. 461, il verbale e' inviato direttamente al comitato dalla commissione, che provvede a dare comunicazione all'interessato ai sensi del comma 2 dello stesso articolo 8.

6. In caso di accertamento diagnostico di infezione da HIV o di AIDS, il presidente della Commissione interpella l'interessato per il consenso, da sottoscrivere specificamente a verbale, circa l'ulteriore prosecuzione del procedimento; il presidente impartisce le necessarie disposizioni, anche organizzative, in aggiunta a quanto previsto dal decreto legislativo 30 giugno 2003, n. 196, per l'ulteriore utilizzazione e conservazione dei contenuti del verbale, in modo da limitarne la conoscibilita'.

7. La data di effettuazione della visita e' comunicata al dipendente con anticipo non inferiore a dieci giorni. In caso di mancata partecipazione, per giustificato motivo, del medico designato dal dipendente alla visita, e' convocata una nuova visita da effettuarsi entro trenta giorni dalla prima.

8. In caso di giustificata assenza del dipendente alla visita, la commissione convoca il dipendente per una nuova visita da effettuarsi entro trenta giorni dalla prima.

9. In caso di ingiustificata assenza del dipendente alla visita, la commissione redige processo verbale e restituisce gli atti all'Amministrazione nel termine di quindici giorni.

10. Il presidente della commissione, in caso di comprovato e permanente impedimento fisico del dipendente, puo' disporre l'esecuzione della visita domiciliare da parte di un componente della Commissione stessa.

### SEZIONE II - SERVIZI MEDICO LEGALI

#### Art. 199. - Attribuzioni medico-legali

1. Gli accertamenti medico-legali che, in conformita' alle norme del codice e del regolamento, devono o possono farsi presso le strutture sanitarie di cui all'articolo 195, possono essere compiuti anche presso le infermerie presidiarie dirette da ufficiali superiori medici.

2. Ai direttori di tali infermerie che hanno i gradi predetti sono in ogni caso estese le attribuzioni medico-legali riservate ((ai direttori delle strutture sanitarie di cui all'articolo 195)), sia in sede di osservazione per tutti i casi nei quali questa e' attualmente prevista, sia in sede di rassegna.

#### Art. 200.

Visite ((medico-legali))

1. Tutte le pubbliche amministrazioni e gli enti pubblici possono richiedere l'opera degli ufficiali medici per visite ((medico-legali)) ai propri dipendenti, nei seguenti casi:

- a) per accertare l'esistenza, la natura e il grado di infermita' sulle quali si devono motivare provvedimenti di licenza, di aspettativa, di riforma e di riposo, di impiegati non appartenenti a quelle amministrazioni statali contemplate nel decreto del Presidente della Repubblica 29 ottobre 2001, n. 461; tali accertamenti sono praticati sempre con visite collegiali se si tratta di collocamento in riforma o a riposo, mentre per il collocamento in aspettativa la visita e' fatta da un solo ufficiale medico;
- b) per stabilire la reale esistenza dell'allegata inabilita' fisica dei rivenditori di generi di privativa, che chiedono di essere rappresentati da un commesso; l'accertamento si esegue mediante visita collegiale;
- c) per verificare l'inabilita' allegata dagli alunni delle scuole primarie e secondarie che domandano la esenzione dalle esercitazioni di educazione fisica; la visita e' eseguita da un solo ufficiale medico;
- d) per constatare l'idoneita' fisica degli aspiranti a impieghi in pubbliche amministrazioni; la visita e' eseguita da un solo ufficiale medico, se non e' esplicitamente richiesto l'intervento di un collegio medico;
- e) per accertare malattie dei docenti delle scuole primarie e secondarie, che chiedono il conferimento di indennita' per motivi di salute; la visita e' eseguita da un solo ufficiale medico, salvo i casi nei quali venga tassativamente richiesta la visita collegiale dall'autorita' interessata;
- f) per accertare se esista indicazione alle cure balneo-termali negli stabilimenti militari, secondo le relative norme in vigore;
- g) per accertare l'inabilita' assoluta e permanente dei dipendenti delle amministrazioni pubbliche;
- h) per stabilire le condizioni fisiche dei dipendenti delle amministrazioni pubbliche i quali chiedono di fare la cessione del quinto dello stipendio; la visita e' eseguita da un solo ufficiale medico;
- i) per accertare l'idoneita' fisico-psichica di coloro che aspirano alla patente di conduttori di autoveicoli: la visita e' eseguita da un solo ufficiale medico;
- l) per reclutamento e riforma degli appartenenti alle Forze di polizia a ordinamento civile;
- m) ai fini del collocamento in congedo straordinario per infermita' dei dipendenti della pubblica amministrazione;
- n) altre visite non contemplate nelle lettere precedenti, autorizzate dal Ministero della difesa, ovvero attribuite dalla legge alla competenza di ufficiali medici, in base alle disposizioni che ne regolano l'esercizio.

2. Le autorita' o i privati che richiedono le visite rivolgono ufficialmente la domanda alla Direzione dell'ospedale militare o dell'infermeria autonoma o presidiaria oppure al Comando dal quale dipende l'infermeria di corpo se la visita deve essere eseguita presso tale ente, oppure, nei casi previsti, alla Direzione dell'istituto ((di medicina aerospaziale)) dell'Aeronautica militare competente per territorio.

#### Art. 201.

Modalita' delle visite ((medico-legali))

1. Le visite ((medico legali)) di cui all'articolo 200 possono essere praticate:

- a) presso il policlinico o i centri ospedalieri militari;
- b) presso i dipartimenti militari di medicina legale;
- c) presso le infermerie di corpo ovvero ogni altro ente militare, purche' provvisto di idonei gabinetti medici e dei necessari mezzi di indagine e non si tratti di visite collegiali;
- d) presso gli istituti di medicina ((aerospaziale)) dell'Aeronautica militare per effettuare ogni tipo di accertamento in materia di idoneita' al volo civile.

2. Le visite di cui al comma 1 del presente articolo possono, eventualmente, essere eseguite anche a domicilio allorche' si tratti di constatare infermita' che, per la loro gravita' reale o addotta, impediscano all'interessato di muoversi dalla propria abitazione.

3. Per ogni visita praticata e' redatta apposita dichiarazione medica da rimettere alla Direzione dello stabilimento sanitario o al Comando del Corpo o distaccamento presso cui e' stata eseguita la visita, per la trasmissione d'ufficio all'autorita' che ha richiesto la visita stessa.

4. Per ogni visita eseguita, anche a domicilio dagli ufficiali medici, i privati e le autorita' corrispondono un compenso il cui importo e modalita' di versamento e' stabilito con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

### SEZIONE III - SERVIZI IN MATERIA DI DIPENDENZE

#### Art. 202. - Centri di formazione e di informazione in materia di tossicodipendenze, alcoldipendenze e uso di sostanze dopanti

1. Il Ministero della difesa promuove:

- a) corsi formativi di psicologia e sociologia per tutti gli ufficiali medici e per gli allievi delle scuole infermieri, nonche' per ufficiali e sottufficiali di arma finalizzati ad addestrare personale esperto preposto alla tutela della salute fisica e psichica dei giovani alle armi;
- b) sessioni di studio sulla psicologia di gruppo e su temi specifici di sociologia;
- c) seminari sul disadattamento giovanile, sulle tossicodipendenze, le alcoldipendenze e l'uso di sostanze dopanti, da svolgersi periodicamente per la continua formazione e aggiornamento dei quadri permanenti.

2. Il Ministero della difesa:

- a) organizza presso accademie, scuole militari, scuole di sanita' militare, comandi ed enti militari, corsi di informazione sui danni derivanti dall'uso di sostanze stupefacenti, psicotrope, alcoliche, tabacco e sostanze dopanti, inserendoli nel piu' ampio contesto dell'azione di educazione civica e sanitaria che e' svolta nei confronti dei giovani arruolati e dei militari di leva, in caso di ripristino della stessa;
- b) da' informazioni complessive sul fenomeno criminoso del traffico di sostanze stupefacenti, psicotrope e dopanti; tali informazioni sono attuate anche mediante periodiche campagne basate su conferenze di ufficiali medici al personale militare, con il supporto di mezzi audiovisivi e opuscoli.

#### Art. 203. - Azione di prevenzione e accertamenti sanitari

1. Il Ministero della difesa tramite i consultori e i servizi di psicologia delle Forze armate svolge azione di prevenzione contro le tossicodipendenze, le alcoldipendenze e l'uso di sostanze dopanti.

2. In occasione delle operazioni di arruolamento dei volontari e di selezione per la leva, in caso di ripristino della stessa, se e' individuato un caso di tossicodipendenza, tossicofilia, alcoldipendenza o doping, l'autorita' militare, che presiede alla visita medica e alle prove psicoattitudinali, dispone l'invio dell'interessato all'ospedale militare per gli opportuni accertamenti.

3. Analogamente provvede l'autorita' sanitaria militare nel corso delle visite mediche previste dall'articolo 929.

#### Art. 204. - Rapporti con le strutture socio-sanitarie civili

1. I rapporti di collaborazione tra struttura sanitaria militare e strutture sanitarie civili impegnate nel settore delle tossicodipendenze, alcoldipendenze e contrasto dell'uso di sostanze dopanti, sono volti ad assicurare, in ogni caso, la continuita' dell'assistenza e a favorire il recupero socio-sanitario dell'interessato.

2. I dati statistici relativi all'andamento del fenomeno della tossicodipendenza, alcoldipendenza e uso di sostanze dopanti, rilevati nell'ambito militare, sono trasmessi ogni dodici mesi ai Ministeri della salute e dell'interno.

### SEZIONE IV - ALTRI SERVIZI

#### Art. 205. - Servizio trasfusionale delle Forze armate

1. Le Forze armate organizzano autonomamente il servizio trasfusionale in modo da essere in grado di svolgere tutte le competenze previste dalla legge 21 ottobre 2005, n. 219.

2. Nel quadro delle iniziative di educazione sanitaria impartite ai militari, l'autorita' militare favorisce la cultura della donazione volontaria di sangue, di sangue cordonale e dei loro componenti da parte dei militari presso le strutture trasfusionali militari e civili.

3. Il servizio trasfusionale militare coopera con le strutture del Servizio sanitario nazionale, del Ministero dell'interno e del Dipartimento della protezione civile, al fine di assicurare, in relazione alle previsioni delle necessita' trasfusionali per le situazioni di emergenza, il mantenimento di adeguate scorte di prodotti del sangue.

4. Per la realizzazione delle finalita' di cui ai commi 1, 2 e 3 sono stipulate apposite convenzioni tra le regioni e il Ministero della difesa, secondo lo schema tipo di convenzione definito con decreto del Ministro della salute.

5. Il Ministero della difesa e' l'autorita' responsabile, relativamente al servizio trasfusionale di cui al presente articolo, del rispetto dei requisiti previsti dal decreto legislativo 20 dicembre 2007, n. 261, in materia di raccolta e controllo del sangue umano e dei suoi componenti.

6. Le norme relative all'organizzazione e funzionamento del servizio trasfusionale delle Forze armate sono individuate con decreto del Ministro della difesa, non avente natura regolamentare.

#### Art. 206. - Servizio per le emergenze di salute pubblica

1. Gli organi della Sanita' militare collaborano, nell'ambito dell'attivita' di contrasto delle emergenze di salute pubblica, legate prevalentemente alle malattie infettive e diffusive e al bioterrorismo, e della prevenzione e lotta contro l'influenza aviaria e le malattie degli animali, con:

- a) il Centro nazionale per la prevenzione e il controllo delle malattie con analisi e gestione dei rischi, previamente quelli legati alle malattie infettive e diffusive e al bioterrorismo, ai sensi dell'articolo 1, del decreto-legge 29 marzo 2004, n. 81, convertito dalla legge 26 maggio 2004, n. 138;
- b) il Centro nazionale di lotta ed emergenza contro le malattie animali, ai sensi dell'articolo 1 del decreto-legge 1° ottobre 2005, n. 202, convertito, dalla legge 30 novembre 2005, n. 244.

#### Art. 206-bis. - (Profilassi vaccinale del personale militare)

1. La Sanita' militare puo' dichiarare indispensabile la somministrazione, secondo appositi protocolli, di specifiche profilassi vaccinali al personale militare per poterlo impiegare in particolari e individuate condizioni operative o di servizio, al fine di garantire la salute dei singoli e della collettivita'. ((100))

2. Con decreto del Ministro della difesa adottato di concerto con il Ministro della salute sono approvati i protocolli sanitari di cui al comma 1 che recano altresi' l'indicazione analitica degli adempimenti riferiti alle modalita' di somministrazione dei vaccini, quali quelli di comporre il quadro anamnestico del paziente prima di iniziare le profilassi vaccinali e di registrare su apposita documentazione, anche elettronica, riferita a ciascun militare tutte le profilassi vaccinali adottate nei suoi confronti.

3. Se il militare da sottoporre a profilassi vaccinale rappresenta documentati motivi sanitari per non sottoporsi alla profilassi stessa, la valutazione di merito e' rimessa alla commissione medica ospedaliera competente per territorio.

--------------- AGGIORNAMENTO (100) La Corte Costituzionale, con sentenza 12 gennaio - 20 febbraio 2023, n. 25 (in G.U. 1ª s.s. 22/02/2023, n. 8) ha dichiarato "l'illegittimita' costituzionale dell'art. 206-bis, comma 1, del decreto legislativo 15 marzo 2010, n. 66 (Codice dell'ordinamento militare), introdotto dall'art. 12, comma 1, lettera a), del decreto legislativo 26 aprile 2016, n. 91 (Disposizioni integrative e correttive ai decreti legislativi 28 gennaio 2014, n. 7 e 8, adottate ai sensi dell'articolo 1, comma 5, della legge 31 dicembre 2012, n. 244), nella parte in cui autorizza la sanita' militare a imporre al personale militare la somministrazione di specifiche profilassi vaccinali, senza che esse siano previamente individuate in via legislativa".

#### Art. 207. - Attivita' in materia di vaccinazioni

1. I documenti relativi alla vaccinazione rilasciati dalle Forze armate al proprio personale in attivita' di servizio sono accettati in luogo del certificato internazionale, di cui alla riproduzione nelle appendici 2, 3, o 4, della legge 9 febbraio 1982, n. 106, a condizione che essi contengano:

- a) le informazioni mediche equivalenti a quelle da indicarsi sul modello relativo;
- b) una dichiarazione in francese o in inglese che precisi la natura e la data della vaccinazione e attesti che i documenti vengano rilasciati in virtu' del presente articolo.

## CAPO IV - PERSONALE ADDETTO ALLA SANITA' MILITARE

### SEZIONE I - ((PERSONALE DEL SERVIZIO SANITARIO MILITARE))

#### Art. 208. - (( (Categorie di personale).))

((

1. Il personale impiegato dalla Sanita' militare e' costituito da:

- a) ufficiali e sottufficiali, abilitati all'esercizio delle professioni sanitarie, inquadrati nei ruoli e nei Corpi sanitari delle Forze armate;
- b) graduati e militari di truppa esercenti quali figure di supporto sanitario;
- c) ufficiali, sottufficiali, graduati e militari di truppa delle varie armi e corpi, impiegati presso le strutture sanitarie;
- d) cappellani militari, religiose e altro personale assunto o convenzionato sulla base delle vigenti disposizioni.

2. L'attivita' sanitaria e' consentita al personale in possesso dei titoli per l'esercizio delle professioni sanitarie e alle figure di supporto sanitario, riconosciute dal Ministero della salute, fatto salvo quanto previsto dall'articolo 213 per i soccorritori militari.

))

#### Art. 209. - Ufficiali medici

1. Gli ufficiali medici uniscono alle peculiari doti professionali tutte le piu' spiccate virtu' militari e devono avere perfetta conoscenza delle norme relative al reclutamento e ordinamento delle Forze armate e al servizio sanitario in tempo di pace, di guerra e di grave crisi internazionale.

2. Gli ufficiali medici, oltre a quanto previsto dal libro IV, titolo III, capo IV, sezione III del presente codice, si aggiornano sui progressi delle discipline medico-chirurgiche. Al fine di perfezionare la loro cultura o indirizzarla a branche speciali, possono, in seguito a concorso, essere nominati con le qualifiche di sanitari militari, corrispondenti a quelle previste per i sanitari civili, presso cliniche o istituti universitari. Possono pure essere chiamati a frequentare corsi speciali di perfezionamento o di preparazione agli esami d'avanzamento presso la scuola di sanita' militare o presso ospedali militari.

3. Al fine di consentire un costante aggiornamento degli ufficiali medici, ((lo Stato maggiore della difesa)) indica, con propria direttiva, le modalita' e la frequenza di speciali conferenze da tenersi presso strutture sanitarie militari in cui trattare argomenti essenzialmente pratici di scienza e di servizio sanitario militare, oltre a conversazioni scientifiche sulle piu' attuali tematiche del movimento scientifico sanitario.

4. E' vietato agli ufficiali medici di eseguire visite e redigere certificati nella loro qualita' di medici militari, quando le visite:

- a) non sono previste da disposizioni di legge;
- b) non sono autorizzate dal Ministero della difesa, ai sensi dell'articolo 200;
- c) non sono ordinate o autorizzate dai superiori diretti.

5. Gli ufficiali medici, ai sensi dell'articolo 38 del decreto legislativo 9 aprile 2008, n. 81, svolgono l'attivita' di medico nel settore del lavoro nell'ambito delle strutture dipendenti dal Ministero della difesa, mediante la sorveglianza e la vigilanza sanitaria del personale e dei luoghi di lavoro.

#### Art. 210. - Attivita' libero professionale del personale medico

1. In deroga all'articolo 894, comma 1, ai medici militari non sono applicabili le norme relative alle incompatibilita' inerenti l'esercizio delle attivita' libero professionali, nonche' le limitazioni previste dai contratti e dalle convenzioni con il servizio sanitario nazionale, fermo restando il divieto di visitare privatamente gli iscritti di leva e di rilasciare loro certificati di infermita' e di imperfezioni fisiche che possano dar luogo alla riforma. ((102)) 1.1. Nell'esercizio delle attivita' libero professionali di cui al comma 1, i medici militari non possono svolgere attivita' peritali di parte in giudizi civili, penali o amministrativi in cui e' coinvolta l'Amministrazione della difesa ovvero, per i medici militari del Corpo della Guardia di finanza, l'Amministrazione di appartenenza.

1-bis. COMMA ABROGATO DAL D.LGS. 22 GENNAIO 2016, N. 10.

-------------- AGGIORNAMENTO (102) La Corte Costituzionale, con sentenza 5 aprile - 18 maggio 2023, n. 98, (in G.U. 1a s.s. 24/05/2023, n. 21), ha dichiarato "l'illegittimita' costituzionale dell'art. 210, comma 1, del decreto legislativo 15 marzo 2010, n. 66 (Codice dell'ordinamento militare), nella parte in cui non contempla, accanto ai medici militari, anche gli psicologi militari tra i soggetti a cui, in deroga all'art. 894 del codice medesimo, non sono applicabili le norme relative alle incompatibilita' inerenti l'esercizio delle attivita' libero professionali, nonche' le limitazioni previste dai contratti e dalle convenzioni con il servizio sanitario nazionale".

### SEZIONE II - ((ESERCIZIO DELLE PROFESSIONI SANITARIE))

#### Art. 211. - (( (Formazione continua).))

((1. Il personale sanitario esercente le professioni sanitarie, adempie agli obblighi di formazione continua previsti dal decreto legislativo 30 dicembre 1992, n. 502, e successive modificazioni,))

#### Art. 212. - Requisiti per l'esercizio delle professioni sanitarie infermieristiche, ostetrica, riabilitative, tecnico-sanitarie e della prevenzione

1. Il personale delle professioni sanitarie infermieristiche, ostetriche, riabilitative, tecnico-sanitarie svolge con autonomia professionale le specifiche funzioni ed e' articolato in conformita' a quanto previsto dalla legge 1° febbraio 2006, n. 43.

2. Fermo restando il titolo universitario abilitante di cui alla legge 1° febbraio 2006, n. 43, il personale del servizio sanitario militare puo' svolgere il percorso formativo presso le strutture del servizio stesso, individuate con decreto del Ministro della salute, che garantisce la completezza del percorso formativo.

3. Al personale infermieristico e' attribuita la diretta responsabilita' e gestione delle attivita' di assistenza infermieristica e delle connesse funzioni.

((

3-bis. A decorrere dal 2020, l'Amministrazione della difesa provvede al rimborso delle spese sostenute dal personale del servizio sanitario militare di cui al comma 1, nonche' dagli psicologi militari per l'iscrizione obbligatoria al relativo albo professionale ai sensi dell'articolo 2, comma 3, della legge 1° febbraio 2006, n. 43.

))

#### Art. 213. - Speciali competenze del personale infermieristico e dei soccorritori militari

1. Nelle aree operative in cui si svolgono le missioni internazionali, nonche' sui mezzi aerei e unita' navali impegnati in operazioni militari al di fuori dello spazio aereo e delle acque territoriali nazionali, nei casi di urgenza ed emergenza:

- a) in assenza di personale medico, al personale infermieristico militare specificatamente formato e addestrato e' consentita l'effettuazione di manovre per il sostegno di base e avanzato delle funzioni vitali e per il supporto di base e avanzato nella fase di pre-ospedalizzazione del traumatizzato;
- b) in assenza di personale sanitario, ai soccorritori militari e' consentita l'applicazione di tecniche di primo soccorso nei limiti di quanto previsto da apposito protocollo d'intesa sottoscritto dal Ministero della difesa e dal Ministero della salute.

## TITOLO VI ISTITUTI DI ISTRUZIONE E FORMAZIONE CAPO I DISPOSIZIONI GENERALI

### Art. 214. - Individuazione degli istituti

1. Il presente titolo disciplina:

- a) le scuole militari;
- b) gli istituti militari di formazione iniziale o di base degli ufficiali e dei sottufficiali delle Forze armate;
- c) gli istituti di formazione superiore degli ufficiali delle Forze armate;
- d) le scuole carabinieri;
- e) le scuole allievi operai.

2. La formazione del personale militare avviene ai sensi delle disposizioni contenute nel titolo III del libro IV.

### Art. 215. - Ordinamento e funzionamento degli istituti militari

1. Le disposizioni relative alle sedi all'ordinamento e al funzionamento generale degli istituti militari di cui al presente titolo sono emanate:

- a) dal Capo di stato maggiore della difesa, per gli istituti interforze;
- b) dai Capi di stato maggiore di Forza armata e dal Comandante generale dell'Arma dei carabinieri, per quanto di rispettiva competenza.

1-bis. Le disposizioni relative a ordinamento e funzionamento dei programmi scolastici delle scuole militari sono adottate con decreto del Ministro della difesa, di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca.

((1-ter. Con uno o piu' decreti del Ministro della difesa, adottati di concerto con il Ministro dell'istruzione e del merito, coerentemente con la disciplina del sistema nazionale di istruzione e formazione e con le specificita' dell'ordinamento militare, sono adottate le disposizioni necessarie ad assicurare il piu' efficace funzionamento dei licei militari in materia di ordinamento dei corsi, di svolgimento delle funzioni connesse alla dirigenza scolastica nonche' di modalita' di selezione e assegnazione del personale docente di ruolo e supplente))

### Art. 216. - Altri enti e istituti di istruzione a carattere interforze e di Forza armata

1. Gli enti e istituti militari di istruzione a carattere interforze e di Forza armata non disciplinati dal presente titolo e deputati all'aggiornamento, alla specializzazione, alla qualificazione e al ricondizionamento del personale militare sono individuati nel regolamento.

### Art. 217. - Collaborazione con le universita'

1. La collaborazione tra universita', accademie, istituti anche ospedalieri militari, puo' assumere aspetti istituzionali attraverso convenzioni da stipularsi da parte delle amministrazioni interessate.

2. Allo scopo di incentivare lo studio, l'aggiornamento e la ricerca, al personale docente appartenente ai ruoli organici delle accademie militari e dell'Istituto idrografico della Marina militare, puo' essere consentito, previo nulla osta degli enti di appartenenza e di concerto con i consigli di facolta', di svolgere attivita' didattica e di ricerca presso le universita' statali.

## CAPO II - SCUOLE MILITARI

### Art. 218. - Finalita' delle scuole militari

1. Le scuole militari sono istituti di istruzione che perseguono lo scopo principale di preparare i futuri allievi delle accademie militari; la scuola navale militare ha anche lo scopo di suscitare nei giovani l'interesse alla vita sul mare, orientandoli verso le attivita' a esso connesse; la scuola militare aeronautica ha anche lo scopo di stimolare nei giovani l'interesse per la vita aeronautica, orientandoli nel corso degli studi verso le attivita' a essa connesse.

2. Le funzioni di cui al comma 1 sono affidate alle seguenti scuole militari:

- a) Scuola militare <<Nunziatella>> dell'Esercito italiano;
- b) Scuola navale militare <<Francesco Morosini>>;
- c) Scuola militare <<Teulie>> dell'Esercito italiano;
- d) Scuola militare aeronautica <<Giulio Douhet>>.

3. ((COMMA ABROGATO DAL D. LGS. 31 DICEMBRE 2012, N. 248)).

### Art. 219. - Corsi di studio delle scuole militari

1. I corsi di studio seguiti presso le scuole militari sono stabiliti ai sensi dell'articolo 786.

### Art. 220. - Ammissione alle scuole militari

1. Le ammissioni alle scuole militari si effettuano ai sensi delle disposizioni contenute nel libro IV, titolo II, capi I e IX, e titolo III, capo XI del presente codice.

## CAPO III - ISTITUTI DI FORMAZIONE

### SEZIONE I - ACCADEMIE MILITARI

#### Art. 221. - Finalita' delle Accademie militari

1. Le accademie militari sono istituti di istruzione che perseguono lo scopo di consentire agli allievi ufficiali l'accesso ai ruoli normali degli ufficiali in servizio permanente.

2. Le funzioni di cui al comma 1 sono affidate alle seguenti accademie militari:

- a) Accademia militare dell'Esercito italiano;
- b) Accademia navale;
- c) Accademia aeronautica;
- d) Accademia dell'Arma dei carabinieri.

3. L'Accademia navale e l'Accademia aeronautica si occupano anche del completamento della formazione iniziale degli ufficiali dei vari ruoli, costituendo a tale scopo istituti militari di istruzione superiore di cui alla sezione II del presente capo.

#### Art. 222. - Corsi di studio delle Accademie militari

1. I corsi di studio seguiti presso le accademie militari sono definiti in base a quanto disposto dall'articolo 719.

2. Per le materie militari e professionali non rientranti negli ordinamenti didattici, definiti ai sensi del comma 1, i programmi sono stabiliti in base a quanto disposto nel libro IV, titolo III, capo I del regolamento.

#### Art. 223. - Ammissioni alle Accademie militari

1. L'ammissione degli allievi ufficiali presso le accademie militari si effettua ai sensi delle disposizioni contenute nel libro IV, titolo II, capi I e II.

### SEZIONE II - ISTITUTI MILITARI DI ISTRUZIONE SUPERIORE PER UFFICIALI

#### Art. 224. - Finalita' degli istituti militari di istruzione superiore

1. Gli istituti militari di istruzione superiore per gli ufficiali perseguono, nell'ambito delle rispettive competenze, i seguenti scopi:

- a) il completamento della formazione iniziale degli ufficiali, in base a quanto disposto dal libro IV, titolo III, capo II, e dal libro IV, titolo III, capo I del regolamento;
- b) la formazione superiore degli ufficiali, anche in previsione dell'impiego in incarichi di rilievo in ambito nazionale e internazionale, definita dal libro IV, titolo III, capo IV, e dal libro IV, titolo III, capo II del regolamento.

2. Le finalita' di cui al comma 1 sono affidate ai seguenti istituti militari di istruzione superiore:

- a) Istituto alti studi della difesa;
- b) Istituto superiore di Stato maggiore interforze;
- c) Istituto di studi militari marittimi;
- d) Istituto di scienze militari aeronautiche;
- e) Scuola di applicazione e Istituto di studi militari dell'Esercito italiano;
- f) Scuola ufficiali carabinieri.

#### Art. 225. - Corsi di studio degli istituti militari di istruzione superiore

1. I corsi di studio seguiti presso gli istituti militari di cui all'articolo 224 sono definiti in base a quanto disposto dall'articolo 719.

2. Per le materie militari e professionali non rientranti negli ordinamenti didattici, definiti ai sensi del comma 1, e per gli altri corsi di carattere non universitario o postuniversitario, l'ordine degli studi e i programmi sono stabiliti in base a quanto disposto nel libro IV, titolo III, capi I e II del regolamento.

### SEZIONE III - ALTRE SCUOLE

#### Art. 226. - Scuole per sottufficiali

1. Le scuole sottufficiali sono istituti di istruzione che perseguono lo scopo di consentire agli allievi l'accesso ai ruoli dei sottufficiali ai sensi delle disposizioni di cui al libro IV, titolo III, capi V, VI, VII e VIII.

2. Le finalita' di cui al comma 1 sono affidate alle seguenti scuole per sottufficiali:

- a) Scuola sottufficiali dell'Esercito italiano;
- b) Scuole sottufficiali della Marina militare;
- c) Scuola marescialli dell'Aeronautica militare;
- d) Scuola specialisti dell'Aeronautica militare;
- e) Scuola marescialli dell'Arma dei carabinieri;
- f) Scuola brigadieri dell'Arma dei carabinieri.

#### Art. 227. - Corsi di studio e ammissioni delle scuole sottufficiali

1. I corsi di studio seguiti presso le scuole sottufficiali si svolgono in base a quanto stabilito dalle disposizioni di cui al libro IV, titolo III, capi V, VI, VII e VIII e al libro IV, titolo III, capo I del regolamento.

2. L'ammissione degli allievi presso le scuole sottufficiali si effettua ai sensi delle disposizioni contenute nel libro IV, titolo II, capi I, IV e V del presente codice.

#### Art. 228. - Scuole carabinieri

1. Le scuole carabinieri hanno lo scopo di consentire agli allievi l'accesso al ruolo appuntati e carabinieri ai sensi delle disposizioni contenute nel libro IV, titolo III, capo X del presente codice.

2. I corsi di studio seguiti presso le scuole carabinieri sono definiti con determinazione del Comandante generale dell'Arma dei carabinieri.

3. L'ammissione degli allievi alle scuole carabinieri si effettua ai sensi delle disposizioni contenute nel libro IV, titolo II, capo VIII del presente codice.

#### Art. 229. - Scuola allievi operai delle Forze armate

1. Presso gli stabilimenti e le officine militari possono essere istituite, con decreto del Ministro per la difesa, scuole allievi operai per la formazione professionale di operai occorrenti alle Forze armate. Con lo stesso decreto istitutivo sono, altresi', stabiliti l'ordinamento delle scuole, la durata dei corsi, le prove di esame e le condizioni di ammissione degli allievi nonche', sentito il Ministro del lavoro e delle politiche sociali, i programmi dei corsi.

2. Le scuole allievi operai svolgono corsi annuali, biennali e triennali. Presso le stesse scuole possono essere svolti corsi per l'addestramento, la qualificazione e l'aggiornamento degli apprendisti e degli altri operai delle Forze armate.

3. Le scuole allievi operai sono dirette da un ufficiale superiore in servizio presso lo stabilimento od officina. Agli insegnamenti si provvede con personale militare e civile dipendente dal Ministero della difesa. Le funzioni di segretario sono affidate a un sottufficiale o a un impiegato della carriera di concetto o esecutiva in servizio presso lo stabilimento o l'officina.

## LIBRO SECONDO BENI TITOLO I DISPOSIZIONI GENERALI

### Art. 230. - Categorie dei beni della Difesa - Rinvio ad altre fonti

1. I beni della Difesa si distinguono in demanio pubblico e beni patrimoniali, disponibili e indisponibili, secondo le norme del codice civile, e sono sottoposti:

- a) alle disposizioni dettate nel codice civile per tali categorie di beni;
- b) alle disposizioni dettate nel codice della navigazione e relativo regolamento, e nelle pertinenti leggi speciali, per porti e aeroporti militari, navi e ((aeromobili)) militari;
- c) alle disposizioni dettate nel codice della proprieta' industriale (decreto legislativo 10 febbraio 2005 n. 30) per le invenzioni militari;
- d) alle disposizioni dettate nel codice penale per la tutela dei beni militari.

2. Per i beni culturali, come definiti dall'articolo 2, del decreto legislativo 22 gennaio 2004, n. 42, recante il codice dei beni culturali e del paesaggio, in uso al Ministero della difesa, resta ferma la disciplina all'uopo dettata dal citato decreto legislativo n. 42 del 2004, e, segnatamente, le regole in tema di verifica dell'interesse culturale di cui all'articolo 12 e le regole e relative deroghe in ordine agli obblighi di versamento di documenti all'Archivio di Stato di cui all'articolo 41. Restano ferme le specifiche competenze del Ministero della difesa in materia di patrimonio culturale subacqueo, previste dalla legge 23 ottobre 2009, n. 157.

3. Il presente libro detta le disposizioni specifiche per i beni della Difesa, ulteriori rispetto a quelle recate dai codici menzionati nel presente articolo. Sono fatte salve le convenzioni internazionali e relative leggi di ratifica.

### Art. 231. - Demanio militare e demanio culturale in consegna alla Difesa

1. Appartengono al demanio militare del Ministero della difesa le opere destinate alla difesa nazionale.

2. Gli aeroporti militari fanno parte del demanio militare aeronautico.

3. Appartengono al demanio culturale gli immobili in consegna al Ministero della difesa, non rientranti nel demanio militare di cui al comma 1, riconosciuti di interesse storico, archeologico e artistico a norma delle leggi in materia, le raccolte di musei, pinacoteche, archivi, biblioteche a esso assegnati.

4. Fatta salva l'applicazione dell'articolo 147, comma 1, del decreto legislativo 22 gennaio 2004, n. 42, recante il codice dei beni culturali e del paesaggio, rientrano tra le opere destinate alla difesa nazionale e sono considerati infrastrutture militari, a ogni effetto, tutti gli alloggi di servizio per il personale militare realizzati su aree ubicate all'interno di basi, impianti, installazioni militari o posti al loro diretto e funzionale servizio.

### Art. 232. - Patrimonio indisponibile della Difesa

1. Fanno parte del patrimonio indisponibile del Ministero della difesa, se a esso assegnati in uso, le caserme, gli armamenti, gli aeromobili militari e le navi da guerra e comunque militari, gli edifici destinati a sede di pubblici uffici con i loro arredi e gli altri beni destinati a un pubblico servizio della Difesa.

### Art. 233.

Individuazione delle opere destinate alla difesa ((e alla sicurezza)) nazionale a fini determinati

1. Ai fini urbanistici, edilizi, ambientali e al fine dell'affidamento ed esecuzione di contratti pubblici relativi a lavori, servizi e forniture, sono opere destinate alla difesa ((e alla sicurezza)) nazionale le infrastrutture rientranti nelle seguenti categorie:

- a) sedi di servizio e relative pertinenze necessarie a soddisfare le esigenze logistico - operative dell'Arma dei carabinieri;
- b) opere di costruzione, ampliamento e modificazione di edifici o infrastrutture destinati ai servizi della leva, del reclutamento, incorporamento, formazione professionale e addestramento dei militari della Marina militare, da realizzare nelle sedi di La Spezia, Taranto e La Maddalena su terreni del demanio, compreso quello marittimo;
- c) aeroporti ed eliporti;
- d) basi navali;
- e) caserme;
- f) stabilimenti e arsenali;
- g) reti, depositi carburanti e lubrificanti;
- h) depositi munizioni e di sistemi d'arma;
- i) comandi di unita' operative e di supporto logistico;
- l) basi missilistiche;
- m) strutture di comando e di controllo dello spazio terrestre, marittimo e aereo;
- n) segnali e ausili alla navigazione marittima e aerea;
- o) strutture relative alle telecomunicazioni e ai sistemi di allarme;
- p) poligoni e strutture di addestramento;
- q) centri sperimentali di manutenzione dei sistemi d'arma;
- r) opere di protezione ambientale correlate alle opere della difesa e sicurezza nazionale;
- s) installazioni temporanee per esigenze di rapido dispiegamento;
- s-bis) le strutture di cui agli articoli 10-ter e 14 del ((testo unico di cui al decreto legislativo 25 luglio 1998, n. 286,)) e agli articoli 9 e 11 del decreto legislativo 18 agosto 2015, n. 142;
- t) attivita' finanziate con fondi comuni della NATO e da utenti alleati sul territorio nazionale.

1-bis. Alle costruzioni e alle ricostruzioni di edilizia residenziale pubblica destinate a uso militare si applica l'articolo 1 della legge 29 luglio 1949, n. 717, e successive modificazioni. ((1-ter).)) Per la realizzazione delle opere di cui al presente articolo, il Ministero della difesa e' autorizzato ad avvalersi delle procedure di cui all'articolo 140 del ((codice dei contratti pubblici, di cui al)) decreto legislativo 31 marzo 2023, n. 36.

### Art. 234. - Registri e inventari

1. I beni della Difesa sono descritti in appositi registri di consistenza o inventari.

2. L'inventario dei beni di demanio pubblico della Difesa e' eseguito a cura del Ministero della difesa e consiste in uno stato descrittivo desunto dai rispettivi catasti, ovvero dai registri dell'amministrazione.

3. L'originale dell'inventario e' conservato dalle amministrazioni centrali militari e gli estratti dalle rispettive direzioni territoriali o uffici dipendenti.

### Art. 235. - Disciplina del segreto su beni e attivita' militari. Rinvio

1. Il segreto su atti, documenti, notizie, attivita' e beni militari e' disciplinato dalla legge 3 agosto 2007, n. 124 e dai decreti del Presidente del Consiglio dei Ministri 8 aprile 2008, 12 giugno 2009, n. 7 e 12 giugno 2009, n. 8.

## TITOLO II SINGOLE CATEGORIE DI BENI MILITARI CAPO I OPERE PERMANENTI DI PROTEZIONE ANTIAEREA

### Art. 236. - Opere permanenti di protezione antiaerea

1. Rientrano tra le opere destinate alla difesa nazionale e costituiscono demanio militare le opere permanenti di protezione antiaerea.

## CAPO II - STRADE MILITARI, VEICOLI E PATENTI MILITARI, ESIGENZE MILITARI IN RELAZIONE ALLA CIRCOLAZIONE STRADALE

### Art. 237. - Strade militari ed esigenze militari in relazione alla circolazione stradale

1. Sono strade militari quelle destinate esclusivamente al traffico militare.

2. Ente proprietario e' considerato il comando ((interregionale)).

3. La classifica delle strade militari e' fatta con decreto del Ministro della difesa. L'elenco delle strade militari, redatto a cura del Ministero della difesa, non e' pubblico.

4. Alle strade di esclusivo uso militare non si applica l'articolo 13 del decreto legislativo 30 aprile 1992, n. 285 recante il nuovo codice della strada.

5. Il Comandante ((interregionale)), in relazione alle strade militari di cui e' proprietario il comando ((interregionale)) a cui e' preposto:

- a) puo' destinare le strade militari all'uso pubblico con provvedimento generale, ovvero all'uso privato con provvedimento particolare;
- b) adotta i provvedimenti per la regolamentazione della circolazione, di cui agli articoli 6 e 7 del decreto legislativo n. 285 del 1992, con ordinanze motivate e rese note al pubblico mediante i prescritti segnali;
- c) per motivi di sicurezza pubblica o inerenti alla sicurezza della circolazione, di tutela della salute, nonche' per esigenze di carattere militare puo', conformemente alle direttive del Ministro delle infrastrutture e dei trasporti, sospendere temporaneamente la circolazione di tutte o di alcune categorie di utenti sulle strade militari o su tratti di esse;
- d) puo' vietare la circolazione di veicoli adibiti al trasporto di cose nei giorni festivi o in particolari altri giorni fissati con apposito calendario, da emanarsi con decreto del Ministro delle infrastrutture e dei trasporti;
- e) stabilisce, anno per anno, le opportune prescrizioni per il transito periodico di armenti e di greggi determinando, quando occorra, gli itinerari e gli intervalli di tempo e di spazio;
- f) rilascia l'autorizzazione alla circolazione per i trasporti e i veicoli eccezionali come definiti dall'articolo 10 del decreto legislativo n. 285 del 1992 alle condizioni di cui al citato articolo 10;
- g) rilascia le autorizzazioni di cui all'articolo 26 del decreto legislativo n. 285 del 1992;
- h) impartisce le direttive per l'organizzazione della circolazione e della relativa segnaletica stradale, di cui all'articolo 35 del decreto legislativo n. 285 del 1992.

6. Contro i provvedimenti emessi dal comandante ((interregionale)) e' ammesso ricorso gerarchico al Ministro della difesa.

7. L'impianto su strade militari e sulle relative pertinenze di linee ferroviarie, tranviarie, di speciali tubazioni o altre condotte comunque destinate a servizio pubblico, o anche il solo attraversamento di strade o relative pertinenze con uno qualsiasi degli impianti di cui sopra, sono autorizzati, in caso di assoluta necessita' e ove non siano possibili altre soluzioni tecniche, con decreto del Ministro delle infrastrutture e dei trasporti, di concerto con il Ministro della difesa.

8. Alla manutenzione ordinaria e straordinaria delle strade militari aperte al pubblico transito provvede l'amministrazione militare con il contributo dei comuni attraversati dalle strade medesime, da fissare mediante speciali convenzioni. L'obbligo del contributo cessa ogni qual volta, per esigenze della Difesa, e' vietato il transito pubblico sulla strada militare, e risorge cessato il divieto. L'obbligo del contributo dei comuni decorre dal 1° gennaio o dal 1° luglio successivo alla data del decreto ministeriale di classificazione di cui al comma 3, in modo che rimanga sempre un periodo di almeno sei mesi fra la data del decreto e l'inizio della manutenzione.

9. Per le esigenze esclusive del traffico militare, nelle strade di uso pubblico e' ammessa l'installazione di segnaletica stradale militare, secondo le disposizioni all'uopo dettate dall'articolo 38 del decreto legislativo n. 285 del 1992 e del relativo regolamento. Gli enti proprietari delle strade sono tenuti a consentire l'installazione provvisoria o permanente dei segnali ritenuti necessari dall'autorita' militare per la circolazione dei propri veicoli.

10. Fermo quanto disposto dall'articolo 12 del decreto legislativo n. 285 del 1992, la scorta e l'attuazione dei servizi diretti ad assicurare la marcia delle colonne militari spetta, altresi', agli ufficiali, sottufficiali, graduati e militari di truppa delle Forze armate, appositamente qualificati con specifico attestato rilasciato dall'autorita' militare competente.

11. Ai veicoli e conducenti delle Forze armate si applicano gli articoli 138 e 142, comma 4 del decreto legislativo n. 285 del 1992.

12. Ai convogli militari e colonne di truppe su strada si applicano gli articoli 163 e 192, commi 5 e 6, del decreto legislativo n. 285 del 1992.

13. Per quanto non disposto nel presente articolo, alle strade militari aperte al traffico civile, ai veicoli e conducenti delle Forze armate, ai convogli militari e simili su strada si applicano le disposizioni del decreto legislativo n. 285 del 1992, in quanto compatibili.

## CAPO III - PORTI E AEROPORTI MILITARI, NAVI E ((AEROMOBILI)) MILITARI

### SEZIONE I - PORTI E AEROPORTI MILITARI

#### Art. 238. - Porti e aeroporti militari

1. I porti, o le specifiche aree portuali, destinati unicamente o principalmente alla difesa militare e alla sicurezza dello Stato appartengono ai porti di prima categoria.

2. Fermo quanto disposto dall'articolo 59 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, e dalle analoghe disposizioni contenute nei decreti del Presidente della Repubblica di attuazione degli statuti delle Regioni a statuto speciale, il Ministro della difesa, con proprio decreto, emanato di concerto con il Ministro delle infrastrutture e dei trasporti, determina le caratteristiche e procede all'individuazione dei porti o delle specifiche aree portuali di cui alla prima categoria; con lo stesso provvedimento sono disciplinate le attivita' nei porti di prima categoria e relative baie, rade e golfi.

3. Negli aeroporti militari aperti al traffico aereo civile, ogni modifica alle infrastrutture di volo esistenti e ai relativi impianti e' realizzata d'intesa tra il Ministero delle infrastrutture e dei trasporti e il Ministero della difesa, avendo cura di non limitare l'agibilita' al traffico aereo e di assicurare la rispondenza delle infrastrutture di volo alle norme di sicurezza regolanti il traffico militare e quello civile. Alla progettazione delle opere da eseguire negli aeroporti militari aperti al traffico civile provvede il Ministero delle infrastrutture e dei trasporti, di intesa con il Ministero della difesa.

((

3-bis. Nella determinazione dei diritti aeroportuali da applicarsi negli aeroporti militari aperti al traffico civile, si tiene conto anche delle infrastrutture e dei servizi forniti dall'Aeronautica militare, che stipula apposita convenzione con il gestore aeroportuale, per la definizione degli stessi e l'individuazione delle modalita' per il ristoro dei costi sostenuti.

))

4. Fatto salvo quanto disposto dal comma 3, per gli aeroporti militari resta ferma la disciplina all'uopo prevista nel codice della navigazione, e le relative disposizioni tecniche di attuazione.

### SEZIONE II - NAVI MILITARI E NAVI DA GUERRA REGISTRO DELLE NAVI GALLEGGIANTI IN SERVIZIO GOVERNATIVO NON COMMERCIALE

#### Art. 239. - Navi militari e navi da guerra

1. Sono navi militari quelle che hanno i seguenti requisiti:

- a) sono iscritte nel ruolo del naviglio militare ((, classificate, per la Marina militare, in base alle caratteristiche costruttive e d'impiego, in navi di prima linea, navi di seconda linea e naviglio specialistico e collocate nelle categorie e nelle posizioni stabilite con decreto del Ministro della difesa));
- b) sono comandate ed equipaggiate da personale militare, sottoposto alla relativa disciplina;
- c) recano i segni distintivi della Marina militare o di altra Forza armata o di Forza di polizia a ordinamento militare.

2. Per "nave da guerra" si intende una nave che appartiene alle Forze armate di uno Stato, che porta i segni distintivi esteriori delle navi militari della sua nazionalita' ed e' posta sotto il comando di un ufficiale di ((marina)) al servizio dello Stato e iscritto nell'apposito ruolo degli ufficiali o in documento equipollente, il cui equipaggio e' sottoposto alle regole della disciplina militare.

3. La nave da guerra costituisce una parte del territorio dello Stato.

#### Art. 240. - Navi armate e navi in disponibilita'

1. Le navi, secondo le loro condizioni nei riguardi degli effettivi del personale e dell'efficienza del materiale, si distinguono nel modo seguente:

- a) navi armate;
- b) navi in disponibilita'.

#### Art. 241. - Assegnazione delle unita' navali

1. La costituzione delle Forze navali armate e del naviglio in disponibilita', l'assegnazione ai servizi costieri e al naviglio sussidiario, e' stabilita dal Capo di stato maggiore della Marina militare.

#### Art. 242. - Radiazione dal ruolo del naviglio militare

1. Sono radiate dai ruoli del naviglio militare, le unita' che, ((iscritte con decreto del Ministro della difesa nel ruolo del naviglio militare dello Stato all'atto della consegna,)) a giudizio del Ministro della difesa, sentito il parere del Capo di stato maggiore della Marina militare, non possono piu' rendere utili servizi in rapporto alla spesa di manutenzione e di esercizio. Le navi radiate possono essere temporaneamente impiegate come navi caserme, o per servizi non bellici.

#### Art. 243. - Iscrizione nel quadro del naviglio militare dello Stato di unita' dell'Esercito italiano, dell'Aeronautica militare, dell'Arma dei carabinieri, del Corpo della Guardia di finanza e del Corpo delle capitanerie di porto

1. Le unita' navali in dotazione all'Esercito italiano, all'Aeronautica militare, all'Arma dei carabinieri, al Corpo della Guardia di finanza e al Corpo delle capitanerie di porto sono iscritte in ruoli speciali del naviglio militare dello Stato.

2. I piani delle unita' sopraindicate sono trasmessi allo Stato maggiore della Marina militare che indica gli eventuali lavori e modifiche da eseguirsi allo scopo di consentire l'installazione di particolari apprestamenti militari compatibili con il normale impiego nei servizi di istituto.

3. Con il regolamento, sul quale su tale parte e' acquisito il concerto dei Ministri interessati, sono stabilite le modalita' per l'applicazione del presente articolo e regolati i rapporti che ne derivano; e' anche disciplinata la posizione del personale che costituisce l'equipaggio delle suddette unita'.

#### Art. 244. - Registro delle navi e galleggianti in servizio governativo non commerciale

1. Il Ministero della difesa cura la tenuta del registro delle navi e galleggianti in servizio governativo non commerciale.

2. Nel registro e' iscritto il naviglio delle amministrazioni dello Stato adibito a servizio governativo non commerciale, il cui personale non e' a ordinamento militare.

3. Le unita' e i mezzi navali, iscritti nel registro, inalberano la bandiera nazionale costituita dal tricolore italiano caricato al centro della banda bianca dell'emblema araldico della Repubblica italiana.

4. Le norme di attuazione sono contenute nel regolamento.

#### Art. 245. - Incendio su nave da guerra

1. In caso d'incendio su nave da guerra, la direzione delle operazioni a bordo spetta esclusivamente al comandante della nave, il quale tiene informato il comandante del porto dell'entita' dell'incendio e dell'andamento delle operazioni.

2. Il comandante del porto assume la direzione delle operazioni di soccorso per quanto riguarda la sicurezza del porto e delle altre navi, e coadiuva, ove richiesto, il comando della nave da guerra con i mezzi e l'organizzazione antincendi del porto.

### SEZIONE III - AEROMOBILI A PILOTAGGIO REMOTO DELLE FORZE ARMATE

#### Art. 246. - Nozione

1. Ai fini della presente sezione, per aeromobile a pilotaggio remoto, di seguito denominato <<APR>>, si intende un mezzo aereo pilotato da un equipaggio che opera da una stazione remota di comando e controllo.

#### Art. 247. - Autorizzazione e limiti all'impiego degli APR in dotazione alle Forze armate

1.((. . . )) ((Le)) Forze armate italiane sono autorizzate a impiegare APR in dotazione in attivita' operative e addestrative per la difesa e la sicurezza nazionale.

2. L'impiego degli APR avviene nell'ambito di spazi aerei determinati e con le limitazioni stabilite nell'apposito documento tecnico-operativo adottato dall'Aeronautica militare, sentita la Forza armata che impiega gli APR, e dall'Ente nazionale per l'aviazione civile, di concerto con l'Ente nazionale di assistenza al volo, per gli aspetti di gestione e controllo del traffico aereo.

3. Le limitazioni di cui al comma 2, riguardanti i profili di missione, le procedure operative, le aree di lavoro e gli equipaggiamenti, sono stabilite nel rispetto dei principi della sicurezza del volo.

4. Nel corso di operazioni sul territorio nazionale o all'estero connesse a situazioni di crisi o di conflitto armato l'impiego degli APR non e' sottoposto alle limitazioni di cui al comma 2.

#### Art. 248. - (( (APR di peso inferiore a 20 chilogrammi).))

((1.La conduzione degli APR di peso inferiore a 20 chilogrammi, ammessi alla navigazione e certificati dalla competente struttura del Ministero della difesa e dalla stessa iscritti in apposito registro, impiegati dalle Forze armate entro aree identificate e sottoposte al divieto temporaneo di sorvolo ovvero al di fuori di tali aree nei casi di cui all'articolo 247, comma 4, e' affidata a personale militare in possesso di idonea qualifica e non comporta la corresponsione di specifici emolumenti. I criteri d'impiego dei medesimi APR e le modalita' per il conseguimento della qualifica per la conduzione degli stessi sono disciplinati dal regolamento.))

#### Art. 248-bis.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

## CAPO IV - RIFUGI ALPINI

### Art. 249. - Rifugi alpini demaniali e rifugi alpini pubblici e privati di interesse della Difesa

1. I rifugi alpini, gia' appartenenti a cittadini, a societa' e a enti ex nemici, devoluti al demanio dello Stato in virtu' dell'articolo 1 del regio decreto 10 aprile 1921, n. 470, restano assegnati al Ministero della difesa, che puo' concederli in esercizio a cittadini italiani e a societa' ed enti nazionali. Le concessioni di esercizio sono accordate previa intesa con il Ministro dell'economia e delle finanze nonche' con il Ministro per i beni e le attivita' culturali per i rifugi alpini sottoposti a tutela o ricadenti in aree sottoposte a tutela ai sensi del decreto legislativo 22 gennaio 2004, n. 42, ovvero con quello delle politiche agricole, alimentari e forestali, per i rifugi alpini ubicati in fondi e boschi appartenenti al demanio forestale. Resta fermo quanto disposto dall'articolo 3 del decreto legislativo 21 dicembre 1998, n. 495, in ordine al trasferimento di rifugi alpini alla Provincia autonoma di Bolzano e al loro utilizzo per esigenze addestrative - operative del Ministero della difesa.

2. Dei rifugi alpini di proprieta' privata puo' essere disposta l'espropriazione dall'autorita' militare, secondo le norme per le espropriazioni finalizzate alla realizzazione delle opere militari dettate dal decreto del Presidente della Repubblica 8 giugno 2001, n. 327.

## CAPO V - CAMPI DI TIRO A SEGNO

### Art. 250.

(( (Campi e impianti di tiro a segno) )). ((

1. I campi di tiro a segno impiantati a spese dello Stato sono compresi tra gli immobili demaniali militari.

2. L'esecuzione tecnica dei lavori relativi all'impianto, sistemazione e manutenzione dei campi e impianti di tiro a segno di cui al comma 1 e' affidata alla vigilanza del Ministero della difesa.

3. I campi di tiro a segno di cui al comma 1 sono dati in uso, a titolo gratuito, alle sezioni di tiro a segno, senza oneri a carico dello Stato.

### Art. 251. - Uso speciale e obbligatorio dei campi di tiro a segno - Quota di iscrizione

1. Coloro che prestano servizio armato presso enti pubblici o privati sono obbligati a iscriversi a una sezione di tiro a segno nazionale e devono superare ogni anno un corso di lezioni regolamentari di tiro a segno.

2. L'iscrizione e la frequenza a una sezione di tiro a segno nazionale sono obbligatorie, ai fini della richiesta del permesso di porto d'armi per la caccia o per uso personale, per coloro che non hanno prestato o non prestano servizio presso le Forze armate dello Stato.

3. La quota annua per l'iscrizione obbligatoria alle sezioni di tiro a segno nazionale per le categorie indicate ai commi 1 e 2 e' stabilita in euro 11,56. Con decreto dirigenziale della competente struttura del Ministero della difesa, di concerto con i ((...)) Ministeri dell'interno, della giustizia, dell'economia e delle finanze e delle politiche agricole, alimentari e forestali, si provvede ad adeguare annualmente detta quota, sulla base delle variazioni percentuali del costo della vita quale risulta ai fini delle rilevazioni ISTAT per i conti economici nazionali pubblicati a marzo di ogni anno nella relazione sulla situazione economica del Paese. Gli aumenti decorrono dal 1° gennaio dell'anno successivo a quello di rilevazione.

## CAPO VI - ZONE MONUMENTALI DI GUERRA, PATRIMONIO STORICO DELLA PRIMA GUERRA MONDIALE, SEPOLCRETI DI GUERRA

### SEZIONE I - ZONE MONUMENTALI DI GUERRA

#### Art. 252. - Individuazione delle zone monumentali di guerra

1. Istituite ai sensi dell'abrogato regio decreto-legge 29 ottobre 1922, n. 1386, a consacrazione nei secoli della gratitudine della Patria verso i figli che per la sua grandezza vi combatterono epiche lotte nella guerra di redenzione 1915- 1918, le seguenti zone, scelte fra quelle piu' legate a immortali fasti di gloria, sono dichiarate monumentali e costituiscono demanio culturale gestito dal Ministero della difesa:

- a) Monte Pasubio;
- b) Monte Grappa;
- c) Monte Sabotino;
- d) Monte San Michele.

2. Sono altresi' zone monumentali di guerra e demanio culturale gestito dal Ministero della difesa:

- a) la zona di Castel Dante in Rovereto;
- b) la zona di Monte Cengio;
- c) la zona di Monte Ortigara;
- d) la zona Punta Serauta della Marmolada, sita nel comune di Rocca Pietore (Belluno).

#### Art. 253. - Delimitazione delle zone monumentali di guerra

1. Le zone monumentali di cui alle lettere a), b), c), e d) del comma 1 dell'articolo 252 sono cosi' delimitate:

- a) Pasubio: sommita' del monte elevantesi sulla curva di livello di 2200 metri, comprendente il Dente Italiano, la cima Palom e il cocuzzolo immediatamente a Sud di detta cima. Strada d'accesso: rotabile Ponte Verde (presso il Pian delle Fugazze) - colle Xomo - Scarubbi - Porte Pasubio, indi mulattiera al Palom;
- b) Grappa: sommita' del monte al di sopra della quota di 1700 metri, con lo sprone della Nave, la galleria Vittorio Emanuele e la caserma Milano, esclusa la parte meridionale su cui sorge la Madonnina e il rifugio del Club alpino. Strada d'accesso: rotabile Romano Alto-Osteria del Campo-Monte Grappa;
- c) Sabotino: sommita' del monte al di sopra della curva di livello di 520 metri dal Sasso Spaccato a ovest, ai ruderi della chiesa di San Valentino (esclusi) a est. Strada d'accesso: rotabile Gunjace Bala-bivio Ver-holje-Sabotino;
- d) San Michele: sommita' del Monte al di sopra della curva di livello di 250 metri con le cime 1, 2, 3 e 4 e il monumentino commemorativo della Brigata <<Ferrara>> a sud-est della cima 4. Strada d'accesso : rotabile Peteano - San Michele - San Martino.

2. La delimitazione delle zone di cui al comma 2 dell'articolo 252 e' effettuata con decreto del Ministro della difesa, di concerto con il Ministro per i beni e le attivita' culturali.

#### Art. 254. - Vigilanza e conservazione

1. Le zone monumentali di cui alla presente sezione sono poste sotto l'alta sorveglianza del Ministero della difesa - ((Ufficio per la tutela della cultura e della memoria della difesa)), che provvede alla loro delimitazione, custodia e conservazione, alla intangibilita' dei monumenti e delle opere di guerra in esse esistenti e alla manutenzione delle strade d'accesso.

2. Il Ministero della difesa - ((Ufficio per la tutela della cultura e della memoria della difesa)) provvede a far erigere e a mantenere stele romane nelle localita' del fronte di guerra - pur esse notevoli per azioni svoltesi - sulle quali non e' stato collocato un particolare ricordo.

### SEZIONE II - PATRIMONIO STORICO DELLA PRIMA GUERRA MONDIALE

#### Art. 255. - (( (Attribuzioni del Ministero della difesa in materia di patrimonio storico della Prima guerra mondiale).))

((

1. Le competenze del Ministero della difesa in materia di patrimonio storico della Prima guerra mondiale sono disciplinate dalla legge 7 marzo 2001, n. 78.

))

#### Art. 256.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 257.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 258.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 259.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 260.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 261.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 262.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 263.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 264.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

### SEZIONE III - SEPOLCRETI DI GUERRA ITALIANI

#### Art. 265. - Nozione e qualificazione

1. I sepolcreti di guerra sono comprensivi di cimiteri, ossari e sacrari di guerra.

2. Fatto salvo quanto diversamente disposto dalla sezione IV del presente capo o da accordi internazionali, i sepolcreti di guerra, definitivamente sistemati nel territorio nazionale, fanno parte, con le loro dipendenze, del patrimonio dello Stato.

#### Art. 266. - Organi e uffici

1. Il ((capo dell'Ufficio per la tutela della cultura e della memoria della difesa)), nel presente capo denominato <<((capo dell'Ufficio))>>, esercita le proprie funzioni alla diretta dipendenza del Ministro della difesa.

2. Al Ministro della difesa compete la nomina del ((capo dell'Ufficio)) e la vigilanza su di esso, l'organizzazione ((dell'Ufficio)), e la decisione in caso di dissenso tra il ((capo dell'Ufficio)) e le altre amministrazioni con le quali questi debba prendere accordi per l'espletamento delle sue funzioni.

3. Le indennita' dovute al ((capo dell'Ufficio)) sono stabilite con il decreto di nomina.

4. Alle dipendenze del ((capo dell'Ufficio)) opera ((l'Ufficio per la tutela della cultura e della memoria della difesa)).

#### Art. 267. - Competenze

1. Il ((capo dell'Ufficio)) e' competente in ordine a:

- a) la sistemazione, manutenzione e custodia dei cimiteri di guerra esistenti nel territorio dello Stato italiano, nonche' di quelli esistenti all'estero contenenti salme di Caduti italiani;
- b) gli accordi anche direttamente con i rappresentanti dei governi interessati per la sistemazione di caduti ex nemici e alleati in Italia e dei caduti italiani tumulati all'estero, in conformita' alle disposizioni dei Trattati di pace;
- c) gli accordi con le singole amministrazioni dello Stato e con gli enti locali e, tramite il Ministero degli affari esteri, con le rappresentanze dello Stato all'estero;
- d) la conservazione delle zone monumentali di guerra, la raccolta di documentazioni e cimeli, la diffusione di notizie sui caduti e sulle vicende belliche, l'organizzazione delle visite e dell'assistenza religiosa ai sepolcreti di guerra.

2. Il ((capo dell'Ufficio)) e' competente per il censimento, la raccolta, la sistemazione provvisoria e successiva sistemazione definitiva delle salme:

- a) dei militari italiani morti in conseguenza della Grande guerra dal 24 maggio 1915 al 31 ottobre 1920;
- b) dei militari e militarizzati italiani deceduti in conseguenza della guerra, sia nel territorio metropolitano sia fuori di esso, dal 10 giugno 1940 al 15 aprile 1946, purche' per i militarizzati e' accertato, in sede di liquidazione della pensione di guerra ai familiari, che la morte fu dovuta al servizio di guerra;
- c) dei militari e civili deceduti in stato di prigionia o di internamento successivamente al 10 giugno 1940;
- d) dei partigiani e dei patrioti deceduti in conseguenza della lotta di liberazione dopo l'8 settembre 1943;
- e) di tutti i civili deceduti dopo l'8 settembre 1943 quali ostaggi o per atti di rappresaglia;
- f) dei marittimi mercantili deceduti per fatto di guerra nel periodo 10 giugno 1940-15 aprile 1946;
- g) dei militari, dei militarizzati e dei civili italiani deceduti in conseguenza di eventi di guerra nelle ex colonie italiane dell'Africa, del Dodecaneso e nella guerra di Spagna;
- h) dei militari, dei militarizzati e volontari deceduti in conseguenza di eventi bellici che hanno interessato anche gli Stati preunitari a decorrere dal 4 marzo 1848;
- i) dei militari e dei militarizzati deceduti durante le missioni di pace.

3. Il ((capo dell'Ufficio)) provvede inoltre a:

- a) la sistemazione delle salme degli italiani appartenenti a Forze armate operanti al servizio della sedicente repubblica sociale italiana, deceduti in conseguenza della guerra;
- b) la sistemazione provvisoria delle salme dei militari appartenenti alle Forze armate delle Nazioni Unite deceduti in Italia durante la guerra 1940-1945, ove non vi hanno provveduto direttamente i rispettivi Stati e salva la competenza, per quanto riguarda l'impianto e la manutenzione di cimiteri destinati all'inumazione dei militari delle Forze armate delle Nazioni Unite caduti in territorio italiano durante la seconda guerra mondiale, del Ministero delle infrastrutture e dei trasporti;
- c) alla sistemazione delle salme dei militari degli eserciti nemici caduti in Italia, nei limiti dell'articolo 4 della Convenzione di Ginevra del 27 luglio 1929, ratificata dal regio decreto-legge 23 ottobre 1930, n. 1615 e di quanto altro stabilito nei trattati di pace.

4. Alle sistemazioni di cui al comma 2 e di cui al comma 3, lettera b) si fara' luogo se e in quanto i congiunti non vi hanno provveduto, o non vi provvedano coi sussidi che il ((capo dell'Ufficio)) puo' mettere a loro disposizione di concerto con il Ministero dell'economia e delle finanze.

5. I progetti tecnici delle opere da eseguirsi nei cimiteri di guerra dello Stato italiano sono compilati, di regola, a cura ((dell'Ufficio per la tutela della cultura e della memoria della difesa)).

#### Art. 268. - Contratti per le sepolture militari in Italia e all'estero

1. Il ((capo dell'Ufficio)) puo' provvedere agli affidamenti in economia di lavori, servizi e forniture relativi alla sistemazione delle sepolture militari, nei limiti consentiti dalla vigente legislazione.

2. La sistemazione nei territori esteri delle salme dei militari e civili italiani e' di regola affidata dal ((capo dell'Ufficio)), tramite le rappresentanze diplomatiche o consolari italiane, a organizzazioni o persone esistenti in detti territori. Solo eccezionalmente possono essere inviate missioni all'estero per tale scopo, previa intesa con il Ministero dell'economia e delle finanze.

3. Per quanto riguarda le spese relative alla sistemazione delle salme di italiani caduti o deceduti all'estero in conseguenza della guerra, e' data facolta' al ((capo dell'Ufficio)) di adottare provvedimenti in deroga alle norme di contabilita' dello Stato e delle spese pubbliche.

4. Agli atti e ai contratti stipulati ai sensi del presente articolo e' applicato il trattamento tributario stabilito per gli atti e contratti dello Stato.

#### Art. 269. - Affidamento della sistemazione provvisoria delle salme ai comuni

1. Il compito della sistemazione provvisoria delle salme di cui al comma 2 e al comma 3 dell'articolo 267 nei cimiteri comunali puo' essere affidato, dal ((capo dell'Ufficio)) ovvero dal Ministero delle infrastrutture e trasporti, nell'ambito delle rispettive competenze, ai singoli Comuni, con l'osservanza delle direttive generali e particolari impartite di intesa, ove occorra, con il Ministero dell'interno.

2. In tal caso i Comuni hanno diritto al rimborso delle spese.

#### Art. 270. - Localizzazione delle aree ed espropriazione

1. Nella scelta delle localita' per la sistemazione dei sepolcreti di guerra, va acquisito il parere preventivo del Ministero per i beni e le attivita' culturali se si tratta di zone che, ai sensi del codice dei beni culturali e del paesaggio, hanno interesse artistico o archeologico, oppure di bellezza naturale o panoramica.

2. All'eventuale espropriazione si applica l'articolo 51 del decreto del Presidente della Repubblica 8 giugno 2001, n. 327, recante il testo unico delle disposizioni legislative e regolamentari in materia di espropriazione per pubblica utilita'. Se necessario, il decreto ministeriale che dichiara la pubblica utilita' dichiara altresi' l'indifferibilita' e urgenza ai fini dell'articolo 22-bis del citato testo unico.

#### Art. 271. - Inventariazione e affidamento dei sepolcreti nel territorio nazionale

1. I sepolcreti, previa iscrizione negli inventari tenuti dall'amministrazione finanziaria, sono dati in consegna, ove possibile, a cura del ((capo dell'Ufficio)) mediante stipula di regolari atti, ai Comuni nel cui territorio si trovano, con l'obbligo di mantenerli e custodirli in perpetuo.

2. L'obbligo dell'iscrizione negli inventari tenuti dall'amministrazione finanziaria si riferisce anche ai diritti di uso costituiti a favore dello Stato su sepolcreti di guerra esistenti o sistemati a cura dei Comuni o di altri enti locali.

3. Le salme dei Caduti in guerra e nella lotta di liberazione, sepolte nei cimiteri civili, sono esenti dai normali turni di esumazione previsti dal regolamento di polizia mortuaria, e i comuni interessati hanno l'obbligo di conservarle fino a quando tali salme non sono definitivamente sistemate negli ossari o sacrari all'uopo costruiti.

4. A richiesta dei comuni interessati e mediante apposite convenzioni da approvarsi dal Ministero della difesa, di concerto con i Ministeri dell'interno e dell'economia e delle finanze, in base alle competenze di cui all'articolo 267, sono stabilite le somme da corrispondere dallo Stato a titolo di contributo nelle spese di manutenzione e custodia delle opere date in consegna e a titolo di contributo nelle spese di manutenzione e custodia delle sepolture di cui al comma 3.

#### Art. 272. - Restituzione delle salme ai congiunti

1. Le salme dei Caduti a suo tempo contemplati dall'abrogata legge 9 gennaio 1951, n. 204, definitivamente sistemate a cura del ((capo dell'Ufficio)) possono essere concesse ai congiunti su richiesta e a spese degli interessati.

#### Art. 273. - Soppressione di cimiteri di guerra

1. E' in facolta' del ((capo dell'Ufficio)) abolire i cimiteri di guerra che per l'ubicazione, per ragioni tecniche e per altri motivi non offrano la possibilita' di uno stabile assetto.

2. I resti mortali esistenti nei cimiteri soppressi sono raccolti in cimiteri viciniori ovvero in appositi sacrari costruiti in localita' opportunamente prescelte.

#### Art. 274. - Altre norme applicabili

1. Per quanto non stabilito nella presente sezione, vanno osservate le disposizioni relative ai cimiteri comuni stabilite dalla legge sanitaria e dal regolamento di polizia mortuaria.

2. Le disposizioni di cui all'articolo 338, comma 1, del regio decreto 27 luglio 1934, n. 1265, recante il testo unico delle leggi sanitarie, relative a una distanza minima di 200 metri dei cimiteri dai centri abitati e in genere da ogni edificio, non si applicano ai cimiteri militari di guerra, quando siano trascorsi dieci anni dal seppellimento dell'ultima salma.

#### Art. 275. - Estensione della disciplina dei sepolcreti di guerra a sacrari nominati

1. Sono equiparati a tutti gli effetti ai cimiteri di guerra, e sono soggetti alla disciplina prevista nella presente sezione:

- a) il Sacrario di Monte Zurrone (Roccaraso);
- b) il Monumento sacrario dei 51 martiri di Leonessa (Rieti);
- c) il Monumento sacrario dedicato al ricordo dei caduti e dei dispersi di tutte le guerre, denominato <<Ara Pacis Mundi>> di Medea (Gorizia);
- d) il Sacrario nazionale <<Mater Captivorum>> di Melle, in Valle Varaita (Cuneo);
- e) il Tempio Sacrario di Terranegra con il museo dell'ex internato denominato <<Tempio nazionale dell'internato ignoto>> (Padova);
- e-bis) (( il Sacrario militare subacqueo del regio sommergibile "Scire'" nella Baia di Haifa (Israele) )).

### SEZIONE IV - CIMITERI DI GUERRA STRANIERI IN ITALIA E CIMITERI DI GUERRA ITALIANI ALL'ESTERO

#### Art. 276. - Acquisto e manutenzione di aree cimiteriali per l'inumazione dei militari degli eserciti alleati in relazione alla prima guerra mondiale

1. Sono a carico dello Stato le spese per l'acquisto, l'occupazione, delimitazione e manutenzione in perpetuo dei terreni destinati a cimiteri per l'inumazione dei militari degli eserciti alleati, morti per ferite o malattie durante la prima guerra mondiale.

2. La manutenzione di tali cimiteri puo' essere affidata ai comuni, nel cui territorio siano situati, o anche ad altri enti, regolarmente costituiti, che ne facciano richiesta. Le condizioni relative saranno convenute fra il comune o l'ente e il ((capo dell'Ufficio)) di cui alla sezione III.

3. L'impianto di ciascun cimitero, in localita' prescelta dalle autorita' militari interessate, e' approvato con decreto del prefetto, sentita la giunta comunale, su parere favorevole della competente azienda sanitaria locale, senza alcuna ulteriore formalita'.

4. Per quanto non diversamente disposto nel presente articolo, si applicano le norme di cui alla sezione III del presente capo.

#### Art. 277. - Salvezza di Trattati internazionali in materia di cimiteri di guerra

1. Sono fatte salve le leggi di autorizzazione alla ratifica di accordi internazionali, comunque denominati, in materia di cimiteri di guerra stranieri in Italia, o di cimiteri italiani all'estero, e, segnatamente, a titolo esemplificativo:

- a) il decreto legislativo 22 febbraio 1948, n. 88 e la legge 6 ottobre 1951, n. 1577, relativi ai cimiteri di guerra statunitensi;
- b) la legge 2 febbraio 1955, n. 262, relativa ai cimiteri di guerra di militari di Paesi del Commonwealth;
- c) la legge 12 agosto 1957, n. 801, relativa ai cimiteri di guerra della Repubblica Federale di Germania in Italia e ai cimiteri di guerra italiani in Germania;
- d) la legge 30 luglio 1973, n. 485, relativa ai cimiteri di guerra della ex Jugoslavia in Italia e ai cimiteri di guerra italiani nel territorio della ex Jugoslavia;
- e) la legge 28 aprile 1976, n. 400, relativa ai cimiteri di guerra francesi in Italia e italiani in Francia.

## CAPO VII - ALLOGGI DI SERVIZIO

### SEZIONE I - ALLOGGI DI SERVIZIO DI TIPO ECONOMICO

#### Art. 278. - Disciplina applicabile

1. Agli alloggi di servizio di tipo economico si applicano le disposizioni della presente sezione.

#### Art. 279. - Classificazione degli alloggi di servizio

1. In relazione alle esigenze da soddisfare, gli alloggi della presente sezione sono cosi' classificati:

- a) alloggi di servizio gratuito per consegnatari e custodi (ASGC);
- b) alloggi di servizio connessi all'incarico con o senza annessi locali di rappresentanza (ASIR-ASI);
- c) alloggi di servizio di temporanea sistemazione per le famiglie dei militari (AST);
- d) alloggi di servizio per esigenze logistiche del personale militare in transito (APP) o imbarcato (SLI) e relativi familiari di passaggio;
- e) alloggi collettivi di servizio nell'ambito delle infrastrutture militari per ufficiali, sottufficiali e volontari in servizio permanente destinati nella sede (ASC).

#### Art. 280. - Alloggi ASGC

1. L'alloggio gratuito di cui al comma 1, lettera a), dell'articolo 279 puo' essere concesso unicamente al personale dipendente cui e' affidata, in modo continuativo, la custodia dell'edificio o dell'impianto nel quale insiste l'alloggio, nonche' al personale militare e civile cui siano affidate in modo continuativo, con provvedimento formale, mansioni di consegnatario di deposito o magazzino isolato e che alloggia sul posto.

2. La concessione dell'alloggio e' disposta dai comandi militari territoriali, dai ((Comandi marittimi)) e dai comandi di regione aerea, secondo le direttive impartite al riguardo dagli organi centrali del Ministero della difesa.

3. Della concessione e' data notizia al Ministero dell'economia e delle finanze.

4. La concessione scade con la cessazione dell'incarico dal quale l'utente trae titolo.

5. Sono a carico dell'amministrazione militare le spese per l'illuminazione, l'acqua, il canone telefonico, il riscaldamento e per eventuali altri servizi necessari.

#### Art. 281. - Alloggi ASI

1. Gli alloggi di cui al comma 1, lettera b), dell'articolo 279 sono assegnati al personale dipendente cui sono affidati incarichi che richiedono l'obbligo di abitare presso la localita' di servizio.

2. Con il regolamento il Ministro della difesa stabilisce, in base alle esigenze operative con uniforme indirizzo interforze, gli incarichi che per necessita' funzionali richiedono l'assegnazione dell'alloggio di servizio.

3. La concessione decade con la cessazione dell'incarico dal quale l'utente trae titolo.

#### Art. 282. - Alloggi ASIR

1. Gli alloggi di cui al comma 1, lettera b), dell'articolo 279, quando sono assegnati a titolari di incarichi che comportano obblighi di rappresentanza, sono dotati di locali appositamente predisposti, annessi agli alloggi stessi.

2. Tali locali rimangono nella disponibilita' dell'amministrazione militare cui fanno carico tutte le relative spese.

3. Gli incarichi che comportano obblighi di rappresentanza sono i seguenti:

- a) Capo di Stato maggiore della difesa, Capo di Stato maggiore di Forza armata, incluso il Comandante generale dell'Arma dei carabinieri, ((Direttore nazionale degli armamenti));
- b) LETTERA ABROGATA DALLA L. 23 DICEMBRE 2014, N. 190;
- c) LETTERA ABROGATA DALLA L. 23 DICEMBRE 2014, N. 190.

#### Art. 283. - Alloggi AST

1. Gli alloggi di servizio di temporanea sistemazione per le famiglie dei militari di cui al comma 1, lettera c), dell'articolo 279, sono assegnati in base a criteri di rotazione e secondo modalita' stabilite con il regolamento, al personale che presta servizio nella localita' in cui e' situato l'alloggio.

#### Art. 284. - Alloggi APP e SLI

1. Gli alloggi di servizio di cui al comma 1, lettera d), dell'articolo 279, sono predisposti in funzione di motivate esigenze di servizio.

#### Art. 285. - Alloggi ASC.

1. Gli ufficiali, i sottufficiali e i volontari in servizio permanente possono usufruire dei locali che, nell'ambito delle infrastrutture militari, sono destinati ad alloggiamenti collettivi di servizio.

2. Non sono considerati alloggi collettivi di servizio quelli costituiti in baracche, attendamenti o in altre sistemazioni analoghe, come pure le sistemazioni predisposte per il personale che ha l'obbligo di alloggiare in caserma.

#### Art. 286. - Determinazione dei canoni

1. Il regolamento fissa i criteri per la determinazione dei canoni di concessione, sulla base delle disposizioni di legge vigenti in materia di determinazione dell'equo canone; su tali criteri e' acquisito il concerto del Ministro delle infrastrutture e dei trasporti e del Ministro dell'economia e delle finanze. In tutti i casi in cui disposizioni, anche regolamentari, fissano criteri di aggiornamento dei canoni degli alloggi della Difesa, il canone e' aggiornato, annualmente, in misura pari al 75 per cento della variazione accertata dall'Istituto nazionale di statistica dell'ammontare dei prezzi al consumo per le famiglie degli operai e impiegati, verificatasi nell'anno precedente, con decreto del Ministro della difesa, d'intesa con il Ministro dell'economia e delle finanze, o degli organi corrispondenti. Agli oneri derivanti dal presente comma, pari a ottantamila euro annui a decorrere dall'anno 2014, si provvede mediante utilizzo di quota parte dei risparmi di spesa rivenienti dall'applicazione delle norme di riorganizzazione contenute nel titolo III del libro primo.

2. Ferma restando la gratuita' degli alloggi di cui al comma 1, lettera a), dell'articolo 279, e l'esclusione di quelli di cui al comma 1, lettera b), del medesimo articolo, il cui canone e' determinato dal Ministro della difesa con il regolamento, alla concessione di alloggi costituenti il patrimonio abitativo della difesa si applica un canone determinato ai sensi del comma 1, ovvero, se piu' favorevole all'utente, un canone pari a quello derivante dall'applicazione della normativa vigente in materia di equo canone.

3. Agli utenti non aventi titolo alla concessione dell'alloggio, fermo restando per l'occupante l'obbligo di rilascio, e' applicato, anche se in regime di proroga, un canone pari a quello risultante dalla normativa sull'equo canone maggiorato del venti per cento per un reddito annuo lordo complessivo del nucleo familiare fino a euro 30.987,00 e del cinquanta per cento per un reddito lordo annuo complessivo del nucleo familiare oltre detto importo. L'amministrazione della difesa ha facolta' di concedere proroghe temporanee secondo le modalita' definite con il regolamento.

3-bis. Con decreto del Ministro della difesa, adottato d'intesa con l'Agenzia del demanio, ((sentite le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)), si provvede alla rideterminazione del canone di occupazione, a decorrere dalla data di notifica del provvedimento amministrativo di rideterminazione del canone stesso, dovuto dagli utenti non aventi titolo alla concessione di alloggi di servizio del Ministero della difesa, fermo restando per l'occupante l'obbligo di rilascio entro il termine fissato dall'Amministrazione, sulla base dei prezzi di mercato, ovvero, in mancanza di essi, delle quotazioni rese disponibili dall'Agenzia del territorio, del reddito dell'occupante e della durata dell'occupazione. Le maggiorazioni del canone derivanti dalla rideterminazione prevista dal presente comma affluiscono ad apposito capitolo dell'entrata del bilancio dello Stato, per essere riassegnate per le esigenze del Ministero della difesa.

4. COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 7.

#### Art. 287. - Modalita' di riscossione del canone e sua destinazione

1. Il canone e' trattenuto sulle competenze mensili del concessionario e versato in tesoreria con imputazione al bilancio di entrata dello Stato.

2. Il cinquanta per cento dell'importo relativo e' riassegnato allo stato di previsione del Ministero della difesa; la quota parte delle risorse complessivamente derivanti all'amministrazione della difesa ai sensi del presente articolo e' destinata, nella misura dell'85 per cento, alla manutenzione degli alloggi di servizio e, nella misura del 15 per cento, al fondo - casa.

3. Il Ministro della difesa emana con il regolamento le norme per la gestione e utilizzo del fondo - casa, sentito il parere delle ((associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478 interessate)).

#### Art. 288. - Altri oneri a carico del concessionario dell'alloggio

1. Oltre al canone mensile, sono a carico del concessionario dell'alloggio di cui al comma 1, lettere b) e c), dell'articolo 279 le piccole riparazioni previste dall'articolo 1609 del codice civile, il consumo di acqua, luce e riscaldamento dell'alloggio ed eventuali altri servizi necessari. Il concessionario provvede direttamente alle piccole riparazioni di cui sopra.

2. Sono ripartite tra i concessionari, in rapporto alla consistenza millesimale dell'alloggio, le spese di gestione e di funzionamento degli ascensori e montacarichi, della pulizia delle parti in comune e della loro illuminazione.

#### Art. 289. - Retta giornaliera

1. I concessionari degli alloggi di servizio di cui ai al comma 1, lettere d) ed e), dell'articolo 279 sono tenuti al pagamento di una retta giornaliera commisurata ai costi di gestione dei servizi e per l'uso della mobilia, secondo le disposizioni da stabilirsi con il regolamento.

#### Art. 290. - Altre norme applicabili

1. Per tutto quanto non previsto nella presente sezione e nelle relative norme regolamentari, l'assegnazione degli alloggi e' assoggettata al regime delle concessioni amministrative.

#### Art. 291. - Estensione della disciplina

1. Le disposizioni di cui alla presente sezione si applicano anche agli alloggi costruiti o acquistati in base alla legge 16 aprile 1974, n. 173, e a tutti gli altri alloggi di cui all'articolo 231, comma 4, diversi da quelli realizzati ai sensi della sezione II del presente capo.

#### Art. 292. - Assegnazione provvisoria di alloggi di servizio a personale di Forze armate estere

1. Per sopperire a temporanee esigenze organizzative dei comandi internazionali operanti nel territorio nazionale e' facolta' dell'amministrazione della difesa assegnare temporaneamente gli alloggi di cui alla presente sezione, alle medesime condizioni ivi previste e fatte salve le prioritarie esigenze delle Forze armate nazionali, a personale appartenente a Forze armate estere impiegato presso i predetti comandi.

#### Art. 293. - Disciplina transitoria per gli utenti di alloggi AST

1. In via transitoria ed eccezionale, per preminenti ragioni sociali, gli utenti che perdono il titolo a occupare l'alloggio di servizio di temporanea sistemazione permangono nello stesso per un periodo di tempo limitato e definito con il regolamento.

#### Art. 294. - Norme di attuazione

1. Il regolamento detta:

- a) le norme per la classificazione e la ripartizione tra ufficiali e sottufficiali degli alloggi;
- b) le modalita' di assegnazione degli alloggi stessi; il calcolo del canone e degli altri oneri;
- c) i tempi di adeguamento dei canoni per gli alloggi preesistenti;
- d) la formazione delle graduatorie con particolare riferimento al punteggio che e' determinato in base alla composizione e al reddito del nucleo familiare, nonche' ai benefici gia' goduti o alle condizioni di disagio di arrivo in una nuova sede;
- e) la composizione, d'intesa con ((le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)), di commissioni per l'assegnazione degli alloggi stessi.

2. ((Le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478 sono chiamate)) preventivamente a esprimere il parere sulle norme regolamentari emanate ai sensi del presente articolo.

### SEZIONE II - CRITERI DI CLASSIFICAZIONE E DI ASSEGNAZIONE DEGLI ALLOGGI DI SERVIZIO AI MILITARI DELL'ARMA DEI CARABINIERI

#### Art. 295. - Criteri di classificazione degli alloggi

1. Il Ministro della difesa di concerto con quello dell'interno stabilisce, con il regolamento, sulla base delle esigenze rappresentate dal Comando generale dell'Arma dei carabinieri, i criteri per la classificazione degli alloggi di servizio nelle seguenti categorie:

- a) alloggi di servizio gratuiti connessi all'incarico;
- b) alloggi di servizio in temporanea concessione.

2. La concessione dell'alloggio di servizio di cui al comma 1, lettera a) e' autorizzata dal Comando generale dell'Arma dei carabinieri e decade con la cessazione dell'incarico. I criteri per la determinazione dei canoni di concessione degli alloggi di cui alla lettera b) del comma 1 sono stabiliti con il regolamento sulla base delle disposizioni di legge vigenti in materia di definizione dell'equo canone; sulle relative norme e' acquisito il concerto con il Ministro dell'interno. Il canone e' aggiornato, annualmente, in misura pari al 75 per cento della variazione accertata dall'Istituto nazionale di statistica dell'ammontare dei prezzi al consumo per le famiglie degli operai e impiegati, verificatasi nell'anno precedente, con decreto del Ministro della difesa, d'intesa con il Ministro dell'economia e delle finanze e con il Ministro dell'interno. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 296. - Criteri di assegnazione degli alloggi e di determinazione del canone

1. Il Ministro della difesa di concerto con quello dell'interno, con proprio decreto, emana le norme regolamentari per la ripartizione tra ufficiali, sottufficiali, appuntati e carabinieri degli alloggi di cui alla lettera b) dell'articolo 295, le modalita' di assegnazione degli alloggi stessi, il calcolo del canone e degli altri oneri, i tempi di adeguamento dei canoni per gli alloggi preesistenti, la formazione delle graduatorie, con particolare riferimento al punteggio, che e' determinato in base alla composizione e al reddito del nucleo familiare, nonche' ai benefici gia' goduti o alle condizioni di disagio di arrivo in una nuova sede, e la composizione, d'intesa con ((le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)), di commissioni per l'assegnazione degli alloggi stessi. Sono comunque a carico del concessionario, che vi provvede direttamente, le spese per le piccole riparazioni di cui all'articolo 1609 del codice civile, nonche' le spese per il consumo di acqua, luce e riscaldamento dell'alloggio ed eventuali altri servizi necessari, ivi comprese, in rapporto alla consistenza millesimale dell'alloggio, le spese di gestione e funzionamento degli ascensori, di pulizia delle parti in comune e della loro illuminazione. ((Le associazioni professionali a carattere sindacale tra militari rappresentative del personale dell'Arma dei carabinieri ai sensi dell'articolo 1478 sono chiamate)) preventivamente a esprimere il parere sulle norme regolamentari emanate ai sensi del presente articolo, da comunicare al Comando generale dell'Arma dei carabinieri entro il termine di quindici giorni dalla richiesta, termine oltre il quale il parere si intende acquisito.

### SEZIONE III - ALLOGGI DI SERVIZIO CONNESSI AL NUOVO MODELLO DELLE FORZE ARMATE

#### Art. 297. - Programma pluriennale per gli alloggi di servizio costituenti infrastrutture militari e opere destinate alla difesa nazionale

1. In relazione alle esigenze derivanti dalla riforma strutturale connessa al nuovo modello delle Forze armate, conseguito alla sospensione del servizio obbligatorio di leva, il Ministero della difesa predispone, con criteri di semplificazione, di razionalizzazione e di contenimento della spesa, un programma pluriennale per la costruzione, l'acquisto e la ristrutturazione di alloggi di servizio di cui all'articolo 231, comma 4.

2. Ai fini della realizzazione del programma di cui al comma 1, il Ministero della difesa procede all'individuazione di tre categorie di alloggi di servizio:

- a) alloggi da assegnare al personale per il periodo di tempo in cui svolge particolari incarichi di servizio richiedenti la costante presenza del titolare nella sede di servizio;
- b) alloggi da assegnare per una durata determinata e rinnovabile in ragione delle esigenze di mobilita' e abitative;
- c) alloggi da assegnare con possibilita' di opzione di acquisto mediante riscatto.

3. Ai fini della realizzazione del programma di cui al comma 1, il Ministero della difesa puo' inoltre procedere alla concessione di lavori pubblici di cui agli articoli 153 e seguenti del decreto legislativo 12 aprile 2006, n. 163, recante il codice dei contratti pubblici relativi a lavori, servizi e forniture, con le modalita' previste dal regolamento, prevedendo, a tal fine, la possibilita' di cessione, a titolo di prezzo, di beni immobili in uso non piu' necessari ai fini istituzionali, individuati d'intesa con l'Agenzia del demanio e ulteriori rispetto a quelli da individuare ai sensi dell'articolo 307, comma 2, nonche' la destinazione della totalita' dei canoni degli alloggi di servizio realizzati in attuazione del programma fino al termine della concessione, con conseguente cessazione della sospensione delle vigenti disposizioni normative in materia di riparto dei proventi derivanti dai canoni di concessione degli alloggi di servizio delle Forze armate.

4. Le norme di attuazione per la realizzazione del programma infrastrutturale di cui al presente articolo sono dettate dal regolamento. Sullo schema di tali norme ((sono sentite le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)) e acquisito il parere delle competenti Commissioni parlamentari.

### SEZIONE IV - PROVVIDENZE IN FAVORE DEI MILITARI DI CARRIERA AL FINE DELL'ACQUISTO O LOCAZIONE DI ALLOGGI

#### Art. 298. - Modalita' inerenti il requisito della residenza

1. Ai soli fini dell'accesso dei militari di carriera ai mutui agevolati per l'edilizia residenziale previsti dalle disposizioni di legge vigenti in materia, non e' richiesto il requisito della residenza nel comune ove sorge la costruzione.

2. I militari di carriera possono in ogni momento predeterminare la residenza che intendono eleggere nel momento in cui lasceranno il servizio, con dichiarazione irrevocabile resa dinanzi al sindaco del comune ove la residenza viene prescelta, che ne prende nota nei registri anagrafici.

3. Le disposizioni di cui ai commi 1 e 2, si applicano, limitatamente all'acquisto o all'assegnazione in proprieta' della prima casa, a decorrere dal 1° gennaio 1979, a tutte le cooperative edilizie costituite tra gli appartenenti alle Forze armate, al Corpo della Guardia di finanza e alle Forze di polizia a ordinamento civile, comunque finanziate, anche dallo Stato, comprese quelle disciplinate dal testo unico delle disposizioni sull'edilizia popolare ed economica, di cui al regio decreto 28 aprile 1938, n. 1165. Non e' richiesto il requisito della residenza nel comune ove sorge la costruzione, anche ai fini dell'assegnazione in proprieta' individuale, ai sensi dell'articolo 9 della legge 30 aprile 1999, n. 136, degli alloggi gia' realizzati a proprieta' indivisa dalle cooperative di cui al presente comma, fruenti comunque del contributo erariale. I benefici derivanti dal presente comma si applicano nei limiti degli stanziamenti autorizzati dalla legislazione vigente.

#### Art. 299. - Conservazione dei diritti in ordine ad alloggi di edilizia sovvenzionata in caso di trasferimento del militare ad altra sede

1. Il personale militare di carriera che ha inoltrato domanda per ottenere in assegnazione un alloggio di edilizia pubblica sovvenzionata, in caso di trasferimento in altra sede avvenuto durante in periodo nel quale e' in servizio attivo, non perde i diritti precedentemente maturati, i quali sono cumulati, previa domanda documentata, nella sede o nelle sedi di successiva destinazione.

2. Ai fini della assegnazione di alloggi di edilizia pubblica sovvenzionata al personale militare fruente di alloggi di servizio nel triennio precedente al collocamento a riposo, e' riconosciuto il punteggio previsto per lo sfratto o l'ordine di sgombero per pubblica utilita'.

## CAPO VIII - DIRITTI DI PROPRIETA' INDUSTRIALE DELLE FORZE ARMATE

### Art. 300. - Diritti di proprieta' industriale delle Forze armate

1. Le Forze armate, compresa l'Arma dei carabinieri, hanno il diritto all'uso esclusivo delle proprie denominazioni, dei propri stemmi, degli emblemi e di ogni altro segno distintivo. Il Ministero della difesa, anche avvalendosi della Difesa Servizi s.p.a. di cui all'articolo 535, puo' consentire l'uso anche temporaneo delle denominazioni, degli stemmi, degli emblemi e dei segni distintivi, in via convenzionale ai sensi dell'articolo 26 del codice dei contratti pubblici relativi a lavori, servizi e forniture, di cui al decreto legislativo 12 aprile 2006, n. 163, nel rispetto delle finalita' istituzionali e dell'immagine delle Forze armate. Si applicano le disposizioni contenute negli articoli 124, 125 e 126 del codice della proprieta' industriale di cui al decreto legislativo 10 febbraio 2005, n. 30, e successive modificazioni.

2. Salvo che il fatto costituisca piu' grave reato, chiunque fabbrica, vende, espone, adopera industrialmente ovvero utilizza al fine di trarne profitto le denominazioni, gli stemmi, gli emblemi e i ((segni distintivi)) di cui al comma 1 in violazione delle disposizioni di cui al medesimo comma e' punito con la multa da euro 1.000,00 a euro 5.000,00.

3. Le disposizioni contenute nel comma 2 non si applicano ai collezionisti e agli amatori che operano per finalita' strettamente personali e non lucrative.

4. Ferme restando le competenze attribuite alla Presidenza del Consiglio dei Ministri e disciplinate con decreto del Presidente del Consiglio dei Ministri 28 gennaio 2011, pubblicato nella Gazzetta Ufficiale n. 25 del 1° febbraio 2011, e successive modificazioni, in materia di approvazione e procedure per la concessione degli emblemi araldici, anche a favore delle Forze armate, mediante apposito regolamento adottato con decreto del Ministro della difesa, di concerto con i Ministri dello sviluppo economico e dell'economia e delle finanze, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, sono individuati le denominazioni, gli stemmi, gli emblemi e gli altri segni distintivi ai fini di cui al comma 1, nonche' le specifiche modalita' attuative.

## TITOLO III ACCESSO DI PARLAMENTARI A STRUTTURE MILITARI

### Art. 301. - Visite dei parlamentari nelle strutture militari

1. I membri del Parlamento possono visitare senza autorizzazione le strutture militari della Difesa e ogni altro luogo e zona militare ovvero le installazioni, fisse o mobili, che ospitano corpi, reparti o comunque personale delle Forze armate.

2. Le visite sono annunciate con preavviso di almeno ventiquattro ore, inviato al Ministro della difesa. Le aree riservate possono essere visitate previa specifica autorizzazione.

3. Le visite si svolgono secondo le modalita' definite dal regolamento, tali comunque da non interferire con la normale attivita' di servizio e con la funzionalita' delle strutture.

### Art. 302. - Strutture militari straniere e plurinazionali

1. Le visite a strutture militari straniere o plurinazionali in territorio italiano sono autorizzate dal Ministro della difesa, sentito il Ministro degli affari esteri, previa specifica richiesta allo stesso Ministro della difesa, che si pronuncia nel termine di venti giorni.

2. Con apposite convenzioni tra le parti interessate sono regolate le modalita' delle visite previste dal presente articolo.

### Art. 303. - Acquisizione di informazioni e partecipazione alle visite

1. Nel corso della visita i membri del Parlamento, accompagnati dal comandante o dal direttore oppure dal rispettivo delegato, ricevono tutte le informazioni, non classificate, relative alla struttura o alla installazione; possono incontrare il personale militare e i dipendenti civili.

### Art. 304. - Stabilimenti di pena

1. Per le visite agli stabilimenti di pena militari si applicano gli articoli 301 e 303. Nel corso delle visite i parlamentari possono incontrare i detenuti.

### Art. 305. - Accesso senza preavviso

1. In caso di richiesta di accesso non preannunciata, da parte di una delegazione di parlamentari o di singoli parlamentari, i membri del Parlamento sono ricevuti dal comandante o dal direttore oppure, in loro assenza, dall'ufficiale piu' elevato in grado presente presso la struttura o l'installazione militare, che riceve gli ospiti e fornisce le relative informazioni di carattere non classificato e notizie di interesse per il parlamentare, senza procedere alla visita della struttura.

## TITOLO IV VALORIZZAZIONE E DISMISSIONE DI BENI IMMOBILI E MOBILI CAPO I DISMISSIONI DI BENI IMMOBILI E CESSIONI DI BENI MOBILI

### Art. 306. - Dismissione degli alloggi di servizio del Ministero della difesa

1. Alla dismissione degli alloggi di servizio del Ministero della difesa non realizzati su aree ubicate all'interno di basi, impianti, installazioni militari o posti al loro diretto e funzionale servizio, si applicano le disposizioni del presente articolo.

2. Ogni due anni, entro il mese di marzo, il Ministro della difesa, sentite le competenti Commissioni permanenti della Camera dei deputati e del Senato della Repubblica, definisce con proprio decreto il piano di gestione del patrimonio abitativo della Difesa, con l'indicazione dell'entita', dell'utilizzo e della futura destinazione degli alloggi di servizio, nonche' degli alloggi non piu' ritenuti utili nel quadro delle esigenze dell'amministrazione e quindi transitabili in regime di locazione ovvero alienabili, anche mediante riscatto. Il piano indica altresi' i parametri di reddito sulla base dei quali gli attuali utenti degli alloggi di servizio, ancorche' si tratti di personale in quiescenza o di coniuge superstite non legalmente separato, ne' divorziato, possono mantenerne la conduzione, purche' non siano proprietari di altro alloggio di certificata abitabilita'. Con il regolamento sono fissati i criteri e le modalita' di alienazione, nonche' il riconoscimento, in favore del conduttore non proprietario di altra abitazione nella provincia, del diritto di prelazione all'acquisto della piena proprieta' ovvero di opzione sul diritto di usufrutto e, in caso di mancato esercizio del diritto di prelazione da parte del conduttore, le modalita' della vendita all'asta con diritto di preferenza in favore del personale militare e civile del Ministero della difesa. I proventi derivanti dalla gestione o vendita del patrimonio alloggiativo sono utilizzati per la realizzazione di nuovi alloggi di servizio e per la manutenzione di quelli esistenti.

3. Al fine della realizzazione del programma pluriennale di cui all'articolo 297, il Ministero della difesa provvede all'alienazione della proprieta', dell'usufrutto o della nuda proprieta' di alloggi non piu' ritenuti utili nel quadro delle esigenze dell'amministrazione, in numero non inferiore a tremila, compresi in interi stabili da alienare in blocco, con diritto di prelazione all'acquisto della piena proprieta' ovvero di opzione sul diritto di usufrutto per il conduttore e, in caso di mancato esercizio del diritto di prelazione da parte dello stesso, con diritto di preferenza per il personale militare e civile del Ministero della difesa, con prezzo di vendita determinato d'intesa con l'Agenzia del demanio, ridotto nella misura massima del 25 per cento e minima del 10 per cento, tenendo conto del reddito del nucleo familiare, della presenza di portatori di handicap tra i componenti di tale nucleo e dell'eventuale avvenuta perdita del titolo alla concessione e assicurando la permanenza negli alloggi dei conduttori delle unita' immobiliari e del coniuge superstite, alle condizioni di cui al comma 2, con basso reddito familiare, non superiore a quello determinato con il decreto ministeriale di cui al comma 2, ovvero con componenti familiari portatori di handicap, dietro corresponsione del canone in vigore all'atto della vendita, aggiornato in base agli indici ISTAT. Gli acquirenti degli alloggi non possono rivenderli prima della scadenza del quinto anno dalla data di acquisto. I proventi derivanti dalle alienazioni sono versati all'entrata del bilancio dello Stato per essere riassegnati in apposita unita' previsionale di base dello stato di previsione del Ministero della difesa.

3-bis. Al fine di accelerare il programma pluriennale di dismissione di alloggi di servizio ritenuti non piu' utili per le esigenze istituzionali della Difesa, mediante un incremento percentuale degli immobili alienati, il prezzo di vendita degli alloggi occupati, determinato d'intesa con l'Agenzia del demanio ai sensi del comma 3, e' ridotto, limitatamente alle procedure di alienazione con offerta formalizzata entro il 30 giugno 2015, nella misura del 33 per cento. Di tale riduzione e' data evidenza nella comunicazione dell'offerta di vendita con diritto di prelazione dell'alloggio posto in vendita.

4. Al fine di accelerare il procedimento di alienazione di cui al comma 3, il Ministero della difesa puo' avvalersi, tramite la ((l'Ufficio centrale competente)), dell'attivita' di tecnici dell'Agenzia del demanio. 4 bis. Al fine di semplificare le procedure di alienazione di cui ai commi 2 e 3, con decreto del Ministro della Difesa, sottoposto al controllo preventivo di legittimita' della Corte dei conti, sono definiti i contenuti essenziali nonche' le eventuali condizioni e clausole di garanzia dei diritti dello Stato, dei contratti di compravendita stipulati in forma pubblico amministrativa o notarile, tra l'amministrazione della Difesa e gli acquirenti. I contratti producono effetti anticipati dal momento della loro sottoscrizione, e sono sottoposti esclusivamente al controllo successivo della Corte dei conti, la quale si pronuncia sulla regolarita', sulla correttezza e sulla efficacia della gestione.

5. Fatte salve le alienazioni con i procedimenti di cui al comma 2 e di cui al comma 3, gli alloggi di servizio individuati per essere destinati a procedure di dismissione in virtu' di previgenti disposizioni normative, restano nella disponibilita' del Ministero della difesa per l'utilizzo o per l'alienazione.

5-bis. Nel rispetto delle finalita' del programma pluriennale di cui all'articolo 297 ed allo scopo di rendere piu' celeri le procedure di alienazione degli alloggi di cui al comma 3, il Ministero della difesa, in caso di gare deserte, puo' procedere alla dismissione unitaria di piu' immobili liberi inseriti in un unico fabbricato ovvero comprensorio abitativo, mediante la procedura ad evidenza pubblica di cui all'articolo 307, comma 10. Il valore dei beni da porre a base d'asta e' stabilito con decreto del Ministero della difesa - ((Ufficio centrale competente)) sulla base del valore dei singoli alloggi costituenti il lotto in vendita. Le dismissioni di cui al presente comma sono effettuate senza il riconoscimento del diritto di preferenza per il personale militare e civile del Ministero della difesa di cui al comma 3.

### Art. 307. - Dismissioni di altri beni immobili del Ministero della difesa

1. Alla dismissione di beni immobili del Ministero della difesa diversi da quelli di cui all'articolo 306, si applica il presente articolo.

2. Il Ministero della difesa, sentita l'Agenzia del demanio, adotta un programma di razionalizzazione, accorpamento, riduzione e ammodernamento del patrimonio infrastrutturale in uso, in coerenza con il processo di pianificazione territoriale e urbanistica previsto dalla legislazione nazionale e regionale, allo scopo di favorirne la riallocazione in aree maggiormente funzionali per migliorare l'efficienza dei servizi assolti, e individua, con le stesse modalita' indicate nel primo periodo, immobili non piu' utilizzati per finalita' istituzionali, da consegnare all'Agenzia del demanio ad avvenuto completamento delle procedure di riallocazione concernente il programma di cui al presente comma.

3. Il programma di cui al comma 2:

- a) individua, oltre gli immobili non piu' utilizzati, anche quelli parzialmente utilizzati e quelli in uso all'amministrazione della difesa nei quali sono tuttora presenti funzioni altrove ricollocabili;
- b) definisce le nuove localizzazioni delle funzioni, individuando le opere da realizzare;
- c) quantifica il costo della costruzione ex novo e dell'ammodernamento delle infrastrutture individuate e quello del trasferimento delle funzioni nelle nuove localizzazioni;
- d) stabilisce le modalita' temporali delle procedure di razionalizzazione, accorpamento, riduzione e ammodernamento e del successivo rilascio dei beni immobili non piu' in uso.

3-bis. Con uno o piu' decreti, il Ministero della difesa, d'intesa con l'Agenzia del demanio, promuove la concessione d'uso a titolo gratuito, per una durata massima di dieci anni, dei beni immobili militari gia' individuati e proposti per le finalita' di cui all'articolo 56-bis del decreto-legge 21 giugno 2013, n. 69, convertito, con modificazioni, dalla legge 9 agosto 2013, n. 98, che non siano stati richiesti in proprieta' dai comuni, dalle province, dalle citta' metropolitane e dalle regioni. I medesimi immobili sono concessi, a cura dell'Agenzia del demanio, nello stato di fatto e di diritto in cui si trovano e nel rispetto delle volumetrie esistenti, a chiunque presenti formale domanda al Ministero della difesa nella quale dimostri di essere in possesso di idonei requisiti economici e imprenditoriali per la loro valorizzazione, nonche' di un piano di utilizzo. Sulla accettazione della domanda, l'Agenzia del demanio, d'intesa con il Ministero della difesa, si esprime entro 180 giorni. La concessione, ad opera dell'Agenzia del demanio, dei beni immobili ad essa trasferiti, e' condizionata al versamento di un deposito cauzionale, infruttifero, rilasciato nei termini e secondo le modalita' di cui al decreto del Presidente della Repubblica 15 novembre 2012, n. 236, in quanto compatibili, che sara' restituito al termine della concessione, salvo il mancato adempimento dell'obbligo di valorizzazione o il deterioramento del bene stesso. Il concessionario, per tutta la durata della concessione, si impegna a mantenere indenne l'Amministrazione da qualsivoglia rivendicazione relativa agli immobili. Le procedure e i tempi per la concessione sono i medesimi di cui al citato articolo 56-bis, nei limiti in cui essi sono compatibili. Qualora, entro tre anni dall'avvenuto trasferimento, l'assegnatario del bene non abbia valorizzato il bene nei termini indicati al momento della concessione, l'Agenzia del demanio si riserva la facolta' di revocare la medesima mediante una dichiarazione unilaterale comunicata all'assegnatario stesso. La concessione non e' rinnovabile. Entro sei mesi dalla scadenza, l'Agenzia del demanio avvia le procedure ad evidenza pubblica di alienazione del bene, riconoscendo al concessionario il diritto di prelazione tenuto conto degli investimenti effettuati dal concessionario durante il periodo di concessione. In caso di mancata aggiudicazione, le opere e i manufatti eventualmente realizzati dal concessionario sul bene immobile oggetto della concessione restano acquisiti allo Stato, senza alcun compenso o rimborso, salva la facolta' dell'autorita' concedente di ordinare la restituzione del bene medesimo nel pristino stato. L'immobile acquisito non puo' essere oggetto di trasferimento, a qualsiasi titolo giuridico, prima di cinque anni dall'acquisizione. All'Amministrazione concedente e' data facolta', comunque e a suo insindacabile giudizio, di rientrare nella piena proprieta' dell'immobile ove ne ravvisi un uso in contrasto con norme di legge, difforme da quello pattuito in sede di cessione, o quando subentra un interesse pubblico a riacquisire l'immobile concesso.

4. Le infrastrutture militari, gli immobili e le porzioni di piu' ampi compendi ancora in uso al Ministero della difesa, individuati nell'ambito del programma, sono consegnati all'Agenzia del demanio ad avvenuta riallocazione delle funzioni presso idonee e funzionali strutture sostitutive. La riallocazione puo' avvenire mediante:

- a) la trasformazione e riqualificazione di altri immobili militari;
- b) nuove costruzioni, da realizzarsi in conformita' con gli strumenti urbanistici e salvaguardando l'integrita' delle aree di pregio ambientale anche attraverso il ricorso ad accordi o a procedure negoziate con enti territoriali, societa' a partecipazione pubblica e soggetti privati, promosse dal Ministero della difesa, di concerto con il Ministero dell'economia e delle finanze;
- c) permuta ai sensi del comma 7.

5. Per consentire la riallocazione delle predette funzioni nonche' per le piu' generali esigenze di funzionamento, ammodernamento e manutenzione e supporto dei mezzi, dei sistemi, dei materiali e delle strutture in dotazione alle Forze armate, inclusa l'Arma dei carabinieri, si utilizzano il fondo in conto capitale e il fondo di parte corrente di cui all'articolo 619.

6. Gli immobili individuati e consegnati ai sensi del presente articolo entrano a far parte del patrimonio disponibile dello Stato per essere assoggettati alle procedure di valorizzazione e di dismissione di cui al decreto-legge 25 settembre 2001, n. 351, convertito, con modificazioni, dalla legge 23 novembre 2001, n. 410, e alle altre procedure di dismissioni previste dalle norme vigenti, ovvero alla vendita a trattativa privata anche in blocco. Gli immobili individuati sono stimati a cura dell'Agenzia del demanio nello stato di fatto e di diritto in cui si trovano. L'elenco degli immobili individuati e consegnati e' sottoposto al Ministro per i beni e le attivita' culturali, il quale, nel termine di novanta giorni dalla data di pubblicazione del decreto di individuazione, provvede, attraverso le competenti soprintendenze, a verificare quali tra detti beni siano soggetti a tutela ai sensi del codice dei beni culturali e del paesaggio, di cui al decreto legislativo 22 gennaio 2004, n. 42, dandone comunicazione al Ministro dell'economia e delle finanze. L'Agenzia del demanio apporta le conseguenti modifiche all'elenco degli immobili.

7. Nell'ambito dei processi di razionalizzazione dell'uso degli immobili pubblici e al fine di adeguare l'assetto infrastrutturale delle Forze armate alle esigenze derivanti dall'adozione dello strumento professionale, il Ministero della difesa puo' individuare beni immobili di proprieta' dello Stato mantenuti in uso al medesimo dicastero per finalita' istituzionali, suscettibili di permuta di beni e di servizi con gli enti territoriali, con le societa' a partecipazione pubblica e con i soggetti privati. Le procedure di permuta sono effettuate dal Ministero della difesa, d'intesa con l'Agenzia del demanio, nel rispetto dei principi generali dell'ordinamento giuridico - contabile.

8. Il divieto di dismissione temporanea per i beni immobili statali assegnati in uso gratuito alle amministrazioni pubbliche e le conseguenze della eventuale dismissione temporanea, rispettivamente previsti dai primi due periodi dell'articolo 1, comma 216, della legge 27 dicembre 2006 n. 296, non si applicano ai beni immobili in uso all'amministrazione della difesa affidati, in tutto o in parte, a terzi per lo svolgimento di attivita' funzionali alle finalita' istituzionali dell'amministrazione stessa.

9. E' salvo quanto disposto dagli statuti delle Regioni a statuto speciale e delle Province autonome di Trento e di Bolzano e dalle pertinenti norme di attuazione relativamente al trasferimento di beni della Difesa, nonche' quanto disposto dall'articolo 5, comma 4, del decreto legislativo 28 maggio 2010, n. 85.

10. Il Ministero della difesa - ((Ufficio centrale competente)), sentito il Ministero dell'economia e delle finanze - Agenzia del demanio, individua, con uno o piu' decreti, gli immobili militari, non compresi negli elenchi di cui al comma 2, da alienare secondo le seguenti procedure:

- a) le alienazioni, permute, valorizzazioni e gestioni dei beni, che possono essere effettuate anche ai sensi dell'articolo 58 del decreto legge 25 giugno 2008 n. 112, convertito dalla legge 6 agosto 2008 n. 133, in deroga alla legge 24 dicembre 1908, n. 783, e al regolamento di cui al regio decreto 17 giugno 1909, n. 454, nonche' alle norme della contabilita' generale dello Stato, fermi restando i principi generali dell'ordinamento giuridico - contabile, sono effettuate direttamente dal Ministero della difesa - ((Ufficio centrale competente)) che puo' avvalersi del supporto tecnico-operativo di una societa' pubblica o a partecipazione pubblica con particolare qualificazione professionale ed esperienza commerciale nel settore immobiliare;
- b) la determinazione del valore dei beni da porre a base d'asta e' decretata dal Ministero della difesa - ((Ufficio centrale competente)), d'intesa con l'Agenzia del demanio; (9)
- c) i contratti di trasferimento di ciascun bene sono approvati dal Ministero della difesa. L'approvazione puo' essere negata per sopravvenute esigenze di carattere istituzionale dello stesso Ministero;
- d) i proventi monetari derivanti dalle procedure di cui alla lettera a) sono determinati con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, tenuto anche conto dei saldi strutturali di finanza pubblica, e sono versati all'entrata del bilancio dello Stato per essere destinati, mediante riassegnazione anche in deroga ai limiti previsti per le riassegnazioni, con decreto del Ministro dell'economia e delle finanze, fino 31 dicembre 2022, agli stati di previsione del Ministero dell'economia e delle finanze, per una quota corrispondente al 55 per cento, da assegnare al fondo ammortamento dei titoli di Stato, e del Ministero della difesa, per una quota corrispondente al 35 per cento, nonche' agli enti territoriali interessati alle valorizzazioni, per la rimanente quota del 10 per cento. Le somme riassegnate al Ministero della difesa sono finalizzate esclusivamente a spese di investimento. E' in ogni caso precluso l'utilizzo di questa somma per la copertura di oneri di parte corrente. Ai fini della valorizzazione dei medesimi beni, le cui procedure sono concluse entro il termine perentorio di centottanta giorni dal loro avvio, si applicano le disposizioni di cui all'articolo 4, comma 4-decies, del decreto-legge 25 gennaio 2010, n. 2, convertito, con modificazioni, dalla legge 26 marzo 2010, n. 42, ovvero all'articolo 34 del decreto legislativo 18 agosto 2000, n. 267, e la determinazione finale delle conferenze di servizio o il decreto di approvazione degli accordi di programma, comportanti variazione degli strumenti urbanistici, sono deliberati dal consiglio comunale entro trenta giorni, decorsi i quali i due citati provvedimenti, in caso di mancata deliberazione, si intendono comunque ratificati. Il medesimo termine perentorio e il meccanismo del silenzio assenso per la ratifica delle determinazioni finali delle conferenze di servizi si applicano alle procedure di valorizzazione di cui all'articolo 314;
- e) le alienazioni e permute dei beni individuati possono essere effettuate a trattativa privata, se il valore del singolo bene, determinato ai sensi del presente comma, lettera b) e' inferiore a euro 400.000,00;
- f) ai fini delle permute e delle alienazioni degli immobili da dismettere, con cessazione del carattere demaniale, il Ministero della difesa comunica, insieme alle schede descrittive di cui all'articolo 12, comma 3, del codice dei beni culturali e del paesaggio, di cui al decreto legislativo 22 gennaio 2004, n. 42, l'elenco di tali immobili al Ministero per i beni e le attivita' culturali che si pronuncia, entro il termine perentorio di quarantacinque giorni dalla ricezione della comunicazione, in ordine alla verifica dell'interesse storico-artistico e individua, in caso positivo, le parti degli immobili stessi soggette a tutela, con riguardo agli indirizzi di carattere generale di cui all'articolo 12, comma 2, del citato codice di cui al decreto legislativo n. 42 del 2004. Per i beni riconosciuti di interesse storico-artistico, l'accertamento della relativa condizione costituisce dichiarazione ai sensi dell'articolo 13 del citato codice. Le approvazioni e le autorizzazioni previste dal citato codice sono rilasciate o negate entro novanta giorni dalla ricezione della istanza. Le disposizioni del citato codice, parti prima e seconda, si applicano anche dopo la dismissione.

11. Ferme restando le disposizioni di cui all'articolo 545 i proventi derivanti dalle alienazioni di cui all'articolo 49, comma 2, della legge 23 dicembre 2000, n. 388, sono integralmente riassegnati al fondo di parte corrente istituito nello stato di previsione del Ministero della difesa, in relazione alle esigenze di realizzazione del programma di cui al comma 2.

11-bis. In materia di valorizzazione e dismissione, nonche' di trasferimento o conferimento a fondi immobiliari, di beni immobili del Ministero della difesa, si applicano altresi' le seguenti disposizioni:

- a) articolo 3-ter, commi 12 e 13, del decreto-legge 25 settembre 2001, n. 351, convertito, con modificazioni, dalla legge 23 novembre 2001, n. 410, introdotto dall'articolo 27, comma 2, del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214;
- b) articoli 43 e 53, comma 2, lettera a), del decreto-legge 9 febbraio 2012, n. 5, convertito, con modificazioni, dalla legge 4 aprile 2012, n. 35;
- c) comma 8-quater dell'articolo 33 del decreto-legge 6 luglio 2011, n. 98, convertito, con modificazioni, dalla legge 15 luglio 2011, n. 111, introdotto dall'articolo 23-ter, comma 1, lettera g), del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135;
- d) comma 1 dell'articolo 6 della legge 12 novembre 2011, n. 183, e successive modificazioni.
- d-bis) LETTERA ABROGATA DALLA L. 27 DICEMBRE 2019, N. 160.

------------- AGGIORNAMENTO (9) Il D.L. 12 luglio 2011, n. 107, convertito con modificazioni dalla L. 2 agosto 2011, n. 130, ha disposto (con l'art. 8, comma 2-bis) che "Al fine di accelerare il processo di acquisizione di risorse da destinare al complessivo quadro delle esigenze del Ministero della difesa, consentendo il conseguimento dei relativi effetti positivi per la finanza pubblica e per la dotazione del fondo di cui all'articolo 1, comma 1240, della legge 27 dicembre 2006, n. 296, e successive modificazioni, l'articolo 307, comma 10, lettera b), del codice dell'ordinamento militare di cui al decreto legislativo 15 marzo 2010, n. 66, si interpreta nel senso che gli oneri per la partecipazione alla commissione ivi prevista sono a carico, in aggiunta a quanto stabilito per la dismissione del bene, del privato cittadino acquirente. A tal fine il parere di congruita' richiesto alla commissione di cui all'articolo 307, comma 10, lettera b), del citato codice, rispetto ai beni per i quali sono gia' stati pubblicati i relativi decreti di individuazione ai fini del trasferimento al patrimonio disponibile dello Stato e per i quali esistono istanze di acquisizione formalizzate prima della data di entrata in vigore del presente decreto, e' adottato entro il 31 ottobre 2011".

### Art. 308. - Documentazione necessaria per la vendita di immobili del Ministero della difesa

1. Il Ministero della difesa e' esonerato dalla consegna all'acquirente dei documenti previsti dalle norme vigenti relativi alla proprieta' o al diritto sul bene immobile ceduto nonche' alla regolarita' urbanistica, tecnica e fiscale, necessari per la stipulazione dei contratti di alienazione, sostituiti da apposita dichiarazione.

### Art. 309. - Destinazione al piano casa di immobili demaniali non piu' utilizzati a fini militari

1. Una quota del patrimonio immobiliare del demanio, costituita da aree ed edifici non piu' utilizzati, puo' essere destinata alla realizzazione degli interventi previsti dall'articolo 11 del decreto legge 2008, n. 112, convertito dalla legge 6 agosto 2008 n. 133, sulla base di accordi tra l'Agenzia del demanio, il Ministero delle infrastrutture e dei trasporti, il Ministero della difesa in caso di aree ed edifici non piu' utilizzati a fini militari, le regioni e gli enti locali.

### Art. 310. - Cessione di beni mobili a titolo oneroso

1. Il regolamento, secondo le procedure di modifica da esso previste, individua, nell'ambito delle pianificazioni di ammodernamento connesse al nuovo modello organizzativo delle Forze armate, i materiali e i mezzi suscettibili di alienazione e le procedure, anche in deroga alle norme sulla contabilita' generale dello Stato, nel rispetto della legge 9 luglio 1990, n. 185.

2. L'alienazione puo' avere luogo anche nei confronti delle imprese fornitrici dei materiali e mezzi da alienare, eventualmente a fronte di programmi di ammodernamento predisposti dalle imprese stesse, anche ai fini della relativa esportazione nel rispetto delle norme vigenti.

3. Ai fini del contenimento dei costi per l'ammodernamento, l'amministrazione della difesa, nel rispetto delle vigenti norme in materia di esportazione di materiali d'armamento, puo' procedere a permute o vendite di mezzi e materiali obsoleti ma non ancora fuori uso.

4. Fatto salvo quanto stabilito dal presente articolo e dal comma 4 dell'articolo 311, per la dichiarazione di fuori servizio e di fuori uso dei materiali, per la loro alienazione, cessione e prestito si applicano le disposizioni del regolamento. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 311. - Cessione di beni mobili a titolo gratuito

1. Il Ministero della difesa puo' cedere a titolo gratuito materiali non d'armamento, dichiarati fuori servizio o fuori uso, in favore di:

- a) Paesi in via di sviluppo e Paesi partecipanti al partenariato per la pace, nell'ambito dei vigenti accordi di cooperazione;
- b) organismi di volontariato di protezione civile iscritti negli appositi registri;

2. La cessione di materiali d'armamento dichiarati obsoleti per cause tecniche in favore dei soggetti di cui al comma 1 e' consentita esclusivamente per materiali difensivi previo parere vincolante delle competenti Commissioni parlamentari.

3. I materiali delle Forze armate impiegati per i soccorsi urgenti a favore di popolazioni colpite di calamita' naturali, in Italia o all'estero, quando non ne e' possibile il recupero, sono scaricati agli effetti contabili. Lo scarico e' disposto con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, e, quando si tratta di materiali utilizzati o ceduti per il soccorso a popolazioni estere, di concerto anche con il Ministro degli affari esteri.

4. Nel regolamento, ai sensi del comma 1 dell'articolo 310, sono disciplinate le modalita' per la cessione a titolo gratuito ai musei, pubblici o privati, dei materiali o dei mezzi non piu' destinati all'impiego, allo scopo di consentirne l'esposizione al pubblico.

((4-bis. Fatto salvo quanto previsto dal comma 2, alle cessioni di cui al comma 1, lettera b-bis), si provvede con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze e con il Ministro dello sviluppo economico))

### Art. 312. - Cessioni di beni mobili a titolo gratuito nell'ambito delle missioni internazionali

1. Su disposizione delle autorita' logistiche di Forza armata, previa autorizzazione del Capo di stato maggiore della difesa, secondo le modalita' stabilite con decreto del Ministro della difesa, possono essere ceduti, direttamente e a titolo gratuito nelle localita' in cui si trovano, alle Forze armate e alle Forze di polizia estere, ad autorita' locali, a organizzazioni internazionali ((anche)) non governative ovvero a organismi di volontariato e di protezione civile, prioritariamente italiani, ivi operanti:

- a) i mezzi e materiali, escluso il materiale d'armamento, utilizzati a supporto dell'attivita' operativa di unita' militari all'estero, per i quali non risulta conveniente il rimpatrio in relazione ai ((relativi costi));
- b) i mezzi e materiali, escluso il materiale d'armamento, dismessi alla data di entrata in vigore dell'atto che autorizza la missione internazionale.

### Art. 313. - Dismissione di beni culturali del Ministero della difesa

1. Non e' consentita la dismissione di beni culturali del Ministero della difesa, salvo quanto disposto dall'articolo 12 del decreto legislativo 22 gennaio 2004, n. 42, recante il codice dei beni culturali e del paesaggio.

## CAPO II - FONDI COMUNI DI INVESTIMENTO IMMOBILIARE PER LA VALORIZZAZIONE E L'ALIENAZIONE DI IMMOBILI MILITARI

### Art. 314.

((ARTICOLO ABROGATO DAL D.L. 6 LUGLIO 2012, N. 95, CONVERTITO CON MODIFICAZIONI DALLA L. 7 AGOSTO 2012, N. 135))

## TITOLO V MODI DI ACQUISTO COATTIVO DI BENI E DIRITTI NELL'INTERESSE DELLA DIFESA MILITARE CAPO I AMBITO

### Art. 315. - Ambito

1. Il presente titolo disciplina i modi di acquisto coattivo di beni e diritti nell'interesse della difesa militare che trovano applicazione in tempo di pace.

2. Resta fermo quanto disposto dal titolo VIII del presente libro per le requisizioni in tempo di guerra, di grave crisi internazionale o di mobilitazione.

## CAPO II - ESPROPRIAZIONI, REQUISIZIONI, ACQUISTI A SEGUITO DI CONFISCA

### Art. 316. - Espropriazione di invenzioni nell'interesse della difesa militare. Rinvio al codice della proprieta' industriale

1. Per le espropriazioni di invenzioni nell'interesse della difesa militare resta ferma la disciplina all'uopo dettata dal decreto legislativo 10 febbraio 2005, n. 30, recante il codice della proprieta' industriale.

### Art. 317. - Espropriazioni immobiliari. Rinvio al testo unico dell'espropriazione per pubblica utilita'

1. Fatto salvo quanto disposto nel titolo VI in ordine alle servitu' militari, per le espropriazioni immobiliari finalizzate alla realizzazione di opere destinate alla difesa militare resta ferma la disciplina all'uopo dettata dal decreto del Presidente della Repubblica 8 giugno 2001, n. 327, recante il testo unico delle disposizioni legislative e regolamentari in materia di espropriazione per pubblica utilita'. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 318. - Requisizioni nell'interesse della Difesa

1. Alle requisizioni nell'interesse della Difesa si provvede nei casi di grave necessita' pubblica in cui occorra senza indugio disporre della proprieta' privata, con provvedimento motivato e senza pregiudizio dei diritti dei destinatari del provvedimento.

2. Si applicano in quanto compatibili i procedimenti previsti nel titolo VIII del presente libro, secondo l'oggetto della requisizione.

### Art. 319. - Acquisti a seguito di confisca

1. Le armi, le munizioni, gli esplosivi e gli altri materiali di interesse militare sequestrati e acquisiti dallo Stato a seguito di provvedimento definitivo di confisca dell'autorita' giudiziaria possono essere assegnati al Ministero della difesa per finalita' istituzionali, con decreto del Ministro della giustizia, di concerto con i Ministri della difesa e dell'economia e delle finanze. Si provvede con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, nel caso in cui la confisca e' stata disposta dall'autorita' giudiziaria militare. ((E' fatto salvo, per l'Arma dei carabinieri, quanto previsto dall'articolo 1, comma 437, della legge 27 dicembre 2006, n. 296.))

## TITOLO VI LIMITAZIONI A BENI E ATTIVITA' ALTRUI NELL'INTERESSE DELLA DIFESA CAPO I LIMITAZIONI A SINGOLI BENI E ATTIVITA'

### Art. 320. - Ambito

1. In vicinanza delle opere e installazioni permanenti e semipermanenti di difesa, di segnalazione e riconoscimento costiero, delle basi navali, degli aeroporti, degli impianti e installazioni radar e radio, degli stabilimenti nei quali sono fabbricati, manipolati o depositati materiali bellici o sostanze pericolose, dei campi di esperienze e dei poligoni di tiro, il diritto di proprieta' e di impresa puo' essere soggetto a limitazioni secondo le norme del presente capo.

2. Tali limitazioni sono stabilite nella durata massima di cinque anni, salvo quanto previsto dall'articolo 331, e sono imposte nella misura direttamente e strettamente necessaria per il tipo di opere o di installazioni di difesa. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 321. - Contenuto delle limitazioni

1. Le limitazioni possono consistere nel divieto di:

- a) fare elevazioni di terra o di altro materiale;
- b) costruire condotte o canali sopraelevati;
- c) impiantare condotte o depositi di gas o liquidi infiammabili;
- d) scavare fossi o canali di profondita' superiore a 50 cm.;
- e) aprire o esercitare cave di qualunque specie;
- f) installare macchinari o apparati elettrici e centri trasmittenti;
- g) fare le piantagioni e le operazioni campestri che sono determinate con il regolamento.

2. Le limitazioni possono anche consistere nel divieto di:

- a) aprire strade;
- b) fabbricare muri o edifici;
- c) sopraelevare muri o edifici esistenti;
- d) adoperare nelle costruzioni alcuni materiali.

### Art. 322. - Comitato misto paritetico - Programmi delle installazioni militari

1. In ciascuna regione e' costituito un Comitato misto paritetico di reciproca consultazione per l'esame, anche con proposte alternative della regione e dell'autorita' militare, dei problemi connessi all'armonizzazione tra i piani di assetto territoriale e di sviluppo economico e sociale della regione e delle aree subregionali e i programmi delle installazioni militari e delle conseguenti limitazioni.

2. Nel Trentino-Alto Adige il comitato regionale e' sostituito da due comitati provinciali, rispettivamente per la provincia di Trento e per quella di Bolzano. Nel presente articolo l'indicazione della regione, del consiglio regionale e del presidente della giunta regionale si intende, per il Trentino-Alto Adige, riferita alla provincia, al consiglio provinciale e al presidente della giunta provinciale.

3. Il Comitato e' formato da cinque rappresentanti del Ministero della difesa, da due rappresentanti del Ministero dell'economia e delle finanze, designati dai rispettivi Ministri, e da sette rappresentanti della regione nominati dal presidente della Giunta regionale, su designazione, con voto limitato, del consiglio regionale. Per ogni membro e' nominato un supplente.

4. Nei comitati misti paritetici provinciali di cui al comma 2, i rappresentanti della provincia sono nominati dalla Giunta provinciale rispettiva.

5. Il Comitato e' consultato semestralmente su tutti i programmi delle esercitazioni a fuoco di reparto o di unita', per la definizione delle localita', degli spazi aerei e marittimi regionali, del tempo e delle modalita' di svolgimento, nonche' sull'impiego dei poligoni della regione. Se la maggioranza dei membri designati dalla regione si esprime in senso contrario, sui programmi di attivita' addestrative decide in via definitiva il Ministro della difesa.

6. Ciascun comitato, sentiti gli enti locali e gli altri organismi interessati, definisce le zone idonee alla concentrazione delle esercitazioni di tiro a fuoco nella regione per la costituzione di poligoni, utilizzando prioritariamente, ove possibile, aree demaniali.

7. Una volta costituite tali aree militari, le esercitazioni di tiro a fuoco devono di massima svolgersi entro le aree stesse. Per le aree addestrative, terrestri, marittime e aeree, sia provvisorie sia permanenti, si stipulano disciplinari d'uso fra l'autorita' militare e la regione interessata. In caso di mancato accordo il progetto di disciplinare e' rimesso al Ministro della difesa che decide sentiti il presidente della giunta regionale e il presidente del comitato misto paritetico competenti.

8. Se esigenze di segreto militare non consentono un approfondito esame, il presidente della giunta regionale puo' chiedere all'autorita' competente di autorizzare la comunicazione delle notizie necessarie.

9. Il Comitato si riunisce a richiesta del Comandante militare territoriale ((o del Comandante marittimo)) o del Comandante di regione aerea o del Presidente della regione; presiede l'ufficiale generale o ammiraglio piu' elevato in grado o piu' anziano; funge da segretario l'ufficiale meno elevato in grado o meno anziano.

10. Delle riunioni del Comitato e' redatto verbale che contiene anche le eventuali proposte di membri discordanti sull'insieme della questione trattata o su singoli punti di essa.

11. Le definitive decisioni sui programmi di installazioni militari e relative limitazioni di cui al comma 1 sono riservate al Ministro della difesa. La regione interessata puo' richiedere al Presidente del Consiglio dei Ministri, entro quindici giorni dal giorno successivo alla pubblicazione o comunicazione della decisione ministeriale, di sottoporre la questione a riesame da parte del Consiglio dei Ministri.

12. Il Presidente del Consiglio dei Ministri puo', in casi particolari, disporre che i provvedimenti di limitazione della proprieta' siano sospesi sino alla decisione del Consiglio dei Ministri.

13. Il Consiglio dei Ministri si pronuncia sulle richieste di riesame entro novanta giorni.

14. Alla riunione del Consiglio dei Ministri e' invitato il presidente della giunta regionale interessata.

### Art. 323. - Procedimento di imposizione delle limitazioni

1. Il Comandante militare territoriale ((o il Comandante marittimo)) o il Comandante di regione aerea, se l'opera e', rispettivamente, dell'Esercito italiano o interforze, della Marina militare o dell'Aeronautica militare, predispone il progetto di imposizione delle limitazioni, in attuazione e nell'ambito dei programmi di cui all'articolo 322, corredandolo di un preventivo di spesa relativo agli indennizzi.

2. Nel presente capo, l'espressione <<il Comandante territoriale>> si intende riferita al Comandante militare territoriale ((, al Comandante marittimo)) o al Comandante di regione aerea, se l'opera e', rispettivamente, dell'Esercito italiano o interforze, della Marina militare o dell'Aeronautica militare.

3. Il progetto, con l'allegato preventivo di spesa, e' trasmesso alla ragioneria centrale del Ministero della difesa, ai sensi e per gli effetti dell'articolo 11 del decreto del Presidente della Repubblica 20 aprile 1994, n. 367.

4. Ad avvenuta prenotazione dell'impegno provvisorio, il provvedimento impositivo e' adottato dal Comandante territoriale con decreto nel quale sono indicati gli estremi di registrazione dell'impegno provvisorio di spesa.

5. Le zone soggette a limitazioni e le limitazioni stesse sono indicate su mappe catastali da allegare al decreto impositivo, nelle quali devono risultare individuate le singole proprieta' assoggettate.

### Art. 324. - Pubblicita' del decreto impositivo - Esecutivita' - Impugnazioni

1. Il decreto, corredato di mappe, e' pubblicato mediante deposito, per sessanta giorni consecutivi, nell'ufficio di ciascun comune, nel quale sono situati i fondi assoggettati alle limitazioni.

2. Dell'avvenuto deposito e' data notizia, entro i primi quindici giorni, mediante manifesti del comando militare territoriale affissi, in numero congruo, a cura del sindaco, nel territorio del predetto comune. Di tale deposito e' effettuata contestuale notifica, tramite i comuni interessati, ai proprietari degli immobili assoggettati alle limitazioni.

3. Successivamente il decreto, corredato di un certificato del segretario comunale attestante l'avvenuto deposito per sessanta giorni consecutivi e l'avvenuta affissione dei manifesti, e' custodito nell'archivio dello stesso comune.

4. Chiunque puo' prendere visione del decreto e dei suoi allegati durante il deposito e successivamente, fino a che l'imposizione ha effetto.

5. Il decreto diviene esecutivo decorso il novantesimo giorno dalla data di deposito nell'ufficio comunale.

6. In attesa che le limitazioni diventino esecutive, il Comandante territoriale puo' ordinare la sospensione di lavori o di piantagioni che siano in contrasto con le limitazioni risultanti dal decreto impositivo.

7. Fatta salva la tutela giurisdizionale secondo le norme vigenti, chiunque vi ha interesse puo' proporre ricorso gerarchico al Ministro della difesa avverso il decreto del Comandante territoriale, entro i termini e secondo le modalita' previsti dal decreto legislativo 24 novembre 1971, n. 1199.

8. Di tale diritto e del termine entro il quale puo' esercitarsi e' fatta menzione nei manifesti di cui al presente articolo.

9. D'ufficio o su domanda del ricorrente, proposta nello stesso ricorso gerarchico o in successiva istanza da presentarsi nei modi previsti dall'articolo 2, comma 2, del decreto legislativo n. 1199 del 1971, il Ministro della difesa puo' sospendere l'esecuzione dell'atto impugnato.

10. I ricorsi gerarchici presentati ai comandanti territoriali sono da questi trasmessi entro quindici giorni ((all'Ufficio centrale competente)) del Ministero della difesa, accompagnati da una breve relazione e da una copia del decreto impositivo con la prova dell'avvenuta pubblicazione e notificazione.

### Art. 325. - Indennizzo per le limitazioni

1. Ai proprietari degli immobili assoggettati alle limitazioni spetta un indennizzo annuo rapportato al doppio del reddito dominicale e agrario dei terreni e del reddito dei fabbricati, quali valutati ai fini dell'imposizione sul reddito.

2. Tale indennizzo e' stabilito in una meta' dei predetti redditi per le limitazioni di cui a ciascuno dei commi 1 e 2 dell'articolo 321 e nell'intero reddito in caso di concorso di limitazioni di entrambi i commi del citato articolo.

3. Per i terreni con preesistente destinazione edificatoria e non suscettibili di altra utilizzazione e rendita agraria, l'indennizzo annuo e' pari al doppio del reddito medio del fabbricato che sarebbe edificabile in assenza della limitazione. La destinazione edificatoria si determina ai sensi dell'articolo 37 del decreto del Presidente della Repubblica 8 giugno 2001, n. 327.

4. Se il fondo e' stato concesso prima dell'imposizione delle limitazioni in conduzione a terzi, il proprietario corrisponde a essi parte dell'indennizzo, in rapporto al danno subito. La relativa misura, se manca l'accordo fra le parti, e' determinata da un collegio di tre arbitri, nominati uno dal proprietario, l'altro dal conduttore e il terzo dagli arbitri scelti dalle parti e, in caso di mancato accordo, dal presidente del tribunale del circondario. Lo stesso presidente procede alla nomina dell'arbitro non designato dalla parte.

5. La decisione del collegio arbitrale, se non e' diversamente stabilito dalle parti, e' suscettibile dei gravami previsti per il lodo arbitrale dal codice di procedura civile.

6. Gli indennizzi sono corrisposti ai proprietari degli immobili su domanda degli stessi o degli interessati di cui al comma 4, diretta al sindaco del comune ove esistono i beni soggetti a vincolo.

7. La sottoscrizione della domanda e' autenticata dal funzionario competente a ricevere la domanda, o da un notaio, cancelliere, segretario comunale o altro funzionario incaricato dal sindaco. La domanda ha efficacia per tutto il periodo di validita' del decreto di imposizione della limitazione. L'autorita' militare determina le eventuali variazioni degli indennizzi conseguenti a modifiche delle condizioni di asservimento che possono sopravvenire nel quinquennio di validita' del decreto.

8. Per il pagamento degli indennizzi il cui importo annuale non superi la somma di euro 258,00 non e' richiesta altra documentazione.

9. Il decreto di imposizione delle limitazioni specifica che gli indennizzi sono corrisposti a domanda degli aventi diritto.

10. Le disposizioni di cui ai commi precedenti sono rese note con le forme di pubblicita' di cui all'articolo 324.

11. A richiesta dell'amministrazione militare, le conservatorie dei registri immobiliari, gli uffici tavolari e le Agenzie del territorio comunicano i dati necessari per la determinazione della misura degli indennizzi.

12. La determinazione dell'indennizzo effettuata all'atto dell'imposizione vale per l'intero quinquennio, salvo le variazioni derivanti dai coefficienti di aggiornamento dei redditi catastali nonche' quanto previsto dal comma 7.

13. L'indennizzo e' corrisposto annualmente per la durata delle limitazioni.

14. E' fatto obbligo al proprietario di comunicare all'amministrazione militare l'eventuale cessione del bene.

15. Per il pagamento degli indennizzi si provvede mediante aperture di credito disposte a favore dei sindaci dei comuni nel cui territorio insistono le aree ammesse all'indennizzo, secondo le norme sulla contabilita' generale dello Stato. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 326. - Contenuto del decreto impositivo

1. Il decreto impositivo del Comandante territoriale, oltre a quanto previsto dagli articoli 323, 324 e 325, da' atto dell'avvenuta consultazione del Comitato nonche' delle decisioni del Ministro della difesa o della deliberazione del Consiglio dei Ministri nei casi di cui ai commi 11 e 12 dell'articolo 322.

### Art. 327. - Modifiche alle proprieta' private e relativo indennizzo

1. L'amministrazione militare, all'atto dell'imposizione delle limitazioni, ha facolta' di modificare, nelle proprieta' assoggettate, lo stato delle cose che contrasti con le esigenze militari.

2. Tali modificazioni danno diritto a indennizzo che e' determinato con i criteri di cui al decreto del Presidente della Repubblica 8 giugno 2001, n. 327, dettati per i fabbricati e per i terreni.

### Art. 328. - Deroghe alle limitazioni

1. Il Comandante territoriale puo', su richiesta degli interessati, autorizzare che sui fondi siano eseguite opere in deroga alle limitazioni imposte. L'atto non e' soggetto a particolari formalita'.

2. Se l'autorizzazione e' subordinata a speciali condizioni o importa una riduzione dell'indennizzo, l'atto e' sottoscritto per accettazione da parte dell'interessato.

3. La deroga comporta il mantenimento dell'indennizzo, se restano in vigore anche solo alcuni divieti previsti dal comma 1 o dal comma 2 dell'articolo 321 e se resta invariata la ipotesi di cumulo di cui al comma 2 dell'articolo 325, o la riduzione conseguente al venir meno della ipotesi di cumulo.

4. La deroga di tutti i divieti comporta cessazione dell'indennizzo.

5. Il Comandante territoriale ne da' notizia all'Ufficio centrale del bilancio presso il Ministero della difesa per le conseguenti variazioni degli impegni di spesa provvisori o definitivi gia' registrati.

### Art. 329. - Contributo ai comuni

1. Ai comuni il cui territorio e' assoggettato alle limitazioni previste dall'articolo 321 e' dovuto un contributo annuo pari al cinquanta per cento dell'ammontare complessivo degli indennizzi spettanti ai proprietari degli immobili siti nei comuni stessi.

2. Il contributo ai comuni e' annualmente erogato, indipendentemente dalla presentazione delle domande di indennizzo.

3. Il contributo e' erogato in base alle limitazioni risultanti gravanti sul territorio comunale al 1° gennaio di ogni anno.

### Art. 330. - Ulteriori provvidenze in favore di comuni e regioni

1. Fermo quanto previsto dall'articolo 329, ai comuni nel cui territorio sono presenti aree appartenenti allo Stato, in uso all'amministrazione militare e destinate a poligoni addestrativi di tiro, e' corrisposto un contributo annuo rapportato al reddito dominicale e agrario medio delle aree confinanti con quelle su cui insistono i poligoni di tiro, rivalutato secondo i coefficienti stabiliti ai fini dell'imposizione sul reddito.

2. Alle regioni maggiormente oberate dai vincoli e dalle attivita' militari, comprese la dimostrazione e la sperimentazione di sistemi d'arma, individuate ogni quinquennio con decreto del Presidente del Consiglio dei Ministri, sentito il Ministro della difesa, lo Stato corrisponde un contributo annuo da destinarsi alla realizzazione di opere pubbliche e servizi sociali nei comuni nei quali le esigenze militari (compresi particolari tipi di insediamenti), incidono maggiormente sull'uso del territorio e sui programmi di sviluppo economico e sociale.

3. Il contributo e' corrisposto alle singole regioni sulla base della incidenza dei vincoli e delle attivita' di cui al comma 2, determinata secondo parametri da stabilirsi con decreto del Ministro della difesa di concerto dell'economia e delle finanze, sentite le regioni interessate.

4. Ai comuni con popolazione fino a centomila abitanti, in cui esistono insediamenti militari (caserme, depositi, o altre infrastrutture militari), sono corrisposte entrate ordinarie da parte dello Stato facendo riferimento, oltre che al numero degli abitanti, anche a quello del personale militare presente, che e' considerato, a tal fine, come popolazione residente. Uguale trattamento verra' riservato ai comuni che ospitano basi della NATO o di Paesi alleati.

### Art. 331. - Revisione generale quinquennale delle limitazioni

1. Ogni cinque anni dall'imposizione delle limitazioni si procede a revisione generale per accertare se le limitazioni stesse sono ancora necessarie per le esigenze della difesa nazionale.

2. Gli uffici tecnici militari, con sufficiente anticipo rispetto alla scadenza quinquennale delle limitazioni, inoltrano al Comandante territoriale motivata proposta di conferma per le limitazioni ancora necessarie, sentiti gli organi operativi interessati.

3. I predetti uffici allegano alla proposta di conferma un preventivo di spesa relativo alla determinazione dell'indennizzo valevole per l'ulteriore quinquennio salve le variazioni derivanti dai coefficienti di aggiornamento dei redditi catastali.

4. Il Comandante territoriale, per le limitazioni ancora necessarie, trasmette lo schema di decreto di conferma alla ragioneria centrale del Ministero della difesa, ai sensi e per gli effetti dell'articolo 11, del decreto del Presidente della Repubblica 20 aprile 1994, n. 367, unitamente al preventivo di spesa e alla copia del precedente decreto impositivo con relativi allegati.

5. Ad avvenuta prenotazione dell'impegno provvisorio il Comandante territoriale emana decreto di proroga per altri cinque anni, sentito il Comitato.

6. Il decreto di proroga e' adottato e pubblicato nella forma e con le modalita' previste per il decreto impositivo originario.

7. Le limitazioni possono essere ridotte o revocate, con decreto del Comandante territoriale, anche prima dello scadere del quinquennio. Detto decreto e' trasmesso alla ragioneria centrale per le conseguenti variazioni dell'impegno di spesa.

8. Il decreto di revoca prima della scadenza del quinquennio, di riduzione o di conferma e' pubblicato con le modalita' indicate nell'articolo 324.

9. Se non interviene decreto di conferma alla prevista scadenza, le limitazioni sono estinte a ogni effetto.

10. In caso di conferma, se per effetto delle limitazioni l'esercizio del diritto di proprieta' sul bene o su parte di esso e' reso impossibile o eccessivamente difficile, il proprietario puo' chiedere la espropriazione totale o parziale del bene stesso.

11. L'indennita' di espropriazione e' determinata con i criteri di cui al decreto del Presidente della Repubblica 8 giugno 2001, n. 327, dettati per i fabbricati e per i terreni.

### Art. 332. - Limitazioni per il tempo necessario allo svolgimento di esercitazioni militari

1. Per il tempo strettamente necessario allo svolgimento di esercitazioni, il Comandante territoriale puo' disporre, per motivi di pubblica incolumita', lo sgombero e l'occupazione di immobili e il divieto di accedervi, lo sgombero di specchi d'acqua interni e marini, e imporre limitazioni alla circolazione stradale.

2. I relativi provvedimenti sono comunicati almeno trenta giorni prima al prefetto della provincia, al sindaco dei comuni interessati e al comitato misto paritetico. Se le esercitazioni interessano aree ricadenti in foreste demaniali, la comunicazione va fatta anche agli uffici ai quali compete l'amministrazione delle medesime.

3. Nei casi di urgente necessita', gli sgomberi, le occupazioni e le limitazioni di cui al comma 1 possono essere disposte, con effetto immediato, dal comandante di corpo, che provvede sollecitamente alle comunicazioni di cui al comma 2.

4. Detti provvedimenti sono resi pubblici mediante affissione all'albo pretorio comunale e mediante affissione di manifesti murali in luoghi pubblici di normale frequentazione.

5. Al pagamento degli indennizzi per tutti gli sgomberi e le occupazioni di cui al comma 1 nonche' per eventuali danni si provvede con le modalita' previste dal comma 15 dell'articolo 325.

6. La misura dell'indennizzo per i lavoratori dipendenti e' pari al salario corrente; per i lavoratori autonomi e' rapportata alla retribuzione spettante ai lavoratori dipendenti con qualifica o specializzazione corrispondente o affine.

## CAPO II - LIMITAZIONI PER INTERE CATEGORIE DI BENI E ATTIVITA'

### Art. 333. - Autorizzazioni dell'autorita' militare per talune opere e uso di beni nei comuni militarmente importanti, nelle zone costiere e nelle isole

1. Nel territorio dei comuni militarmente importanti indicati nel comma 7, la costruzione di strade di sviluppo superiore ai 500 metri, le edificazioni, l'uso di grotte e cavita' sotterranee e i rilevamenti per qualsiasi scopo effettuati, a eccezione di quelli catastali, non possono avere luogo senza autorizzazione del Comandante territoriale.

2. Nel territorio dei comuni costieri militarmente importanti indicati nel comma 8 le edificazioni e i lavori afferenti ai porti e ai porti turistici e alle opere marittime in genere non possono aver luogo senza la preventiva autorizzazione del Comandante territoriale.

3. Nelle zone costiere e nelle isole indicate nel comma 9 l'uso delle grotte, gallerie e altre cavita' sotterranee, entro il limite di cento metri dal demanio marittimo o dal ciglio dei terreni elevati sul mare, non puo' aver luogo senza autorizzazione del Comandante territoriale.

4. Per le strade, salvo quanto disposto dal comma 5, per le edificazioni e per i lavori afferenti ai porti e ai porti turistici, l'autorizzazione di cui ai commi 1 e 2 non e' richiesta se sono previsti dai piani urbanistici approvati nel loro complesso su conforme parere del Comandante territoriale e se sono eseguiti in conformita' dei piani stessi.

5. Per i progetti delle opere stradali intercomunali e' sentita l'autorita' militare, che esprime il proprio parere nel termine di novanta giorni; decorso tale termine la mancata pronuncia equivale a parere favorevole.

6. Se le esigenze della difesa lo consentono, il Ministro della difesa dichiara, con proprio decreto, non soggette in tutto o in parte al regime previsto dal presente articolo nell'ambito dei territori e delle zone costiere, indicati nei commi 7, 8 e 9, le aree che non sono direttamente o indirettamente interessate a opere o installazioni di difesa.

7. Sono comuni militarmente importanti:

- a) provincia di Udine: Paluzza - Pontebba - Malborghetto Valbruna - Tarvisio - Dogna - Chiusaforte -Resia - Lusevera - Taipana - Nimis - Attimis - Faedis - Pulfero - Torreano - Savogna - San Pietro al Natisone - Drenchia - Grimacco - San Leonardo - Stregna - Prepotto;
- b) provincia di Gorizia: Dolegna del Collio - Monfalcone;
- c) provincia di Trieste: Trieste.

8. Sono comuni costieri militarmente importanti:

- a) provincia di Venezia: Venezia;
- b) provincia di Ancona: Ancona;
- c) provincia di La Spezia: La Spezia - Porto Venere - Lerici -Ameglia;
- d) provincia di Livorno: Portoferraio;
- e) provincia di Latina: Gaeta;
- f) provincia di Napoli: Napoli - Pozzuoli;
- g) provincia di Taranto: Taranto;
- h) provincia di Brindisi: Brindisi;
- i) provincia di Foggia: Isole Tremiti e Pianosa;
- l) provincia di Agrigento: Isole Lampedusa e Linosa;
- m) provincia di Messina: Messina;
- n) provincia di Siracusa: Augusta - Melilli;
- o) provincia di Trapani: Trapani - Isole Egadi - Pantelleria;
- p) provincia di Cagliari: Cagliari;
- q) provincia di Sassari: La Maddalena - Olbia (solo isola Tavolara).

9. L'autorizzazione di cui al comma 3 occorre nelle seguenti zone costiere e isole:

- a) da San Remo ad Alassio;
- b) da Punta Mesco alla foce del Magra;
- c) da Sperlonga a Gaeta;
- d) da Capo Miseno a Punta Campanella;
- e) da Punta Rondinella a Capo S. Vito;
- f) da Capo S. Maria di Leuca a Capo d'Otranto;
- g) da Punta Penne a Punta della Contessa;
- h) da Numana a Falconara;
- i) da Capo S. Croce a Capo Murro di Porco;
- l) da Punta Pizzolungo a Punta Nubia;
- m) da Capo Ferro a Capo Testa;
- n) da Capo Spartivento Sardo a Capo Carbonara;
- o) isole Palmaria e Tino;
- p) arcipelago Toscano;
- q) isole Tremiti e Pianosa (Adriatico);
- r) isole Eolie, Egadi, Pantelleria, Lampedusa e Linosa;
- s) isole Tavolara e Asinara;
- t) arcipelago de La Maddalena.

### Art. 334. - Parere dell'autorita' militare per talune opere e lavori

1. E' richiesto il parere del Comandante territoriale per tutte le nuove realizzazioni o varianti strutturali significative interessanti grandi comunicazioni stradali (strade statali e autostrade) e ferrovie nonche' per tutti i lavori interessanti dighe di ritenuta, impianti minerari marittimi, idroelettrici, grandi stabilimenti industriali, centri termonucleari, impianti elettrici ad altissimo potenziale, grandi depositi di oli minerali, oleodotti, metanodotti, in qualsiasi parte del territorio nazionale le opere vengano compiute.

2. Il parere e' espresso nel termine di novanta giorni. Se il Comandante territoriale non si pronuncia entro il predetto termine, la mancata pronuncia equivale a parere favorevole.

### Art. 335. - Alienazioni di immobili nelle zone dichiarate di importanza militare dal Ministro della difesa

1. Tutti gli atti di alienazione totale o parziale dei beni immobili sono sottoposti all'approvazione del prefetto della provincia se tali immobili sono ubicati nelle zone del territorio nazionale dichiarate di importanza militare, individuate con il regolamento, sul quale per tale parte e' acquisito il concerto del Ministro dell'interno e del Ministro della giustizia.

2. L'approvazione e' necessaria anche per l'aggiudicazione di tali beni a seguito di vendita in via esecutiva. Il prefetto, previo parere dell'autorita' militare, provvede in materia entro il termine di cui al comma 6. L'approvazione non puo' essere data in difformita' del parere dell'autorita' militare. 4. In mancanza di tale approvazione, gli atti sopraindicati sono privi di efficacia giuridica. I conservatori dei registri immobiliari non procedono alla trascrizione degli atti previsti se non e' esibita la prova dell'intervenuta approvazione prefettizia. 5. L'autorizzazione del prefetto e il parere dell'autorita' militare non sono richiesti per gli atti di alienazione totale o parziale ai cittadini dell'Unione europea o alle amministrazioni dello Stato, ivi comprese le aziende autonome, ai comuni, alle province e agli altri enti locali, alle regioni, agli enti pubblici economici, nonche' a ogni altra persona giuridica pubblica o privata, avente la sede principale delle proprie attivita' nel territorio dell'Unione europea. 6. Il decreto di autorizzazione prefettizia e' emanato entro sessanta giorni dalla presentazione della domanda. In tale termine e' computato anche quello di quarantacinque giorni concesso all'autorita' militare competente per esprimere il proprio parere in ordine alle istanze di autorizzazione. Trascorso il predetto termine di quarantacinque giorni, se l'autorita' militare non ha fatto pervenire al prefetto il richiesto parere, lo stesso si intende favorevolmente dato. 7. L'autorizzazione del prefetto, da allegare in originale all'atto di alienazione, perde efficacia se non si procede alla stipulazione dell'atto entro sei mesi dal giorno in cui e' stata rilasciata. 8. Il diniego di autorizzazione e' motivato. Gli atti di alienazione di immobili e le relative trascrizioni presso le conservatorie immobiliari eseguiti tra il 12 gennaio 1977 e il 31 dicembre 1984 sono riconosciuti giuridicamente validi a tutti gli effetti. 9. Gli atti compiuti per interposta persona sono nulli. 10. Il responsabile e' punito con la reclusione da sei mesi a tre anni e con la multa da euro 41,00 a euro 207,00. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

## CAPO III - DISPOSIZIONI COMUNI

### Art. 336. - Sanzioni

1. Le violazioni del presente titolo, escluse le violazioni dell'articolo 335, sempre che il fatto non costituisce reato, sono soggette alla sanzione amministrativa del pagamento di una somma di denaro non inferiore a euro 52,00 e non superiore a euro 516,00.

2. La sanzione amministrativa e' inflitta previa contestazione della violazione e se il trasgressore non ha ottemperato alla diffida a cessare la violazione.

3. Competente a provvedere alla diffida, a determinare la misura e ingiungere il pagamento della sanzione amministrativa e' il Comandante territoriale. Il procedimento e le eventuali opposizioni sono regolati dalla legge 24 novembre 1981, n. 689, in quanto applicabile.

4. L'autorita' militare puo' ordinare al trasgressore di compiere a proprie spese il ripristino. Se il trasgressore non ottempera all'ordine di ripristino nel termine assegnatogli, o in caso di assoluta urgenza, l'autorita' militare provvede d'ufficio addebitando le relative spese al trasgressore.

### Art. 337. - Regime fiscale

1. Tutti gli atti necessari per l'esecuzione del presente titolo, compiuti nell'interesse dello Stato, comprese le cancellazioni ipotecarie, sono esenti dalle imposte di bollo, di registro, ipotecarie e catastali, nonche' dagli emolumenti riscossi dai conservatori dei registri immobiliari, dai diritti di scritturato e dai tributi speciali di cui al decreto-legge 31 luglio 1954, n. 533 , convertito dalla legge 26 settembre 1954, n. 869.

### Art. 338. - Disciplina di esecuzione

1. Il regolamento detta le norme di esecuzione del presente titolo; per tale parte su di esso e' acquisito il concerto dei Ministri interessati.

## CAPO IV - NORME SPECIALI PER LA PROVINCIA DI BOLZANO

### Art. 339. - Ambito di applicazione quanto alla provincia di Bolzano

1. Le disposizioni del capo II del presente titolo non si applicano per i comuni della provincia di Bolzano elencati nell'articolo 22 del decreto del Presidente della Repubblica 22 marzo 1974, n. 381, per i quali si provvede con la procedura prevista dall'articolo 107 del decreto del Presidente della Repubblica 31 agosto 1972, n. 670. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 340. - Disciplina speciale per taluni comuni della provincia di Bolzano

1. Nei comuni della provincia autonoma di Bolzano elencati nell'articolo 22 del decreto del Presidente della Repubblica 22 marzo 1974, n. 381, e nei limiti in tale articolo 22 stabiliti, si applicano le disposizioni degli articoli seguenti.

2. Nei comuni di cui al comma 1 sono soggette alle limitazioni stabilite nel presente capo tutte le proprieta' fondiarie.

### Art. 341. - Opere per le quali occorre l'autorizzazione dell'autorita' militare

1. E' vietato procedere a costruzioni ferroviarie, e a lavori minerari, idraulici, elettrici (ivi comprese le linee di trasporto di energia elettrica, le linee telegrafiche e telefoniche, ecc.), alla costruzione di linee teleferiche, ad attivazione di cave, a qualsiasi uso di grotte e cavita' sotterranee, nonche' al disboscamento, senza autorizzazione dell'autorita' militare.

2. Tale autorizzazione occorre anche per lavori di altra specie come strade, edificazioni, depositi e cumuli di materiale in genere, elevazioni, scavi e demolizioni, se essi superano i limiti da fissarsi con le norme regolamentari.

3. Le grotte e cavita' sotterranee sono ritenute esistenti nei comuni di cui al presente capo, quando si estendono in essi, senza riguardo al luogo dove e' sita la loro entrata.

### Art. 342. - Condizioni e ambito dell'autorizzazione

1. L'autorita' militare su istanza dell'interessato, corredata degli occorrenti piani e progetti, autorizza l'esecuzione delle opere proposte dopo aver accertato che esse non possono recare ostacolo a eventuali misure di difesa o altrimenti pregiudizio alla tutela del territorio.

2. L'autorizzazione e' subordinata alla condizione - da rendersi pubblica nei modi stabiliti dalle leggi civili per le servitu' - che l'interessato resta obbligato a effettuare a ogni richiesta la demolizione delle opere stesse dietro compenso da determinarsi a norma dell'articolo 343.

3. Per i boschi amministrati da enti pubblici, dichiarati militarmente importanti, sono sottoposti al preventivo esame e approvazione delle autorita' militari i relativi programmi di gestione.

4. Nei centri urbani, i lavori stradali, le edificazioni, le elevazioni, i cumuli e le demolizioni possono essere eseguiti senza preventivo nulla osta dell'autorita' militare, purche' per detti centri urbani esista strumento urbanistico gia' approvato nel suo complesso dall'autorita' militare.

### Art. 343. - Ordini di demolizione

1. E' sempre in facolta' dell'autorita' militare ordinare, per sopraggiunte esigenze di pubblico interesse, la demolizione delle costruzioni, che esistono sopra e sotto il suolo e la costruzione di opere di difesa con la costituzione delle occorrenti servitu' di accesso. La misura delle indennita' per tali provvedimenti dovute ai proprietari e' determinata con i criteri stabiliti dal decreto del Presidente della Repubblica 8 giugno 2001, n. 327.

2. Per quanto concerne le opere di bonifica e quelle idraulico - forestali, le demolizioni delle costruzioni sono ordinate previo concerto con il Ministero delle politiche agricole, alimentari e forestali.

### Art. 344. - Vigilanza

1. Sui beni immobili, comprese le grotte e cavita' sotterranee, l'autorita' militare esercita una continua vigilanza. A tale scopo gli uffici dei registri immobiliari segnalano all'autorita' militare tutti gli atti relativi ai passaggi di proprieta' e quelli costitutivi di diritti reali sui beni medesimi.

### Art. 345. - Pubblicita'

1. Le limitazioni del diritto di proprieta' stabilite dagli articoli 341, 343 e 344 sono rese di pubblica conoscenza con mezzi idonei, a cura del prefetto, di concerto con l'autorita' militare.

### Art. 346. - Opere in prossimita' della linea doganale

1. Se si tratta di opere da eseguire in prossimita' della linea doganale, oltre l'autorizzazione dell'autorita' militare, e' necessaria quella del Comando della Guardia di finanza, territorialmente competente.

### Art. 347. - Espropriazione

1. Dei beni indicati nel presente capo puo' essere disposta in ogni tempo l'espropriazione dall'autorita' militare secondo le norme per le espropriazioni per le opere militari dettate dal decreto del Presidente della Repubblica 8 giugno 2001, n. 327. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 348. - Autorita' militare competente

1. Le istanze per ottenere le autorizzazioni e i pareri previsti dal presente capo sono rivolte ai Comandi militari territoriali. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 349. - Tutela amministrativa

1. Ferma restando la tutela giurisdizionale secondo le norme vigenti, contro i provvedimenti dell'autorita' militare e' ammesso il ricorso gerarchico al Ministro della difesa ai sensi del decreto legislativo 24 novembre 1971, n. 1199.

### Art. 350.

((ARTICOLO ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248))

## CAPO V - SALVEZZA DI ALTRE FONTI

### Art. 351. - Rinvio ad altre fonti

1. E' fatto salvo quanto previsto:

- a) dall'articolo 5, comma 4, lettera b), del decreto del Presidente della Repubblica 6 giugno 2001, n. 380;
- b) dall'articolo 6, comma 6, del decreto legislativo 25 luglio 1998, n. 286, recante il testo unico delle disposizioni concernenti la disciplina dell'immigrazione e norme sulla condizione dello straniero.

## TITOLO VII URBANISTICA, EDILIZIA, PAESAGGIO, ENERGIA, AMBIENTE E SALUTE CAPO I URBANISTICA, EDILIZIA, PAESAGGIO, ENERGIA

### Art. 352. - Disciplina urbanistica delle opere destinate alla difesa nazionale

1. Per la localizzazione di tutte le opere che siano qualificate dalle norme vigenti come destinate alla difesa nazionale, o che siano comunque destinate alla difesa nazionale non occorre l'accertamento di conformita' urbanistica di cui al decreto del Presidente della Repubblica 18 aprile 1994, n. 383.

2. La regione o la provincia autonoma interessata o il Ministero della difesa hanno facolta' di acquisire il parere del Comitato misto paritetico di cui all'articolo 322, in ordine alla compatibilita' urbanistica dell'opera.

### Art. 353. - Disciplina edilizia delle opere del Ministero della difesa

1. Fermo quanto disposto dall'articolo 352 non occorre titolo abilitativo edilizio per la realizzazione di opere del Ministero della difesa ai sensi dell'articolo 7, comma 1, lettera b), del decreto del Presidente della Repubblica 6 giugno 2001, n. 380.

2. Si applica l'articolo 106 del decreto del Presidente della Repubblica n. 380 del 2001, per le opere che si eseguono a cura del genio militare.

### Art. 354. - Disciplina paesaggistica delle opere del Ministero della difesa

1. Agli alloggi di servizio per il personale militare e alle opere destinate alla difesa nazionale, incidenti su immobili o aree sottoposti a tutela paesaggistica, si applica l'articolo 147 del decreto legislativo 22 gennaio 2004, n. 42, recante il codice dei beni culturali e del paesaggio.

### Art. 355. - Valorizzazione ambientale degli immobili militari

1. Il Ministero della difesa, nel rispetto del codice dei beni culturali e del paesaggio, di cui al decreto legislativo 22 gennaio 2004, n. 42, allo scopo di soddisfare le proprie esigenze energetiche, nonche' per conseguire significative misure di contenimento degli oneri connessi e delle spese per la gestione delle aree interessate, puo', fatti salvi i diritti dei terzi, affidare in concessione o in locazione, o utilizzare direttamente, in tutto o in parte, i siti militari, le infrastrutture e i beni del demanio militare o a qualunque titolo in uso o in dotazione all'Esercito italiano, alla Marina militare, all'Aeronautica militare e all'Arma dei carabinieri, con la finalita' di installare impianti energetici destinati al miglioramento del quadro di approvvigionamento strategico dell'energia, della sicurezza e dell'affidabilita' del sistema, nonche' della flessibilita' e della diversificazione dell'offerta, nel quadro degli obiettivi comunitari in materia di energia e ambiente. Resta ferma l'appartenenza al demanio dello Stato. A tal fine, il Ministero della difesa puo' definire un programma di interventi per la transizione energetica dei siti, delle infrastrutture e dei beni del demanio militare a qualunque titolo in uso o in dotazione, dislocati sul territorio nazionale. (119)

2. Non possono essere utilizzati ai fini del comma 1 i beni immobili individuati ai sensi dell'articolo 27, comma 13-ter, del decreto-legge 30 settembre 2003, n. 269, convertito, con modificazioni, dalla legge 24 novembre 2003, n. 326, e successive modificazioni, e dell'articolo 307, comma 2.

3. Ai fini di cui al comma 1, il Ministero della difesa, di concerto con il Ministero dello sviluppo economico, con il Ministero dell'ambiente e della tutela del territorio e del mare e con il Ministero delle infrastrutture e dei trasporti, sentita la regione interessata, nel rispetto dei principi e con le modalita' previsti dal codice dei contratti pubblici relativi a lavori, servizi e forniture, di cui al decreto legislativo 12 aprile 2006, n. 163, anche con particolare riferimento all'articolo 17 del medesimo codice, e successive modificazioni, puo' stipulare accordi con imprese a partecipazione pubblica o private. All'accordo sono allegati un progetto preliminare e uno studio di impatto ambientale che attesti la conformita' del progetto medesimo alla normativa vigente in materia di ambiente.

4. Il proponente, contemporaneamente alla presentazione del progetto preliminare al Ministero della difesa e al Ministero dello sviluppo economico, presenta al Ministero dell'ambiente e della tutela del territorio e del mare, ovvero alla regione territorialmente competente, istanza per la valutazione di impatto ambientale, ovvero per la verifica di assoggettabilita' a valutazione di impatto ambientale, se previste dalla normativa vigente. ((Qualora il programma di cui al comma 1 ovvero, singolarmente, gli interventi ivi inseriti, anche a seguito di successiva modifica del programma, siano sottoposti alle procedure di cui alla parte seconda del decreto legislativo 3 aprile 2006, n. 152, tali procedure sono svolte, senza nuovi o maggiori oneri per la finanza pubblica, dalla Commissione tecnica PNRR-PNIEC e integrate dalla valutazione ambientale strategica per gli eventuali contenuti di pianificazione)). ((119))

5. Il Ministero della difesa, quale amministrazione procedente, convoca una conferenza di servizi per l'acquisizione delle intese, dei concerti, dei nulla osta o degli assensi comunque denominati delle altre amministrazioni, che svolge i propri lavori secondo le modalita' di cui agli articoli da 14 a 14-quater della legge 7 agosto 1990, n. 241, e successive modificazioni, anche con riferimento alle disposizioni concernenti il raccordo con le procedure di valutazione di impatto ambientale. Restano ferme le competenze del Ministero delle infrastrutture e dei trasporti in merito all'accertamento della conformita' delle opere alle prescrizioni delle norme di settore e dei piani urbanistici ed edilizi. Il parere del Consiglio superiore dei lavori pubblici, se previsto, e' reso in base alla normativa vigente.

6. La determinazione finale della conferenza di servizi di cui al comma 6 costituisce provvedimento unico di autorizzazione, concessione, atto amministrativo, parere o atto di assenso comunque denominato.

7. Il Ministero della difesa, ai fini di quanto previsto dal comma 1, puo' usufruire per l'energia elettrica prodotta da fonti rinnovabili del servizio di scambio sul posto dell'energia elettrica prodotta secondo le modalita' di cui al comma 4, dell'articolo 27, della legge 23 luglio 2009, n. 99, anche per impianti di potenza superiore a 200 kW, nei limiti del proprio fabbisogno energetico e previo pagamento degli oneri di rete riconosciuti per l'illuminazione pubblica.

--------------- AGGIORNAMENTO (119) Il D.L. 17 ottobre 2024, n. 153, convertito con modificazioni dalla L. 13 dicembre 2024, n. 191, ha disposto (con l'art. 1, comma 5) che "Le disposizioni di cui al comma 4 si applicano, in quanto compatibili, agli interventi di cui all'articolo 20 del decreto-legge 1° marzo 2022, n. 17, convertito, con modificazioni, dalla legge 27 aprile 2022, n. 34".

## CAPO II - AMBIENTE

### Art. 356. - Disciplina applicabile- Rinvio

1. Fatto salvo quanto disposto dagli articoli seguenti, e ove non diversamente disposto dalle norme in materia ambientale, ai beni e alle attivita' dell'amministrazione della difesa e delle Forze armate si applicano le vigenti norme in materia di ambiente nei limiti di compatibilita' con gli speciali compiti e attivita' da esse svolti, tenuto conto delle insopprimibili esigenze connesse all'utilizzo dello strumento militare. I limiti di compatibilita' e le esigenze connesse all'utilizzo dello strumento militare sono valutate dai competenti organismi militari sanitari e tecnici.

2. Nel corso di attivita' addestrative od operative militari condotte all'estero in Paesi extracomunitari, l'amministrazione della difesa osserva le disposizioni di tutela ambientale e della salute al cui rispetto sarebbe tenuta nel territorio nazionale, nei limiti di compatibilita' con le esigenze dell'addestramento e delle attivita' operative in territorio estero, e nel rispetto di quanto disposto dal diritto pubblico locale. Sono salve diverse convenzioni internazionali, diversi accordi con le competenti autorita' locali o diverse regole fissate nell'ambito della missione all'estero.

### Art. 357. - Attivita' addestrative e tutela ambientale

1. L'amministrazione della difesa, nell'ambito delle aree in uso esclusivo delle Forze armate, puo' stipulare convenzioni con amministrazioni o enti, allo scopo di regolamentare attivita' finalizzate alla tutela ambientale, fatta salva la destinazione d'uso delle aree medesime necessarie per il perseguimento dei fini istituzionali della difesa. Allo stesso scopo promuove lo sviluppo di metodologie alternative alle attivita' addestrative reali quale la simulazione operativa. Le modalita' applicative dell'intervento a tutela e l'individuazione dei beni da salvaguardare sono demandate alla valutazione congiunta dei soggetti stipulanti la convenzione, sulla base delle direttive emanate dal ((direttore dell'Ufficio centrale competente)).

2. Se le aree addestrative non demaniali e i poligoni semipermanenti od occasionali insistono nell'area di parchi nazionali e regionali o nelle aree sottoposte a tutela ambientale, l'utilizzazione e il mantenimento conservativo dei siti si attuano a mezzo di protocolli d'intesa tra l'amministrazione della difesa, il Ministero dell'ambiente e della tutela del territorio e del mare, il Corpo forestale dello Stato e l'Ente gestore del parco.

### Art. 358. - Valutazione ambientale strategica e valutazione di impatto ambientale

1. Ai sensi dell'articolo 6, comma 4, lettera a), del decreto legislativo 3 aprile 2006, n. 152, sono comunque esclusi dal campo di applicazione di detto decreto i piani e i programmi destinati esclusivamente a scopi di difesa nazionale caratterizzati da somma urgenza o coperti dal segreto di Stato.

2. Ai sensi dell'articolo 6, comma 10, del decreto legislativo n. 152 del 2006, l'autorita' competente in sede statale valuta caso per caso i progetti relativi a opere e interventi destinati esclusivamente a scopo di difesa nazionale ai fini della valutazione di impatto ambientale. L'esclusione di tali progetti dal campo di applicazione del decreto legislativo n. 152 del 2006, se cio' possa pregiudicare gli scopi della difesa nazionale, e' determinata con decreto del Ministro della difesa e del Ministro dell'ambiente e della tutela del territorio e del mare.

3. Ai sensi dell'articolo 182, comma 3, del decreto legislativo 12 aprile 2006, n. 163, recante il codice dei contratti pubblici relativi a lavori, servizi e forniture, e con il procedimento ivi previsto, sono esclusi dalla procedura di valutazione di impatto ambientale, per le opere ivi previste, gli interventi destinati alla difesa nazionale in vista di un pericolo imminente.

### Art. 359. - Gestione dei rifiuti e bonifica dei siti inquinati

1. Ai sensi dell'articolo 184, comma 5-bis, del decreto legislativo 3 aprile 2006, n. 152, i sistemi d'arma, i mezzi, i materiali e le infrastrutture direttamente destinati alla difesa militare e alla sicurezza nazionale, individuati con decreto del Ministero della difesa, nonche' la gestione dei materiali e dei rifiuti e la bonifica dei siti ove sono immagazzinati i citati materiali, sono disciplinati dalla parte quarta del decreto legislativo n. 152 del 2006, con procedure speciali da definirsi con decreto del Ministro della difesa, di concerto con il Ministro dell'ambiente e della tutela del territorio e del mare e il Ministro della salute. I magazzini, i depositi e i siti di stoccaggio nei quali sono custoditi i medesimi materiali e rifiuti sono soggetti alle autorizzazioni e ai nulla osta previsti dal medesimo decreto interministeriale.

2. Ai sensi dell'articolo 185, comma 1, lettera b), numero 3, del decreto n. 152 del 2006, non rientrano nel campo di applicazione della parte quarta di detto decreto, in quanto regolati da altre disposizioni normative che assicurano tutela ambientale e sanitaria, i materiali esplosivi in disuso.

### Art. 360. - Rifiuti da apparecchiature elettriche ed elettroniche

1. Ai sensi dell'articolo 2, comma 3, del decreto legislativo 25 luglio 2005, n. 151, sono escluse dall'ambito di applicazione del citato decreto le apparecchiature connesse alla tutela di interessi essenziali della sicurezza nazionale, le armi, le munizioni e il materiale bellico, purche' destinati a fini specificatamente militari.

### Art. 361. - Inquinamento atmosferico

1. Ai sensi dell'articolo 272, comma 5, del decreto legislativo 3 aprile 2006, n. 152, il titolo I della parte V del citato decreto, relativo alla prevenzione e limitazione delle emissioni in atmosfera di impianti e attivita', non si applica agli impianti destinati alla difesa nazionale.

### Art. 362. - Controllo dei pericoli di incidenti rilevanti connessi con determinate sostanze pericolose

1. Ai sensi dell'articolo 4, comma 1, lettera a), del decreto legislativo 17 agosto 1999, n. 334, sono esclusi dall'applicazione del citato decreto gli stabilimenti, gli impianti o i depositi militari.

2. Ai sensi dell'articolo 22, comma 2, del decreto legislativo n. 334 del 1999, il gestore (come definito dall'articolo 3, comma 1, lettera d), del citato decreto) puo' chiedere alla regione di non diffondere le parti del rapporto di sicurezza di cui all'articolo 8 del citato decreto che contengono informazioni riservate che si riferiscono alla difesa nazionale. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 363. - Limiti di zolfo nei combustibili per uso marittimo, riduzione degli scarichi in mare e protezione da inquinamento marino

1. I limiti relativi al tenore di zolfo nei combustibili a uso marittimo, previsti dall'articolo 295 del decreto legislativo 3 aprile 2006, n. 152, non si applicano, ai sensi del comma 13, lettera a) del citato articolo 295, ai combustibili utilizzati dalle navi da guerra, come definite dall'articolo 292, comma 2, lettera s), del citato decreto legislativo, e da altre navi in servizio militare se le rotte non prevedono l'accesso a porti in cui sono presenti fornitori di combustibili conformi a tali limiti o, comunque, se il relativo rifornimento puo' pregiudicare le operazioni o le capacita' operative; in tale secondo caso il comandante informa il Ministero della difesa dei motivi della scelta.

1-bis. Continuano ad applicarsi alle navi militari da guerra o ausiliarie le disposizioni in materia di impianti per la raccolta di rifiuti e di antinquinamento, di cui all'articolo 3, comma 1, lettera a), del decreto legislativo 24 giugno 2003, n. 182, e all'articolo 3, comma 2, del decreto legislativo 6 novembre 2007, n. 202. Con il decreto del Ministro della difesa di cui all'articolo 3, comma 2, del decreto legislativo n. 182 del 2003 sono stabilite le misure necessarie ad assicurare che le navi militari da guerra ed ausiliarie conferiscano i rifiuti e i residui del carico in conformita' alla normativa vigente in materia, tenuto conto delle specifiche prescrizioni tecniche previste per le medesime navi e delle caratteristiche di ogni classe di unita'. ((Si applica, altresi', l'articolo 2, comma 2, del decreto legislativo 13 ottobre 2010, n. 190.))

### Art. 364. - Inquinamento acustico

1. Fermo restando quanto previsto dall'articolo 11, legge 26 ottobre 1995, n. 447, la prevenzione e il contenimento acustico nelle aree esclusivamente interessate da installazioni militari e nelle attivita' delle Forze armate sono definiti mediante specifici accordi dai comitati misti paritetici di cui all'articolo 322.

### Art. 365.

Inquinamento acustico derivante da aeroporti e ((aeromobili)) militari

1. Ai sensi dell'articolo 2 del decreto legislativo 17 gennaio 2005, n. 13, il citato decreto si applica agli aeroporti militari aperti al traffico civile, limitatamente al traffico di ((aeromobili)) civili, nei quali e' rilevato un superamento dei limiti acustici stabiliti dalle vigenti norme per le zone di rispetto individuate in attuazione dell'articolo 3, comma 1, lettera m), numero 3), della legge 26 ottobre 1995, n. 447.

2. Il decreto legislativo n. 13 del 2005 non si applica alle emissioni acustiche dei voli militari e ai voli effettuati a cura del Ministero della difesa per fini di preminente interesse pubblico, di sicurezza nazionale, di emergenza, di soccorso.

### Art. 366. - Inquinamento elettromagnetico

1. Ai sensi dell'articolo 2, commi 3 e 4, legge 22 febbraio 2001, n. 36, nei riguardi delle Forze armate le norme di detta legge sono applicate tenendo conto delle particolari esigenze al servizio espletato, individuate con il decreto di cui all'articolo 4, comma 2, lettera a), della legge n. 36 del 2001.

2. Restano ferme le competenze in materia di sicurezza e salute dei lavoratori attribuite dalle disposizioni vigenti ai servizi sanitari e tecnici istituiti per le Forze armate; i predetti servizi sono competenti altresi' per le aree riservate od operative e per quelle che presentano analoghe esigenze individuate con il decreto di cui al comma 1.

3. Ai sensi dell'articolo 8, comma 5, della legge n. 36 del 2001, le attivita' di competenza delle Regioni, elencate nell'articolo 8, comma 1, di detta legge, riguardanti aree interessate da installazioni militari sono definite mediante specifici accordi dai comitati misti paritetici di cui all'articolo 322.

4. Ai sensi dell'articolo 14, comma 3, della legge n. 36 del 2001, i controlli di competenza dei comuni all'interno degli impianti fissi o mobili destinati alle attivita' istituzionali delle Forze armate e' disciplinato dalla specifica normativa di settore. Resta fermo in particolare, quanto previsto per le Forze armate dei dagli articoli 3 e 13 del decreto legislativo 9 aprile 2008, n. 81.

### Art. 367. - Efficienza degli usi finali dell'energia e servizi energetici

1. Ai sensi dell'articolo 1, comma 2, lettera c), del decreto legislativo 30 maggio 2008, n. 115, il decreto legislativo n. 115 del 2008 si applica alle Forze armate limitatamente al titolo II, capo IV del citato decreto legislativo e solamente nella misura in cui l'applicazione del citato decreto non e' in contrasto con la natura e l'obiettivo primario delle attivita' delle Forze armate e a eccezione dei materiali utilizzati esclusivamente a fini militari.

### Art. 368. - Accesso all'informazione ambientale e difesa nazionale

1. Ai sensi dell'articolo 5 del decreto legislativo 19 agosto 2005, n. 195, l'accesso all'informazione ambientale e' negato quando la divulgazione dell'informazione reca pregiudizio alla difesa nazionale. 2.((Ai sensi degli articoli 29-ter, comma 2, e 29-quater, comma 14, del decreto legislativo 3 aprile 2006, n. 152)), la domanda di autorizzazione integrata ambientale deve contenere l'indicazione delle informazioni che ad avviso del gestore non devono essere diffuse per ragioni di difesa nazionale, tenendo conto delle indicazioni di cui all'articolo 39 della legge 3 agosto 2007, n. 124. In tale caso il richiedente fornisce all'autorita' competente anche una versione della domanda priva delle informazioni riservate, ai fini dell'accessibilita' al pubblico. L'autorita' competente puo' sottrarre all'accesso le informazioni, in particolare quelle relative agli impianti militari di produzione di esplosivi di cui al punto 4.6 dell'((allegato VIII alla Parte II al decreto legislativo n. 152 del 2006)), se cio' si rende necessario per l'esigenza di salvaguardare, ai sensi dell'articolo 24 della legge 7 agosto 1990, n. 241, e relative norme di attuazione, la sicurezza pubblica o la difesa nazionale.

### Art. 369. - Danno ambientale

1. Ai sensi dell'articolo 303, comma 1, lettere a) ed e), del decreto legislativo 3 aprile 2006, n. 152, la parte sesta del citato decreto:

- a) non riguarda il danno ambientale o la minaccia imminente di tale danno cagionati da atti di conflitto armato, atti di ostilita', guerra civile, insurrezione;
- b) non si applica alle attivita' svolte in condizioni di necessita' e aventi come scopo esclusivo la difesa nazionale o la sicurezza internazionale.

## TITOLO VIII REQUISIZIONI IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE CAPO I DISCIPLINA GENERALE DELLE REQUISIZIONI IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

### SEZIONE I - AMBITO DI APPLICAZIONE TEMPORALE E BENI REQUISIBILI

#### Art. 370. - Ambito di applicazione

1. Le disposizioni del presente capo si applicano:

- a) quando e' ordinata l'applicazione, in tutto o in parte, della legge di guerra, se il provvedimento, che ordina detta applicazione, non dispone diversamente;
- b) in caso di mobilitazione generale o parziale, se il provvedimento, che ordina la mobilitazione, non dispone diversamente;
- c) in caso di grave crisi internazionale, se non diversamente disposto nel provvedimento che la dichiara.

2. Alle requisizioni di aeromobili si applicano le disposizioni dettate dal presente capo per la requisizione dei beni mobili.

3. Le disposizioni del presente capo non si applicano alle requisizioni:

- a) dei quadrupedi, dei veicoli e dei natanti per le Forze armate dello Stato, cui si applica il capo II del presente titolo;
- b) delle navi mercantili e dei galleggianti, cui si applica il capo III del presente titolo;
- c) delle merci che si trovano nel territorio dello Stato in attesa del giudizio del Tribunale delle prede, o comunque in conseguenza di misure dipendenti dal diritto di preda o di controllo, cui si applica la legge di guerra. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 01/06/2010, n. 126 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 371. - Categorie generali dei beni requisibili

1. Sono requisibili:

- a) le cose immobili e mobili, comprese le aziende;
- b) le invenzioni;
- c) i servizi individuali e collettivi.

2. Sotto la denominazione di beni, si intendono compresi le cose, le invenzioni, e i servizi indicati nel comma 1.

#### Art. 372. - Beni non requisibili per cause soggettive

1. Non sono requisibili:

- a) i beni appartenenti o in uso alla Presidenza della Repubblica;
- b) i beni in uso di rappresentanze diplomatiche o consolari di Stati esteri o dei capi e del personale di esse, sempre che si tratti di persone che non esercitano il commercio;
- c) i beni in uso di rappresentanze diplomatiche di Governi esteri presso la Santa Sede o dei capi e del personale di esse, sempre che si tratti di persone che non esercitano il commercio;
- d) i beni in uso di Istituti internazionali o di loro delegati e funzionari, ai quali siano estese le immunita' diplomatiche;
- e) le cose appartenenti a stranieri escluse da requisizione in virtu' di accordi internazionali;
- f) gli immobili indicati negli articoli 13, 14, commi 1 e 2, e 15, del Trattato dell'11 febbraio 1929 fra l'Italia e la Santa Sede , nonche' i mobili che vi si trovano.

2. Gli immobili indicati nell'art. 14, comma 3, del Trattato di cui al comma 1, lettera f), o quelli adibiti a sede degli istituti pontifici menzionati nell'articolo 16, comma 1, dello stesso Trattato non possono essere requisiti se non previo accordo con la Santa Sede.

3. Sono esenti dalla requisizione di servizi:

- a) i dignitari della Chiesa e le persone indicate nell'articolo 10, commi 1 e 2, del Trattato di cui al comma 1, lettera f);
- b) gli agenti diplomatici di Stati esteri presso il Governo italiano e gli inviati di Governi esteri presso la Santa Sede;
- c) i delegati e funzionari di Istituti internazionali, di cui alla lettera d) del comma 1;
- d) i consoli di Stati esteri e gli stranieri per i quali tale esenzione e' stabilita da accordi internazionali.

4. Con decreto del Ministro degli affari esteri, di concerto con i Ministri interessati, possono essere esclusi da requisizione anche altri beni, per ragioni di opportunita' nei rapporti internazionali.

#### Art. 373. - Beni non requisibili per cause oggettive

1. Non sono requisibili:

- a) gli edifici aperti al culto, nonche' le cose consacrate al culto e comunque destinate all'esercizio di esso;
- b) gli edifici direttamente destinati a un fine di pubblica assistenza o beneficenza;
- c) i locali dove sono custodite casse pubbliche;
- d) i locali occupati da comunita' religiose;
- e) i locali occupati da collegi femminili.

2. Tuttavia, in caso di urgente necessita', le autorita', che hanno il potere di ordinare requisizioni, possono assoggettare le cose suindicate a requisizione, previi accordi con l'Ordinario diocesano, per quanto concerne i beni indicati nel comma 1, lettera a), e, in ogni altro caso, con il prefetto.

3. Gli edifici di istituti scolastici o educativi appartenenti allo Stato o ad altri enti pubblici, possono essere, previi accordi con le autorita' scolastiche, requisiti soltanto per essere destinati a uso di caserme, di alloggi militari o di ospedali di riserva, se non e' possibile trovare altri edifici adatti a tale scopo; esclusi, in ogni caso, i locali destinati a musei, gabinetti scientifici e biblioteche.

4. I beni in uso delle amministrazioni dello Stato, delle regioni, delle province e dei comuni, o direttamente destinati all'esercizio di servizi pubblici, anche se concessi a privati, nonche' gli attrezzi, i materiali, le scorte e le riserve direttamente destinati ai servizi stessi o alla esecuzione di opere pubbliche, possono essere requisiti soltanto con l'assenso dell'amministrazione interessata.

#### Art. 374. - Beni culturali e archivi

1. I beni culturali di cui al decreto legislativo 22 gennaio 2004, n. 42, appartenenti a enti pubblici, non possono essere requisiti se non in caso di assoluta necessita', previo assenso del Ministro per i beni e le attivita' culturali, il quale puo' subordinare l'assenso a determinate condizioni per l'uso della cosa.

2. Il comma 1 si applica relativamente ai beni culturali appartenenti a privati, che hanno formato oggetto di notifica della dichiarazione di interesse culturale ai sensi del decreto legislativo 22 gennaio 2004, n. 42, nonche' relativamente alle raccolte scientifiche, e, in genere, culturali, appartenenti a privati, che siano soggette a pubblico uso o godimento.

3. Non possono essere requisiti, finche' dura tale loro destinazione, gli immobili, che sono sede di raccolte culturali, che appartengono a enti pubblici, ovvero a privati, se e' intervenuta la notifica di cui al comma 2 o che sono soggette a pubblico uso o godimento, ovvero di raccolte di interesse scientifico, o, in genere culturali, appartenenti a privati, che sono soggette a pubblico uso o godimento.

4. Le disposizioni del comma 3 si applicano anche agli immobili che siano sede di archivi appartenenti allo Stato, ad altri enti pubblici, alle istituzioni pubbliche di assistenza e beneficenza, agli istituti di credito, di diritto pubblico e alle associazioni sindacali e degli archivi privati, che hanno formato oggetto di notifica della dichiarazione di interesse culturale ai sensi del decreto legislativo 22 gennaio 2004, n. 42.

#### Art. 375. - Beni paesaggistici

1. I beni paesaggistici di cui all'articolo 136, del decreto legislativo 22 gennaio 2004, n. 42, per i quali e' intervenuta la dichiarazione di notevole interesse pubblico, non possono essere requisiti se non in caso di assoluta necessita', previo assenso del Ministro per i beni e le attivita' culturali, il quale puo' subordinare l'assenso a determinate condizioni per l'uso della cosa.

2. In caso di requisizione di beni di cui all'articolo 136 del decreto legislativo 22 gennaio 2004, n. 42, per i quali non e' intervenuta la dichiarazione di notevole interesse pubblico, il Ministro per i beni e le attivita' culturali puo' prescrivere le opportune cautele per l'uso della cosa requisita.

#### Art. 376. - Persone esenti dalla requisizione di servizi

1. Sono esenti dalla requisizione di servizi:

- a) i minori di eta';
- b) le persone, se uomini che hanno compiuto settanta anni, se donne che hanno compiuto sessanta anni;
- c) coloro che sono riconosciuti inabili a prestare il servizio richiesto;
- d) ogni altra persona che e' esentata per particolari disposizioni di legge.

#### Art. 377. - Dispensa dalla requisizione

1. Con decreto del Presidente del Consiglio dei Ministri, possono essere stabilite dispense da requisizione, relativamente a determinati beni o categorie di beni, per imprescindibili bisogni dell'industria, dell'agricoltura, del commercio o per altre necessita'.

### SEZIONE II - REQUISIZIONE DI IMMOBILI E DI AZIENDE

#### Art. 378. - Cose immobili

1. Gli immobili possono essere requisiti solo in uso.

2. La requisizione si estende, salva esclusione espressa nell'ordine di requisizione:

- a) alle cose che costituiscono pertinenza dell'immobile requisito ai sensi dell'articolo 817 del codice civile;
- b) alle cose di cui all'articolo 812, comma 2 del codice civile.

3. I mobili che si trovano nell'immobile requisito sono compresi nella requisizione, solo se ne e' stata fatta espressa menzione nell'ordine predetto.

#### Art. 379. - Poteri dell'autorita' che usa l'immobile

1. L'autorita' che usa l'immobile puo' dare a esso la destinazione che reputa piu' opportuna, e puo' anche eseguirvi nuove opere.

#### Art. 380. - Aziende e stabilimenti

1. La requisizione delle aziende o degli stabilimenti si estende, se l'ordine di requisizione non stabilisce diversamente, a tutto quanto e' destinato all'esercizio di essi.

#### Art. 381. - Miniere e cave

1. La requisizione delle miniere e delle cave si estende, salva espressa indicazione diversa, a quanto e' destinato all'esercizio di esse, all'arricchimento e all'elaborazione delle sostanze minerali, come impianti fissi interni ed esterni, edifici, strade, teleferiche, ferrovie e filovie, mezzi di trasporto, macchinari.

#### Art. 382. - Impianti elettrici

1. La requisizione degli impianti per produzione, trasporto e distribuzione di energia elettrica si estende, salva espressa indicazione diversa, alle opere, edifici, impianti, macchinari, linee e, in genere, a ogni materiale destinato all'esercizio dell'impianto requisito.

#### Art. 383. - Linee di comunicazione

1. La requisizione delle reti ferroviarie, tramviarie e simili, e delle linee di navigazione interna e di navigazione aerea si estende, salva espressa indicazione diversa, agli edifici, agli impianti e al materiale che siano destinati all'esercizio delle reti o delle linee requisite.

#### Art. 384. - Legnami

1. Le requisizioni per l'approvvigionamento dei legnami possono avere per oggetto il soprasuolo dei boschi, i tagli boschivi in corso di esecuzione, gruppi di piante, di alberature, piante sparse per la produzione di legname da ardere o da lavoro, legname da opera e da ardere e carbone vegetale, in qualsiasi fase di allestimento, nonche' qualunque altro bene destinato alla produzione, alla lavorazione, al deposito e al trasporto dei legnami.

#### Art. 385. - Poteri dell'autorita' nella requisizione di aziende

1. Nei casi di requisizione di aziende e stabilimenti, miniere e cave, impianti elettrici, linee di comunicazione, legnami, l'autorita', che ha emanato l'ordine di requisizione puo' assumere direttamente la gestione dell'azienda o dello stabilimento, ovvero provvedervi per mezzo della persona che ne aveva l'esercizio al momento della requisizione, o di altra persona, ente o ufficio.

2. Puo' anche eseguire opere occorrenti a mantenere e, se necessario, ad aumentare l'efficienza dell'azienda o dello stabilimento o dare all'azienda o allo stabilimento una destinazione diversa da quella che aveva al momento della requisizione.

3. La requisizione puo' essere estesa anche alle prestazioni di tutto o di parte del personale addetto all'azienda o allo stabilimento.

4. Fuori del caso previsto dal comma 3, tutti coloro che in qualita' di dirigenti, impiegati o lavoratori manuali, sono destinati dalle aziende o dagli stabilimenti al servizio requisito, hanno l'obbligo di prestare la loro opera.

#### Art. 386. - Requisizione dei prodotti

1. La requisizione puo' avere per oggetto, anziche' l'azienda o lo stabilimento o la cava o la miniera o l'azienda forestale, i prodotti esistenti o futuri, comprendendosi fra essi anche l'energia elettrica producibile. In tal caso, l'ordine di requisizione indica la quantita', il luogo, il modo e il tempo della consegna dei prodotti.

2. L'autorita' che procede alla requisizione puo' controllare l'esercizio dell'azienda o dello stabilimento al fine di garantire l'esecuzione dell'ordine di requisizione.

### SEZIONE III - REQUISIZIONE DI BENI MOBILI

#### Art. 387. - Cose mobili requisibili

1. Sono requisibili:

- a) le materie prime;
- b) i materiali di qualsiasi natura;
- c) le merci, derrate, generi alimentari di qualsiasi natura, bestiame e foraggi;
- d) le macchine, strumenti e utensili di qualsiasi genere;
- e) l'energia elettrica, idraulica, a vapore o comunque prodotta.

#### Art. 388. - Cose consumabili

1. Le cose mobili, che con l'uso sono consumate o alterate nella sostanza, sono requisibili solo in proprieta'.

#### Art. 389. - Cose non consumabili

1. Le cose mobili, che con l'uso non sono distrutte ne' alterate nella sostanza, sono requisibili in uso o in proprieta'. Sono requisibili in uso, quando esse possono essere rilasciate nel termine massimo di sei mesi e nella stessa localita' in cui furono requisite, o in altra localita' quando l'interessato vi consenta.

2. Alla scadenza del termine la requisizione in uso si trasforma in requisizione in proprieta':

- a) se l'amministrazione ritiene di trattenere definitivamente la cosa;
- b) se l'amministrazione reputa di non poter ancora effettuare la restituzione e l'interessato non consente alla proroga del termine;
- c) se l'interessato non consente di ricevere la cosa in localita' diversa da quella in cui fu requisita.

### SEZIONE IV - REQUISIZIONE DI INVENZIONI

#### Art. 390. - Oggetto della requisizione delle invenzioni e procedimento

1. Salve le disposizioni concernenti l'espropriazione o l'uso dei diritti di brevetto per invenzioni nell'interesse della difesa militare del Paese o per altre ragioni di pubblica utilita', le invenzioni possono essere requisite in proprieta', a tempo determinato o indeterminato, oppure in uso esclusivo o non esclusivo.

2. Il provvedimento di requisizione e' emanato dal Ministro interessato.

3. Quando e' presentata istanza di autorizzazione ai sensi dell'articolo 198 del decreto legislativo 10 febbraio 2005, n. 30, il Ministero interessato, se ritiene che l'invenzione e' utile alla difesa militare o comunque allo Stato, emana il provvedimento di requisizione, e ne trasmette copia al Ministero dello sviluppo economico, il quale provvede alla notificazione.

4. Nel caso di requisizione in uso non esclusivo, il divieto di alienare, applicare, divulgare ovunque e quello di depositare presso Stati esteri invenzioni, o comunque di rivelare notizie relative alle medesime, puo' essere imposto con provvedimento del Ministero interessato, per la durata da questo stabilita.

5. Il Ministero interessato, anche se non ritiene di emanare l'ordine di requisizione, puo' vietare l'alienazione, l'applicazione, la divulgazione ovunque, come pure il deposito presso Stati esteri dell'invenzione per un periodo di cinque mesi dalla data della notificazione del divieto.

#### Art. 391. - Invenzione depositata in Italia

1. Se l'invenzione e' stata depositata in Italia agli effetti del rilascio del brevetto, il richiedente non puo' alienarla, applicarla, divulgarla ne' depositarla presso Stati esteri, se non sono trascorsi almeno sessanta giorni dalla data del deposito; fermi i poteri attribuiti dalle disposizioni vigenti al Ministero della difesa per il vincolo del segreto dei brevetti interessanti la difesa nazionale.

### SEZIONE V - REQUISIZIONE DI SERVIZI

#### Art. 392. - Servizi requisibili

1. E' requisibile qualsiasi servizio intellettuale o manuale.

2. L'ordine di requisizione puo' riguardare:

- a) l'opera di persone determinate;
- b) l'opera di tutti coloro che appartengono alle categorie indicate nell'ordine di requisizione.

#### Art. 393. - Servizi di enti, societa' o associazioni

1. Quando la requisizione ha per oggetto servizi di enti, societa' o associazioni, il provvedimento relativo importa, per tutti coloro che, in qualita' di dirigenti, impiegati o lavoratori manuali, sono destinati dall'ente, societa' o associazione al servizio requisito, l'obbligo di prestare la loro opera.

#### Art. 394. - Obbligo di dare indicazioni

1. Chiunque, per ragioni d'ufficio o di professione, d'industria o di commercio, e' in grado di indicare le persone idonee a compiere determinati servizi, da' le indicazioni richiestegli dall'autorita', secondo le modalita' e nel termine da essa stabiliti.

### SEZIONE VI - DISPOSIZIONI COMUNI

#### Art. 395. - Precettazione

1. L'autorita' competente puo' far precedere l'ordine di requisizione dalla precettazione. Questa importa l'obbligo di tenere il bene precettato a disposizione dell'amministrazione.

2. Se, nel termine di quindici giorni dalla notificazione della precettazione non si procede alla requisizione, la persona cui e' stata intimata la precettazione riacquista la disponibilita' del bene precettato.

3. La precettazione non attribuisce al precettato alcun diritto a indennizzo.

#### Art. 396. - Cose deteriorabili

1. Se vi e' pericolo che le cose precettate si deteriorano, il detentore ne da' avviso, anche telegrafico, all'autorita' precettante; se entro tre giorni dall'avviso non e' ordinata la requisizione, il detentore riacquista la disponibilita' delle cose precettate.

#### Art. 397. - Effetti dell'ordine di requisizione

1. L'amministrazione acquista la proprieta' della cosa requisita o il diritto a farne uso dal momento della notificazione dell'ordine di requisizione.

2. Qualsiasi contestazione, anche in sede giurisdizionale, non sospende l'esecutorieta' dell'ordine di requisizione.

3. Il detentore, sotto la sua personale responsabilita', custodisce le cose requisite sino alla consegna.

4. La requisizione e' effettuata nei confronti del detentore del bene, senza alcuna responsabilita' dell'amministrazione verso gli aventi diritto sul bene requisito. Tuttavia il detentore, sotto la sua responsabilita', e' tenuto a dare a essi immediata comunicazione dell'ordine di requisizione ricevuto.

#### Art. 398. - Risoluzione dei contratti stipulati anteriormente alla requisizione

1. L'ordine di requisizione risolve di diritto qualsiasi contratto che ha per oggetto il bene requisito, se l'esecuzione del contratto non e' compatibile con l'esecuzione dell'ordine di requisizione. L'ordine di requisizione libera di diritto il proprietario da qualsiasi obbligazione nei confronti di terzi. La risoluzione dei contratti non da' luogo a rimborso di spese ne' a risarcimento di danni a favore di chiunque.

2. Se la requisizione cessa prima della scadenza convenuta o prorogata del contratto, il contraente che aveva l'uso o il godimento del bene requisito ha diritto a riavere tale uso o godimento, fino al termine convenuto o prorogato del contratto, alle stesse condizioni precedenti, salve le modificazioni legali eventualmente intervenute.

#### Art. 399. - Denuncia obbligatoria

1. Le autorita' competenti a ordinare la requisizione possono imporre a coloro, che detengono a qualunque titolo cose requisibili, l'obbligo di denunciarne la quantita', con le modalita' e nei termini che saranno di volta in volta stabiliti.

#### Art. 400. - Obblighi del sindaco

1. I Sindaci hanno l'obbligo di collaborare per tutto quanto riguarda le requisizioni, in particolare mettendo a disposizione il personale dipendente per le necessarie ricerche, e fornendo notizie e informazioni anche ai fini di un'equa ripartizione, fra gli abitanti, delle prestazioni richieste.

### SEZIONE VII - AUTORITA' COMPETENTI

#### Art. 401. - Autorita' militari

1. I generali di corpo d'armata, di divisione e di brigata dell'Esercito italiano, e dei corrispondenti gradi della Marina militare, dell'Aeronautica militare e dell'Arma dei carabinieri, nei limiti della propria circoscrizione territoriale, hanno il potere di ordinare requisizioni nell'interesse delle Forze armate dello Stato.

2. I comandanti indicati nel comma 1 provvedono d'intesa coi prefetti.

3. Alle requisizioni suindicate provvedono le commissioni previste dall'articolo 403 o, quando non siano costituite, i comandi dipendenti dai comandanti menzionati nel comma 1.

4. In caso di urgente necessita' qualsiasi comandante di corpo o di reparto di truppa o qualsiasi altro capo servizio puo', sotto la sua personale responsabilita', ordinare requisizioni di beni occorrenti ai bisogni giornalieri del corpo, reparto o servizio che da lui dipende. In tal caso una copia dell'ordine di requisizione e' immediatamente trasmessa, per via gerarchica, ai comandi competenti ai sensi del comma 1.

#### Art. 402. - Autorita' civili

1. Hanno il potere di ordinare requisizioni le amministrazioni centrali dello Stato, previe intese fra di loro, provvedendovi a mezzo dei prefetti e degli organi da essi dipendenti, i quali in tal caso prenderanno accordi con i prefetti.

2. In caso di urgente necessita' i prefetti possono ordinare, di propria iniziativa, requisizioni.

#### Art. 403. - Commissioni di requisizione

1. Il Ministro della difesa, previa intesa con gli altri Ministri interessati, puo' istituire commissioni di requisizione, determinandone la sede, il numero dei componenti e la rispettiva competenza per materia e per territorio. Possono essere nominate commissioni miste in caso di requisizioni che interessano piu' Forze armate.

2. I membri delle commissioni sono nominati dalle autorita' militari che hanno il potere di ordinare requisizioni.

3. Le commissioni sono presiedute da ufficiali, possibilmente superiori, e sono composte con ufficiali, nonche' rappresentanti delle categorie professionali designati fra persone esperte dalle Camere di commercio, industria, artigianato e agricoltura. Nel caso di requisizione di legnami, fa parte della commissione un funzionario del Corpo forestale dello Stato; nel caso di requisizione di beni indicati negli articoli 380, 381, 382, 383 fa parte un ingegnere dell'Agenzia del territorio.

4. I membri delle commissioni miste sono nominati di concerto fra i Comandi competenti alle requisizioni.

#### Art. 404. - Collaborazione con altri organi

1. Ogni autorita' competente a emanare ordini di requisizione si avvale, salvi i casi di urgente necessita', della collaborazione degli organi tecnici ed economici che sono all'uopo indicati dal Ministero dello sviluppo economico e dal Ministero dell'economia e delle finanze.

#### Art. 405. - Comunicazioni all'autorita' civile e accordi per l'esecuzione

1. Gli incaricati dell'esecuzione delle requisizioni, in ogni caso, danno avviso al sindaco del comune in cui si trovano gli immobili, le aziende e gli stabilimenti da requisire, o, quando trattasi dei beni indicati negli articoli 373, 374, 375, agli uffici pubblici interessati. Se non ostano ragioni di urgenza, prendono, ai fini dell'esecuzione, preventivi accordi con il sindaco e con gli uffici predetti.

### SEZIONE VIII - PROCEDIMENTO

#### Art. 406. - Destinatari dell'ordine di requisizione

1. L'ordine di requisizione puo' essere diretto a singole persone o a determinate categorie di persone: in questo secondo caso puo' essere reso noto con pubblico manifesto.

#### Art. 407. - Contenuto dell'ordine di requisizione

1. L'ordine di requisizione contiene, di regola, le seguenti indicazioni:

- a) autorita' per conto della quale la requisizione e' effettuata;
- b) organo che procede alla requisizione;
- c) beni che formano oggetto della requisizione;
- d) persone alle quali l'ordine e' diretto;
- e) termine entro il quale la persona intimata deve adempiere l'ordine di requisizione, e modalita' relative;
- f) se la requisizione e' in proprieta' o in uso;
- g) data dell'ordine di requisizione; firma dell'autorita' che lo emana.

2. Per le requisizioni in uso, l'ordine ne indica, possibilmente, anche la prevedibile durata.

#### Art. 408. - Forma e notificazione dell'ordine di requisizione

1. L'ordine di requisizione e' staccato da apposito registro, diviso in tre parti. La prima e' conservata dall'autorita' che esegue la requisizione; la seconda e' consegnata, per notificazione, alla persona cui l'ordine e' diretto o, in sua assenza, ai suoi familiari o alle persone addette al suo servizio. In caso di mancanza o di assenza di questi, la notificazione si considera eseguita con la consegna della seconda parte suindicata all'ufficio di segreteria del comune. La terza parte, sottoscritta dalla persona che riceve l'ordine e' anch'essa conservata dall'autorita' che esegue requisizione.

#### Art. 409. - Rilascio della ricevuta

1. L'autorita' che esegue le requisizioni rilascia senza indugio agli interessati ricevuta scritta del bene requisito.

2. La ricevuta, distaccata da apposito registro, contiene le seguenti indicazioni:

- a) autorita' che ha ordinato la requisizione;
- b) descrizione sommaria del bene requisito;
- c) data e firma.

3. La ricevuta indica l'importo dell'indennita' dovuta per il bene requisito. Se cio' non e' possibile, e' emanato successivamente l'ordine di pagamento con l'indicazione dell'importo anzidetto.

#### Art. 410. - Trasporto delle cose requisite

1. Il trasporto delle cose requisite dal luogo dove si trovano al momento della requisizione e' fatto a cura e spese dell'autorita' procedente, la quale puo' anche requisire i mezzi a cio' necessari.

#### Art. 411. - Processo verbale

1. In caso di requisizione in uso, si provvede, a cura dell'autorita' procedente, alla redazione di un processo verbale, in duplice originale, in cui si fa la descrizione sommaria detta cosa requisita.

2. Il processo verbale e' redatto in presenza del detentore o, in sua assenza, in presenza del sindaco o di un suo delegato.

3. Uno degli originali del processo verbale e' consegnato all'interessato e, se questi rifiuta di riceverlo o e' assente, al sindaco o a chi ne fa le veci.

4. Quando trattasi di immobili, aziende o stabilimenti, al processo verbale sono uniti, se possibile, gli atti estimativi, i disegni, le fotografie e gli altri documenti illustrativi che si ritengono necessari per comprovare la consistenza dei beni requisiti.

5. La compilazione del processo verbale puo' omettersi, quando trattasi di requisizione di immobili per la durata non superiore a trenta giorni purche' il locale non debba essere sgombrato e il detentore non debba allontanarsene; ovvero quando trattasi di requisizione di cose mobili di valore non eccedente il valore di euro 1.000,00.

#### Art. 412. - Esecuzione d'ufficio

1. In caso di inosservanza degli ordini di requisizione, l'autorita' puo' provvedere d'ufficio all'esecuzione degli ordini medesimi, salva l'applicazione delle sanzioni penali.

2. Ai fini di tale esecuzione, l'autorita' puo' accedere, sia di giorno sia di notte, anche in luoghi chiusi, facendo, all'occorrenza, forzare le porte esterne e interne.

3. Negli atti di esecuzione d'ufficio e' necessario l'intervento del sindaco, o di un suo delegato, e la presenza di due testimoni da esso designati.

4. Dell'esecuzione d'ufficio e' redatto processo verbale, in duplice originale, di cui uno e' rimesso al sindaco.

### SEZIONE IX - REQUISIZIONI ((...))

#### Art. 413. - Disposizioni generali

1. Nella zona delle operazioni, i competenti comandi di grandi unita' possono, in qualunque momento, ordinare requisizioni, per provvedere ai bisogni delle Forze armate.

2. Per tali requisizioni si applicano le disposizioni della presente sezione, se e' altrimenti disposto con bandi militari e, in quanto non provvedono le disposizioni della presente sezione o dei bandi, si osservano quelle delle altre sezioni del presente capo.

#### Art. 414. - Commissioni di requisizione

1. Le requisizioni sono ordinate dagli organi direttivi dei servizi d'armata ed eseguite per mezzo di commissioni da essi costituite.

2. Dette commissioni, per la redazione dei verbali di consegna e riconsegna d'immobili, aziende o stabilimenti, nonche' per la determinazione delle relative indennita' conseguenti alle effettuate requisizioni, sono coadiuvate da personale tecnico dell'Agenzia del territorio e del Genio militare.

#### Art. 415. - Requisizioni per la Marina militare e per l'Aeronautica militare

1. Alle requisizioni interessanti unita' e servizi della Marina militare e dell'Aeronautica militare, dislocati nella zona delle operazioni, possono provvedere, rispettivamente, i competenti Comandi mobilitati della Marina militare e dell'Aeronautica militare retti da ammiragli o da generali, previi accordi con i comandi di grandi unita' dell'Esercito italiano competenti sul territorio ove le requisizioni si effettuano, e sotto il controllo dell'alto comando dell'Esercito italiano.

#### Art. 416. - Requisizione da parte dei comandanti di reparto

1. Nei casi di urgenza, i comandanti di grandi unita' possono, con disposizione speciale e temporanea, autorizzare i comandanti di truppa a procedere direttamente a requisizione di risorse locali.

#### Art. 417. - Casi di eccezionale urgenza

1. Nei casi di eccezionale urgenza e limitatamente al bisogno, la requisizione di risorse locali puo' essere ordinata anche dall'ufficiale di grado piu' elevato, che ha il comando di un reparto o di un servizio sul posto.

#### Art. 418. - Modalita' per l'esecuzione delle requisizioni

1. Se non e' possibile avvalersi degli organi indicati nell'articolo 404, le autorita' che procedono alla requisizione possono richiedere l'intervento diretto del sindaco, per ripartire le prestazioni richieste tra gli abitanti e per consegnare all'autorita' militare le cose requisite.

#### Art. 419. - Commissioni di controllo

1. Presso i Comandi di grande unita' e' costituita una commissione di controllo per le requisizioni.

2. Essa provvede:

- a) a confermare o a rivedere le indennita' stabilite provvisoriamente dagli organi che hanno proceduto alla requisizione;
- b) a regolarizzare, su domanda dell'interessato, la requisizione eseguita senza l'osservanza delle forme prescritte;
- c) ad accertare le eventuali responsabilita' di agenti dell'amministrazione militare, per irregolarita' da essi eventualmente commesse e per i danni relativi, e a procedere ai conseguenti addebiti, salva la competenza della Corte dei conti.

### SEZIONE X - LIQUIDAZIONE E PAGAMENTO DELLE INDENNITA'

#### Art. 420. - Indennita'

1. Per ogni requisizione e' corrisposta una giusta indennita' che e' liquidata dall'autorita' procedente, secondo i criteri stabiliti dagli articoli della presente sezione.

2. Il pagamento dell'indennita' e' effettuato senza indugio; quando non si possa determinare l'indennita' al momento della requisizione, l'autorita' procedente puo' disporre il pagamento di una somma a titolo di acconto.

#### Art. 421. - Indennita' per aziende e stabilimenti

1. L'indennita' per la requisizione delle aziende o stabilimenti e' liquidata dalle commissioni di requisizione. Se alla requisizione ha proceduto un'autorita' civile, l'indennita' e' liquidata dall'amministrazione centrale nell'interesse della quale la requisizione e' stata effettuata ed e' stabilita in base a perizia di una commissione di cinque membri nominata dall'amministrazione interessata. Di tale commissione fa parte un tecnico dell'Agenzia del territorio e un rappresentante dell'associazione di categoria di cui l'azienda e lo stabilimento fa parte.

#### Art. 422. - Indennita' per immobili

1. L'indennita' per la requisizione degli immobili e' ragguagliata al reddito normale che l'immobile e' atto a produrre, tenuto anche conto delle cose indicate nel comma 3 dell'articolo 378.

2. Inoltre, per l'asportazione dall'immobile delle cose non comprese nell'ordine di requisizione, e' accordata al detentore dell'immobile medesimo un'indennita' commisurata alle normali spese di trasporto nell'ambito dello stesso comune.

#### Art. 423. - Indennita' per beni mobili requisiti in proprieta'

1. L'indennita' per la requisizione di mobili in proprieta', se non si tratta di cose per le quali l'amministrazione competente ha stabilito i prezzi a norma delle disposizioni vigenti, e' determinata in base ai prezzi di mercato desunti dai listini esistenti presso le Camere di commercio, o, in mancanza, in base alla media dei prezzi correnti sul luogo negli ultimi trenta giorni. Quando si tratta di cose che non hanno un prezzo corrente, si tiene conto dei prezzi fatti nelle ultime contrattazioni.

2. In ogni caso, l'indennita' e' adeguata allo stato d'uso e alla qualita' dei beni.

#### Art. 424. - Indennita' per i mobili requisiti in uso

1. L'indennita' per la requisizione in uso di mobili e' ragguagliata all'interesse legale sul valore venale dell'oggetto.

#### Art. 425. - Indennita' per cose indispensabili per l'esercizio di industrie, commercio, professioni

1. Se la cosa requisita in uso e' mezzo indispensabile per l'esercizio di un'industria, di un commercio o di una professione e non puo' essere prontamente e facilmente sostituita, ovvero e' troppo onerosa la sostituzione, e' corrisposta, per una volta sola, oltre l'indennita' per l'uso della cosa, un'indennita' supplementare proporzionata alla presumibile durata della requisizione e, in nessun caso, eccedente l'importo di un'annualita' dell'interesse legale sul valore venale della cosa.

#### Art. 426. - Indennita' per requisizione di invenzioni

1. L'indennita' per la requisizione di invenzioni, ancorche' non brevettate, e' liquidata dal Ministero della difesa che dispone la requisizione, d'intesa con il Ministero dello sviluppo economico.

2. Per i divieti di alienazione, applicazione, divulgazione e deposito presso Stati esteri non e' dovuta alcuna indennita', salvo che i divieti hanno per oggetto invenzioni requisite in uso non esclusivo. In tal caso l'indennita' e' liquidata ai sensi del comma 1.

#### Art. 427. - Indennita' per requisizione di servizi

1. L'indennita' per la requisizione di servizi e' stabilita tenendo presenti le tariffe stabilite a norma delle leggi vigenti.

#### Art. 428. - Fondi per il pagamento delle indennita'

1. Le commissioni procedono al pagamento delle indennita' di requisizione:

- a) in zona territoriale mediante ordinativi su aperture di credito disposte a favore dei presidenti delle commissioni stesse presso le competenti direzioni territoriali del Ministero dell'economia e delle finanze;
- b) nella zona delle operazioni, mediante ordinativi tratti sulle casse militari.

2. Per somme di piccola entita', il pagamento puo' essere direttamente effettuato dalle commissioni stesse sui fondi prelevabili in contanti. Il limite delle somme che possono essere pagate direttamente e di quelle da prelevarsi a tale scopo e' stabilito dall'autorita' da cui la commissione dipende.

3. I presidenti delle commissioni di requisizione, nella gestione dei fondi loro assegnati, assumono la qualifica, le attribuzioni e le responsabilita' dei funzionari delegati ai sensi del decreto del Presidente della Repubblica 20 aprile 1994, n. 367.

#### Art. 429. - Modalita' di pagamento

1. L'indennita' di requisizione e' pagata alla persona nei cui confronti la requisizione e' stata effettuata, restando l'amministrazione esonerata da qualsiasi responsabilita' verso gli aventi diritto sul bene requisito. Tuttavia colui che riceve il pagamento ne versa immediatamente l'importo all'avente diritto.

2. Nel caso di requisizione in uso eccedenti la durata di un mese, l'indennita' puo' essere corrisposta a rate mensili posticipate.

3. Le prestazioni personali che durano piu' di sette giorni sono pagate alla fine di ciascuna settimana.

#### Art. 430. - Quietanza del pagamento

1. La ricevuta rilasciata a norma dell'articolo 409 e' consegnata, all'atto del pagamento, all'agente pagatore, il quale la trattiene dopo averla fatta firmare per quietanza. La stessa disposizione si applica nel caso in cui e' emanato separato ordine di pagamento a norma del comma 3 dello stesso articolo 409.

2. Nel caso di pagamento eseguito direttamente dalla commissione, la seconda parte del foglio di ricevuta non e' consegnata al creditore, ma e' allegata al rendiconto, munita della quietanza.

#### Art. 431. - Effetti della riscossione dell'indennita'

1. La riscossione dell'indennita' di requisizione costituisce acquiescenza e comporta rinuncia a qualunque impugnazione, amministrativa o giurisdizionale, sia avverso l'ordine di requisizione sia avverso la determinazione della indennita'.

### SEZIONE XI - RESTITUZIONE DELLE COSE REQUISITE IN USO

#### Art. 432. - Restituzione degli immobili, delle aziende e dei stabilimenti

1. Appena cessata la necessita' che aveva determinata la requisizione, gli immobili, le aziende o stabilimenti sono senza indugio restituiti.

#### Art. 433. - Preavviso di restituzione dell'immobile, azienda o stabilimento

1. Se non e' stata indicata la durata dell'uso, la restituzione dell'immobile, azienda o stabilimento e' preceduta da un preavviso notificato all'interessato entro un congruo termine che, quando si tratta di azienda o stabilimento in esercizio, non puo' essere minore di otto giorni.

#### Art. 434. - Processo verbale di restituzione

1. Al momento della restituzione e' compilato, a cura degli organi tecnici competenti, un nuovo processo verbale, sulla scorta di quello redatto all'atto dell'occupazione, facendo menzione delle variazioni avvenute, per effetto di deterioramenti, spostamenti o per qualsiasi altra modificazione dipendente dall'occupazione.

2. Dal processo verbale risultano tutti gli elementi atti a dirimere le questioni gia' sorte o che potessero sorgere con l'interessato, nei riguardi dell'occupazione, specialmente in merito alla determinazione dell'eventuale compenso da corrispondersi per qualsivoglia motivo.

#### Art. 435. - Miglioria senza alterazione del bene

1. Se, in seguito a nuove opere, l'immobile, l'azienda o lo stabilimento requisito e' aumentato di valore, senza alterare la primitiva struttura in rapporto alla destinazione che l'immobile, l'azienda o lo stabilimento aveva al momento della requisizione, l'avente diritto non puo' opporsi a ricevere la cosa requisita ed e' tenuto a corrispondere all'erario la somma minore tra lo speso e il migliorato. A tale scopo, l'amministrazione che ha proceduto alla requisizione determina detta somma, indicando la somma spesa e quella che l'amministrazione dichiara corrispondere all'effettiva miglioria. Il provvedimento e' comunicato all'avente diritto.

#### Art. 436. - Miglioria con alterazione del bene

1. Quando le nuove opere hanno alterato la primitiva struttura in rapporto alla destinazione che l'immobile, l'azienda o lo stabilimento aveva al momento della requisizione, l'amministrazione che vi ha proceduto, se non intende provvedere al ripristino, invita l'avente diritto a dichiarare, nel termine di sessanta giorni dalla notificazione, se intende ricevere la cosa nello stato in cui si trova, pagando la somma minore tra quella che l'amministrazione dichiara di aver speso e quella che la stessa amministrazione dichiara corrispondere all'effettiva miglioria. Il provvedimento e' comunicato all'avente diritto.

2. Se l'interessato, nel termine suindicato, non dichiara di voler corrispondere la somma determinata dall'amministrazione a norma del comma 1, il Ministro dell'economia e delle finanze, entro sei mesi dalla scadenza del termine fissato nell'invito predetto, puo' disporre, con suo decreto, che la cosa passi in proprieta' dello Stato, dietro pagamento di un'indennita' corrispondente al valore che essa aveva al momento della requisizione. Con lo stesso decreto e' determinata anche l'indennita'.

#### Art. 437. - Nuove opere senza miglioria

1. Quando le nuove opere non hanno recato alcun miglioramento all'immobile, all'azienda o allo stabilimento requisito, l'amministrazione che ha proceduto alla requisizione, ove non intenda provvedere al ripristino, restituisce la cosa nello stato in cui si trova, salvo indennizzo per l'eventuale diminuzione di valore, a norma degli articoli seguenti.

#### Art. 438. - Indennita' speciale per il deprezzamento

1. Se durante il periodo della requisizione la cosa ha subito logorio o deterioramento in misura eccedente quella derivante dall'uso normale del bene stesso, alle indennita' indicate nella sezione X del presente capo e' aggiunta una speciale indennita' corrispondente al maggior deprezzamento della cosa.

2. Nei casi previsti dal comma 2 dell'articolo 389 e quando la cosa mobile per effetto dell'uso e' divenuta inservibile, e' corrisposta un'indennita' ragguagliata al prezzo della cosa nel momento della requisizione, oltre gli interessi legali su detto prezzo da tale momento a quello del pagamento, dedotto quanto l'interessato ha ricevuto a titolo di indennita' per la requisizione in uso.

#### Art. 439. - Spese per il ripristino

1. Se l'amministrazione intende provvedere al ripristino, ha facolta' di eseguire direttamente le opere necessarie, ovvero di corrispondere l'importo all'avente diritto.

#### Art. 440. - Riscossione dei crediti dell'amministrazione

1. I crediti dell'amministrazione sono riscossi con le forme stabilite per la riscossione delle entrate patrimoniali dello Stato.

2. A richiesta dell'interessato, l'amministrazione puo' consentire la ripartizione in rate o in annualita' del pagamento delle somme da esso dovute.

### SEZIONE XII - TUTELA GIURISDIZIONALE

#### Art. 441. - (( Tutela giurisdizionale. ))

((

1. La cognizione delle controversie in ordine ai requisiti di cui al presente Capo e' devoluta al giudice ordinario per quanto attiene alla liquidazione delle indennita'; la tutela davanti al giudice amministrativo e' disciplinata dal codice del processo amministrativo.

))

### SEZIONE XIII - DISPOSIZIONI PENALI

#### Art. 442. - Omessa custodia di cose requisite

1. Il detentore della cosa requisita, che omette di custodirla fino alla consegna, e' punito con l'arresto fino a sei mesi o con l'ammenda da euro 21,00 a euro 103,00.

2. Per casi piu' gravi, possono applicarsi congiuntamente le pene dell'arresto e dell'ammenda nei limiti indicati nel comma 1.

#### Art. 443. - Omissione di denuncia o denuncia inesatta

1. Chiunque, senza giustificato motivo, non ottempera all'ordine di fare, nei modi e nei termini stabiliti, la denuncia prevista dall'articolo 399 o la fa inesattamente, e' punito con l'arresto fino a sei mesi o con l'ammenda da euro 10,00 a euro 516,00. 2- Nei casi piu' gravi, possono applicarsi congiuntamente le pene dell'arresto e dell'ammenda, nei limiti di cui al comma 1.

#### Art. 444. - Inadempimento dell'ordine di precettazione o requisizione

1. Chiunque distrae, occulta o in qualsiasi modo dissimula una cosa, al fine di impedire la precettazione o la requisizione, ovvero, senza giustificato motivo, non ottempera, in tutto o in parte, all'ordine di precettazione o di requisizione, dato dall'autorita' competente, o comunque ne impedisce od ostacola l'esecuzione, e' punito con la reclusione fino a un anno e con la multa fino a euro 310,00.

2. Se il fatto e' commesso per colpa, si applica la multa fino a euro 207,00.

#### Art. 445. - Alterazione dello stato di immobili o aziende requisiti

1. Chiunque, senza l'autorizzazione dell'autorita' che ha ordinato la requisizione, altera o modifica, in qualsiasi modo, lo stato degli immobili, aziende o stabilimenti requisiti, e' punito con l'arresto fino a un anno o con l'ammenda fino a euro 516,00.

2. Nei casi piu' gravi, possono applicarsi congiuntamente le pene dell'arresto e dell'ammenda, nei limiti di cui al comma 1.

#### Art. 446. - Alterazione di documenti o notizie

1. Chiunque, per sottrarre in tutto o in parte, alla precettazione o alla requisizione di beni, che ne possono formare oggetto, presenta libri o documenti contraffatti o alterati, e' punito con la reclusione fino a un anno e con la multa fino a euro 310,00.

2. Chiunque, allo scopo suindicato, fornisce alle autorita' competenti indicazioni mendaci, e' punito con la reclusione fino a sei mesi o con la multa fino a euro 103,00.

3. Se sono fornite, per colpa, indicazioni non conformi alla verita', si applica la multa fino a euro 31,00.

#### Art. 447. - Sottrazione o danneggiamento di cose requisite

1. Chiunque, fuori dei casi previsti dagli altri articoli della presente sezione, sottrae, distrae, sopprime, occulta, dissimula, sostituisce, disperde, distrugge o altrimenti rende inservibili, in tutto o in parte, o deteriora le cose requisite e affidate alla sua custodia, o di cui e' proprietario, e' punito secondo le disposizioni dell'articolo 334 del codice penale.

2. Se il fatto e' avvenuto o e' stato agevolato per colpa, si applica la reclusione fino a sei mesi o la multa fino a euro 310,00.

#### Art. 448. - Consegna della cosa prima dell'apertura del dibattimento

1. Nei casi previsti dagli articoli della presente sezione, se il colpevole, prima dell'apertura del dibattimento, consegna la cosa, la pena e' diminuita da un sesto a un terzo.

#### Art. 449. - Applicazione, divulgazione e deposito presso Stati esteri di invenzioni

1. Chiunque aliena, applica o divulga un'invenzione o la deposita presso Stati esteri, ovvero rivela notizie relative alla medesima senza l'autorizzazione prevista dall'articolo 390, o prima che siano trascorsi i periodi di tempo indicati negli articoli 390 e 391, ovvero dopo l'avvenuta requisizione, e' punito con la reclusione fino a tre anni e con la multa fino a euro 516,00.

2. Con la stessa pena e' punito chiunque aliena, applica, divulga o deposita all'estero un'invenzione, ovvero rivela notizie relative alla medesima in violazione di alcuno dei divieti indicati nell'articolo 390.

#### Art. 450. - Rifiuto di prestazione di servizi

1. Chiunque, senza giustificato motivo, rifiuta di ottemperare a un ordine legalmente dato di compiere un servizio individuale o collettivo, e' punito con l'arresto fino a un anno e con l'ammenda fino a euro 516,00.

2. Si applica l'ammenda fino a euro 516,00 ai dirigenti, impiegati, operai che non ottemperano all'obbligo di cui all'articolo 385, comma 4 e di cui all'articolo 393.

#### Art. 451. - Rifiuto di dare indicazioni

1. Chiunque non ottempera all'obbligo previsto dall'articolo 394, e' punito con l'arresto fino a tre mesi e con l'ammenda fino a euro 310,00.

2. Se il colpevole da' informazioni mendaci, e' punito con l'arresto fino a sei mesi e con l'ammenda fino a euro 620,00.

3. Se il colpevole e' pubblico ufficiale, la pena e' aumentata fino al doppio.

4. Se sono date, per colpa, informazioni non corrispondenti alla verita', si applica l'ammenda fino a euro 52,00.

#### Art. 452. - Reati piu' gravi

1. Le disposizioni della presente sezione non si applicano se i fatti da essa previsti costituiscono un piu' grave reato ai sensi delle leggi vigenti.

#### Art. 453. - Competenza dei tribunali militari

1. Durante lo stato di guerra, i reati previsti nella presente sezione sono di competenza dei tribunali militari, e, per i procedimenti penali relativi, nei casi in cui si ritenga di infliggere la sola pena pecuniaria, puo' provvedersi con decreto penale, secondo le norme del codice penale militare di pace.

#### Art. 454. - Omissione di comunicazioni agli aventi diritto

1. Il detentore, che non ottempera verso gli aventi diritto all'obbligo previsto dal comma 4 dell'articolo 397, e' punito, su querela della persona offesa, con la multa fino a euro 103,00.

## CAPO II - DISCIPLINA SPECIALE DELLE REQUISIZIONI DI QUADRUPEDI, VEICOLI E NATANTI DI ACQUA DOLCE IN CASO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

### SEZIONE I - AMBITO, OGGETTO E PROCEDIMENTO

#### Art. 455. - Ambito e oggetto - Disciplina applicabile

1. Nei casi previsti dall'articolo 370, comma 1, possono essere requisiti, in proprieta' o in uso, per i bisogni delle Forze armate dello Stato, i seguenti beni e le prestazioni connesse indicate nel presente capo:

- a) i cavalli, i muli e altri quadrupedi da soma o da tiro, senza distinzione di sesso e loro bardature;
- b) i veicoli ordinari a trazione animale, i veicoli a motore a trazione meccanica, nonche' i loro eventuali rimorchi, le trattrici e le locomotive stradali coi rispettivi rimorchi;
- c) le biciclette d'ogni sorta a motore e semplici;
- d) i natanti d'ogni specie, adibiti alla navigazione dei fiumi, laghi e lagune delle diverse regioni, atti al trasporto di persone, animali o cose, di portata non inferiore ai cinque quintali, con la rispettiva attrezzatura.

2. Sotto la denominazione di <<capi>> si intendono designate indistintamente tutte le cose indicate nel comma 1.

3. Ogni capo puo' essere requisito se si trova nel territorio dello Stato, se appartiene a cittadini italiani, ovvero a stranieri residenti in Italia, ed e' idoneo al servizio militare.

4. Alla requisizione dei natanti di acqua dolce si applicano le disposizioni del presente capo, tranne per quanto riguarda le indennita' e le altre somme spettanti a proprietari e detentori, cui si applicano le disposizioni del capo III del presente titolo.

5. Per la tutela giurisdizionale, si applica l'articolo 441.

#### Art. 456. - Capi non requisibili

1. Non sono requisibili:

- a) i capi appartenenti ai soggetti indicati nell'articolo 372, comma 1, lettere da a) a e);
- b) i quadrupedi appartenenti agli ufficiali delle Forze armate dello Stato in servizio effettivo e degli ufficiali richiamati dal congedo, sempreche' siano usati personalmente e nei limiti del numero attribuito dalla legge alla loro carica e grado;
- c) gli automezzi e i natanti in dotazione dell'amministrazione della pubblica sicurezza;
- d) gli stalloni appartenenti allo Stato o di pertinenza delle regioni o loro consorzi per il compito dell'incremento ippico;
- e) le giumente di puro sangue e quelle brade indome, destinate esclusivamente alla riproduzione;
- f) i soggetti da riproduzione e da allevamento (fattrici, puledri) facente parte delle stazioni speciali di monta selezionate.

2. Le giumente con puledri lattanti o riconosciute pregne sono escluse da requisizione, ma non dalle riviste e dalle dichiarazioni di cui agli articoli seguenti.

3. Sono altresi' esenti da requisizione, ma non dalla rivista e dalle dichiarazioni, di cui ai seguenti articoli, gli automezzi in dotazione alla Croce rossa italiana e all'Associazione dei cavalieri italiani del sovrano militare ordine di Malta. E' pero' in facolta' delle autorita' militari di requisire l'aliquota di automezzi che eventualmente risultasse esuberante alle necessita' degli Enti predetti.

4. I capi di proprieta' delle amministrazioni dello Stato possono essere requisiti soltanto con l'assenso delle amministrazioni interessate.

5. I capi di proprieta' privata adibiti a trasporti postali e al servizio telefonico possono essere requisiti soltanto con l'assenso dei soggetti titolari. A tale scopo sono compilate annualmente le liste dei mezzi di trasporto adibiti ai servizi postali e di telecomunicazioni che sono esentati dalla precettazione e conseguentemente dalla requisizione.

6. Con decreto del Presidente del Consiglio dei Ministri, per imprescindibili bisogni dell'industria, dell'agricoltura, del commercio o per altre necessita' possono essere stabilite dispense da requisizione, relativamente a determinati capi o categorie di capi.

#### Art. 457. - Ambito territoriale e competenza

1. La requisizione puo' essere estesa a tutto il territorio della Repubblica o limitata a parte di esso, puo' essere generale per ogni capo o circoscritta ad alcuni.

2. Essa e' ordinata dal Ministro della difesa, sentito il Consiglio dei Ministri.

#### Art. 458. - Effetti dell'ordine di requisizione

1. Trascorse ventiquattro ore dalla pubblicazione o dalla notificazione personale dell'ordine di requisizione, non e' piu' ammessa l'alienazione, sotto qualsiasi forma, dei capi dichiarati idonei al servizio militare.

2. Tale divieto resta fermo, se non e' revocato con analoga disposizione del Ministro della difesa.

((

2-bis. Qualsiasi contestazione, anche in sede giurisdizionale, non sospende l'esecutorieta' dell'ordine di requisizione.

))

#### Art. 459. - Obblighi dei destinatari della requisizione

1. Ogni proprietario dei quadrupedi, veicoli e natanti chiamati a requisizione e' tenuto a farne la presentazione nel luogo, giorno e ora fissati con apposito manifesto, o con ordine di presentazione personale.

#### Art. 460. - Selezione dei capi da requisire

1. La scelta dei capi da requisire e' fatta per categoria da una o piu' commissioni provinciali nominate dalla competente autorita' militare e costituite ognuna da un ufficiale superiore dell'Esercito italiano, che la presiede, da un delegato della Camera di commercio e da un esperto scelto dalla stessa autorita' militare.

2. Nel caso di requisizione di veicoli, fa parte della commissione, quale consulente, anche un delegato del P.R.A. (Pubblico Registro Automobilistico) e l'esperto e' scelto dalla suddetta autorita' militare, fra una terna di nomi designati dal presidente della sede dell'Automobile club d'Italia e individuati possibilmente tra persone che rivestono la qualifica di ufficiale delle Forze armate dello Stato, in servizio permanente effettivo o in congedo.

#### Art. 461. - Indennita' di requisizione e altre somme spettanti in caso di requisizione in proprieta'

1. Le commissioni provinciali fissano una giusta indennita' per ogni capo da requisire basandosi - ove possibile - sul prezzo corrente di mercato.

2. Nel caso di requisizione in proprieta' spettano al proprietario:

- a) l'indennita' di cui al comma 1;
- b) l'eventuale quota di cui all'articolo 469;
- c) il valore del carburante eventualmente contenuto nei serbatoi degli autoveicoli all'atto del prelevamento.

3. Spettano inoltre:

- a) al proprietario di autoveicoli e carri rimorchio requisiti un'indennita' corrispondente alla tassa di circolazione gia' soddisfatta, limitatamente alla quota parte relativa ai mesi interi che intercorrono fra la data di requisizione e la scadenza della rata soddisfatta;
- b) al proprietario di autocarro e rispettivo rimorchio al quale venga requisita la sola motrice, un indennizzo pari a un ventesimo del prezzo di stima, attribuito alla motrice, per il rimorchio non requisito.

4. Per effetto dell'avvenuta requisizione decade automaticamente, dal giorno stesso in cui la requisizione ha avuto luogo, ogni contratto assicurativo relativo al capo requisito; le societa' assicuratrici non possono applicare penalita' per l'anticipata risoluzione del contratto determinata da requisizione.

5. Le societa' assicuratrici hanno l'obbligo di rimborsare la quota parte dei premi anticipati e non ancora goduti, riferiti al periodo decorrente dal primo del mese successivo alla data dell'avvenuta requisizione.

6. Il proprietario del capo requisito chiede il rimborso dovutogli su presentazione di certificato rilasciato dalla competente commissione e che attesti l'avvenuta requisizione del capo predetto.

#### Art. 462. - Precettazione

1. L'autorita' militare puo' fare intimare al proprietario di un quadrupede, veicolo o natante, il precetto preventivo, per effetto del quale il capo precettato puo' essere sottoposto a requisizione.

2. In tal caso il proprietario del capo precettato ha l'obbligo di conservare il <<precetto preventivo>> e l'<<avviso personale>> successivamente inviatogli dall'autorita' militare; in caso di perdita deve avvisarne, entro ventiquattro ore, l'autorita' militare stessa.

3. L'autorita' militare ha inoltre facolta' di intimare il precetto preventivo per quanto riguarda le prestazioni occorrenti per trasporti da eseguire nell'interesse delle Forze armate, di quadrupedi, veicoli e natanti.

4. Il capo precettato puo' essere sempre venduto, permutato o altrimenti ceduto dal proprietario, se non e' indetta la requisizione o non e' pervenuto a questi avviso personale di presentazione; il proprietario ne informa entro le ventiquattro ore l'autorita' militare che lo ha precettato.

5. Il proprietario di autoveicoli o natanti a motore e' tenuto altresi' a informare, entro le ventiquattro ore, l'autorita' militare delle trasformazioni avvenute nei capi precettati, delle sostituzioni di targhe, dei cambiamenti di dimora o di indirizzo anche nell'interno della stessa citta'.

6. Il proprietario che vende, cede e permuta un capo precettato ha l'obbligo di informare il nuovo proprietario che il detto capo trovasi sotto vincolo della precettazione, e, a proprio discarico, ha il diritto di esigere dal nuovo proprietario attestazione scritta della effettuata notificazione. In mancanza di tale attestazione la effettuata notificazione puo' essere fatta risultare da prova testimoniale.

7. Il nuovo proprietario e' sottoposto al vincolo della precettazione senza bisogno di nuovo precetto, per giorni sessanta dalla data in cui e' venuto in possesso del capo precettato, salva facolta' dell'autorita' di intimare altro precetto intestato al nuovo proprietario.

8. L'autorita' militare puo' sospendere l'alienazione dei capi precettati anche prima di indire la requisizione e di notificare l'avviso personale di presentazione; la sospensione ha effetto sino alla revoca.

#### Art. 463. - Verbale

1. All'atto della requisizione, sia essa in proprieta' o in uso, oppure di prestazioni, la commissione provinciale redige un verbale contenente la particolareggiata descrizione del capo prelevato, l'indennita' di requisizione e la dimostrazione delle somme spettanti al proprietario per l'avvenuta requisizione.

2. La parte e' invitata a sottoscrivere il verbale con facolta' di farvi inserire le proprie eventuali osservazioni.

#### Art. 464. - Requisizione in uso

1. La requisizione puo' farsi in uso, sulla base della precettazione preventiva, per il tempo ritenuto necessario a giudizio insindacabile dell'autorita' militare. In tal caso e' corrisposta al proprietario l'indennita' di requisizione in uso di cui all'articolo 465.

2. Trascorsi due mesi dall'avvenuta requisizione, il proprietario del capo requisito puo' chiedere, dimostrando di non poter senza grave danno sopportare ulteriormente la requisizione in uso, la trasformazione di essa in requisizione in proprieta'.

3. Per la durata della requisizione in uso i contratti assicurativi sono sospesi. Essi riprendono automaticamente il loro corso alla data di restituzione del capo precettato e la scadenza e' prorogata di un periodo uguale alla durata della requisizione stessa.

4. La restituzione del capo requisito in uso e' effettuata nello stesso luogo del prelevamento, ovvero in altro luogo ogni qualvolta la parte interessata accetti di provvedere essa al ritiro.

5. Nel caso in cui durante il tempo della requisizione il capo requisito ha subito un deterioramento maggiore di quello ordinariamente dipendente dall'uso normale di esso, al proprietario e' liquidata una maggiore indennita' in corrispondenza del deterioramento verificatosi, indennita' che, se del caso, puo' raggiungere la totalita' dell'indennita' di requisizione di cui all'articolo 461, comma 1 dedotte le quote gia' corrisposte per l'uso e il valore d'uso del capo al momento della restituzione.

#### Art. 465. - Indennita' di requisizione in uso

1. Nel caso di requisizione in uso l'indennita' per i capi requisiti e' corrisposta a rate quindicinali posticipate e composta degli elementi indicati nei commi seguenti.

2. Per i veicoli a motore a trazione meccanica si computa:

- a) una quota giornaliera stabilita dal Ministero della difesa, di concerto con il Ministero dell'economia e delle finanze e con quello dello sviluppo economico, secondo si tratti di autovetture, ovvero di autobus o di autocarri, suddivisi questi ultimi in categorie per le portate nelle seguenti: fino a 25 quintali; oltre 25 fino a 40 quintali; oltre 40 fino a 60 quintali; oltre 60 quintali. Analogamente e' stabilita la quota giornaliera per motociclo, motocarrozzetta, motocarro, motofurgoncino o altro qualsiasi capo da requisire in suo;
- b) una quota pure giornaliera da stabilirsi dalla commissione provinciale nella misura non superiore allo 0,05 per cento del prezzo di mercato fissato per la requisizione in proprieta';
- c) il rimborso in quota giornaliera, e limitatamente alla durata dell'uso, della tassa di circolazione gia' soddisfatta;
- d) un'indennita' giornaliera per ogni rimorchio non requisito in misura stabilita in relazione alla portata dei rimorchi, dall'autorita' di cui alla lettera a) del presente comma;
- e) il valore del carburante eventualmente contenuto nei serbatoi degli autoveicoli all'atto del prelevamento;
- f) l'eventuale quota di cui all'articolo 469.

3. Per i quadrupedi, carreggio, finimenti, e bardature si computa una quota giornaliera - per cavallo o mulo - per carretta - per finimento, stabilita secondo le norme che saranno emanate dall'autorita' di cui alla lettera a) del comma 2.

#### Art. 466. - Indennita' in caso di trasformazione di requisizione in uso in requisizione in proprieta'

1. Quando una requisizione in uso e' trasformata in proprieta' spetta al proprietario l'ammontare delle somme che gli sarebbero state corrisposte se la requisizione fosse stata in proprieta' fin dall'inizio, aumentato dall'interesse legale dal giorno del prelevamento a quello del pagamento o del deposito, diminuito di quanto e' stato corrisposto a titolo di uso.

#### Art. 467. - Requisizione senza precettazione

1. Le autorita' militari dell'Esercito italiano e della Marina militare di grado non inferiore a comandanti di divisione e i comandanti di zona aerea territoriale possono ordinare di procedere alle requisizioni sia in uso sia in proprieta' senza la preventiva precettazione e senza il preavviso di presentazione, secondo le norme del presente articolo.

2. L'esecuzione degli ordini di requisizione e' affidata alla commissione provinciale ovvero, quando questa non e' costituita, a una commissione composta di tre ufficiali di corpi, uffici, istituti o stabilimenti dipendenti dall'autorita' dalla quale sono emanati gli ordini di requisizione e da quest'ultima nominata.

3. La commissione incaricata dell'esecuzione degli ordini da' per iscritto al proprietario o detentore della cosa da requisire l'ordine di requisizione sotto forma di precetto personale indicando nel medesimo la cosa da requisire e il luogo e ora della consegna.

4. Il prezzo o l'indennita' di requisizione sono determinati dalle commissioni secondo le norme stabilite per i vari casi dal presente capo e sono comunicati con l'ordine di requisizione o con provvedimento successivo.

5. Il prezzo o l'indennita' sono attribuiti al detentore se esso e' anche il proprietario della cosa requisita. In caso contrario sono attribuiti al detentore e al proprietario insieme, con buono unico, intestato a entrambi se essi sono d'accordo. Se manchi tale accordo o il proprietario non e' conosciuto o e' assente, sono depositati alla Cassa depositi e prestiti, perche' ciascuno di essi faccia valere le proprie ragioni secondo le norme di diritto comune.

6. Della requisizione eseguita in base al presente articolo si redige certificato inviato a colui che l'ha soddisfatta e di cui si tiene nota in apposito registro.

7. Salvi i casi di urgente necessita', la commissione che requisisce si avvale della collaborazione degli organi che sono all'uopo indicati dal Ministero dello sviluppo economico e dal Ministero dell'economia e delle finanze.

#### Art. 468. - Requisizione di prestazioni

1. Le autorita' militari non inferiori a comandanti di divisione e i comandanti delle zone aeree territoriali possono requisire, valendosi delle stesse commissioni di cui all'articolo 467, le prestazioni occorrenti per i trasporti da eseguire nell'interesse delle Forze armate, a mezzo di quadrupedi, veicoli e natanti.

2. L'ordine e' dato per iscritto sotto forma di precetto personale ai proprietari o detentori di fatto di quadrupedi, veicoli e natanti, sempreche' detti proprietari o detentori esercitino un'industria di trasporto o comunque si trovino, a giudizio dell'autorita' militare, in condizioni di poter corrispondere alla richiesta. Detto precetto indica, secondo i casi, la specie, il titolo, la potenza e la portata del mezzo di trasporto specificando anche, nei limiti del prevedibile, la durata approssimativa della prestazione.

3. Il proprietario o detentore precettato soddisfa le prestazioni requisite o personalmente o mediante suoi incaricati, con quadrupedi, veicoli o natanti di sua scelta, purche' rispondenti ai requisiti indicati nel precetto, e con personale di condotta e di servizio di sua fiducia, restando a suo esclusivo carico di provvedere a quanto possa occorrere per la regolare esecuzione del trasporto ordinatogli.

4. Se il proprietario o detentore precettato per le prestazioni di cui nel presente articolo ha in corso contratti di locazione d'opera con persone addette al servizio di quadrupedi, alla condotta e al servizio dei veicoli e natanti ovvero contratti di fornitura di generi e materiali di consumo relativi a tali mezzi di trasporto, i contratti stessi continuano ad aver vigore durante la requisizione.

5. L'indennita' e' stabilita dalla commissione incaricata della requisizione o con l'ordine di requisizione o con provvedimento successivo. Essa e' determinata in ragione di tonnellata-chilometro per i trasporti di cose in cui ha principale importanza il peso; in ragione di chilometro per i trasporti di persone o di cose ingombranti; sotto forma di nolo giornaliero quando il mezzo di trasporto, con il personale addetto, resta a disposizione dell'autorita' militare per i servizi che essa credera' compiere. Si tiene conto, secondo i casi, della specie, tipo, potenza, portata del mezzo di trasporto, del suo stato d'uso, del genere di trasporto, delle strade da percorrere, delle tariffe vigenti nel luogo e di ogni altro elemento influente sulla determinazione del giusto prezzo delle prestazioni.

6. In caso di urgente necessita', allorquando manchi il tempo e la possibilita' di ricorrere alle commissioni di cui all'articolo 467, qualsiasi autorita' militare puo' eccezionalmente procedere alla requisizione di prestazioni occorrenti, quando ha ricevuto formale delega dal Comando del corpo d'armata e le prestazioni sono di quelle sottoposte a precetto preventivo.

7. Nel caso di cui al comma 6 l'indennita' e' stabilita sempre con provvedimento successivo dalla commissione provinciale di visita e accettazione appositamente designata dal comando del corpo d'armata, sulla base degli accertamenti effettuati dall'autorita' militare all'atto della requisizione e della prestazione realmente compiuta.

8. Si applica il comma 5 dell'articolo 467.

#### Art. 469. - Elevazione dell'indennita' di requisizione

1. L'indennita' di requisizione e' elevata di una quota non superiore a un decimo quando la cosa o la prestazione requisita o e' mezzo al fine dell'esercizio di una industria, di un commercio, e non e' prontamente sostituibile, o costituisce l'unico mezzo di sostentamento e di lavoro del proprietario.

#### Art. 470. - Disponibilita' e sostituzione dei capi

1. I capi dichiarati idonei al servizio militare rimangono a disposizione dell'autorita' militare, ancorche' non requisiti.

2. E' pero' in facolta' del proprietario di offrire, in luogo capo prescelto, altro capo fra quelli di sua proprieta' non requisiti, purche' idoneo al medesimo servizio.

3. Sull'offerta sostituzione decide la commissione.

### SEZIONE II - SANZIONI

#### Art. 471. - Sanzioni penali

1. Chiunque distrae, occulta o in qualsiasi modo dissimula un capo al fine di impedire la precettazione o la requisizione, e' punito con la reclusione da uno a quindici mesi e con la multa:

- a) da euro 13,00 a euro 52,00 se trattasi di bicicletta semplice o a motore;
- b) da euro 26,00 a euro 129,00, se trattasi di cavalli, muli e altri quadrupedi da soma o da tiro e loro bardature o di veicoli a trazione animale;
- c) da euro 129,00 a euro 646,00, se trattasi di veicoli a motore, a trazione meccanica, di trattrici e locomotive stradali, di rimorchi di ogni tipo, di natanti adibiti alla navigazione dei fiumi, laghi e lagune con la rispettiva attrezzatura.

2. Le sanzioni di cui al comma 1 si applicano anche a chiunque senza giustificato motivo, non ottempera, in tutto o in parte, all'ordine di precettazione o di requisizione dato dall'autorita' competente, o comunque ne impedisce od ostacola l'esecuzione.

3. Se i fatti previsti nei commi 1 e 2 sono commessi per colpa, si applicano le multe di cui alle lettere a), b) e c) del comma 1 ridotte di tre quinti.

4. Fuori dai casi previsti dai commi precedenti, chiunque, per sottrarre, in tutto o in parte, alla precettazione o alla requisizione, capi che possono formarne oggetto presenta documenti contraffatti o alterati, e' punito con la reclusione da uno a quindici mesi e con la multa di cui alle lettere a), b) e c) del comma 1.

5. Chiunque, allo scopo di cui al comma 4, fornisce alle autorita' competenti indicazioni mendaci, e' punito con la reclusione fino a sei mesi e con la multa di cui alle lettere a), b) e c) del comma 1, ridotta di due quinti.

6. Se i fatti di cui al comma 5 sono commessi per colpa, si applica la multa di cui alle lettere a), b) e c) del comma 1, ridotta di quattro quinti.

7. Tutte le sanzioni di cui al presente articolo sono raddoppiate se i reati sono commessi durante lo stato di guerra.

8. Se il colpevole, prima dell'apertura del dibattimento, consegna il capo, la pena e' diminuita di un terzo.

9. Le disposizioni dei commi da 1 a 8 non si applicano, se i fatti da esse previsti costituiscono un reato piu' grave.

#### Art. 472. - Competenza dei tribunali militari

1. Durante lo stato di guerra, i reati previsti dalla presente sezione, sono di competenza dei tribunali militari.

2. Nei casi in cui si ritenga di infliggere la sola pena pecuniaria, puo' provvedersi con decreto penale, secondo le norme di cui al codice penale militare di pace.

## CAPO III - DISCIPLINA SPECIALE DELLA REQUISIZIONE DEL NAVIGLIO MERCANTILE IN CASO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 473. - Presupposti e oggetto - Norme applicabili

1. Nei casi previsti dall'articolo 370, comma 1, puo' essere disposta la requisizione delle navi nazionali, ovunque esse siano, e dei galleggianti che si trovino nelle acque territoriali dello Stato.

2. La requisizione puo' avere per oggetto la proprieta' della nave o del galleggiante, da parte dello Stato, oppure l'uso temporaneo della nave o del galleggiante, con o senza equipaggio, o con una parte di questo.

3. La requisizione puo' essere fatta in proprieta' quando per la durata, per lo scopo cui e' preordinata ovvero per la natura della cosa, l'amministrazione ravvisi una sua maggiore convenienza economica.

4. La requisizione puo' avere a oggetto la prestazione di trasporto obbligatorio su una nave o su un galleggiante determinato, non requisito, di un carico che ne importi la parziale utilizzazione.

5. Il Ministro delle infrastrutture e dei trasporti ha facolta' di disporre, con proprio decreto, sulle navi o galleggianti non requisiti, l'assoluta precedenza al trasporto di uomini, quadrupedi e materiali, per esigenze delle amministrazioni dello Stato, sui percorsi che dette navi o galleggianti compiono per effetto del loro normale impiego.

6. Per la tutela giurisdizionale, si applica l'articolo 441.

#### Art. 474. - Navi e galleggianti esenti dalla requisizione

1. Non sono soggetti a requisizione i galleggianti appartenenti:

- a) ai rappresentanti diplomatici di Stati esteri e al personale lo Stato italiano e presso lo Stato della Citta' del Vaticano;
- b) ai consoli, vice consoli e agenti consolari, cittadini dello Stato che rappresentano, se e' constatata l'esistenza di un trattamento di reciprocita';
- c) a stranieri che, in virtu' di accordi internazionali, hanno diritto all'esenzione dalla requisizione.

2. Con determinazione del Ministro degli affari esteri, di concerto con quelli della difesa e delle infrastrutture e dei trasporti, possono, per ragioni di opportunita' e di cortesia internazionale, essere dichiarati esenti da requisizione altre navi o galleggianti.

#### Art. 475. - Competenza

1. Le requisizioni di cui all'articolo 473, commi 1, 2, e 3, sono disposte dal Ministro della difesa o dal Ministro delle infrastrutture e dei trasporti, secondo le seguenti regole di competenza:

- a) il Ministero delle infrastrutture e dei trasporti per le navi da adibire a naviglio da traffico e che occorrono per soddisfare le esigenze di tutti i Ministeri e organi;
- b) il Ministero della difesa per le navi da inscriversi nel naviglio ausiliario dello Stato e per quelle occorrenti per le operazioni belliche e sussidiarie delle Forze armate.

2. La requisizione di prestazioni di cui all'articolo 473, commi 4 e 5, e' disposta dal Ministero delle infrastrutture e dei trasporti, per esigenze proprie o su richiesta di altre amministrazioni dello Stato.

3. Per eseguire la requisizione della nave o del galleggiante, il Ministro della difesa e il Ministro delle infrastrutture e dei trasporti possono delegare l'autorita' militare marittima o l'autorita' portuale locale.

4. Per la requisizione di navi o galleggianti fuori delle acque territoriali dello Stato provvedono i consoli o i comandanti navali.

5. Nei casi di urgente necessita', la requisizione puo' essere eseguita dalle autorita' di cui al comma 3, anche senza delega, salva ratifica del competente Ministro. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 476. - Requisizione di unita' per il naviglio ausiliario, per operazioni belliche e sussidiarie

1. Il Ministero della difesa ha precedenza sul Ministero delle infrastrutture e dei trasporti per la requisizione del naviglio ausiliario e del naviglio occorrente alle operazioni belliche e sussidiarie delle Forze armate.

2. Prima di disporre la requisizione e, nei casi di urgenza, dopo che la requisizione e' stata eseguita, il Ministero della difesa ne da' notizia al Ministero delle infrastrutture e dei trasporti. Se la nave da requisire e' normalmente adibita a una linea sovvenzionata dallo Stato, o a linee libere regolari, la requisizione e' disposta dal Ministero della difesa, previa intesa, salvo i casi di urgenza, col Ministero delle infrastrutture e dei trasporti.

3. Salvo i casi di urgenza, per le navi e i galleggianti di proprieta' privata in uso delle amministrazioni dello Stato o direttamente destinati all'esercizio di servizi pubblici, anche se concessi a privati, o all'esecuzione di opere pubbliche dello Stato, la requisizione e' disposta previa intesa con l'amministrazione interessata.

#### Art. 477. - Uffici di requisizione presso i Ministeri della difesa e delle infrastrutture e dei trasporti

1. Per l'esercizio di tutte le attribuzioni demandate ai Ministeri della difesa e delle infrastrutture e dei trasporti relativamente alla requisizione di navi o di galleggianti possono essere costituiti presso i Ministeri stessi speciali uffici, secondo le necessita' del momento.

2. Per l'esecuzione delle loro attribuzioni relativamente a navi o galleggianti requisiti, gli uffici predetti consultano preventivamente le amministrazioni interessate, le quali possono, a tal fine, designare un loro rappresentante.

3. Gli uffici provvedono anche al pagamento delle indennita' relative alle requisizioni disposte su richiesta di altre amministrazioni, salvo rimborso da parte dell'amministrazione interessata.

#### Art. 478. - Ordine di requisizione e di trasporto obbligatorio

1. L'ordine di requisizione o di trasporto obbligatorio e' notificato all'armatore, o al capitano o al guardiano della nave o del galleggiante e ha immediata esecuzione.

2. Se l'ordine e' stato notificato al capitano o guardiano, esso, appena possibile, e' notificato anche all'armatore o proprietario o ai loro legali rappresentanti.

3. Il capitano o il guardiano fa registrare l'ordine dall'autorita' competente sul giornale generale o sul ruolo dell'equipaggio o, nel caso di galleggianti, sulla licenza, e ne da' immediata comunicazione all'armatore o proprietario. L'ordine e' inoltre reso noto all'equipaggio con ordini di servizio da esporsi secondo gli usi.

4. Il capitano o il guardiano della nave o del galleggiante ne diventa custode per conto dell'amministrazione che lo ha requisito e gli armatori o proprietari sono tenuti a ottemperare alle disposizioni del presente capo nel termine che sara' loro fissato.

((

4-bis. Qualsiasi contestazione, anche in sede giurisdizionale, non sospende l'esecutorieta' dell'ordine di requisizione.

))

#### Art. 479. - Consegna dell'unita' requisita

1. Gli armatori o i proprietari, ricevuto l'ordine di requisizione, mettono a disposizione dell'amministrazione la nave o il galleggiante richiesto nel giorno e nell'ora indicati nell'ordine. In caso di ingiustificato ritardo nella consegna l'amministrazione puo' richiedere all'armatore o proprietario della nave o del galleggiante il risarcimento dei danni, salvo le eventuali sanzioni penali.

2. Le navi o i galleggianti requisiti sono consegnati all'amministrazione nelle condizioni di navigabilita' e assetto previste dalle norme che regolano l'esercizio della navigazione, ben puliti esternamente e internamente, con l'equipaggio al completo, se richiesto, con tutti i locali per le merci vuoti, in buon ordine, pronti all'uso e con le relative sistemazioni.

3. Gli alloggi per passeggeri esistenti a bordo devono essere in ordine, arredati, pronti all'uso e con le relative sistemazioni.

4. Nel caso che la nave, o galleggiante non si trovasse, al momento dell'ordine di requisizione, nelle condizioni ora indicate, l'armatore o il proprietario provvede, nel termine stabilito dall'amministrazione, a eliminare le eventuali manchevolezze. In difetto, i Ministeri interessati provvedono d'ufficio, salvo rimborso della spesa, secondo le norme indicate nell'articolo 505.

#### Art. 480. - Risoluzione dei contratti anteriori alla requisizione

1. L'ordine di requisizione della nave o del galleggiante risolve di diritto qualsiasi contratto che ha per oggetto l'utilizzazione della nave o del galleggiante requisito e libera inoltre di diritto il proprietario e l'armatore da qualsiasi obbligazione nei confronti di terzi, che presupponga la libera disponibilita' della nave o del galleggiante o parte degli stessi. La risoluzione dei contratti e delle obbligazioni non da' luogo a rimborsi di spesa ne' a risarcimento di danni a favore di terzi.

2. L'ordine di requisizione della nave o del galleggiante non risolve i contratti di vendita della nave o del galleggiante stipulati prima della notifica dell'ordine di requisizione, ancorche' non e' avvenuta la consegna della nave o del galleggiante, ne' pagato il prezzo convenuto ne' eseguite le trascrizioni di legge.

3. E' in facolta' dell'amministrazione che procede alla requisizione di rescindere o sospendere i contratti di assicurazione in corso, all'atto della requisizione, sostituendosi nei confronti del proprietario o armatori agli assicuratori, i quali non possono richiedere ulteriori pagamenti di premi.

#### Art. 481. - Lavori di trasformazione e di adattamento dell'unita' requisita

1. In tutte le navi e su tutti i galleggianti requisiti in uso il Ministero che procede alla requisizione puo' disporre l'esecuzione di tutti i lavori di trasformazione e di adattamento opportuni, salvo a provvedere, all'atto della cessazione della requisizione, al ripristino della nave, e al pagamento dell'indennita' anche per il tempo occorrente per i lavori di ripristino.

2. Se i lavori di ripristino sono affidati all'armatore o al proprietario, e' fissato il tempo occorrente per il ripristino e la relativa indennita' si aggiunge alla somma fissata per effettuare il ripristino stesso.

#### Art. 482. - Determinazione e corresponsione delle indennita'

1. Presso il Ministero delle infrastrutture e dei trasporti un apposito ufficio a richiesta degli uffici di requisizione determina, sentito l'armatore o il proprietario, l'indennita' di requisizione.

2. Nel caso di requisizione in uso, l'indennita' e' dovuta dal momento in cui la nave o il galleggiante e' consegnato, fino al momento della riconsegna.

3. La liquidazione dell'indennita' di requisizione esonera l'amministrazione da qualsiasi altra obbligazione non espressamente prevista dal presente capo.

#### Art. 483. - Trasformazione della requisizione in uso in requisizione in proprieta'

1. Il Ministero competente puo' procedere alla requisizione in proprieta' di navi o galleggianti gia' requisiti in uso nel caso in cui le navi o galleggianti siano stati per eventi di guerra gravemente danneggiati e si trovino immobilizzati in maniera che risulti impossibile o non conveniente procedere ai lavori necessari per la loro rimessa in efficienza.

2. Tuttavia, i proprietari, ove intendano procedere, a loro rischio, alla rimessa in efficienza delle navi o galleggianti, possono compatibilmente con le esigenze di carattere militare, da valutarsi dal Ministero della difesa, conservare la proprieta' del relitto. In tal caso pero' dall'ammontare dell'indennita' a essi spettante sara' dedotto il valore del relitto, da determinarsi dal Ministero delle infrastrutture e dei trasporti.

3. Dal giorno in cui si e' verificato l'evento di guerra al giorno in cui ha luogo la requisizione in proprieta' sono corrisposte all'armatore o al proprietario della nave o del galleggiante le sole quote b) e c) della parte A) dell'indennita' di requisizione prevista dall'articolo 500. Le predette quote b) e c) non possono essere in ogni caso corrisposte per un periodo superiore ai 720 giorni a partire dalla data dell'evento di guerra, che ha determinato il sinistro, e dalla quale e' cessata la corresponsione dell'intera parte A) del compenso di requisizione.

4. Ai fini del presente capo, la cattura da parte del nemico e il sequestro o in genere l'impossessamento da parte di uno Stato estero della nave o del galleggiante requisito in uso si considera come perdita della nave o del galleggiante derivante da rischio di guerra dal momento della cattura o sequestro o impossessamento.

#### Art. 484. - Riconsegna dell'unita' requisita

1. La riconsegna della nave o galleggiante requisito da parte dell'amministrazione e' disposta dal Ministero che ha ordinato la requisizione, e comunicata dall'autorita', all'uopo delegata dal Ministero stesso, all'armatore o proprietario o ai loro legali rappresentanti, possibilmente con preavviso.

2. Salve speciali esigenze o accordi particolari, la nave o galleggiante requisito e' restituito all'armatore o proprietario nel porto ove ebbe luogo la requisizione.

#### Art. 485. - Verbali

1. L'inizio, la sospensione, la ripresa, la fine della requisizione sono fatti risultare da appositi documenti, da compilarsi secondo le disposizioni della sezione V del presente capo.

### SEZIONE II - PERSONE IMBARCATE SULLE NAVI E SUI GALLEGGIANTI OGGETTO DI REQUISIZIONE

#### Art. 486. - Contratto di arruolamento

1. Il contratto di arruolamento, in atto al momento in cui e' notificato l'ordine di requisizione, continua ad avere vigore, e alla sua scadenza si considera prorogato per tutto il tempo della requisizione, salvi i casi di invalidita' o di infermita' debitamente constatati dal sanitario designato dall'autorita' portuale. Nel caso di requisizione in proprieta', il contratto di arruolamento in atto al momento in cui e' notificato l'ordine di requisizione puo' essere risolto dall'amministrazione che ha proceduto alla requisizione. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 487. - Sbarco dell'equipaggio mercantile

1. Il Ministero delle infrastrutture e dei trasporti o il Ministero della difesa possono disporre lo sbarco, in tutto o in parte, dell'intero equipaggio dalle navi o dai galleggianti dei quali effettuano la requisizione, sostituendolo con personale militare.

2. Il Ministero delle infrastrutture e dei trasporti o il Ministero della difesa possono, a loro insindacabile giudizio, ordinare lo sbarco dalle navi o dai galleggianti requisiti di una o piu' persone dell'equipaggio. In questo caso l'armatore, il proprietario o il capitano provvedono immediatamente, salva comprovata impossibilita', alla sostituzione delle persone sbarcate, assumendo, se richiesto dall'amministrazione, le persone da questa nominativamente designate.

3. Se l'armatore, il proprietario, o il capitano non vi provvede nel termine fissato dall'amministrazione, questa ha facolta' di provvedervi d'ufficio, e il personale cosi' imbarcato si intende arruolato a tutti gli effetti per conto dell'armatore o proprietario.

4. I predetti Ministeri possono inoltre disporre l'aumento dell'equipaggio delle navi o dei galleggianti requisiti per il disimpegno di speciali servizi, e il Ministero della infrastrutture e dei trasporti puo' anche disporre per tali servizi l'imbarco di personale militare in soprannumero.

5. Nei casi previsti dai commi 1 e 2, al personale sbarcato, se particolari norme di carattere legislativo o sindacale non dispongono diversamente, e' dovuto il trattamento previsto dalla norme vigenti per il caso di risoluzione del rapporto di lavoro per fatto del datore di lavoro.

6. Le spese per lo sbarco o la sostituzione di persone dell'equipaggio, o per l'aumento di questo, sono a carico dello Stato.

#### Art. 488. - Previdenza

1. Il periodo di navigazione compiuto dai componenti degli equipaggi delle navi requisite e' considerato utile a tutti gli effetti ai fini previdenziali.

#### Art. 489. - Equipaggio mercantile imbarcato su unita' requisite iscritte nel naviglio dello Stato

1. Per gli equipaggi delle navi requisite che sono inscritte nel naviglio ausiliario si applicano le norme relative alla Marina militare in tempo di guerra.

### SEZIONE III - CAPITANO DELLA NAVE COMMISSARIO STATALE COMANDANTE MILITARE LORO COADIUTORI

#### Art. 490. - Capitano della nave

1. Il capitano al comando della nave o galleggiante requisito, ancorche' nominato dall'armatore o proprietario, si intende, per tutto il periodo di requisizione, agli ordini dell'amministrazione per cio' che concerne l'impiego della nave o galleggiante.

2. Il capitano conserva tutti i poteri e gli obblighi inerenti alla sua carica, salve le limitazioni previste dagli articoli seguenti.

3. Egli compie i viaggi e le operazioni ordinategli con la massima sollecitudine, adottando tutte le provvidenze e gli accorgimenti necessari affinche' l'amministrazione requisitrice tragga il maggior vantaggio possibile dalle missioni affidategli. Esegue le operazioni di carico e scarico delle merci, nonche' l'imbarco e lo sbarco delle persone nelle localita' che gli sono indicate dall'amministrazione stessa.

4. Egli resta sempre responsabile personalmente di accertare in ogni momento l'efficienza della nave o galleggiante e dei mezzi di bordo, nonche' la preparazione morale e professionale del suo equipaggio.

#### Art. 491. - Commissario statale

1 Il Ministero delle infrastrutture e dei trasporti o il Ministero della difesa possono imbarcare sulle navi e sui galleggianti da essi requisiti un commissario statale.

2. Il commissario statale vigila l'esecuzione dell'atto di requisizione a tutela degli interessi dell'amministrazione, impartisce per conto di essa le opportune disposizioni al capitano della nave o del galleggiante sulle missioni da compiere e in modo speciale sugli scali da effettuare, sull'imbarco e lo sbarco delle persone e delle cose, riferendo alla fine di ogni viaggio all'amministrazione da cui dipende sulle eventuali manchevolezze riscontrate.

3. Il capitano della nave o del galleggiante requisito esegue fedelmente le istruzioni impartitegli, ma restano salve le facolta' e le responsabilita' relative alla condotta della nave o del galleggiante e alla organizzazione interna di essa. Egli comunque fornisce al commissario statale tutte le spiegazioni che gli siano richieste su qualsiasi provvedimento adottato.

#### Art. 492. - Comandante militare

1. Sulle navi e sui galleggianti requisiti dal Ministero della difesa, non iscritti nel naviglio ausiliario dello Stato, il predetto Ministero puo' conferire al commissario statale il titolo e le attribuzioni di comandante militare, se e' ufficiale di vascello della Marina militare ovvero ufficiale o sottufficiale del Corpo degli equipaggi militari marittimi, appartenente a categorie che conferiscano l'idoneita' al comando della nave o del galleggiante su cui e' imbarcato.

2. Il comandante militare, oltre alle attribuzioni proprie del commissario statale, ha anche le seguenti:

- a) dare ordini al capitano della nave o del galleggiante requisito per tutto cio' che concerne l'organizzazione e il funzionamento dei servizi di bordo, che hanno attinenza con l'impiego speciale della nave o del galleggiante;
- b) esercitare la censura su tutti i telegrammi e radiotelegrammi in arrivo e in partenza, con facolta' di vietarne la trasmissione o la ricezione quando lo ritenga opportuno per ragioni militari.

3. Il capitano della nave o del galleggiante requisito esegue e fa eseguire dalle persone da lui dipendenti tutti gli ordini che gli vengono impartiti, nei limiti sopraindicati, dal comandante militare, il quale ne assume la completa responsabilita' a tutti gli effetti, apponendo apposita nota sul giornale nautico, parte prima.

4. La presenza del comandante militare non esime il capitano della nave o del galleggiante requisito da alcuno degli obblighi per lui previsti nel presente capo, salva l'osservanza degli ordini che gli siano impartiti dal comandante militare.

#### Art. 493. - Assunzione del comando da parte del comandante militare

1. Il comandante militare, a suo insindacabile giudizio, quando speciali circostanze lo richiedano, e in particolare, a titolo esemplificativo, quando la nave o il galleggiante si trova in qualche grave contingenza (atto bellico, incendio, necessita' di abbandono della nave, caduta di uomini in mare, necessita' di getto della merce, navigazione particolarmente difficile), ha facolta' di assumere il comando della nave o del galleggiante, facendone dichiarazione da lui scritta e firmata sul ruolo dell'equipaggio e su tutti i libri del giornale nautico, con l'indicazione della data e dell'ora precisa.

2. Da questo momento il capitano della nave o del galleggiante e' esonerato da qualsiasi obbligo, facolta' o responsabilita' che gli spetti a norma di legge, e a lui subentra, a tutti gli effetti, il comandante militare.

3. In conseguenza, il capitano passa, come ogni altra persona di bordo, alla dipendenza del comandante militare, al quale presta, se richiesto, la propria collaborazione nelle funzioni di comando.

#### Art. 494. - Doveri del personale imbarcato

1. Lo stato maggiore e l'equipaggio mercantile di una nave o di un galleggiante requisito devono al comandante militare, al commissario statale e al rappresentante imbarcato della Forza armata di cui all'articolo 497 il rispetto e la deferenza cui sono tenuti verso il capitano.

2. L'equipaggio militare, e in generale il personale militare imbarcato a bordo di una nave o galleggiante requisito, hanno verso il comandante militare gli stessi doveri che le norme vigenti prescrivono verso il comandante di nave militare.

#### Art. 495. - Capitano marittimo con funzioni di comandante militare

1. Se il capitano che si trova al comando della nave o del galleggiante e' ufficiale di vascello appartenente a una delle categorie in congedo, il Ministero della difesa puo' eccezionalmente affidargli le funzioni di comandante militare, richiamandolo in servizio attivo. In questo caso, l'indennita' di requisizione e' diminuita degli assegni, che in dipendenza del richiamo l'armatore non e' piu' tenuto a corrispondere al comandante della nave.

#### Art. 496. - Sottufficiale o impiegato civile imbarcato per conto dell'amministrazione, quale contabile

1. E' in facolta' dell'amministrazione di imbarcare sulla nave o galleggiante requisito un sottufficiale o un impiegato civile di qualifica equiparata, con l'incarico di coadiuvare il comandante militare o il commissario statale nel controllo dei combustibili e dei materiali di consumo che sono a carico dell'amministrazione requisitrice.

2. Nel caso che l'amministrazione fornisca direttamente combustibili o materiali, questi devono essere regolarmente presi in carico dal predetto sottufficiale o impiegato civile; in mancanza di questo, i combustibili e i materiali predetti sono dati in regolare consegna al capitano della nave, rimanendone affidato il controllo al comandante militare o al commissario statale.

#### Art. 497. - Rappresentante delle Forze armate

1. Il Ministero della difesa interessato puo' imbarcare sulla nave mercantile o galleggiante requisito, un ufficiale o sottufficiale di grado inferiore al comandante militare o commissario statale, perche', ponendosi ai suoi ordini, lo coadiuvi nella vigilanza sulla esecuzione delle clausole dell'atto di requisizione, con attribuzioni da concordare fra i Ministeri interessati a seconda dell'impiego dell'unita' requisita.

2. L'ufficiale o il sottufficiale, imbarcato ai sensi del comma 1, ha verso il comandante militare la stessa subordinazione, che le norme vigenti per le navi militari prescrivono per gli ufficiali e sottufficiali di bordo nei riguardi del comandante.

#### Art. 498. - Trattamento economico del personale delle amministrazioni dello Stato

1. Al personale statale militare e civile imbarcato sulle unita' requisite, e' dovuto il trattamento economico previsto dalle disposizioni vigenti in materia, ovvero, ove non previsto, fissato dal Ministero interessato di concerto con il Ministero dell'economia e delle finanze.

### SEZIONE IV - DETERMINAZIONE DELL'INDENNITA' NEL CASO DI REQUISIZIONE IN PROPRIETA' O IN USO

#### Art. 499. - Indennita' nel caso di requisizione in proprieta'

1. Nel caso di requisizione in proprieta' della nave o del galleggiante l'indennita' e' determinata entro tre mesi dalla requisizione, in una somma pari al valore della nave o del galleggiante requisito.

2. La determinazione dell'indennita' compete al Ministero delle infrastrutture e dei trasporti, con le norme di cui all'articolo 500, anche se la requisizione e' disposta dal Ministero della difesa, ed e' notificata al proprietario dall'amministrazione che ha disposto la requisizione.

3. Nel caso previsto dall'articolo 483, comma 1, l'indennita' dovuta al proprietario e' determinata entro tre mesi dalla data dell'ordine di requisizione, in una somma pari al valore che la nave o il galleggiante requisito aveva al momento precedente il danneggiamento.

4. Nel caso di requisizione in proprieta' i diritti reali costituiti sull'unita' requisita possono farsi valere, dopo l'emanazione dell'ordine di requisizione, soltanto sull'indennita'.

5. Nel caso di ipoteca costituita globalmente sulla nave o galleggiante requisito ((in proprieta' a favore di istituto)) a garanzia dei finanziamenti da esso concessi, l'istituto determina, a richiesta del proprietario o armatore dell'unita' requisita, la quota parte della somma mutuata da attribuire alla nave o galleggiante requisito ai fini dell'applicazione del comma 4. Il pagamento dell'indennita' e' effettuato previa accettazione da parte del proprietario o armatore della quota indicata dall'istituto. In caso di disaccordo in merito decide il Ministro delle infrastrutture e dei trasporti.

6. Nel caso in cui l'amministrazione proceda all'alienazione della nave o del galleggiante requisito in proprieta', colui nei confronti del quale e' stata disposta la requisizione ha facolta' di esercitare il diritto di prelazione a parita' di condizioni con gli altri eventuali concorrenti.

#### Art. 500. - Indennita' nel caso di requisizione in uso

1. Nel caso di requisizione in uso della nave o del galleggiante, l'indennita' e' calcolata a giornate e a frazioni di giornate, che a loro volta sono calcolate a ore, attribuendo a ogni ora un ventiquattresimo della indennita' giornaliera.

2. Non si tiene conto delle frazioni di ore.

3. In caso di perdita della nave o del galleggiante, si corrisponde l'indennita' fino alle ore 24 del giorno della perdita o, se la data della perdita non puo' essere precisata, del giorno a cui risale l'ultima notizia certa.

4. Detta indennita' si compone di due parti designate con le lettere A e B. Il valore della nave o del galleggiante requisito e' determinato come segue:

- a) per le navi per le quali esistono prezzi correnti di mercato, tale valore e' stabilito tenendo conto dei prezzi stessi al giorno della requisizione in proprieta' o al giorno della perdita in relazione al tipo, alle caratteristiche tecniche e commerciali, nonche' allo stato di conservazione e di efficienza della nave;
- b) per le navi per le quali non esistono prezzi correnti di mercato, il valore e' stabilito calcolando il costo di ricostruzione (determinato al giorno della requisizione in proprieta' o al giorno, della perdita) di una nave nuova, avente caratteristiche analoghe e applicando un coefficiente di deprezzamento inerente all'eta', al tipo e allo stato effettivo di conservazione e di efficienza della nave.

5. Sia nell'ipotesi di cui alla lettera a) sia in quella di cui alla lettera b) del comma 4 si aggiunge il valore delle dotazioni e dei corredi.

6. Le quote comprese nella parte A, che sono determinate dall'ufficio di cui all'articolo 482, sono le seguenti:

- a) ammortamento del valore della nave o del galleggiante da calcolarsi sul valore della nave o del galleggiante (diminuito del valore di demolizione) al momento della requisizione con una percentuale variabile a seconda del tipo e dell'eta' e tenendo conto dello stato di conservazione e di efficienza della nave o del galleggiante;
- b) interessi da calcolarsi sul valore della nave o del galleggiante, corredi e dotazioni compresi; se la requisizione si prolunga oltre un anno la quota di interessi e' calcolata sul valore della nave o galleggiante decurtato della quota annuale di ammortamento;
- c) spese generali;
- d) materiali di consumo per coperta, macchina, camera, cucina (compresi i lubrificanti per le navi e i galleggianti semoventi a propulsione a vapore);
- e) manutenzione e riparazioni ordinarie;
- f) manutenzione e riparazioni straordinarie (riclassifica).

7. Quando l'amministrazione lo ritenga opportuno, puo' provvedere a sue spese ai materiali indicati nella lettera a) e ai lavori indicati nelle lettere e) e f) del comma 6. In tal caso, la parte A del compenso si limita alle quote indicate nelle lettere a), b) e c) del comma 6.

8. L'indennita' prevista per la parte A puo' essere, annualmente, soggetta a revisione a richiesta dell'amministrazione interessata o dell'armatore.

9. Le quote comprese nella parte B si riferiscono in massima agli oneri seguenti:

- a) assicurazione della nave o galleggiante contro i rischi ordinari della navigazione e assicurazione contro il rischio della responsabilita' civile per danni alle persone;
- b) equipaggio (quota comprensiva della paga, panatica, assicurazioni infortuni e malattie, contributi sindacali e previdenziali, o altri oneri previsti da apposite disposizioni ed eventuali compensi agli equipaggi stabiliti dagli organi competenti);
- c) lavoro straordinario;
- d) combustibili;
- e) lubrificanti per le motonavi e per i galleggianti semoventi con motori a combustione nonche' per le navi e galleggianti semoventi a propulsione elettrica;
- f) acqua;
- g) spese portuali e diritti marittimi (pilotaggio, rimorchio, ormeggio e disormeggio, ponti di imbarco nei porti ove occorrono, guardia ai fuochi, visita sanitaria, spedizione della nave o del galleggiante, tasse e sopratasse di ancoraggio, fari, transito di canali, e altre eventuali spese portuali e diritti marittimi);
- h) agenzie;
- i) esercizio dell'impianto r. t. (escluse le spese relative al personale r. t. gia' comprese nella quota equipaggio);
- l) operazioni di carico e scarico, stivaggio e distivaggio;
- m) mantenimento delle persone e dei quadrupedi imbarcati;
- n) carenamento di carattere eccezionale da definirsi all'atto della requisizione;
- o) disinfestazione o altre misure sanitarie;
- p) medicinali e materiali per medicazione;
- q) lavatura e rifacimento dei materassi, fasce, federe, guanciali, tovaglieria per il personale di passaggio e per l'equipaggio;
- r) eventuali sistemazioni (di telefoni nei porti e uso del telefono nell'interesse dell'amministrazione;
- s) telegrammi trasmessi nell'interesse dell'amministrazione;
- t) eventuali spese inerenti alla quarantena e approdo in porti infetti;
- u) consumi di coperta, macchina, cucina, camera per eventuali nuove sistemazioni, macchinari e posti aggiunti per ordine dell'amministrazione, nonche' forniture le quali comunque resterebbero di proprieta' dell'amministrazione.

10. Nel caso di navi o galleggianti requisiti, che siano iscritti nel ruolo del naviglio ausiliario della Marina militare, l'indennita' dovuta agli armatori o proprietari si compone della sola parte A. Le quote della parte B, applicabili a tali unita' sono contabilizzate direttamente dal Ministero della difesa come per le navi militari.

11. La parte A dell'indennita' e' determinata dal Ministero delle infrastrutture e dei trasporti, anche nel caso che la requisizione e' fatta dal Ministero della difesa, ed e' notificata all'armatore o proprietario dall'amministrazione che ha disposto la requisizione.

12. All'atto della requisizione, il Ministero delle infrastrutture e dei trasporti, se non e' in possesso di tutti gli elementi necessari, puo' determinare in via provvisoria questa parte dell'indennita', salvo a procedere alla determinazione definitiva entro tre mesi dall'inizio della requisizione. La determinazione provvisoria e' notificata dall'armatore o proprietario dall'amministrazione che ha disposto la requisizione.

13. Nel caso in cui l'armatore o proprietario propone ricorso giurisdizionale contro il provvedimento che determina definitivamente l'indennita', l'indennita' stessa e' corrisposta, fino alla decisione sul ricorso, nella misura fissata dal Ministero delle infrastrutture e dei trasporti.

14. La parte B e' determinata dal Ministero delle infrastrutture e dei trasporti o da quello della difesa rispettivamente per le navi o galleggianti requisiti da ciascuno di essi.

15. Le quote comprese nella parte B possono, a giudizio del Ministero interessato, essere escluse dall'indennita' e:

- a) essere assunte direttamente, in parte o totalmente dal Ministero interessato;
- b) essere corrisposte agli armatori o proprietari nella misura indicata dalle norme in vigore, quando trattasi di quote per le quali gia' esistono regolamentazioni speciali;
- c) essere corrisposte agli armatori o proprietari nella misura stabilita con appositi accordi.

#### Art. 501. - Oneri dell'amministrazione che procede alla requisizione

1. Oltre all'indennita' di requisizione, sono a carico delle amministrazioni che procedono alla requisizione:

- a) la perdita totale della nave o del galleggiante requisiti, l'abbandono degli stessi a tutti gli effetti di legge, le avarie della nave o del galleggiante, i danni alle persone e i danni alle cose di terzi, derivanti, tali eventi, da rischi di guerra o da rischi inerenti ai servizi speciali della requisizione e non coperti, quanto alla nave o al galleggiante, dalla normale polizza di assicurazione rischi ordinari e, quanto alle persone dalla normale polizza di assicurazione e infortuni, malattie e responsabilita' civile, quando risultino da apposito verbale vistato dal comandante militare o dal commissario statale, ovvero da dichiarazione rilasciata dal comandante militare o dal commissario statale;
- b) le spese inerenti a eventuali lavori di adattamento della nave o del galleggiante per i servizi ai quali e' adibito per effetto della requisizione;
- c) le spese inerenti ai lavori di ripristino;
- d) le eventuali cessioni di materiali di dotazione della nave o del galleggiante ad altri enti militari o civili dello Stato.

#### Art. 502. - Pagamento dell'indennita' di requisizione

1. In caso di requisizione in proprieta', l'indennita' non puo' essere pagata se non sono decorsi sessanta giorni dalla data della trascrizione dell'atto di requisizione.

2. Se sorgono contestazioni sulla persona avente diritto all'indennita', e, nel caso previsto dal comma 1, se, nel termine ivi indicato, sono notificate all'amministrazione procedente opposizioni di creditori ipotecari o privilegiati, l'indennita' e' depositata presso la Cassa depositi e prestiti, fino a che sulle contestazioni od opposizioni non decida la competente autorita' giudiziaria, su istanza della parte piu' diligente.

3. Il pagamento dell'indennita' di requisizione in uso si effettua a rate mensili posticipate.

4. L'amministrazione per conto della quale si e' proceduto alla requisizione e' autorizzata a corrispondere agli armatori o proprietari delle navi o dei galleggianti requisiti acconti, nella misura massima di otto decimi, sull'ammontare delle indennita' di requisizione gia' maturate.

5. La determinazione delle suddette indennita', agli effetti del pagamento degli acconti di cui al comma 4, e' fatta a giudizio insindacabile dell'amministrazione per conto della quale si e' proceduto alla requisizione salvo conguaglio, all'atto del pagamento del saldo, in base alla prescritta documentazione.

6. Per il pagamento delle indennita' per la perdita delle navi o dei galleggianti requisiti, sia che le indennita' stesse siano dovute ai sensi dell'articolo 501 sia che esse siano dovute ai sensi dell'articolo 516, e per il pagamento delle indennita' di requisizione, non decorrono, in alcun caso, interessi di mora.

#### Art. 503. - Documenti giustificativi

1. Gli armatori e proprietari, per il rimborso delle spese sottoelencate, se esse non sono gia' comprese nella indennita' o non formino oggetto di speciale accordo, devono presentare i documenti giustificativi indicati nei numeri seguenti:

- a) assicurazione: l'onere relativo si deve rilevare dalla polizza esistente o dal contratto da stipulare;
- b) equipaggio: fattura con prospetto nominativo dell'equipaggio, conforme alle risultanze del ruolo d'equipaggio, con l'indicazione della somma netta percepita da ciascun componente l'equipaggio stesso e delle ritenute effettuate a norma delle disposizioni in vigore; il prospetto deve portare il visto del comandante militare o del commissario statale che attestera' la effettiva percezione delle somme corrisposte; per gli eventuali compensi dovuti per servizi speciali, il prospetto nominativo e' compilato con le stesse modalita' indicate nelle lettera c);
- c) lavoro straordinario: prospetto nominativo con le indicazioni: 1) del periodo di tempo a cui il lavoro straordinario si riferisce; 2) del genere di lavoro straordinario; 3) delle ore di lavoro straordinario; 4) delle ritenute effettuate a norma delle disposizioni in vigore; 5) delle quote spettanti a norma dei contratti di lavoro e del contratto di arruolamento; 6) della somma netta corrisposta a ciascuno. Il prospetto e' vistato dal capitano della nave e dal comandante militare o dal commissario statale;
- d) combustibili, lubrificanti, acqua: fattura con dichiarazione del comandante militare o del commissario statale, attestante che i quantitativi fatturati sono stati effettivamente consumati durante la requisizione. Alla fattura e' allegata anche una dichiarazione dell'autorita' militare marittima o della Camera di commercio, industria, artigianato e agricoltura, se la nave trovarsi all'estero, del console, la quale attesti che il prezzo fatturato corrisponde a quello corrente sulla piazza;
- e) spese portuali e diritti marittimi: fattura con allegati i documenti comprovanti le tasse pagate e le spese sostenute. Tali documenti, quietanzati, sono vistati dal comandante militare o dal commissario statale, o, in loro assenza, dalla autorita' portuale o consolare competente oppure corredati da relativo buono o da una dichiarazione rilasciata dal comandante militare o dal commissario statale;
- f) agenzie: fattura con allegato il buono del comandante militare o del commissario statale, e col visto della autorita' portuale per il controllo della quota del compenso dovuto;
- g) esercizio impianto radiotelegrafico: 1) marconigrammi: riepilogo firmato dal comandante militare o dal commissario statale, con copia, se rilasciato dalle predette autorita', dei marconigrammi trasmessi nell'interesse dell'amministrazione; 2) esercizio: fattura quietanzata dall'ente che ha diritto, a norma di accordi particolari o di norme in vigore, a eventuali canoni, e vistata dal comandante militare o dal commissario statale;
- h) spese, carico e scarico, stivaggio e di stivaggio: fattura vistata dall'ufficio del lavoro portuale, ove esista, o dall'autorita' di porto, per il controllo delle tariffe applicate nel conteggio della quota oraria, con allegato il buono rilasciato dal comandante militare o dal commissario statale. Da questo buono devono risultare la data e l'ora dell'inizio e della cessazione del lavoro, per poter determinare, se necessario, il lavoro eseguito in ore straordinarie e in giorni festivi. Nei casi in cui l'equipaggio della nave o del galleggiante concorra a tali operazioni, il compenso e' corrisposto con le stesse modalita' indicate per il lavoro straordinario e nella misura stabilita dal contratto nazionale di lavoro o dal contratto di arruolamento;
- i) mantenimento delle persone e di quadrupedi imbarcati: 1) per il mantenimento, se richiesto, delle persone trasportate, l'amministrazione puo' stabilire il trattamento tavola, adottando, se esistono per la nave o il galleggiante requisito, le tariffe di 1- classe per gli ufficiali e assimilati, di 2- classe per i sottufficiali e assimilati, di 3- classe per la truppa e personale assimilato; oppure puo' apportare modifiche al trattamento tavola e stabilire nuove tariffe d'accordo con l'armatore o proprietario. Per il vitto speciale agli infermi e per i vini e altre bevande, sono stabilite apposite tariffe. Il rimborso relativo e' effettuato verso presentazione, da parte dell'armatore o del proprietario, di apposite fatture con allegate le note giornaliere compilate dal capitano della nave o del galleggiante attestanti il numero e la categoria delle razioni distribuite; le fatture e le note sono vistate dal comandante militare o dal commissario statale; 2) per il mantenimento dei quadrupedi, se richiesto, sono stabilite speciali tariffe dall'amministrazione, di accordo con l'armatore o proprietario. Il rimborso relativo e' effettuato verso presentazione, da parte dell'armatore o proprietario, di apposite fatture con allegate le note giornaliere, compilate dal capitano della nave o del galleggiante, attestanti il numero dei quadrupedi trasportati, debitamente vistate dal comandante militare o dal commissario statale;
- l) carenamento: i lavori di carenamento sono eseguiti in seguito a ordine dell'amministrazione e, se compiuti a cura degli armatori o proprietari, sono controllati dall'ufficio tecnico designato dall'amministrazione stessa. Le fatture relative portano il visto, per eseguito lavoro, dell'ufficio tecnico predetto;
- m) se il carenamento avviene in porto estero sono osservate le stesse modalita', con la sola variante che il controllo e il visto per eseguito lavoro sono devoluti al comandante militare o al commissario statale o al console;
- n) disinfestazione: le operazioni sono eseguite in seguito a ordine dell'amministrazione e, se compiute a cura degli armatori o proprietari, sono controllate dall'autorita' designata dall'amministrazione e le fatture portano il <<visto per eseguito lavoro>> dell'autorita' predetta;
- o) medicinali e materiali per medicazioni: fattura dettagliata con l'elenco dei materiali consumati, vistato dal comandante militare o dal commissario statale, con l'indicazione dei relativi prezzi, preventivamente approvati dai competenti organi dell'amministrazione;
- p) spese lavatura e rifacimento fasce, materassi, federe, guanciali, tovaglieria:fattura quietanzata dalla ditta che ha eseguito il lavoro, con allegato il verbale vistato dal comandante militare o dal commissario statale, o la dichiarazione rilasciata dal comandante militare o dal commissario statale, constatante la necessita' di procedere al lavoro stesso;
- q) telefono e internet: fattura quietanzata dalla societa' di comunicazione, vistata dall'autorita' portuale, con allegato il buono rilasciato dal comandante militare o dal commissario statale, ove e' indicato il tempo durante il quale il telefono o internet e' stato usato per ragioni di servizio interessanti l'amministrazione;
- r) telegrammi: riepilogo vistato dal comandante militare o dal commissario statale, con copia, se rilasciato dalle autorita' predette, dei telegrammi trasmessi nell'interesse dell'amministrazione;
- s) quarantena e approdo in porto infetto: riepilogo dettagliato, compilato dal capitano della nave o del galleggiante e vistato dal comandante militare o dal commissario statale, delle spese sostenute e delle eventuali indennita' pagate a norma delle disposizioni vigenti. Il riepilogo e' corredato dalle fatture e documenti giustificativi e dall'estratto del giornale nautico, vistati dall'autorita' portuaria, dai quali risulta l'ordine ricevuto e l'esatto periodo di permanenza della nave o del galleggiante in quarantena o in porto infetto;
- t) consumi suppletivi di coperta, camera, macchina, cucina: riepilogo compilato dal capitano della nave o del galleggiante, e vistato dal comandante militare o dal commissario statale, con l'indicazione dei materiali consumati e dei relativi prezzi, preventivamente approvati dai competenti organi dell'amministrazione;
- u) adattamento e ripristino: gli eventuali lavori di adattamento della nave o del galleggiante ai servizi ai quali esso e' adibito per effetto della requisizione, e quelli di ripristino, al termine di questa, se eseguiti direttamente dagli armatori o proprietari sono controllati dall'ufficio tecnico designato dall'amministrazione e le relative fatture portano il visto dell'ufficio tecnico predetto; le fatture relative alle eventuali forniture sono controllate e vistate dal predetto ufficio tecnico designato dall'amministrazione. Nel caso che i lavori e le forniture siano eseguite all'estero, il controllo e il visto sono devoluti al comandante militare o al commissario statale o al console;
- v) cessioni materiali: le eventuali cessioni di materiali di dotazione della nave o del galleggiante a enti civili o militari dello Stato sono rimborsate all'armatore o proprietario da parte dell'amministrazione requisitrice, che a sua volta si fa rimborsare dall'amministrazione dalla quale dipende l'ente che ha ricevuto il materiale. Per tali cessioni l'armatore o proprietario deve presentare regolare fattura, con allegato il verbale vistato dal comandante militare o dal commissario statale, o dichiarazione rilasciata dal comandante militare o commissario statale. In calce al verbale stesso, o separatamente, e' inserita la dichiarazione di ricevuta dell'ente al quale i materiali sono ceduti.

2. Nei casi in cui sulle navi o galleggianti non siano imbarcati commissari statali o comandanti militari, le facolta' di <<visto>> e di regolarizzazione dei documenti attribuite alla loro competenza dal presente articolo sono devolute all'ufficio di requisizione dell'amministrazione che ha ordinato la requisizione. Il presente comma si applica anche ai casi di impedimento delle anzidette autorita'.

#### Art. 504. - Lavori e forniture urgenti

1. In casi eccezionali di speciale importanza e urgenza, l'amministrazione che ha disposto la requisizione, previa intesa con il Ministero dell'economia e delle finanze, puo' derogare alle disposizioni vigenti in materia di contratti pubblici e di limiti per le aperture di credito, per quanto attiene all'esecuzione di lavori e di forniture necessari all'utilizzazione e all'impiego immediato dell'unita' requisita.

#### Art. 505. - Temporanea inutilizzazione, riparazioni dell'unita' e sospensioni dell'indennita'

1. Se le navi e i galleggianti requisiti in uso restano temporaneamente inutilizzati per il servizio effettivo dello Stato, per cause estranee all'amministrazione, e indipendenti dagli eventi che sono a carico dell'amministrazione stessa ai sensi dell'articolo 501, comma 1, lettera a), la requisizione continua ad avere effetto, ma gli armatori o i proprietari non hanno diritto alla corresponsione della indennita' per tutto il periodo durante il quale la nave o il galleggiante rimane inutilizzato in un porto che l'amministrazione ha facolta' di designare.

2. Se gli armatori o proprietari non provvedono, con la dovuta sollecitudine e a regola d'arte all'esecuzione dei lavori necessari per eventuali riparazioni, i ministeri che ordinarono la requisizione possono provvedervi direttamente, a spese degli armatori o proprietari. In tal caso, l'importo delle spese relative e' trattenuto sulle somme dovute, secondo le indicazioni della presente legge. Ove dette somme non siano sufficienti o le trattenute non siano state eseguite, dette spese costituiscono credito privilegiato sulla nave o sul galleggiante a favore dello Stato, e sono graduate fra i crediti elencati nell'articolo 552 del codice della navigazione dopo il n. 6. Esse sono riscosse ai sensi dell'articolo 84 del codice della navigazione.

#### Art. 506. - Salvataggi e rimorchi

1. Qualunque profitto netto spettante all'armatore per salvataggi e rimorchi eseguiti dalla nave o dal galleggiante requisito e' diviso in parti uguali tra l'amministrazione, che ha proceduto alla requisizione, e l'armatore.

### SEZIONE V - ATTO DI REQUISIZIONE MODALITA' DELLA CONSEGNA E DELLA RESTITUZIONE DELLE NAVI E DEI GALLEGGIANTI REQUISITI

#### Art. 507. - Autorita' delegata per la consegna e la restituzione

1. Le formalita' relative alla consegna e alla restituzione delle navi o dei galleggianti requisiti sono compiute dall'autorita' delegata dall'amministrazione che procede alla requisizione.

#### Art. 508. - Controllo dell'inventario

1. All'atto della consegna e della riconsegna di nave requisita si procede al controllo dell'inventario, in contraddittorio con l'armatore o il proprietario o con il loro rappresentante, redigendosene verbale nel quale devono farsi risultare le irregolarita' eventualmente riscontrate.

2. Se il controllo dell'inventario non puo' essere compiuto dall'autorita' delegata, puo' essere a cio' delegata dall'amministrazione altra autorita'.

3. Se esigenze speciali non consentono di procedere a questo controllo, fa fede, fino a prova contraria, l'inventario esistente a bordo, una copia del quale, a cura dell'armatore o proprietario o del capitano della nave, e' rimessa, entro ventiquattro ore dall'ordine, all'autorita' che e' designata dall'amministrazione requisitrice.

4. Dell'esattezza di tale documento rimangono responsabili, salve le eventuali sanzioni penali, l'armatore o proprietario e il capitano.

5. Nel caso di galleggianti, valgono le norme predette, con la sola variante che, non essendo prescritto quale documento di bordo l'inventario, questo e' compilato, anziche' controllato, al momento della requisizione, salvo speciali disposizioni da parte del Ministero che procede alla requisizione.

#### Art. 509. - Verifica materiali di consumo

1. Le autorita' delegate verificano i materiali di consumo esistenti a bordo, esclusi i combustibili, i lubrificanti e l'acqua, nei casi di consegna o di riconsegna, redigendone apposito verbale.

#### Art. 510. - Verbale di consegna

1. In tutti i casi e a tutti gli effetti previsti dal presente capo, l'atto di requisizione e' sostituito dal processo verbale di consegna di cui al comma 2.

2. Agli effetti della requisizione, sia in proprieta' sia in uso, e' compilato un processo verbale di consegna, che contiene le seguenti indicazioni:

- a) autorita' delegata per la consegna;
- b) ordine ricevuto dalla predetta autorita', con le precise indicazioni del documento relativo;
- c) amministrazione dello Stato per conto della quale si effettua la requisizione;
- d) nome dell'unita' requisita, tipo (piroscafo, motonave, veliero, galleggiante, ecc.) e nazionalita';
- e) nome del proprietario (o anche dell'armatore nel caso di requisizione in uso) dell'unita' requisita e sua residenza o domicilio;
- f) compartimento o ufficio marittimo d'iscrizione dell'unita' requisita e relativo numero della matricola delle navi o del registro dei galleggianti;
- g) tonnellaggio di stazza lorda e netta;
- h) porto in cui avviene la consegna;
- i) data e ora della consegna;
- l) consistenza dei combustibili e dell'acqua (potabile e per macchina) esistenti a bordo dell'unita' all'atto della consegna e consistenza dei lubrificanti soltanto nel caso di motonavi e di galleggianti con motori a combustione oppure a propulsione elettrica;
- m) eventuali annotazioni;
- n) firma dell'autorita' delegata per la consegna;
- o) firma del proprietario (o anche dell'armatore, nel caso di requisizione in uso) o del suo legale rappresentante.

#### Art. 511. - Verbali di sospensione e di ripresa della requisizione in uso

1. Le norme relative alle formalita' di consegna e di riconsegna dell'unita' requisita si osservano anche nel caso di sospensione della requisizione in uso e di successiva cessazione di tale sospensione.

#### Art. 512. - Processo verbale di restituzione

1. All'atto della restituzione dell'unita' requisita, l'autorita' delegata dall'amministrazione che ha ordinato la requisizione compila il processo verbale di restituzione, che contiene le stesse indicazioni prescritte per il verbale di consegna, sostituendo la parola <<consegna>> con <<restituzione>>.

#### Art. 513. - Contraddittorio della parte interessata nella redazione dei verbali

1. I processi verbali di consegna e restituzione sono redatti in contraddittorio del proprietario o dell'armatore dell'unita' requisita o di loro rappresentanti o del capitano.

2. A tal fine, e' data tempestiva notizia al proprietario o all'armatore o al capitano del luogo e dell'ora in cui si procedera' alla redazione del processo verbale. Se l'interessato non si presenta, si procede egualmente alla formazione del verbale, facendosi constare l'assenza dell'interessato.

#### Art. 514. - Raccolta dei verbali e delle dichiarazioni

1. Durante la requisizione in uso, il comandante militare o il commissario statale e il capitano della nave o del galleggiante tengono ciascuno una raccolta dei seguenti verbali, riuniti in fascicolo e corredati di un indice:

- a) di consegna e di restituzione, di sospensione e di ripresa della requisizione;
- b) relativi alla presa in carico o alla cessione di combustibili, lubrificanti, acqua;
- c) relativi allo scarico e alla cessione di materiali di dotazione;
- d) attestanti le necessita' della lavatura e del rifacimento di fasce, materassi, federe, guanciali;
- e) concernenti la fornitura di materiali appartenenti all'amministrazione e la consegna temporanea da parte di questa al capitano della nave o del galleggiante;
- f) di controllo di inventari;
- g) ogni altro processo verbale o di dichiarazione concernente l'unita' requisita.

### SEZIONE VI - ASSICURAZIONI E AVARIE

#### Art. 515. - Responsabilita' dell'amministrazione che provvede alla requisizione

1. L'amministrazione, con il pagamento delle quote di assicurazione contro i rischi ordinari di navigazione e contro gli ordinari rischi di malattia e infortuni e contro la responsabilita' civile per danni alle persone, previsti alle lettere a) e b) della parte B dell'indennita' ai sensi dell'articolo 500, rimane esonerata da ogni responsabilita' per tutti i danni che derivano da tali rischi alla nave o galleggiante o alle persone o alle cose durante la requisizione, anche se l'armatore o proprietario della nave o del galleggiante non ha, per qualsiasi motivo, provveduto tempestivamente alla stipulazione o rinnovazione del relativo contratto di assicurazione.

2. In determinate circostanze e per speciali ragioni, l'amministrazione che procede alla requisizione puo' disporre affinche' le polizze di assicurazione non siano rinnovate alla loro scadenza.

#### Art. 516. - Indennita' e rimborsi a carico dell'amministrazione che procede alla requisizione

1. Quando l'amministrazione si avvale della facolta' concessa dall'articolo 500, comma 15, lettera a), o quando comunque per sua disposizione i rischi non siano, in tutto o in parte, coperti da assicurazione, essa corrisponde all'armatore o proprietario della nave o galleggiante:

- a) in caso di perdita, una indennita' pari al valore della nave di cui all'articolo 500, comma 4 rimanendo fermo quanto disposto dall'articolo 499, comma 4;
- b) in caso di avarie, il rimborso delle spese incontrate e di quelle necessarie alla conseguente riparazione, a meno che l'amministrazione non reputi piu' conveniente procedere essa stessa all'esecuzione dei lavori relativi.

### SEZIONE VII - SANZIONI PENALI E DISCIPLINARI

#### Art. 517. - Inosservanza dell'ordine di trasporto obbligatorio o di precedenza

1. Chiunque non ottempera agli ordini dati dal Ministero delle infrastrutture e dei trasporti, a norma dell'articolo 473, commi 4 e 5, e' punito con l'arresto fino a un anno o con l'ammenda fino a euro 207,00.

2. Nei casi piu' gravi possono applicarsi, congiuntamente, le pene dell'arresto e dell'ammenda, nei limiti suindicati.

#### Art. 518. - Sottrazione alla requisizione - Inosservanza dell'ordine di requisizione

1. Chiunque in qualsiasi modo, sottrae alla requisizione una nave o un galleggiante, che ne possa formare oggetto a norma del presente capo, o, senza giustificato motivo, non ottempera, in tutto o in parte, all'ordine di requisizione della nave o del galleggiante, dato dall'autorita' competente o comunque ne impedisce od ostacola l'esecuzione, e' punito con la reclusione fino a un anno e con la multa fino a euro 310,00.

2. Se il fatto e' commesso per colpa, si applica la multa fino a euro 207,00.

3. Nel caso che la consegna all'amministrazione della nave o del galleggiante requisito avvenga, senza giustificato motivo, oltre il termine all'uopo stabilito a norma dell'articolo 479, il colpevole e' punito con l'arresto fino a tre mesi o con l'ammenda fino a euro 310,00.

#### Art. 519. - Alterazione di nave o galleggiante requisiti

1. Chiunque, senza l'autorizzazione dell'autorita' che ha ordinata la requisizione, altera o modifica, in tutto o in parte, lo stato della nave o del galleggiante requisito, e' punito con l'arresto fino a un anno o con l'ammenda fino a euro 516,00.

2. Nei casi piu' gravi, possono applicarsi congiuntamente le pene dell'arresto e dell'ammenda, nei limiti suindicati.

#### Art. 520. - Documenti falsi o indicazioni non vere

1. Chiunque, per sottrarre alla requisizione una nave o un galleggiante presenta libri o documenti contraffatti o alterati e' punito con la reclusione fino a un anno o con la multa fino a euro 310,00.

2. Chiunque, allo scopo suindicato, fornisce all'autorita' competente indicazioni mendaci e' punito con la reclusione fino a sei mesi o con la multa fino a euro 103,00.

3. Se sono fornite, per colpa, indicazioni non conformi alla verita', si applica la multa fino a euro 103,00.

#### Art. 521. - Distruzione o deterioramento di nave o galleggiante requisiti

1. Chiunque, fuori dei casi indicati negli articoli precedenti della presente sezione, distrugge, sostituisce, sottrae o altrimenti rende inservibile, anche temporaneamente, o deteriora la nave o il galleggiante requisiti e affidati alla sua custodia, e' punito secondo le disposizioni dell'articolo 334 del codice penale.

2. Se il fatto e' avvenuto o e' stato agevolato per colpa, si applica la reclusione fino a sei mesi o la multa fino a euro 310,00.

#### Art. 522. - Inosservanza di doveri da parte dell'armatore proprietario o capitano

1. E' punito con l'arresto fino a sei mesi o con l'ammenda fino a euro 310,00 l'armatore, il proprietario o il capitano, che, senza giustificato motivo:

- a) non ottempera immediatamente all'ordine dell'autorita' competente di sbarcare in tutto o in parte, l'equipaggio dalla nave o dal galleggiante requisiti;
- b) nelle condizioni previste dalla lettera a) del presente comma, non ottempera alla richiesta di assunzione delle persone nominativamente designate dall'amministrazione, per sostituire, in tutto o in parte, l'equipaggio sbarcato;
- c) non ottempera all'ordine dell'autorita' competente di aumentare per il disimpegno di speciali servizi, l'equipaggio della nave o del galleggiante requisiti, o di imbarcare, per tali servizi, personale militare in soprannumero;
- d) non ottempera a quanto prescritto nell'articolo 38, al fine del controllo o della compilazione dell'inventario per la consegna o la riconsegna della nave o del galleggiante requisiti.

#### Art. 523. - Inosservanza di ordini dati dall'amministrazione, dal commissario statale o dal comandante militare

1. Il capitano della nave o del galleggiante requisiti, che, senza giustificato motivo, non ottempera agli ordini impartiti dall'amministrazione o dal commissario statale o dal comandante militare, a norma, rispettivamente, degli articoli 490, 491, 492, e' punito con l'arresto fino a sei mesi o con l'ammenda fino a euro 207,00.

#### Art. 524. - Applicazione di sanzioni penali piu' gravi

1. Le disposizioni della sezione VII del presente capo non si applicano, se i fatti da essa previsti costituiscono un piu' grave reato a norma delle leggi vigenti.

#### Art. 525. - Competenza dei tribunali militari

1. Se i reati previsti dagli articoli 517 e 523 sono commessi in tempo di guerra, la competenza spetta ai tribunali militari; quando il giudice ritenga di infliggere la sola pena pecuniaria, puo' provvedersi con decreto penale, secondo le disposizioni del codice penale militare di pace.

#### Art. 526. - Sanzioni disciplinari

1. Le mancanze commesse a bordo dalle persone imbarcate verso i rappresentanti dell'amministrazione dello Stato, indicati nella sezione III del presente capo, sono punite con le sanzioni disciplinari previste dagli articoli 1249 e seguenti del codice della navigazione.

2. L'esercizio del potere disciplinare di cui al comma 1 e' affidato alle persone indicate dagli articoli 1249 e seguenti del codice della navigazione.

3. I rapporti relativi a mancanze disciplinari a carico delle persone imbarcate sono dal comandante militare o dal commissario statale presentati al capitano della nave o galleggiante, che li trascrive nel giornale nautico, con l'indicazione dei provvedimenti disciplinari adottati.

4. Il comandante militare, che ha assunto il comando della nave o del galleggiante in forza della facolta' conferitagli dall'articolo 493, sostituisce interamente il capitano nell'esercizio del potere disciplinare su tutte le persone imbarcate.

5. Oltre alle sanzioni disciplinari di cui al comma 1, per qualsiasi atto od omissione capace di turbare il buon andamento del servizio cui la nave o galleggiante requisito e' adibito puo' essere inflitta ai colpevoli, dall'autorita' marittima competente, la sanzione disciplinare dell'inibizione della navigazione da un minimo di tre mesi a un massimo di due anni, indipendentemente dalle sanzioni penali applicabili in virtu' di altre leggi.

## LIBRO TERZO AMMINISTRAZIONE E CONTABILITA' TITOLO I DISPOSIZIONI GENERALI

### Art. 527. - Norme applicabili all'amministrazione e contabilita' del Ministero della difesa. Rinvio

1. Al Ministero della difesa si applicano le norme vigenti per l'amministrazione e contabilita' delle amministrazioni statali, in quanto non derogate dalle disposizioni del presente libro e con esse compatibili ((, nonche' l'articolo 1 del decreto-legge 25 maggio 1994, n. 313, convertito, con modificazioni, dalla legge 22 luglio 1994, n. 460)).

((

1-bis. L'articolo 1 del decreto-legge n. 313 del 1994, convertito, con modificazioni, dalla legge n. 460 del 1994, si applica anche ai fondi destinati al pagamento di spese, principali e accessorie, per servizi e forniture aventi finalita' di difesa nazionale e sicurezza, nonche' agli emolumenti di qualsiasi tipo dovuti al personale amministrato dal Ministero della difesa, accreditati mediante aperture di credito in favore dei funzionari delegati degli uffici centrali e periferici del Ministero della difesa. Gli atti di sequestro e di pignoramento afferenti ai fondi di cui al presente comma sono nulli; la nullita' e' rilevabile d'ufficio e gli atti non determinano obbligo di accantonamento da parte delle sezioni della Tesoreria dello Stato, ne' sospendono l'accreditamento di somme destinate ai funzionari delegati centrali e periferici.

))

2. Il regolamento detta le norme di attuazione per l'amministrazione e contabilita' del Ministero della difesa, ivi compresa l'attivita' ispettiva. Il controllo strategico e' disciplinato dall'articolo 21 del regolamento, in attuazione dell'articolo 6, comma 1, del decreto legislativo 30 luglio 1999, n. 286.

### Art. 528. - Informatizzazione del Ministero della difesa

((

1. All'informatizzazione delle attivita' del Ministero della difesa si applicano le norme vigenti per l'informatizzazione della pubblica amministrazione statale, con le deroghe ivi eventualmente previste, e segnatamente:

- a) il decreto legislativo 12 febbraio 1993, n. 39;
- b) le norme di attuazione dell'articolo 27 della legge 16 gennaio 2003, n. 3, e, in particolare, il decreto del Presidente della Repubblica 11 febbraio 2005, n. 68;
- c) l'articolo 1, commi 197 e 198, della legge 30 dicembre 2004, n. 311, con le relative norme secondarie di attuazione;
- d) il decreto legislativo 7 marzo 2005, n. 82, con le limitazioni di cui all'articolo 2, comma 6, e all'articolo 75, comma 2, nonche' le facolta' di cui all'articolo 17, comma 1-bis del medesimo decreto legislativo;
- e) l'articolo 8, comma 1, del decreto-legge 9 febbraio 2012, n. 5, convertito, con modificazioni, dalla legge 4 aprile 2012, n. 35.

))

2. In applicazione dell'articolo 16 del decreto legislativo 12 febbraio 1993, n. 39, il regolamento, adottato per tale parte di intesa con ((Agenzia per l'Italia Digitale)), detta le norme volte a coordinare le disposizioni del citato decreto legislativo n. 39 del 1993 con le esigenze di gestione dei sistemi informativi automatizzati concernenti la difesa nazionale.

### Art. 529. - Controlli. Rinvio

1. Al controllo di regolarita' amministrativa e contabile e al controllo di gestione del Ministero della difesa si applicano le norme vigenti per i controlli delle amministrazioni statali.

### Art. 530. - Inchieste su eventi di particolare gravita' o risonanza

1. Il Ministero della difesa dispone le inchieste sommarie e formali volte ad accertare le cause soggettive e oggettive che hanno determinato eventi di particolare gravita' o risonanza nell'ambito dell'Amministrazione della difesa, allo scopo di valutare l'opportunita' di adottare le misure correttive di carattere organizzativo o tecnico necessarie a evitare il ripetersi degli eventi dannosi e di dare l'avvio ai procedimenti rivolti a individuare eventuali responsabilita' penali, disciplinari, amministrative, in merito alla causazione dell'evento.

2. Il regolamento disciplina le procedure per lo svolgimento delle inchieste e delimita gli eventi di cui al comma 1, ivi compresi gli incidenti di volo avvenuti nell'ambito di operazioni o esercitazioni internazionali, multinazionali o NATO, a carattere interforze.

3. Dagli eventi di cui al comma 1 sono esclusi gli incidenti automobilistici, nei quali sono rimasti coinvolti automezzi isolati e che non hanno comportato gravi lesioni fisiche o perdite di vite umane, nonche' gli incidenti di volo accaduti agli aeromobili, diversi da quelli di cui al comma 2.

### Art. 531. - Riutilizzo di documenti

1. Per l'esercizio della facolta' di rendere disponibili a terzi i documenti contenenti dati pubblici nella disponibilita' del Ministero della difesa, trovano applicazione le norme vigenti di cui al decreto legislativo 24 gennaio 2006, n. 36, che da' attuazione alla direttiva 2003/98/CE relativa al riutilizzo di documenti nel settore pubblico.

### Art. 532. - Responsabilita' del personale militare

1. Resta ferma, per il personale militare, la disciplina vigente per i dipendenti delle amministrazioni pubbliche in materia di responsabilita' civile, penale ((...)) e amministrativo-contabile.

### Art. 533. - (( (Polizze assicurative). ))

((

1. In materia di polizze assicurative, al Ministero della difesa si applicano le disposizioni vigenti per le pubbliche amministrazioni statali sul divieto di stipula di assicurazioni per i dipendenti pubblici.

))

## TITOLO II ATTIVITA' NEGOZIALE DEL MINISTERO DELLA DIFESA CAPO I DISPOSIZIONI GENERALI SULL'ATTIVITA' NEGOZIALE DEL MINISTERO DELLA DIFESA

### Art. 534. - Attivita' negoziale del Ministero della difesa. Rinvio

1. Fatto salvo quanto disposto dal presente titolo:

- a) ai contratti del Ministero della difesa si applicano le vigenti disposizioni in materia di attivita' negoziale della pubblica amministrazione statale, ivi comprese la disciplina concernente l'acquisizione di beni e servizi tramite la Concessionaria servizi informativi spa (CONSIP), nonche' la disciplina concernente le forniture e servizi informatici e, segnatamente, gli articoli 1, commi 192, 193 e 194, della legge 30 dicembre 2004, n. 311, e 67 del decreto legislativo 7 marzo 2005, n. 82, e successive modificazioni;
- b) ai contratti del Ministero della difesa relativi a lavori, servizi e forniture, diversi da quelli di cui al comma 2, si applicano il decreto legislativo 12 aprile 2006, n. 163, recante il codice dei contratti pubblici relativi a lavori, servizi e forniture, e le relative disposizioni attuative ((di cui al decreto del Presidente della Repubblica 15 novembre 2012, n. 236,)) emanate ai sensi dell'articolo 196 dello stesso codice dei contratti;
- c) si applica la legge 11 novembre 1986, n. 770;
- d) alle locazioni di immobili per i fabbisogni allocativi del Ministero della difesa si applica l'articolo 2, comma 222, della legge 23 dicembre 2009, n. 191.

2. Ai contratti del Ministero della difesa relativi a lavori, servizi e forniture ricadenti nell'oggetto della direttiva 2009/81/CE, si applicano le disposizioni di cui al decreto legislativo 15 novembre 2011, n. 208, e le relative disposizioni attuative ((di cui al decreto del Presidente della Repubblica 13 marzo 2013, n. 49,)) emanate ai sensi dell'articolo 4, comma 1, dello stesso decreto.

### Art. 535. - Difesa Servizi spa

1. E' costituita la societa' per azioni denominata «Difesa Servizi spa», ai fini dello svolgimento dell'attivita' negoziale diretta all'acquisizione di beni mobili, servizi e connesse prestazioni strettamente correlate allo svolgimento dei compiti istituzionali dell'Amministrazione della difesa e non direttamente correlate all'attivita' operativa delle Forze armate, da individuare con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, nonche' ai fini dell'articolo 7 della legge 24 dicembre 1985, n. 808, nonche' delle attivita' di valorizzazione e di gestione, fatta eccezione per quelle di alienazione, degli immobili militari, da realizzare anche attraverso accordi con altri soggetti e la stipula di contratti di sponsorizzazione.((Le citate attivita' negoziali sono svolte attraverso l'utilizzo integrale delle risorse acquisite dalla societa', attraverso la gestione economica dei beni dell'Amministrazione della difesa e dei servizi da essa resi a terzi, da considerare aggiuntive rispetto a quelle iscritte nello stato di previsione del dicastero)).

2. La societa' e' posta sotto la vigilanza del Ministro della difesa e ha sede in Roma. Il capitale sociale della societa' e' stabilito in euro 1 milione, e i successivi eventuali aumenti del capitale sono determinati con decreto del Ministro della difesa, che esercita i diritti dell'azionista. Le azioni della societa' sono interamente sottoscritte dal Ministero della difesa e non possono formare oggetto di diritti a favore di terzi. La societa' opera secondo gli indirizzi strategici e i programmi stabiliti con decreto del medesimo Ministero, di concerto con il Ministero dell'economia e delle finanze.

3. La societa' ha a oggetto la prestazione di servizi e l'espletamento di attivita' strumentali e di supporto tecnico-amministrativo in favore dell'Amministrazione della difesa per lo svolgimento di compiti istituzionali di quest'ultima. L'oggetto sociale, riguardante l'attivita' negoziale diretta all'acquisizione di beni mobili, servizi e connesse prestazioni, e' strettamente correlato allo svolgimento dei compiti istituzionali del comparto sicurezza e difesa, anche attraverso l'espletamento, per le Forze armate, delle funzioni di centrale di committenza ai sensi dell'articolo 33 del codice dei contratti pubblici relativi a lavori, servizi e forniture, di cui al decreto legislativo 12 aprile 2006, n. 163. Le predette funzioni di centrale di committenza possono essere svolte anche per le altre Forze di polizia, previa stipula di apposite convenzioni con le amministrazioni interessate. La societa' puo' altresi' esercitare ogni attivita' strumentale, connessa o accessoria ai suoi compiti istituzionali, nel rispetto della normativa nazionale e comunitaria in materia di affidamento a societa' a capitale interamente pubblico.

4. La societa', nell'espletare le funzioni di centrale di committenza, utilizza i parametri di prezzo-qualita' delle convenzioni di cui all'articolo 26, comma 1, della legge 23 dicembre 1999, n. 488, e successive modificazioni, come limiti massimi per l'acquisto di beni e servizi comparabili.

5. Lo statuto disciplinante il funzionamento interno della societa' e' approvato con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze. E' ammessa la delega dei poteri dell'organo amministrativo a uno dei suoi membri. Con lo stesso decreto sono nominati i componenti del consiglio di amministrazione e del collegio sindacale per il primo periodo di durata in carica. I membri del consiglio di amministrazione possono essere scelti anche tra gli appartenenti alle Forze armate in servizio permanente. Le successive modifiche allo statuto e le nomine dei componenti degli organi sociali per i successivi periodi sono deliberate a norma del codice civile ed entrano in vigore a seguito dell'approvazione delle stesse con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

6. Lo statuto prevede:

- a) il divieto esplicito di cedere le azioni o di costituire su di esse diritti a favore di terzi;
- b) la nomina da parte del Ministro della difesa dell'intero consiglio di amministrazione e il suo assenso alla nomina dei dirigenti;
- c) le modalita' per l'esercizio del <<controllo analogo>> sulla societa', nel rispetto dei principi del diritto europeo e della relativa giurisprudenza comunitaria;
- d) le modalita' per l'esercizio dei poteri di indirizzo e controllo sulla politica aziendale;
- e) l'obbligo dell'esercizio dell'attivita' societaria in maniera prevalente in favore del Ministero della difesa;
- f) il divieto di chiedere la quotazione in borsa o al mercato ristretto.

7. La pubblicazione del decreto di approvazione dello statuto nella Gazzetta Ufficiale tiene luogo degli adempimenti in materia di costituzione delle societa' previsti dalla normativa vigente.

8. Gli utili netti della societa' sono destinati a riserva, se non altrimenti determinato dall'organo amministrativo della societa' previa autorizzazione del Ministero vigilante.

9. La societa' non puo' sciogliersi se non per legge.

10. Il rapporto di lavoro del personale dipendente della societa' e' disciplinato dalle norme di diritto privato e dalla contrattazione collettiva. In deroga a quanto previsto dal comma 9 dell'articolo 23-bis del decreto legislativo 30 marzo 2001, n. 165, la societa' si avvale anche del personale militare e civile del Ministero della difesa, anche di livello non dirigenziale, in possesso di specifiche competenze in campo amministrativo e gestionale, da impiegare secondo le modalita' previste dallo stesso articolo.

## CAPO II - PROGRAMMAZIONE

### Art. 536. - (Programmi).

1. Con riferimento alla pianificazione dei programmi di ammodernamento e rinnovamento dei sistemi d'arma, delle opere, dei mezzi e dei beni direttamente destinati alla difesa nazionale, annualmente, entro la data del 30 aprile, il Ministro della difesa provvede a trasmettere al Parlamento l'aggiornamento della documentazione di cui agli articoli 12 e 548, comprensivo del piano di impiego pluriennale che riassume:

- a) il quadro generale delle esigenze operative delle Forze armate, comprensive degli indirizzi strategici e delle linee di sviluppo capacitive;
- b) l'elenco dei programmi d'armamento e di ricerca in corso ed il relativo piano di programmazione finanziaria, indicante le risorse assegnate a ciascuno dei programmi per un periodo non inferiore a tre anni, compresi i programmi di ricerca o di sviluppo finanziati nello stato di previsione del Ministero dello sviluppo economico. Nell'elenco sono altresi' indicate le condizioni contrattuali, con particolare riguardo alle eventuali clausole penali.

2. Nell'ambito della stessa documentazione di cui al comma 1 sono riportate, sotto forma di bilancio consolidato, tutte le spese relative alla funzione difesa, comprensive delle risorse assegnate da altri Ministeri.

3. In relazione agli indirizzi di cui al comma 1, i conseguenti programmi ed i relativi impegni di spesa sono approvati:

- a) con legge, se richiedono finanziamenti di natura straordinaria;
- b) con decreto del Ministro della difesa, se si tratta di programmi finanziati attraverso gli ordinari stanziamenti di bilancio, di concerto con il Ministro dell'economia e delle finanze se tali programmi sono di durata pluriennale. Salvo quanto disposto al comma 4 e sempre che i programmi non si riferiscano al mantenimento delle dotazioni o al ripianamento delle scorte, gli schemi di decreto di cui al periodo precedente sono trasmessi alle Camere per l'espressione del parere delle Commissioni competenti. I pareri sono espressi entro quaranta giorni dalla data di assegnazione. Decorso inutilmente il termine per l'espressione del parere, i decreti possono essere adottati. Il Governo, qualora non intenda conformarsi alle condizioni formulate dalle Commissioni competenti, ovvero quando le stesse Commissioni esprimano parere contrario, trasmette nuovamente alle Camere gli schemi di decreto corredati delle necessarie controdeduzioni per i pareri definitivi delle Commissioni competenti da esprimere entro trenta giorni dalla loro assegnazione. In tal caso, qualora entro il termine indicato le Commissioni competenti esprimano sugli schemi di decreto parere contrario a maggioranza assoluta dei componenti, motivato con riferimento alla mancata coerenza con il piano di impiego pluriennale di cui al comma 1, il programma non puo' essere adottato. In ogni altro caso, il Governo puo' procedere all'adozione dei decreti. Gli schemi di decreto sono trasmessi anche alle Commissioni parlamentari competenti per i profili finanziari.

4. I piani di spesa gravanti sugli ordinari stanziamenti di bilancio, ma destinati al completamento di programmi pluriennali finanziati nei precedenti esercizi con leggi speciali, se non richiedono finanziamenti integrativi, sono sottoposti dal Ministro della difesa al Parlamento in apposito allegato al piano di impiego pluriennale di cui al comma 1.

5. L'attivita' contrattuale relativa ai programmi di cui al comma 3 e ai piani di spesa di cui al comma 4 e' svolta dalle competenti ((strutture)) del Ministero della difesa.

### Art. 536-bis. - (( (Verifica dei programmi di ammodernamento e rinnovamento dei sistemi d'arma). ))

((

1. Il Capo di stato maggiore della difesa, sulla base degli obiettivi e degli indirizzi definiti dal Ministro della difesa ai sensi dell'articolo 14, comma 1, del decreto legislativo 30 marzo 2001, n. 165, ferma restando la necessita' di salvaguardare le esigenze operative prioritarie e quelle derivanti dal processo di definizione della politica europea di difesa e sicurezza, procede alla verifica della rispondenza dei programmi di ammodernamento e rinnovamento dei sistemi d'arma e propone al Ministro della difesa la rimodulazione dei programmi relativi a linee di sviluppo capacitive che risultino non piu' adeguate, anche in ragione delle disponibilita' finanziarie autorizzate a legislazione vigente. La predetta verifica tiene altresi' conto dei risultati conseguiti nell'attuazione del processo di riconfigurazione dello strumento militare riportati nel documento di cui all'articolo 4, comma 1, lettera a), della legge 31 dicembre 2012, n. 244.

2. Gli schemi dei decreti che approvano la rimodulazione di programmi sui quali e' stato espresso il parere delle Commissioni parlamentari competenti ai sensi dell'articolo 536, comma 3, lettera b), sono sottoposti a tale parere.

3. Dalle rimodulazioni di cui al comma 1 non devono derivare nuovi o maggiori oneri a carico della finanza pubblica, anche in termini di indebitamento netto.

4. Le eventuali disponibilita' finanziarie emergenti a seguito delle rimodulazioni di cui al comma 1 sono destinate, previa verifica dell'invarianza sui saldi di finanza pubblica da parte del Ministero dell'economia e delle finanze-Dipartimento della Ragioneria generale dello Stato, alle finalita' di cui all'articolo 4, comma 1, lettera c), della legge 31 dicembre 2012, n. 244.

))

### Art. 537. - Programmi con la partecipazione o collaborazione di Paesi esteri

1. Se i rapporti contrattuali derivanti dall'attuazione dei programmi di cui all'articolo 536 implicano la partecipazione o, comunque, la collaborazione di Paesi esteri, direttamente o per il tramite di agenzie o enti plurinazionali, il Ministro della difesa e' autorizzato a stipulare contratti o comunque ad assumere impegni nei limiti dell'intera somma, considerando a questi fini anche gli importi da riassegnare a bilancio ai sensi dell'articolo 549.

### Art. 537-bis. - (( (Semplificazione delle procedure per la realizzazione dei programmi di investimento di interesse dell'Amministrazione della difesa). ))

((

1. Ai fini della semplificazione delle procedure per la realizzazione dei programmi di investimento di interesse dell'Amministrazione della difesa, finanziati mediante contributi pluriennali, il decreto di cui all'articolo 4, comma 177-bis, della legge 24 dicembre 2003, n. 350, e successive modificazioni, e' adottato, previo parere delle competenti Commissioni parlamentari, dal Ministro dello sviluppo economico, di concerto con i Ministri dell'economia e delle finanze e della difesa. Con tale decreto si provvede a:

- a) definire le modalita' di attuazione dei programmi, in sostituzione delle convenzioni di cui all'articolo 5, comma 1, del decreto-legge 17 giugno 1996, n. 321, convertito, con modificazioni, dalla legge 8 agosto 1996, n. 421;
- b) fissare, se necessario, il tasso di interesse massimo secondo le modalita' di cui all'articolo 45, comma 32, della legge 23 dicembre 1998, n. 448, e successive modificazioni, che puo' essere successivamente rideterminato dal Ministero dell'economia e delle finanze, ove occorra;
- c) verificare l'assenza di effetti peggiorativi sul fabbisogno e sull'indebitamento netto, rispetto a quelli previsti dalla legislazione vigente, ovvero quantificarli per la successiva compensazione ai sensi dell'articolo 4, comma 177-bis, della legge n. 350 del 2003, e successive modificazioni.

))

### Art. 537-ter. - (Cooperazione con altri Stati per i materiali di armamento prodotti dall'industria nazionale)

1. Il Ministero della difesa, nel rispetto dei principi, delle norme e delle procedure in materia di esportazione di materiali d'armamento di cui alla legge 9 luglio 1990, n. 185, d'intesa con il Ministero degli affari esteri e con il Ministero dell'economia e delle finanze, al fine di soddisfare esigenze di approvvigionamento di altri Stati esteri con i quali sussistono accordi di cooperazione o di reciproca assistenza tecnico-militare, puo' svolgere ((,)) tramite proprie articolazioni e senza assunzione di garanzie di natura finanziaria, attivita' contrattuale e di supporto tecnico-amministrativo per l'acquisizione di materiali di armamento prodotti dall'industria nazionale anche in uso alle Forze armate e per le correlate esigenze di sostegno logistico e assistenza tecnica, richiesti dai citati Stati, nei limiti e secondo le modalita' disciplinati nei predetti accordi.

2. Con regolamento adottato, ai sensi dell'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, su proposta del Ministro della difesa di concerto con il Ministro degli affari esteri e il Ministro dell'economia e delle finanze, previo parere delle Commissioni parlamentari competenti, e' definita la disciplina esecutiva e attuativa delle disposizioni di cui al presente articolo.

3. Le somme percepite per il rimborso dei costi sostenuti per le attivita' di cui al comma 1 sono versate all'entrata del bilancio dello Stato per essere integralmente riassegnate ai fondi di cui all'articolo 619.

## CAPO III - SEMPLIFICAZIONE E ACCELERAZIONE DELLE PROCEDURE CONTRATTUALI

### Art. 538. - Principi sulle procedure contrattuali

1. Le procedure contrattuali per l'acquisto di beni e servizi da parte dell'Amministrazione della difesa sono improntate a tempestivita', trasparenza e correttezza nel rispetto delle leggi vigenti e della normativa comunitaria.

### Art. 538-bis. - (Contratti relativi alle missioni internazionali)

1. Al fine di garantire, senza soluzione di continuita' ((, i servizi di assicurazione, di trasporto e di vettovagliamento, gli interventi infrastrutturali, l'approvvigionamento di carbolubrificanti e di munizionamento, nonche' l'acquisto e la manutenzione di equipaggiamenti, mezzi, sistemi d'arma, sistemi per il comando e controllo, sistemi per le comunicazioni, sistemi per la raccolta informativa, sistemi per la ricognizione e sorveglianza, sistemi cyber e impianti di telecomunicazioni, comprensivi delle scorte,)) finanziati dai provvedimenti di autorizzazione e proroga delle missioni internazionali delle Forze armate, il Ministero della difesa e' autorizzato ad avviare, ((anche)) nell'anno precedente il finanziamento, le procedure di affidamento dei relativi contratti fino alla fase di stipulazione compresa, mentre resta fermo che puo' procedere all'approvazione dei contratti e all'impegno delle relative spese solo al momento del perfezionamento delle procedure contabili di allocazione delle risorse finanziarie derivanti dai menzionati provvedimenti di autorizzazione e proroga delle missioni internazionali sui pertinenti capitoli del relativo stato di previsione della spesa.

### Art. 539. - Semplificazione in ordine a determinati pareri

1. Le disposizioni di cui all'articolo 3, comma 3, del decreto legislativo 1° dicembre 2009, n. 177, relative al parere obbligatorio di ((Agenzia per l'Italia Digitale)), non trovano applicazione relativamente ai progetti di contratto riguardanti sistemi informativi militari a carattere operativo connessi con lo svolgimento di compiti concernenti la difesa nazionale.

### Art. 540. - Poteri di spesa

1. Per il conseguimento degli obiettivi loro affidati, i Comandanti dei comandi periferici di Forza armata o interforze con funzioni logistiche e amministrative, nonche' gli ufficiali generali ((e ammiragli e gli ufficiali superiori delle Forze armate)) preposti a organismi militari provvisti di autonomia amministrativa, esercitano i poteri di spesa nei limiti dei fondi loro assegnati per la realizzazione di ciascun programma.

### Art. 541. - Termini dei pagamenti e piani di consegna

1. I contratti di fornitura di beni e servizi concernenti sistemi d'arma e apparecchiature funzionalmente correlate, aventi termini di consegna o di esecuzione superiori ai due anni, e i contratti relativi a lavori pubblici di importo eccedente quello indicato per i lavori dall'articolo 28 del decreto legislativo 12 aprile 2006, n. 163, ((e dall'articolo 10 del decreto legislativo 15 novembre 2011, n. 208,)) possono prevedere la corresponsione di pagamenti, previa costituzione di idonea garanzia, sulla base della progressione dell'esecuzione delle prestazioni e dei conseguenti obiettivi quantitativi raggiunti, nei termini contrattualmente definiti. Tali pagamenti non possono comunque eccedere la misura complessiva del 90 per cento dell'importo contrattuale.

2. I termini entro i quali sono effettuati i pagamenti delle prestazioni contrattuali sono indicati nei capitolati generali di oneri applicabili.

2-bis. Il Ministro della difesa, compatibilmente con quanto statuito in sede contrattuale ovvero di accordi internazionali comunque denominati in materia di programmi militari di investimento, puo' autorizzare il differimento del piano di consegna dei relativi mezzi e sistemi d'arma, senza nuovi o maggiori oneri a carico della finanza pubblica.

### Art. 542. - Tempestivita' dei pagamenti per forniture di materiali destinati alle Forze armate

1. Al fine di garantire, attraverso la semplificazione dei correlati adempimenti amministrativi, la tempestivita' dei pagamenti per le forniture di materiali destinati alle Forze armate, relativi ad attivita' operative o addestrative svolte in territorio nazionale o all'estero, l'Amministrazione della difesa e' autorizzata a corrispondere pagamenti in conto nella misura massima del 90 per cento del valore delle forniture ((accettate a seguito della verifica di conformita' e consegnate)).

### Art. 543. - Contratti di manutenzione e riparazione di sistemi d'arma

1. I contratti di manutenzione e riparazione di sistemi d'arma e apparecchiature funzionalmente correlate possono prevedere che nel corso dell'esecuzione siano individuate ulteriori particolari prestazioni e forniture di materiali, da eseguire per soddisfare necessita' urgenti e imprevedibili.

2. Le prestazioni e le forniture di cui al comma 1, fermo restando l'importo complessivo del contratto, non possono in ogni caso eccedere il quinto di detto importo.

### Art. 544. - Sostegno logistico dei contingenti impiegati in missioni internazionali

1. Per soddisfare le esigenze di approvvigionamento di beni e servizi necessari per il sostegno logistico dei contingenti delle Forze armate impiegati in missioni internazionali, o in qualunque modo connessi con tali esigenze, e' autorizzato il ricorso, in caso di necessita' e urgenza, alla Nato Maintenance and Supply Agency, sulla base di accordi quadro appositamente stipulati e nell'ambito dei fondi stanziati per tali esigenze.

2. Il ricorso alla NATO Maintenance and Supply Agency previsto dal comma 1 e' esteso agli approvvigionamenti di beni e servizi comunque connessi al sostegno logistico dei contingenti delle Forze armate impiegati in operazioni fuori dal territorio nazionale condotte sotto l'egida dell'ONU o di altri organismi sovranazionali.

### Art. 544-bis. - (( (Acquisizioni nell'ambito delle attivita' di politica militare). ))

((

1. Per le iniziative aventi finalita' di mantenimento della pace e della sicurezza internazionale, nonche' per le iniziative umanitarie e di tutela dei diritti umani, il Ministero della difesa, nel rispetto delle disposizioni in materia di contratti pubblici e nei limiti delle risorse assegnate, e' autorizzato, per la successiva cessione a titolo gratuito, all'acquisizione dei materiali di cui all'articolo 447, comma 1, lettera o), del regolamento, e di servizi nonche' alla realizzazione di lavori e opere, ad esclusione dei materiali di cui all'articolo 2 della legge 9 luglio 1990, n. 185.

2. Con uno o piu' provvedimenti del Capo di stato maggiore della difesa e' definito l'elenco dei materiali, dei servizi, dei lavori e delle opere di cui al comma 1, anche ai fini delle procedure in materia di scarico contabile))

## CAPO IV - PERMUTE

### Art. 545. - Permute

1. Ai fini del contenimento delle spese di ricerca, potenziamento, ammodernamento, manutenzione e supporto relative ai mezzi, sistemi, materiali e strutture in dotazione alle Forze armate, il Ministero della difesa, anche in deroga alle norme sulla contabilita' generale dello Stato e nel rispetto della legge 9 luglio 1990, n. 185, e' autorizzato a stipulare convenzioni e contratti ((, anche per il tramite della societa' di cui all'articolo 535,)) per la permuta di materiali o prestazioni con soggetti pubblici e privati.

2. Il regolamento, su cui per tale parte e' acquisito il concerto del Ministro dell'economia e delle finanze, disciplina le condizioni e le modalita' per la stipula degli atti e l'esecuzione delle prestazioni, nel rispetto della vigente disciplina in materia negoziale e del principio di economicita'.

## CAPO V - SERVIZIO DI MENSA

### Art. 546. - Servizio di vettovagliamento delle Forze armate

1. Il servizio di vettovagliamento sostituisce le razioni viveri in natura, le quote miglioramento vitto, le integrazioni vitto e i generi di conforto in speciali condizioni di impiego, nonche' ogni altra forma di fornitura di alimenti a titolo gratuito.

2. Le modalita' di fornitura del servizio di vettovagliamento a favore del personale militare sono stabilite con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, da adottare entro il 30 settembre di ogni anno con riferimento all'anno successivo. Con il medesimo decreto sono determinati il valore in denaro delle razioni viveri e del miglioramento vitto, nonche' la composizione dei generi di conforto.

3. Il servizio di vettovagliamento e' assicurato, in relazione alle esigenze operative, logistiche, di dislocazione e di impiego degli enti e reparti delle Forze armate, nelle seguenti forme:

- a) gestione diretta, ovvero affidata, in tutto o in parte, a privati mediante apposite convenzioni, ovvero appaltando il servizio a ditte private specializzate, nel rispetto del decreto legislativo 12 aprile 2006, n. 163;
- b) fornitura di buoni pasto;
- c) fornitura di viveri speciali da combattimento.

4. La gestione diretta e le eventuali convenzioni sono finanziate mediante utilizzo, anche in modo decentrato, del controvalore in contanti dei trattamenti alimentari determinati con il decreto di cui al comma 2.

5. Il regolamento, in tale parte adottato di concerto con il Ministro dell'economia e delle finanze, e su proposta dei Capi di stato maggiore di forza armata e del Comandante generale dell'Arma dei carabinieri e del Corpo della Guardia di finanza, ((sentite le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)), detta norme interforze per disciplinare la struttura, l'organizzazione e il funzionamento delle mense di servizio.

## CAPO VI - CONCESSIONI DI BENI

### Art. 547. - Concessioni per gli interventi di protezione sociale e per le attivita' connesse

1. Al fine di assicurare gli interventi di protezione sociale a favore del personale militare e civile delle Forze armate e dei loro familiari, sono concessi in uso alle organizzazioni costituite tra il personale dipendente ai sensi dell'articolo 1475, oppure a enti e terzi, i locali demaniali, i mezzi, le strutture, i servizi e gli impianti necessari per i predetti interventi. Con il regolamento, di concerto con il Ministro dell'economia e delle finanze, sono determinati le consistenze e il valore di tali apporti nonche' le relative norme d'uso.

2. Per l'esercizio delle attivita' connesse con gli interventi di protezione sociale di cui al comma 1, l'Amministrazione della difesa provvede mediante affidamento in concessione alle organizzazioni di cui al comma 1, oppure a enti e terzi, previo esperimento di indagini comparative secondo le procedure in economia applicabili alla Difesa e con le modalita' che sono stabilite con il regolamento, di concerto con il Ministro dell'economia e delle finanze.

## TITOLO III BILANCIO, NORME DI SPESA, FONDI DA RIPARTIRE CAPO I BILANCIO

### SEZIONE I - FORMAZIONE DEL BILANCIO

#### Art. 548. - Relazioni illustrative sullo stato di attuazione dei programmi

1. ((Il Ministro della difesa, entro il termine di presentazione del disegno di legge di bilancio,)) trasmette al Parlamento relazioni illustrative:

- a) sulla spesa complessiva prevista per il personale militare, con indicazione degli oneri riferiti al personale in servizio permanente e a quello in servizio non permanente, distinguendo, altresi', i dati per grado e per stato giuridico, nell'ambito delle aree tecnico-operativa e tecnico-amministrativa della Difesa;
- b) sullo stato di attuazione dei programmi di costruzione, acquisizione e ammodernamento di mezzi, impianti e sistemi, di cui ai pertinenti capitoli dello stato di previsione del Ministero della difesa. Per ciascun programma sono indicati l'esigenza operativa, l'oggetto, la quantita', l'onere globale, lo sviluppo pluriennale e la percentuale di realizzazione; sono, altresi', fornite indicazioni sui rapporti tra acquisti compiuti all'estero e in Italia e sulla quota di questi effettuata nel Mezzogiorno;
- c) sull'attivita' contrattuale concernente la manutenzione straordinaria e il reintegro dei sistemi d'arma, delle opere, dei mezzi e dei beni direttamente destinati alla difesa nazionale, che si espleta secondo programmi aventi di norma durata annuale, in relazione alle quote da impegnare sugli appositi capitoli dello stato di previsione del Ministero della difesa;
- d) sullo stato di attuazione del programma di potenziamento e ammodernamento delle infrastrutture, con particolare riguardo agli alloggi dei militari di truppa, ai locali adibiti a cucine, mense e ad attivita' del tempo libero, e idoneo a garantire attivita' di promozione sociale e sportiva, al quale si fa fronte mediante gli ordinari stanziamenti di bilancio, specificando, nell'ambito dei pertinenti capitoli dello stato di previsione del Ministero della difesa, le quote da destinare alla realizzazione del programma medesimo;
- e) sui programmi, di competenza del Ministero della difesa, attuati ai sensi della legge 11 novembre 1986, n. 770.

### SEZIONE II - GESTIONE DEL BILANCIO

#### Art. 549. - Riassegnazione di entrate a bilancio

1. Per le spese che l'Amministrazione militare sostiene nell'interesse di altre amministrazioni dello Stato, queste devono anticipare i fondi occorrenti versandoli in tesoreria, con imputazione a uno speciale capitolo dell'entrata per essere portati in aumento allo stato di previsione del Ministero della difesa, tenuto conto dei limiti alle riassegnazioni di bilancio di cui all'articolo 2, comma 615, della legge 24 dicembre 2007, n. 244.

2. Allo stesso modo, le somme dovute da privati, per prestazioni di qualsiasi specie, quelle per il mantenimento degli allievi nelle scuole militari nonche' quelle previste dal comma 3 dell'articolo 159 del regio decreto 23 maggio 1924, n. 827, sono versate in tesoreria e portate in aumento ai capitoli dello stato di previsione del Ministero della difesa.

#### Art. 549-bis. - (Concorsi a titolo oneroso resi dalle Forze armate).

1. Al fine di garantire il rimborso dei concorsi a titolo oneroso resi dalle Forze armate per attivita' di protezione civile, nei casi non soggetti a limitazioni ai sensi della legislazione vigente, possono essere disposte una o piu' aperture di credito, anche su diversi capitoli di bilancio, a favore di uno o piu' funzionari delegati nominati dal Ministero della difesa, per provvedere al ripianamento degli oneri direttamente o indirettamente sostenuti e quantificati sulla base delle tabelle di onerosita' predisposte dallo stesso Ministero. Agli ordini di accreditamento di cui al primo periodo si applica l'articolo 279, primo comma, del regolamento di cui al regio decreto 23 maggio 1924, n. 827. Per le modalita' di gestione dei fondi accreditati e le modalita' di presentazione dei rendiconti amministrativi si applicano le disposizioni di cui all'articolo 8, comma 4, del regolamento di cui al decreto del Presidente della Repubblica 20 aprile 1994, n. 367. Gli ordini di accreditamento disposti dopo la data del 30 settembre di ciascun anno, non estinti al termine dell'esercizio finanziario, possono essere trasportati all'esercizio successivo.

((

1-bis. Il Ministero della difesa e' autorizzato a garantire lo svolgimento di attivita' concorsuali a favore delle altre pubbliche amministrazioni secondo le modalita' di cui al comma 1 nei limiti finanziari disposti dall'articolo 2, commi 615 e 617, della legge 24 dicembre 2007, n. 244.

))

### SEZIONE III - GESTIONE DELLA SPESA

#### Art. 550. - Somministrazione dei fondi

1. A favore delle direzioni di amministrazione sono disposte aperture di credito da commutarsi in quietanze di entrata a valere sulle contabilita' speciali, aperte presso le tesorerie provinciali:

- a) per il pagamento degli emolumenti al personale;
- b) per il pagamento dei fornitori e degli altri creditori.

2. Le aperture di credito ((sono soggette ai controlli preventivi di cui all'articolo 5 del decreto legislativo 30 giugno 2011, n. 123 e)) devono contenere, oltre all'indicazione della somma, quella del numero e della denominazione del capitolo del bilancio sul quale sono effettuate, nonche' la clausola di commutabilita' a favore delle contabilita' speciali.

((

2-bis. Il regolamento individua, in coerenza con l'articolo 60 del regio decreto 18 novembre 1923, n. 2440, e con i principi recati dal decreto legislativo 30 giugno 2011, n. 123, le forme di controllo cui debbono essere sottoposti gli atti di spesa discendenti delle aperture di credito di cui al comma 2.

))

### SEZIONE IV - DISPOSIZIONI VARIE

#### Art. 551. - Fondo scorta

1. Nello stato di previsione del Ministero della difesa e' istituito un fondo, per le esigenze delle Forze armate e per quelle dell'Arma dei carabinieri, destinato a provvedere alle momentanee deficienze di cassa presso i corpi, istituti e stabilimenti militari, rispetto alle periodiche anticipazioni loro fatte sugli stanziamenti di bilancio.

2. Lo stanziamento del fondo e' determinato annualmente con la legge di bilancio.

3. L'utilizzo del fondo e' disciplinato dal regolamento.

## CAPO II - NORME DI SPESA

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 552. - Speciale capitolo per particolari deficienze di cassa

1. Le deficienze di cassa dipendenti da forza maggiore o anche da dolo o negligenza di agenti dell'amministrazione sono ripianate a carico di uno speciale capitolo dello stato di previsione del Ministero della difesa, senza pregiudizio del regolare procedimento per l'accertamento delle eventuali responsabilita'.

#### Art. 553. - Spese di natura riservata

1. Per sopperire alle spese di natura riservata e' assegnata agli organi di vertice, allo Stato maggiore della difesa, al Segretariato generale della difesa ((e alla Direzione nazionale degli armamenti)), agli Stati maggiori di Forza armata e agli altri organi centrali del Ministero della difesa, una somma stabilita annualmente con decreto ministeriale, nell'ambito dello stanziamento determinato con legge di bilancio. Per l'Arma dei carabinieri, l'assegnazione della somma di cui al presente articolo e' disposta con decreto ministeriale concernente attribuzione delle risorse ai sensi dell'articolo 14, comma 1, lettera b), del decreto legislativo 30 marzo 2001, n. 165.

### SEZIONE II - NORME DI SPESA IN RELAZIONE AL LIBRO I

#### Art. 554. - Spese di funzionamento del Consiglio supremo della difesa

1. Le spese per il funzionamento del Consiglio supremo di difesa gravano su apposito capitolo iscritto nello stato di previsione del Ministero della difesa, il cui stanziamento e' determinato con legge di bilancio.

#### Art. 555. - Oneri per subentro del Ministero della difesa nei rapporti di lavoro del Circolo Ufficiali delle Forze armate

1. All'onere derivante dall'attuazione dell'articolo 19, comma 4, per il subentro del Ministero della difesa in tutti i rapporti di lavoro in essere a tempo indeterminato alle dipendenze del Circolo Ufficiali delle Forze armate, valutato in euro 250.000,00 a decorrere dall'anno 2010, si provvede nell'ambito degli stanziamenti di bilancio previsti a legislazione vigente per il reclutamento del personale relativo al Ministero della difesa e nel rispetto dei limiti in materia di assunzioni di personale a tempo indeterminato di cui all'articolo 3, comma 102, della legge 24 dicembre 2007, n. 244.

#### Art. 556. - Spese di funzionamento di organi consultivi

1. Fermo restando quanto previsto dall'articolo 1, comma 58, della legge 23 dicembre 2005, n. 266, la spesa complessiva degli organismi di cui ((agli articoli 24, comma 1, lettera a) e 24-bis, ivi compresi gli oneri di funzionamento,)) e' ridotta del trenta per cento rispetto a quella sostenuta nell'esercizio finanziario 2005.

2. E' fatto salvo quanto disposto dagli articoli 61, comma 1, e 68, comma 2, secondo periodo, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133 ((e 12, comma 20, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135)).

#### Art. 557.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 7))

#### Art. 558. - Uffici degli addetti delle Forze armate in servizio all'estero

1. Per esigenze eccezionali degli uffici degli addetti delle Forze armate, il Ministero della difesa puo' autorizzare l'assunzione di personale a tempo determinato da adibire a mansioni esecutive, con contratti di durata non superiore all'anno, con possibilita' di rinnovo, regolati dalle norme contenute nel decreto del Presidente della Repubblica 5 gennaio 1967, n. 18. I predetti contratti non conferiscono stabilita' di impiego ne' diritto a collocamento nei ruoli del personale dello Stato. E' fatta salva la possibilita' per il Ministero della difesa di utilizzare personale con contratto a tempo indeterminato assunto dall'Amministrazione degli affari esteri a norma del citato decreto.

2. Sono a carico dello stato di previsione del Ministero della difesa:

- a) le spese per la locazione dei locali di ufficio se questi non sono forniti dalla locale rappresentanza diplomatica, compresi gli oneri accessori. Il personale degli uffici degli addetti che abbia la propria abitazione annessa all'ufficio e' tenuto a rimborsare il canone di locazione dei locali adibiti ad abitazione, nella misura determinata dal Ministero della difesa di concerto con il Ministero dell'economia e delle finanze, sentito il capo della rappresentanza diplomatica, secondo i criteri fissati nell'articolo 84, comma 4, del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18;
- b) le altre spese di funzionamento entro i limiti stabiliti dal Ministero.

#### Art. 559. - Finanziamento dell'Agenzia industrie difesa

1. In relazione all'articolo 9, comma 4, lettera c), del decreto legislativo 30 luglio 1999, n. 300, il finanziamento annuale a favore dell'Agenzia industrie difesa, di cui all'articolo 48, e' determinato in apposita tabella, ai sensi dell'articolo 11, comma 3, lettera d), della legge 31 dicembre 2009, n. 196.

#### Art. 560. - Ordinamento giudiziario militare

1. Gli oneri derivanti dalle disposizioni sull'ordinamento giudiziario militare di cui al libro I, titolo III, capo VI, sezione I, gravano su appositi capitoli dello stato di previsione del Ministero della difesa.

#### Art. 561. - Funzionamento del Consiglio della magistratura militare

1. Gli oneri per il funzionamento del Consiglio della magistratura militare, di cui al libro I, titolo III, capo VI, sezione II, comprese le indennita' di seduta e le spese di missione per i componenti non magistrati militari, gravano su apposito capitolo dello stato di previsione del Ministero della difesa.

#### Art. 562. - Funzionamento della commissione per la tenuta del registro nazionale delle imprese operanti nel settore dei materiali di armamento

1. Agli oneri relativi al funzionamento della commissione per la tenuta del registro nazionale delle imprese e consorzi di imprese operanti nel settore della progettazione, produzione, importazione, esportazione, manutenzione e lavorazioni comunque connesse di materiale di armamento ((,trasferimenti e intermediazioni)) di cui all'articolo 44, si provvede a carico del Ministero della difesa.

#### Art. 563. - Collegio medico legale

1. L'onere derivante dalle disposizioni sul Collegio medico legale di cui all'articolo 189, grava sul pertinente capitolo di bilancio dello stato di previsione del Ministero della difesa.

#### Art. 564. - Spese di funzionamento

1. Le spese di funzionamento del Ministero della difesa sono annualmente determinate con la legge di bilancio.

#### Art. 565. - Contributo a favore dell'Organizzazione idrografica internazionale

1. Il contributo annuo dello Stato a favore dell'Organizzazione idrografica internazionale (IHO), con sede nel Principato di Monaco, di cui alla legge 15 novembre 1973, n. 925, da iscrivere su apposito capitolo dello stato di previsione del Ministero della difesa, e' determinato ai sensi dell'articolo 11, comma 3, lettera d), della legge 31 dicembre 2009, n. 196.

#### Art. 565-bis.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

### SEZIONE III - NORME DI SPESA IN RELAZIONE AL LIBRO II

#### Art. 566.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

#### Art. 567. - Stanziamenti e gestione dei fondi per i sepolcreti di guerra e sacrari equiparati

1. Le spese per l'attuazione dei compiti di cui all'articolo 267, ivi comprese tutte quelle connesse con le attivita' istituzionali e funzionali e con l'espletamento dei servizi e dei compiti attribuiti ((all'Ufficio per la tutela della cultura e della memoria della difesa)), gravano sui fondi stanziati su apposito capitolo dello stato di previsione del Ministero della difesa.

2. La gestione dei fondi e' demandata al ((capo dell'Ufficio)) il quale vi provvede con l'osservanza delle norme di cui al regio decreto 18 novembre 1923, n. 2440.

#### Art. 568. - Manutenzione degli alloggi di servizio, modalita' di riscossione del canone e sua destinazione

1. Il Ministero della difesa provvede, con gli stanziamenti iscritti su apposito capitolo del proprio stato di previsione, alla manutenzione ordinaria e straordinaria degli immobili di cui al libro II, titolo II, capo VII, sezione I, alla gestione degli edifici e al versamento dei relativi canoni, operando le conseguenti ritenute stipendiali per le somme dovute dai sublocatari da versare in tesoreria con imputazione al capo X delle entrate statali per la successiva riassegnazione allo stato di previsione del Ministero della difesa, ai sensi dell'articolo 549.

#### Art. 569. - Dotazioni finanziarie destinate agli indennizzi a privati e ai contributi a comuni e regioni

1. La spesa complessiva per indennizzi a privati e per contributi a comuni e regioni, derivante dall'articolo 325, comma 1, e dall'articolo 330, commi 1 e 2, e' determinata annualmente con legge di bilancio.

### SEZIONE IV - NORME DI SPESA IN RELAZIONE AI LIBRI IV E V

#### Art. 570. - Copertura finanziaria degli oneri derivanti dall'attuazione delle norme sullo stato degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. L'onere derivante dall'attuazione delle norme sullo stato giuridico degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare di cui al libro IV, titolo V, grava sui pertinenti capitoli dello stato di previsione del Ministero della difesa.

#### Art. 571. - Copertura finanziaria degli oneri derivanti dalla concessione della medaglia mauriziana al merito di dieci lustri di carriera militare

1. L'onere derivante dalla concessione della medaglia mauriziana al merito di dieci lustri di carriera militare di cui all'articolo 1459 e dall'estensione della stessa ai sottufficiali delle Forze armate, grava sul pertinente capitolo dello stato di previsione del Ministero della difesa.

2. L'onere derivante per la concessione della medaglia mauriziana al personale del Corpo della Guardia di finanza e' a carico del Ministero dell'economia e delle finanze.

#### Art. 572. - Copertura finanziaria degli oneri derivanti dall'istituzione della medaglia al merito aeronautico

1. L'onere derivante dall'istituzione della medaglia al merito aeronautico di cui all'articolo 1439, comma 2, grava sul pertinente capitolo dello stato di previsione del Ministero della difesa.

#### Art. 573. - Copertura finanziaria degli oneri derivanti dall'ammissione di militari stranieri alla frequenza di corsi presso istituti, scuole e altri enti militari delle Forze armate italiane

1. L'onere derivante dall'ammissione di militari stranieri alla frequenza di corsi presso istituti, scuole e altri enti militari delle Forze armate italiane di cui all'articolo 718, grava sui pertinenti capitoli dello stato di previsione del Ministero della difesa.

2. Nel quadro dei rapporti intercorrenti tra i vari Stati in materia di sviluppo sociale, tecnico e culturale, il Ministro della difesa e' autorizzato ad ammettere, annualmente, con proprio decreto, di concerto con il Ministro dell'economia e delle finanze, e nei limiti degli appositi stanziamenti, a frequentare corsi presso istituti, scuole e altri enti militari delle Forze armate italiane, assumendo in tutto o in parte a carico della Difesa le spese per la frequenza, il mantenimento, il vestiario, l'equipaggiamento e il materiale didattico, nonche' le spese per il viaggio dal Paese di provenienza alla sede designata, e viceversa, e per gli eventuali spostamenti connessi con lo svolgimento dei corsi, personale militare estero facente parte di Forze armate di Stati:

- a) nei confronti dei quali non sia in corso embargo deliberato in sede ONU o di Unione europea;
- b) nei confronti dei quali non siano state accertate, da parte delle Nazioni Unite o dell'Unione europea, violazioni della convenzione internazionale in materia di diritti dell'uomo;
- c) che non destinino, ricevendo dall'Italia assistenza allo sviluppo, al proprio bilancio militare risorse eccessive in relazione alle proprie esigenze di difesa.

3. Il Ministro della difesa e', altresi', autorizzato a concedere contributi per lo studio o per il perfezionamento al personale militare e civile delle Forze armate estere ammesso a frequentare in Italia corsi di studio a titolo gratuito.

#### Art. 574. - Copertura finanziaria degli oneri derivanti dal riordino della banda musicale dell'Arma dei carabinieri

1. L'onere derivante dal riordino della banda musicale dell'Arma dei carabinieri grava sul pertinente capitolo dello stato di previsione del Ministero della difesa.

#### Art. 575. - Oneri per il riordino dei ruoli, modifica alle norme di reclutamento, stato e avanzamento del personale non direttivo e non dirigente delle Forze armate

1. All'onere derivante dal riordino dei ruoli e dalla modifica delle norme sul reclutamento, sullo stato e sull'avanzamento del personale non direttivo e non dirigente delle Forze armate, di cui al libro IV, titolo II, capi IV, V, VI, VII sezione III, e capo VIII; titolo III, capi V, VI, VII, VIII, IX e X; titolo IV, capi III, IV, V e VI; titolo VII, capi XIII, XIV e XV, si provvede ai sensi dell'articolo 1 della legge 29 aprile 1995, n. 130.

#### Art. 576. - Oneri per l'attribuzione del grado di vertice per alcuni ruoli

1. L'onere derivante dall'attuazione dell'articolo 1095 grava sui pertinenti capitoli dello stato di previsione del Ministero della difesa.

#### Art. 577. - Oneri per il riordino del reclutamento, dello stato giuridico e dell'avanzamento degli ufficiali dell'Arma dei carabinieri

1. All'onere derivante dal riordino del reclutamento, dello stato giuridico e dell'avanzamento degli ufficiali dell'Arma dei carabinieri, di cui al libro IV, titolo II, capo II, sezione III; titolo III, capo II, sezione V; titolo VII, capo X, si provvede con le risorse finanziarie previste dall'articolo 8 della legge 31 marzo 2000, n. 78.

#### Art. 578. - Copertura finanziaria degli oneri derivanti da disposizioni integrative e correttive in materia di riordino dei ruoli, modifica alle norme di reclutamento, stato e avanzamento del personale non direttivo e non dirigente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. L'onere derivante dalle disposizioni integrative e correttive in materia di riordino dei ruoli, di modifica delle norme sul reclutamento, sullo stato e sull'avanzamento del personale non direttivo e non dirigente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, contenute nel libro IV, titolo III, capi V e VII; titolo VII, capo XIII e capo XV, sezione II, e negli articoli 682, 691 e 704, e' valutato in euro 40.971.042,00 a decorrere dal 2008.

#### Art. 579. - Copertura finanziaria degli oneri derivanti da disposizioni integrative e correttive in materia di riordino dei ruoli, modifica alle norme di reclutamento, stato e avanzamento del personale non direttivo e non dirigente dell'Arma dei carabinieri

1. L'onere derivante dalle disposizioni integrative e correttive in materia di riordino dei ruoli, di modifica delle norme sul reclutamento, sullo stato e sull'avanzamento del personale non direttivo e non dirigente dell'Arma dei carabinieri, contenute nel libro IV, titolo III, capi VI, VIII e X; titolo VII, capo XIV e capo XV, sezione III, e negli articoli 683, 692, 693 e 706, e' valutato in euro 17.465.023,00 a decorrere dal 2008.

#### Art. 580. - Oneri per le consistenze organiche complessive dell'Arma dei carabinieri

1. In relazione alla necessita' di procedere alla progressiva sostituzione dei carabinieri ausiliari in deroga a quanto stabilito dall'articolo 39 della legge 27 dicembre 1997, n. 449, e' attivato un programma di arruolamento di contingenti annui di carabinieri in ferma quadriennale entro il limite di spesa di euro 60 milioni a decorrere dall'anno 2004, ferma rimanendo la necessita' di assicurare nei successivi esercizi finanziari la completa sostituzione del contingente di ausiliari.

2. In relazione alle esigenze di cui al comma 1, e fermo restando quanto ivi previsto, a decorrere dall'anno 2003 e' autorizzata l'ulteriore spesa di euro 17 milioni per l'arruolamento di un contingente aggiuntivo di carabinieri in ferma quadriennale ai sensi dell'articolo 800.

3. A completamento del programma di sostituzione dei carabinieri ausiliari di cui al comma 1, e fermo restando quanto previsto dal comma 2, l'Arma dei carabinieri e' autorizzata, nel limite di spesa di euro 300 milioni a decorrere dall'anno 2006, ad arruolare contingenti annui di carabinieri in ferma quadriennale ai sensi dell'articolo 800.

4. Per esigenze connesse con la prevenzione e il contrasto del terrorismo, anche internazionale, e della criminalita' organizzata, l'Arma dei carabinieri e' autorizzata, in deroga all'articolo 1, comma 95, della legge 30 dicembre 2004, n. 311, a effettuare reclutamenti straordinari, entro un limite di spesa di euro 10 milioni a decorrere dall'anno 2008.

#### Art. 581. - Copertura finanziaria degli oneri derivanti dall'armonizzazione del trattamento giuridico ed economico del personale delle Forze armate con quello delle Forze di polizia

1. L'onere derivante dalle modifiche apportate in materia di armonizzazione del trattamento giuridico ed economico del personale delle Forze armate con quello delle Forze di polizia di cui all'articolo 838, e' quantificato in euro 21.027.000,00 annui a decorrere dall'anno 2006.

#### Art. 582. - Oneri per la progressiva riduzione dell'organico complessivo delle Forze armate

1. Gli oneri derivanti dalla graduale riduzione a 190 mila unita' dell'organico delle Forze armate, a esclusione dell'Arma dei carabinieri, del Corpo della Guardia di finanza e del Corpo delle capitanerie di porto, a seguito della trasformazione progressiva dello strumento militare in professionale, sono determinati nei seguenti importi in euro:

- a) per l'anno 2009: 412.358.865,24;
- b) per l'anno 2010: 431.674.353,27;
- c) per l'anno 2011: 451.428.829,66;
- d) per l'anno 2012: ((403.330.620,21));
- e) per l'anno 2013: 467.671.399,13;
- f) per l'anno 2014: 474.695.212,96;
- g) per l'anno 2015: 482.597.003,52;
- h) per l'anno 2016: 488.742.840,62;
- i) per l'anno 2017: 495.327.666,08;
- l) per l'anno 2018: 503.229.456,64;
- m) per l'anno 2019: 509.814.282,10;
- n) per l'anno 2020 (regime): 511.131.247,19.

2. Fino all'anno 2020, se il tasso di incremento degli oneri individuato dal comma 1 risulta superiore al tasso di incremento del prodotto interno lordo a prezzi correnti, previsto nella decisione di finanza pubblica, come risultante dalle conseguenti deliberazioni parlamentari, la legge di stabilita' quantifica, ai sensi dell'articolo 11, comma 3, lettera h), della legge 31 dicembre 2009, n. 196, la quota dell'onere, relativo all'anno di riferimento, corrispondente alla differenza tra i due tassi di variazione.

#### Art. 583. - Oneri per le consistenze dei volontari in ferma prefissata e in rafferma

1. Gli oneri riferiti alle consistenze dei volontari in ferma prefissata e in rafferma dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, determinate con decreto del Ministro della difesa, di cui all'articolo ((2207)), sono stabiliti, secondo un andamento coerente con l'evoluzione degli oneri complessivamente previsti per l'anno di riferimento dall'articolo 582, nei seguenti importi in euro :

- a) per l'anno 2009: 333.945.955,41;
- b) per l'anno 2010: 330.737.195,75;
- c) per l'anno 2011: 292.549.996,80;
- d) per l'anno 2012: 284.872.024,13;
- e) per l'anno 2013: 281.626.174,47;
- f) per l'anno 2014: 273.897.364,51;
- g) per l'anno 2015: 265.871.323,32;
- h) per l'anno 2016: 259.069.932,78;
- i) per l'anno 2017: 254.063.870,19;
- l) per l'anno 2018: 243.183.877,39;
- m) per l'anno 2019: 227.313.529,85;
- n) per l'anno 2020: 194.689.505,99;
- o) per l'anno 2021: 153.827.384,36.

#### Art. 584. - Riduzione di oneri per le Forze armate

1. In coerenza con il processo di revisione organizzativa del Ministero della difesa e con la politica di riallocazione e ottimizzazione delle risorse, da perseguire anche mediante l'impiego in mansioni tipicamente operative del personale utilizzato per compiti strumentali, gli oneri previsti dagli articoli 582 e 583, sono ridotti del 7 per cento per l'anno 2009 e del 40 per cento a decorrere dall'anno 2010.

2. A decorrere dall'anno 2010, i risparmi di cui al comma 1 per la parte eccedente il 7 per cento, possono essere conseguiti in alternativa anche parziale alle modalita' ivi previste, mediante specifici piani di razionalizzazione predisposti dal Ministero della difesa in altri settori di spesa.

3. Dall'attuazione del comma 1 devono conseguire economie di spesa per un importo non inferiore a euro 304 milioni a decorrere dall'anno 2010. Al fine di garantire l'effettivo conseguimento degli obiettivi di risparmio di cui al presente comma, in caso di accertamento di minori economie, si provvede a ridurre le dotazioni complessive di parte corrente dello stato di previsione del Ministero della difesa a eccezione di quelle relative alle competenze spettanti al personale del dicastero medesimo.

3-bis. In aggiunta alle riduzioni previste dal comma 1 e agli effetti di risparmio correlati alla riduzione organica di cui all'articolo 2, comma 3, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, gli oneri previsti dagli articoli 582 e 583 del presente codice sono ulteriormente ridotti per complessivi 62,3 milioni di euro per l'anno 2015 ((, del 12 per cento dall'anno 2016 all'anno 2024 e del 15,58 per cento a decorrere dall'anno 2025)). Gli oneri previsti dall'articolo 585 del presente codice sono ridotti di euro 4.000.000 ((dall'anno 2018 all'anno 2025 e di euro 4.657.573 a decorrere dall'anno 2026)).

#### Art. 585. - Oneri per le consistenze dei volontari del Corpo delle capitanerie di porto

1. Gli oneri riferiti alle consistenze di ciascuna categoria dei volontari di truppa, determinate con decreto del Ministro della difesa, di cui all'articolo 2217, restano a carico del Ministero delle infrastrutture e dei trasporti e sono determinati negli importi in euro di seguito indicati:

- a) per l'anno 2009: 68.993.137,67;
- b) per l'anno 2010: 65.188.592,32;
- c) per l'anno 2011: 75.106.850,08;
- d) per l'anno 2012: 67.969.382,62;
- e) per l'anno 2013: 67.890.229,41;
- f) per l'anno 2014: 67.814.528,25;
- g) per l'anno 2015: 67.734.308,19;
- h) per l'anno 2016 e per l'anno 2017: 67.650.788,29;
- h-bis) per l'anno 2018: 69.597.638,29;
- h-ter) per l'anno 2019: 71.544.488,29;
- h-quater) per l'anno 2020: 73.491.338,29;
- h-quinquies) per l'anno 2021: 77.371.367,29;
- h-sexies) per l'anno 2022: 82.631.031,99;
- h-septies) per l'anno 2023: 88.748.197,04;
- h-octies) per l'anno 2024: 97.031.795,09; (101)
- h-novies) ((per l'anno 2025: 106.096.389,27;))
- h-decies) ((per l'anno 2026: 111.280.954,46;))
- h-undecies) ((per l'anno 2027: 115.270.142,94;))
- h-duodecies) ((per l'anno 2028: 117.930.173,98;))
- h-terdecies) ((per l'anno 2029: 118.460.976,13;))
- h-quaterdecies) ((per l'anno 2030: 118.986.677,33;))
- h-quinquiesdecies) ((per l'anno 2031: 119.875.431,92;))
- h-sexiesdecies) ((per l'anno 2032: 120.735.094,12;))
- h-septiesdecies) ((per l'anno 2033: 121.650.530,63;))
- h-duodevicies) ((per l'anno 2034: 122.812.631,53;))
- h-undevicies) ((per l'anno 2035: 123.878.731,64;))
- h-vicies) ((per l'anno 2036: 124.429.110,75;)) h-vicies semel) ((per l'anno 2037: 124.824.322,26;)) h-vicies bis) ((a decorrere dall'anno 2038: 125.108.190,75)). (11)(18)

--------------- AGGIORNAMENTO (11) La L. 12 novembre 2011, n. 183, ha disposto (con l'art. 4, comma 57) che "A decorrere dall'anno 2012 gli oneri previsti dall'articolo 585 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, sono ridotti di euro 7.053.093". --------------- AGGIORNAMENTO (18) La L. 24 dicembre 2012, n. 228 ha disposto (con l'art. 1, comma 66) che "Gli oneri previsti dall'articolo 585 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, sono ridotti di euro 10.249.763 per l'anno 2013 e di euro 7.053.093 a decorrere dall'anno 2014." --------------- AGGIORNAMENTO (101) Il D.L. 22 aprile 2023, n. 44, ha disposto (con l'art. 17, comma 1, alinea) che le presenti modifiche decorrono dal 1° gennaio 2024.

#### Art. 586. - Oneri per il reclutamento di personale docente presso le scuole di lingue estere

1. Al fine di salvaguardare l'operativita' dell'impiego delle Forze armate nelle missioni all'estero, assicurando la necessaria continuita' didattica nell'addestramento tecnico-linguistico del personale militare ivi destinato, in sede di prima applicazione e in deroga all'articolo 39 della legge 27 dicembre 1997, n. 449, e all'articolo 1, comma 95, della legge 30 dicembre 2004, n. 311, e' autorizzato il reclutamento del personale di cui all'articolo 1530, comma 2, fino al limite del 40 per cento del contingente ivi previsto, e comunque entro il limite di spesa di euro 416.245,00 annui, a decorrere dall'anno 2006, mediante procedura selettiva per titoli ed esami determinata con decreto del Ministro della difesa, sentiti il Ministro per la pubblica amministrazione e l'innovazione, il Ministro dell'economia e delle finanze e il Ministro dell'istruzione, dell'universita' e della ricerca.

2. La procedura selettiva di cui al comma 1 e' riservata a coloro che, alla data di scadenza del termine di presentazione delle relative domande, hanno maturato presso la Scuola di lingue estere dell'Esercito una specifica professionalita' nell'espletamento di attivita' di insegnamento equivalenti a quelle previste nelle aree funzionali stabilite dai contratti collettivi nazionali di lavoro del comparto scuola ovvero a quelle, inerenti alle stesse attivita', previste dalle direttive addestrative connesse all'applicazione di accordi internazionali, per un periodo complessivamente non inferiore a quattrocento settimane nel decennio precedente alla data predetta.

#### Art. 587. - Oneri per il trattamento economico al personale del servizio di assistenza spirituale

1. L'onere per il trattamento economico di attivita' e di quiescenza dell'Ordinario militare, del Vicario generale militare e degli ispettori, e' a carico dell'Amministrazione della difesa; per i cappellani militari, l'onere per il trattamento economico di attivita' e' a carico dell'Amministrazione presso cui gli stessi cappellani sono impiegati, quello di quiescenza e' a carico dell'Amministrazione della difesa.

### SEZIONE V - NORME DI SPESA IN RELAZIONE AL LIBRO VI

#### Art. 588. - Trattamento economico del personale militare

1. L'onere derivante dalla corresponsione degli istituti dell'omogeneizzazione stipendiale e dell'assegno funzionale per le Forze armate, e' valutato in euro 451,38 milioni annui a decorrere dall'anno 1991.

#### Art. 589. - Omogeneizzazione per le Forze armate

1. L'onere derivante dall'omogeneizzazione del trattamento economico di cui all'articolo 1802, e' valutato in euro 15.365.872,00 annui a decorrere dall'anno 2002.

#### Art. 589-bis. - (( (Incentivi agli ufficiali piloti in servizio permanente delle Forze armate e del Corpo della guardia di finanza).))

((

1. L'onere derivante dagli articoli 1803 e 2161, valutato in 4.018.034,60 euro a decorrere dall'anno 2002, grava sui pertinenti capitoli di bilancio del Ministero della difesa per le Forze armate e del Ministero dell'economia e delle finanze per il Corpo della guardia di finanza. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

))

#### Art. 590. - Incentivi al personale delle Forze armate addetto al controllo del traffico aereo

1. Per le finalita' di cui agli articoli 1804, 1816 e 2262, e' prevista la spesa annua di euro1.836.242,00 a decorrere dall'anno 2005.

#### Art. 591. - Indennita' di impiego operativo

1. L'onere derivante dalla corresponsione al personale militare delle indennita' di impiego operativo di cui alla legge 23 marzo 1983, n. 78, e' quantificato in euro 146,67 milioni annui a decorrere dall'anno 1983.

#### Art. 592. - Trattamento economico di missione e di trasferimento

1. La spesa annua per missioni e trasferimenti, da effettuare all'interno del territorio nazionale, non puo' superare quella prevista per tale finalita' nello stato di previsione del Ministero della difesa.

#### Art. 593. - Trasferimento d'autorita' del personale della Marina militare

1. L'onere derivante dall'applicazione della legge 12 febbraio 1974, n. 35, in materia di trasferimenti d'autorita' del personale della Marina militare, e' quantificato in euro 51.646,00 annui a decorrere dall'anno 1974.

#### Art. 594. - Indennita' di lungo servizio all'estero

1. All'onere derivante dalla corresponsione dell'assegno di lungo servizio all'estero e dell'indennita' speciale eventualmente riconosciuta, di cui all'articolo 1808, si provvede mediante gli stanziamenti iscritti nei capitoli stipendiali dello stato di previsione del Ministero della difesa.

#### Art. 595. - Indennita' di servizio all'estero presso rappresentanze diplomatiche

1. Il Ministero della difesa e' autorizzato a corrispondere al personale militare destinato a prestare servizio presso le rappresentanze diplomatiche italiane all'estero, le indennita', i contributi, gli indennizzi, gli assegni e le provvidenze di cui all'articolo 1809, nell'ambito delle risorse finanziarie stanziate sull'apposito capitolo dello stato di previsione del Ministero medesimo.

#### Art. 596. - Fondo per l'organizzazione e il funzionamento di servizi socio-educativi per la prima infanzia destinati alla popolazione minorile presso enti e reparti del Ministero della difesa

1. Per l'organizzazione e il funzionamento di servizi socio-educativi per la prima infanzia destinati ai minori di eta' fino a 36 mesi, presso enti e reparti del Ministero della difesa, e' istituito un fondo con una dotazione di euro 3 milioni per ciascuno degli anni 2008, 2009 e 2010.

((1-bis. Il fondo di cui al comma 1 e' finanziato per l'importo di 2 milioni di euro per l'anno 2015 e di 5 milioni di euro per ciascuno degli anni 2016 e 2017. Al relativo onere si provvede mediante corrispondente riduzione, per ciascuno degli anni 2015, 2016 e 2017, della quota nazionale del Fondo per lo sviluppo e la coesione, programmazione 2014-2020, di cui all'articolo 1, comma 6, della legge 27 dicembre 2013, n. 147. A decorrere dall'anno 2018, la dotazione del fondo di cui al comma 1 e' determinata annualmente ai sensi dell'articolo 11, comma 3, lettera d), della legge 31 dicembre 2009, n. 196))

2. La programmazione e la progettazione relativa ai servizi di cui al comma 1, nel rispetto delle disposizioni normative e regolamentari vigenti nelle regioni presso le quali sono individuate le sedi di tali servizi, e' effettuata in collaborazione con il Dipartimento per le politiche della famiglia della Presidenza del Consiglio dei ministri, sentito il comitato tecnico-scientifico del Centro nazionale di documentazione e di analisi per l'infanzia e l'adolescenza, di cui al decreto del Presidente della Repubblica 14 maggio 2007, n. 103.

3. I servizi socio-educativi di cui al comma 1 sono accessibili ((oltre che da minori figli di dipendenti dell'Amministrazione della difesa, anche da minori figli di dipendenti delle amministrazioni centrali e periferiche dello Stato, nonche' da minori figli di dipendenti delle amministrazioni locali e da minori che non trovano collocazione nelle strutture pubbliche comunali,)) e concorrono a integrare l'offerta complessiva del sistema integrato dei servizi socio-educativi per la prima infanzia e del relativo Piano straordinario di intervento di cui all'articolo 1, comma 1259, della legge 27 dicembre 2006, n. 296, come modificato dall'articolo 2, comma 457, della legge 24 dicembre 2007, n. 244.

### SEZIONE VI - NORME DI SPESA IN RELAZIONE AL LIBRO VII

#### Art. 597. - Speciale elargizione per i familiari di militari vittime del servizio

1. L'onere derivante dalla corresponsione della speciale elargizione ai familiari dei militari vittime del servizio di cui al libro VII, titolo III, capo IV, sezione I, e' valutato in euro 11.362.052,00 a decorrere dall'anno 1992.

#### Art. 598. - Pensione straordinaria ai decorati dell'Ordine militare d'Italia

1. L'onere derivante dalla corresponsione della pensione straordinaria ai decorati dell'Ordine militare d'Italia di cui all'articolo 1922, e' autorizzato nel limite di euro 1.397.661,00 a decorrere dall'anno 1985.

#### Art. 599. - Indennizzo privilegiato aeronautico

1. L'onere derivante dalla corresponsione dell'indennizzo privilegiato aeronautico e' valutato in euro 345.000,00 a decorrere dall'anno 1981.

#### Art. 600. - Assegni straordinari annessi alle ricompense al valor militare

1. L'onere derivante dalla corresponsione degli assegni straordinari annessi alle ricompense al valor militare di cui agli articoli 1925 e 1926, e' valutato in euro 10.665.351,00 a decorrere dall'anno 1993.

#### Art. 601. - Provvidenze alle vittime di incidenti causati da attivita' istituzionali delle Forze armate

1. L'onere derivante dalla corresponsione delle provvidenze di cui all'articolo 1905, e' valutato in euro 51.646,00 annui a decorrere dal 1993.

#### Art. 602. - Provvidenze a favore dei cittadini deceduti o invalidati a causa di ordigni bellici in tempo di pace

1. L'onere derivante dalla corresponsione delle provvidenze di cui all'articolo 1906, a carico del Ministero dell'economia e delle finanze, e' valutato in euro 598.057,00 annui a decorrere dal 1994.

#### Art. 603. - Autorizzazione di spesa per indennizzi al personale italiano esposto a particolari fattori di rischio

((

1. Al fine di pervenire al riconoscimento della causa di servizio e di adeguati indennizzi al personale italiano che, in occasione o a seguito di missioni di qualunque natura effettuate entro e fuori i confini nazionali, abbia contratto infermita' o patologie tumorali per le particolari condizioni ambientali od operative, al personale impiegato nei poligoni di tiro e nei siti dove vengono stoccati munizionamenti, nonche' al personale civile italiano nei teatri operativi all'estero e nelle zone adiacenti alle basi militari sul territorio nazionale, che abbia contratto le stesse infermita' o patologie tumorali connesse alle medesime condizioni ambientali, e' autorizzata la spesa di 10 milioni di euro per ciascun anno del triennio 2008-2010. In caso di decesso a seguito delle citate infermita' o patologie tumorali, l'indennizzo e' corrisposto al coniuge, al convivente, ai figli superstiti, ai genitori, nonche' ai fratelli conviventi e a carico qualora siano gli unici superstiti.

2. I termini e le modalita' per la corresponsione, ai soggetti di cui al comma 1 ed entro il limite massimo di spesa ivi stabilito, delle misure di sostegno e tutela previste dalle leggi 13 agosto 1980, n. 466, 20 ottobre 1990, n. 302, 23 novembre 1998, n. 407, e 3 agosto 2004, n. 206, sono disciplinati dal libro VII del regolamento, fermo restando quanto disposto dall'articolo 7, comma 4, del decreto-legge 6 luglio 2010, n. 102, convertito, con modificazioni, dalla legge 3 agosto 2010, n. 126))

3. L'autorizzazione di spesa di cui al comma 1, puo' essere utilizzata, fino all'importo massimo complessivo di euro 3 milioni, per l'effettuazione degli accertamenti sanitari e di carattere ambientale strumentali al riconoscimento della causa di servizio e all'attribuzione dell'elargizione.

4. Il Ministero della difesa, di concerto con i Ministeri dell'interno, dell'economia e delle finanze e della salute, provvede al monitoraggio degli effetti derivanti dalle misure di cui al comma 2, che devono risultare nei limiti delle risorse stanziate sul capitolo 1331 dello stato di previsione del Ministero della difesa, per il triennio 2008-2010, ai sensi dell'autorizzazione di spesa di cui al comma 1. Cio' ai fini, nel caso di eventuali eccedenze di spesa, dell'adozione delle conseguenti correzioni per ricondurre la spesa complessiva entro i predetti limiti.

### SEZIONE VII - NORME DI SPESA IN RELAZIONE A SPECIFICI PROGRAMMI DI INVESTIMENTO

#### Art. 604. - Limiti di impegno per prototipi di sistemi e apparati per unita' navali di futura generazione

1. Ai sensi dell'articolo 8, comma 3, lettera c), della legge 30 novembre 1998, n. 413, sono autorizzati limiti di impegno della durata di quindici anni in ragione di euro 1.032.914,00 annui a decorrere dall'anno 1998 e di euro 1.549.371,00 annui a decorrere dall'anno 1999, destinati agli investimenti per la realizzazione di prototipi di sistemi e apparati per unita' navali di futura generazione di cui al comma 1, lettera c), dell'articolo medesimo.

#### Art. 605. - Rifinanziamento dei programmi di investimento

1. Per la prosecuzione degli interventi di cui all'articolo 4, comma 3, della legge 7 agosto 1997, n. 266, il Ministero della difesa e' autorizzato ad assumere impegni pluriennali corrispondenti alle rate di ammortamento dei mutui contratti dalle imprese fornitrici. A tal fine sono autorizzati limiti di impegno quindicennali di euro 12.394.966,00 dall'anno 1999, di euro 25.822.845,00 dall'anno 2000 e di euro 13.427.879,00 dall'anno 2001.

#### Art. 606. - Programmi interforze a elevato contenuto tecnologico

1. Per il finanziamento di programmi interforze a elevato contenuto tecnologico, connessi alle esigenze della difesa nel contesto dell'Unione europea, e' autorizzata la spesa, secondo quanto determinato dalla legge di stabilita', da iscrivere in apposito capitolo dello stato di previsione del Ministero della difesa.

#### Art. 607. - Prosecuzione dei principali programmi internazionali e interforze

1. Al fine di consentire la prosecuzione dei principali programmi internazionali e interforze, anche a valenza internazionale, e specialmente europea, idonei a promuovere qualificati livelli di partecipazione competitiva dell'industria nazionale, e' autorizzata la spesa annua di euro 55 milioni per quindici anni a decorrere dall'anno 2006 per l'erogazione di contributi pluriennali alle imprese nazionali di riferimento, ai sensi dell'articolo 4, comma 177, della legge 24 dicembre 2003, n. 350.

2. Lo stanziamento di cui al comma 1 e' iscritto nello stato di previsione del Ministero della difesa il quale con propri atti provvede all'individuazione sia delle procedure attuative per l'erogazione dei contributi sia delle imprese nazionali di riferimento cui corrispondere i contributi stessi.

#### Art. 608. - Altre spese di investimento

1. Altre spese di investimento del Ministero della difesa sono quantificate in euro 1.989 milioni per l'anno 2010 e rideterminate con la legge di bilancio per gli anni successivi.

## CAPO III - FONDI DA RIPARTIRE

### SEZIONE I - NORME DI RINVIO E FONDI DA RIPARTIRE DI CARATTERE GENERALE

#### Art. 609. - Normativa generale sui fondi da ripartire. Rinvio

1. Il Ministero della difesa si avvale delle risorse stanziate nei fondi, iscritti nello stato di previsione del Ministero dell'economia e delle finanze, previsti dalle vigenti leggi di contabilita' pubblica.

#### Art. 610. - Fondi di incentivazione del personale militare e civile

1. I fondi per l'incentivazione della produttivita' del personale militare appartenente alle Forze armate e del personale civile del Ministero della difesa sono disciplinati dai pertinenti accordi di concertazione e dalla contrattazione collettiva.

#### Art. 611. - Fondo da ripartire per provvedere a eventuali sopravvenute maggiori esigenze di spese per consumi intermedi

1. Si applica al Ministero della difesa la norma di cui all'articolo 23, comma 1, della legge 27 dicembre 2002, n. 289, che istituisce in ciascuno stato di previsione un fondo da ripartire nel corso della gestione per provvedere a eventuali sopravvenute maggiori esigenze di spese per consumi intermedi. ((11))

--------------- AGGIORNAMENTO (11) La L. 12 novembre 2011, n. 183, ha disposto (con l'art. 4, comma 23) che "La dotazione del Fondo di cui all'articolo 611 del codice dell'ordinamento militare di cui al decreto legislativo 15 marzo 2010, n. 66, e' ridotta per l'importo di 50 milioni a decorrere dall'anno 2013".

#### Art. 612. - Fondo da ripartire per finalita' per le quali non si da' luogo a riassegnazioni a bilancio

1. Si applicano al Ministero della difesa le disposizioni di cui all'articolo 2, commi 615, 616 e 617, della legge 24 dicembre 2007, n. 244, che istituiscono, negli stati di previsione dei Ministeri, appositi fondi da ripartire, con decreti del Ministro competente, di concerto con il Ministro dell'economia e delle finanze, in considerazione dell'andamento delle entrate versate per le quali non si da' luogo a riassegnazioni a bilancio.

### SEZIONE II - FONDI DA RIPARTIRE DI ESCLUSIVO INTERESSE DELLA DIFESA

#### Art. 613. - Fondo a disposizione

1. Per provvedere alle eventuali deficienze dei capitoli riguardanti le spese di cui all'articolo 550 e ai bisogni di cui all'articolo 552, e' istituito nello stato di previsione del Ministero della difesa un fondo a disposizione.

2. Il prelevamento di somme da tale fondo e la iscrizione nei capitoli suddetti e' fatta con decreto del Ministro dell'economia e delle finanze.

3. I capitoli a favore dei quali possono farsi prelevamenti dal detto fondo sono indicati in un elenco da annettersi allo stato di previsione del Ministero della difesa.

#### Art. 614. - Incremento del fondo per l'incentivazione della produttivita' del personale del Ministero della difesa

1. In relazione alle prioritarie e urgenti esigenze connesse all'intensificarsi delle attivita' di supporto alle Forze armate impiegate nelle missioni internazionali e ai conseguenti maggiori carichi di lavoro derivanti dall'accresciuta complessita' delle funzioni assegnate al personale in servizio presso il Ministero della difesa, e' autorizzata la spesa di euro 15 milioni a decorrere dal 2008, da destinare, attraverso la contrattazione collettiva nazionale integrativa, all'incentivazione della produttivita' del predetto personale, nella misura di un terzo in favore del personale appartenente alle aree professionali e della restante parte in favore del personale contrattualizzato appartenente alle aree funzionali.

2. E' fatto salvo quanto disposto dall'articolo 67, commi 2 e 3, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, nonche' dal decreto legislativo 27 ottobre 2009, n. 150.

2-bis. In relazione alle medesime esigenze di cui al comma 1, e' autorizzata la spesa di 21 milioni di euro per ciascuno degli anni ((2018, 2019, 2020 e 2021)), da destinare, attraverso la contrattazione collettiva nazionale integrativa, all'incentivazione della produttivita' del personale contrattualizzato appartenente alle aree funzionali del Ministero della difesa. Agli oneri di cui al presente comma si provvede, per ciascuno degli anni ((2018, 2019, 2020 e 2021)), mediante quota parte dei risparmi di cui all'articolo 11, comma 5, lettera b), del decreto legislativo 29 maggio 2017, n. 94.

#### Art. 615. - Fondo per esigenze di difesa nazionale

1. Per il finanziamento degli interventi a sostegno dell'economia nel settore dell'industria nazionale a elevato contenuto tecnologico e' istituito un apposito fondo iscritto nello stato di previsione del Ministero della difesa ((...)) per la realizzazione di programmi di investimento pluriennale per esigenze di difesa nazionale, derivanti anche da accordi internazionali. ((Per la dotazione del fondo si provvede ai sensi dell'articolo 21, comma 1-ter, lettera b),)) della legge 31 dicembre 2009, n. 196. Con uno o piu' decreti del Ministro della difesa, da comunicare al Ministero dell'economia e delle finanze, tramite l'Ufficio centrale del bilancio, e alla Corte dei conti, sono individuati, nell'ambito della predetta pianificazione, i programmi in esecuzione o da avviare con le disponibilita' del fondo, disponendo le conseguenti variazioni di bilancio. Con decreti del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, sono individuate le modalita' e le procedure di assunzione di spesa anche a carattere pluriennale per i programmi derivati da accordi internazionali.

#### Art. 616. - Fondo per l'efficienza dello strumento militare

1. Nello stato di previsione del Ministero della difesa e' istituito un fondo, in conto spese per il funzionamento, con particolare riguardo alla tenuta in efficienza dello strumento militare, mediante interventi di sostituzione, ripristino e manutenzione ordinaria e straordinaria di mezzi, materiali, sistemi, infrastrutture, equipaggiamenti e scorte, assicurando l'adeguamento delle capacita' operative e dei livelli di efficienza ed efficacia delle componenti militari, anche in funzione delle missioni internazionali.

2. Il fondo di cui al comma 1 e', altresi', alimentato con i pagamenti a qualunque titolo effettuati da Stati od organizzazioni internazionali, ivi compresi i rimborsi corrisposti dall'Organizzazione delle Nazioni Unite, quale corrispettivo direttamente collegato alle prestazioni rese dalle Forze armate italiane nell'ambito delle missioni internazionali. A tale fine non si applica l'articolo 1, comma 46, della legge 23 dicembre 2005, n. 266.

3. Il Ministro della difesa e' autorizzato con propri decreti, da comunicare al Ministero dell'economia e delle finanze, a disporre le relative variazioni di bilancio.

#### Art. 617. - Fondo destinato al pagamento dell'accisa sui prodotti energetici impiegati dalle Forze armate nazionali

1. Nello stato di previsione del Ministero della difesa e' istituito un fondo, destinato al pagamento dell'accisa sui prodotti energetici impiegati dalle Forze armate nazionali diverse dal Corpo della Guardia di finanza e dal Corpo delle capitanerie di porto - Guardia costiera, per gli usi consentiti.

2. Con decreto del Ministro della difesa, da comunicare al Ministero dell'economia e delle finanze tramite l'Ufficio centrale del bilancio, nonche' alle competenti Commissioni parlamentari e alla Corte dei conti, si provvede alla ripartizione del fondo fra i pertinenti capitoli dello stato di previsione del predetto Ministero.

#### Art. 618.

((Fondo per le missioni militari di pace))

1. Allo scopo di consentire la necessaria flessibilita' nell'utilizzo delle risorse di cui all'articolo 1, comma 1240, della legge 27 dicembre 2006, n. 296, e' istituito nello stato di previsione del Ministero della difesa, missione "Difesa e sicurezza del territorio", il programma "((Missioni militari di pace))", nel quale confluiscono in apposito fondo le autorizzazioni di spesa correlate alla prosecuzione delle missioni internazionali svolte al di fuori del territorio nazionale, autorizzate dall'autorita' gerarchicamente o funzionalmente sopra ordinata al dipendente.

2. In relazione alle specifiche esigenze da finanziare, il Ministro della difesa, con propri decreti da comunicare al Ministero dell'economia e delle finanze, e' autorizzato a disporre le necessarie variazioni di bilancio sui pertinenti capitoli di spesa, a valere sulle autorizzazioni di spesa confluite nel predetto fondo.

#### Art. 619. - Fondi in conto capitale e di parte corrente per la riallocazione di funzioni svolte presso infrastrutture in uso al Ministero della difesa individuate per la consegna all'Agenzia del demanio

1. Per le finalita' di cui all'articolo 307, comma 5, sono istituiti, nello stato di previsione del Ministero della difesa, un fondo in conto capitale e uno di parte corrente le cui dotazioni sono determinate dalla legge di stabilita' in relazione alle esigenze di realizzazione del programma di cui al predetto articolo, comma 2. Al fondo in conto capitale concorrono anche i proventi derivanti dalle attivita' di valorizzazione effettuate dall'Agenzia del demanio con riguardo alle infrastrutture militari, ancora in uso al Ministero della difesa, oggetto del comma 4 dell'articolo medesimo. Alla ripartizione dei predetti fondi si provvede mediante uno o piu' decreti del Ministro della difesa, da comunicare al Ministero dell'economia e delle finanze. Ai proventi di cui al presente comma non si applica l'articolo 2, comma 615, della legge 24 dicembre 2007, n. 244, ed essi sono integralmente riassegnati allo stato di previsione del Ministero della difesa.

2. Ferme restando le disposizioni di cui all'articolo 545, comma 1, i proventi derivanti dalle alienazioni di cui all'articolo 49, comma 2, della legge 23 dicembre 2000, n. 388, sono integralmente riassegnati al fondo di parte corrente istituito nello stato di previsione del Ministero della difesa, in relazione alle esigenze di realizzazione del programma di cui al citato articolo 307, comma 2.

#### Art. 620. - Fondo per esigenze prioritarie della difesa

1. Nello stato di previsione del Ministero della difesa e' istituito un fondo da utilizzare per far fronte alle esigenze prioritarie del Ministero stesso.

#### Art. 620-bis. - (( (Fondo per gli assetti ad alta e altissima prontezza operativa).))

((1. Per assicurare il rispetto degli impegni assunti dall'Italia connessi con il mantenimento della pace e della sicurezza internazionali, nello stato di previsione del Ministero della difesa e' istituito un fondo per finanziare l'approntamento e l'impiego degli assetti ad alta e altissima prontezza operativa a cio' destinati. La dotazione iniziale del fondo di cui al primo periodo e' pari a 3 milioni di euro per l'anno 2022 e a 6 milioni di euro annui a decorrere dall'anno 2023. Il fondo di cui al presente comma e' ripartito tra le diverse finalita' di impiego con decreto del Ministro della difesa, previa intesa con il Ministero dell'economia e delle finanze))

## LIBRO QUARTO PERSONALE MILITARE TITOLO I DISPOSIZIONI GENERALI CAPO I DEI MILITARI

### Art. 621. - Acquisto dello stato di militare

1. E' militare il cittadino che presta servizio armato a difesa della Patria, nella posizione di servizio o in congedo, secondo quanto stabilito dalle norme del presente codice.

2. Il servizio e' prestato:

- a) su base volontaria ((. . .));
- b) anche su base obbligatoria, al verificarsi delle condizioni e nei limiti stabiliti dal libro VIII del presente codice.

3. Lo stato di militare si acquisisce all'atto dell'arruolamento e si conserva anche durante lo stato di:

- a) disperso;
- b) prigioniero a causa di guerra, di grave crisi internazionale, di conflitti armati assimilabili, ancorche' non formalmente dichiarati, o di impiego in missioni internazionali; i doveri del militare prigioniero sono indicati nel regolamento.

4. E' arruolato il cittadino italiano dichiarato idoneo al servizio militare incondizionato e inserito in un'organizzazione militare dello Stato o legittimamente riconosciuta; l'arruolamento volontario e' disciplinato dal titolo II del presente libro; l'arruolamento obbligatorio e' disciplinato dal libro VIII del presente codice.

5. Lo stato di militare comporta l'osservanza dei doveri e degli obblighi relativi alla disciplina militare stabiliti dal presente codice e dal regolamento.

6. Il militare e' tenuto a prestare giuramento all'atto di assunzione del servizio. Gli ufficiali, i sottufficiali e i graduati prestano giuramento individuale, mentre gli altri militari lo prestano collettivamente. Nel regolamento sono indicate le modalita' con le quali e' prestato il giuramento.

### Art. 622. - Perdita dello stato di militare

1. Lo stato di militare si perde esclusivamente:

- a) per indegnita' a seguito di degradazione, ai sensi degli articoli 28 del codice penale militare di pace e 31 del codice penale militare di guerra;
- b) per interdizione perpetua dai pubblici uffici, anche in base a sentenza penale straniera alla quale e' stato dato riconoscimento nello Stato;
- c) per estinzione del rapporto di impiego ((in applicazione)) dell'articolo 32-quinquies del codice penale.

((

1-bis. Nei casi di cui al comma 1, si applicano gli articoli 867, comma 5, e 923, comma 5.

))

### Art. 623. - Personale militare femminile

1. Le Forze armate si avvalgono, per l'espletamento dei propri compiti, in condizioni di assoluta parita', di personale maschile e femminile, secondo le disposizioni contenute nel presente codice.

### Art. 624. - Rapporti con la legge penale militare

1. Rimangono ferme le definizioni e classificazioni del personale militare e assimilato effettuate dalle leggi penali militari in tempo di pace e di guerra.

### Art. 625. - ((Specificita' e rapporti con l'ordinamento generale del lavoro alle dipendenze delle amministrazioni pubbliche e altri ordinamenti speciali))

((

1. Al personale militare si applicano i principi e gli indirizzi di cui all'articolo 19 della legge 4 novembre 2010, n. 183, nonche' le disposizioni contenute nel presente codice.

))

2. Rimane ferma la disciplina dettata nel titolo II del libro V per il servizio a qualunque titolo prestato da personale civile in favore dell'Amministrazione della difesa e delle Forze armate.

3. Il personale religioso impiegato dall'Amministrazione della difesa, il personale della Croce rossa italiana ausiliario delle Forze armate e il personale militare dell'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta sono disciplinati in via esclusiva dal libro V.

## CAPO II - GERARCHIA MILITARE

### Art. 626. - Gerarchia e subordinazione

1. Il personale militare e' ordinato gerarchicamente in relazione al grado rivestito. Il grado corrisponde alla posizione che il militare occupa nella scala gerarchica.

2. L'ordine di precedenza tra pari grado e' determinato dall'anzianita' di grado, in base a quanto disposto dall'articolo 854.

3. L'ordinamento gerarchico determina il rapporto di subordinazione dell'inferiore nei confronti del superiore. Dal rapporto di subordinazione deriva il dovere di obbedienza.

### Art. 627. - (Categorie di militari e carriere)

1. Il personale militare e' inquadrato nelle seguenti categorie gerarchicamente ordinate:

- a) ufficiali;
- b) sottufficiali;
- c) graduati;
- d) militari di truppa.

2. La categoria degli ufficiali comprende:

- a) ufficiali generali e ammiragli, che rivestono i gradi di generale di brigata, generale di divisione, generale di corpo d'armata, generale e gradi corrispondenti;
- b) ufficiali superiori, che rivestono i gradi di maggiore, tenente colonnello, colonnello e gradi corrispondenti;
- c) ufficiali inferiori, che rivestono i gradi di sottotenente, tenente, capitano e gradi corrispondenti.

3. La carriera degli ufficiali, preposti all'espletamento delle funzioni di direzione, comando, indirizzo, coordinamento e controllo sulle unita' poste alle loro dipendenze, ha sviluppo dirigenziale.

4. La categoria dei sottufficiali comprende i militari appartenenti ai ruoli dei marescialli, dal grado di maresciallo a quello di luogotenente e gradi corrispondenti, e al ruolo dei sergenti dal grado di sergente a quello di sergente maggiore capo e gradi corrispondenti.

5. La carriera del ruolo dei marescialli, preposti a funzioni di comando, coordinamento e controllo sulle unita' poste alle loro dipendenze, e' caratterizzata da uno sviluppo direttivo. Ai militari che rivestono il grado apicale del ruolo dei marescialli puo' essere attribuita la qualifica di cui all'articolo 629, comma 2, lettera b), che comporta l'assunzione di attribuzioni di particolare rilievo in relazione al ruolo di appartenenza e all'anzianita' posseduta.

6. La carriera del ruolo dei sergenti, preposti a funzioni di controllo sulle unita' poste alle loro dipendenze, nonche' al comando di unita' di tipo elementare, ha carattere esecutivo. Ai militari che rivestono il grado apicale del ruolo dei sergenti puo' essere attribuita la qualifica di cui all'articolo 629, comma 2, lettera a), che comporta l'assunzione di attribuzioni di particolare rilievo in relazione al ruolo di appartenenza e all'anzianita' posseduta.

7. La categoria dei graduati comprende i militari appartenenti al ruolo dei volontari in servizio permanente, che rivestono i gradi da ((graduato)) sino a ((primo graduato)) e gradi corrispondenti. La carriera del ruolo dei volontari in servizio permanente ha carattere esecutivo. Ai militari che rivestono il grado apicale del ruolo dei volontari in servizio permanente puo' essere attribuita la qualifica di cui all'articolo 1306, comma 1-bis, che comporta l'assunzione di attribuzioni di particolare rilievo in relazione al ruolo di appartenenza e all'anzianita' posseduta.

8. La categoria dei militari di truppa comprende i militari di leva, i volontari in ferma prefissata, gli allievi carabinieri, gli allievi finanzieri, gli allievi delle scuole militari, gli allievi marescialli in ferma, gli allievi ufficiali in ferma prefissata e gli allievi ufficiali delle accademie militari.

9. Le carriere del personale militare sono disciplinate esclusivamente dal codice.

### Art. 628. - Successione e corrispondenza dei gradi degli ufficiali

1. La successione e la corrispondenza dei gradi degli ufficiali sono cosi' determinate in ordine crescente:

- a) sottotenente: guardiamarina per la Marina militare;
- b) tenente: sottotenente di vascello per la Marina militare;
- c) capitano: tenente di vascello per la Marina militare;
- d) maggiore: capitano di corvetta per la Marina militare;
- e) tenente colonnello: capitano di fregata per la Marina militare;
- f) colonnello: capitano di vascello per la Marina militare;
- g) generale di brigata: brigadiere generale per l'Arma dei trasporti e dei materiali e i corpi logistici dell'Esercito italiano; contrammiraglio per la Marina militare; generale di brigata aerea e brigadiere generale per l'Aeronautica militare;
- h) generale di divisione: maggiore generale per l'Arma dei trasporti e dei materiali e i corpi logistici dell'Esercito italiano; ammiraglio di divisione e ammiraglio ispettore per la Marina militare; generale di divisione aerea e generale ispettore per l'Aeronautica militare;
- i) generale di corpo d'armata: tenente generale per l'Arma dei trasporti e dei materiali e i corpi logistici dell'Esercito italiano; ammiraglio di squadra e ammiraglio ispettore capo per la Marina militare; generale di squadra aerea, generale di squadra e generale ispettore capo per l'Aeronautica militare;
- l) generale: ammiraglio per la Marina militare.

2. ((COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94)).

3. ((COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94)).

### Art. 629. - Successione e corrispondenza dei gradi e delle qualifiche dei sottufficiali

1. La successione e la corrispondenza dei gradi dei sottufficiali sono cosi' determinate in ordine crescente:

- a) sergente: vice brigadiere per l'Arma dei carabinieri e il Corpo della Guardia di finanza;
- b) sergente maggiore: secondo capo della Marina militare; brigadiere per l'Arma dei carabinieri e il Corpo della Guardia di finanza;
- c) sergente maggiore capo: secondo capo scelto della Marina militare; brigadiere capo per l'Arma dei carabinieri e il Corpo della Guardia di finanza;
- d) maresciallo: capo di 3^ classe per la Marina militare; maresciallo di 3^ classe per l'Aeronautica militare;
- e) maresciallo ordinario: capo di 2^ classe per la Marina militare; maresciallo di 2^ classe per l'Aeronautica militare;
- f) maresciallo capo: capo di 1^ classe per la Marina militare; maresciallo di 1^ classe per l'Aeronautica militare;
- g) primo maresciallo: maresciallo maggiore per l'Arma dei carabinieri; maresciallo aiutante per il Corpo della Guardia di finanza.
- g-bis) luogotenente: luogotenente per l'Arma dei carabinieri; luogotenente per il Corpo della guardia di finanza.

2. Le qualifiche attribuibili ai sottufficiali sono cosi' determinate:

- a) ai sergenti maggiori capi e gradi corrispondenti: ((sergente maggiore aiutante per l'Esercito italiano e l'Aeronautica militare; secondo capo aiutante per la Marina militare; brigadiere capo qualifica speciale per l'Arma dei carabinieri e il Corpo della Guardia di finanza));
- b) ai luogotenenti e gradi corrispondenti: primo luogotenente per l'Esercito italiano, la Marina militare e l'Aeronautica militare; carica speciale per l'Arma dei carabinieri; cariche speciali per il Corpo della guardia di finanza.

2-bis. I sottufficiali a cui sono attribuite le qualifiche di cui al comma 2 hanno rango preminente sui pari grado. Fra essi si tiene conto della data di conferimento della qualifica, anche nel caso di pari grado con diversa anzianita'.

### Art. 630. - Successione e corrispondenza dei gradi dei graduati

1. La successione e la corrispondenza dei gradi dei graduati sono cosi' determinate in ordine crescente:

- a) ((graduato)): sottocapo di 3^ classe per la Marina militare; aviere capo per l'Aeronautica militare; carabiniere; finanziere;
- b) ((graduato scelto)): sottocapo di 2^ classe per la Marina militare; primo aviere scelto per l'Aeronautica militare; carabiniere scelto; finanziere scelto;
- c) ((graduato capo)): sottocapo di 1^ classe per la Marina militare; primo aviere capo per l'Aeronautica militare; appuntato per l'Arma dei carabinieri e il Corpo della Guardia di finanza;
- d) ((primo graduato: sottocapo scelto per la Marina militare; primo graduato)) per l'Aeronautica militare; appuntato scelto per l'Arma dei carabinieri e il Corpo della Guardia di finanza.

1-bis. Al ((primo graduato)), o gradi corrispondenti puo' essere attribuita la seguente qualifica ((: graduato aiutante per l'Esercito italiano e l'Aeronautica militare; sottocapo aiutante per la Marina militare; appuntato scelto qualifica speciale per l'Arma dei carabinieri e il Corpo della Guardia di finanza)). I ((graduati aiutanti e corrispondenti)) hanno rango preminente sui pari grado; fra ((graduati aiutanti e corrispondenti)), si tiene conto della data di conferimento della qualifica, anche nel caso di pari grado con diversa anzianita'.

### Art. 631. - Successione e corrispondenza dei gradi dei militari di truppa

1. La successione e la corrispondenza dei gradi dei militari di truppa sono cosi' determinate in ordine crescente:

- a) caporale: comune di 1^ classe per la Marina militare; aviere scelto per l'Aeronautica militare;
- b) caporal maggiore: ((comune scelto)) per la Marina militare; primo aviere per l'Aeronautica militare.

2. Il militare di truppa senza alcun grado e':

- a) il soldato per l'Esercito italiano;
- b) il comune di 2^ classe per la Marina militare;
- c) l'aviere per l'Aeronautica militare;
- d) l'allievo carabiniere e l'allievo finanziere;
- e) l'allievo delle scuole militari, navale e aeronautica;
- f) l'allievo maresciallo in ferma;
- g) l'allievo ufficiale in ferma prefissata;
- h) l'allievo ufficiale delle accademie.

### Art. 632. - (Corrispondenza dei gradi militari con le qualifiche degli appartenenti alle Forze di polizia a ordinamento civile)

1. L'equiparazione tra i gradi militari e le qualifiche delle Forze di polizia a ordinamento civile e' cosi' determinata:

- a) generale di divisione e corrispondenti: dirigente generale di pubblica sicurezza e corrispondenti;
- b) generale di brigata e corrispondenti: dirigente superiore e corrispondenti;
- c) colonnello e corrispondenti: primo dirigente e corrispondenti;
- d) tenente colonnello e corrispondenti: vice questore e corrispondenti;
- e) maggiore e corrispondenti: vice questore aggiunto e corrispondenti;
- f) capitano e corrispondenti: commissario capo e corrispondenti;
- g) tenente e corrispondenti: commissario e corrispondenti;
- h) sottotenente e corrispondenti: vice commissario e corrispondenti;
- i) luogotenente e corrispondenti: sostituto commissario e corrispondenti;
- l) primo maresciallo e corrispondenti: ispettore superiore e corrispondenti;
- m) maresciallo capo e corrispondenti: ispettore capo e corrispondenti;
- n) maresciallo ordinario e corrispondenti: ispettore e corrispondenti;
- o) maresciallo e corrispondenti: vice ispettore e corrispondenti;
- p) sergente maggiore capo e corrispondenti: sovrintendente capo e corrispondenti;
- q) sergente maggiore e corrispondenti: sovrintendente e corrispondenti;
- r) sergente e corrispondenti: vice sovrintendente e corrispondenti;
- s) ((primo graduato)) e corrispondenti: assistente capo e corrispondenti;
- t) ((graduato capo)) e corrispondenti: assistente e corrispondenti;
- u) ((graduato scelto)) e corrispondenti: agente scelto e corrispondenti;
- v) ((graduato)) e corrispondenti: agente e corrispondenti.

## TITOLO II RECLUTAMENTO CAPO I DISPOSIZIONI GENERALI

### Art. 633. - Reclutamento

1. Il reclutamento e' il complesso delle procedure e delle attivita' tecnico-amministrative necessarie per l'immissione in servizio di personale militare. Il reclutamento e' obbligatorio o volontario.

2. Il reclutamento obbligatorio e' disciplinato dal libro VIII del presente codice.

3. Il reclutamento volontario e' disciplinato dal presente titolo.

4. Il reclutamento volontario avviene mediante procedura concorsuale indetta con apposito bando ((, fatto salvo quanto disposto dagli articoli 705 e 709)).

### Art. 634. - Programmazione dei reclutamenti

1. Al fine di assicurare le esigenze di funzionalita' e di ottimizzare le risorse per il miglior funzionamento dei servizi, compatibilmente con le disponibilita' finanziarie e di bilancio, gli organi di vertice dell'Amministrazione della difesa sono tenuti alla programmazione triennale del fabbisogno del personale dell'Arma dei carabinieri.

2. Il numero complessivo dei dipendenti in servizio e' valutato su basi statistiche omogenee, secondo criteri e parametri stabiliti con decreto del Presidente del Consiglio dei Ministri di concerto con il Ministro dell'economia e delle finanze.

3. Per consentire lo sviluppo dei processi di riqualificazione dell'amministrazione, connessi all'attuazione della riforma amministrativa, garantendo il rispetto degli obiettivi di riduzione programmata del personale, il Consiglio dei Ministri, su proposta dei Ministri per la pubblica amministrazione e l'innovazione e dell'economia e delle finanze:

- a) definisce preliminarmente le priorita' e le necessita' operative da soddisfare, tenuto conto in particolare delle correlate esigenze di introduzione di nuove professionalita';
- b) entro il primo semestre di ciascun anno, determina il numero massimo complessivo dei reclutamenti, compatibile con gli obiettivi di riduzione numerica e con i dati sulle cessazioni dell'anno precedente.

4. Le richieste di autorizzazione ad assumere devono essere corredate da una relazione illustrativa delle iniziative di riordino e riqualificazione, adottate o in corso, finalizzate alla definizione di modelli organizzativi rispondenti ai principi di semplificazione e di funzionalita' rispetto ai compiti e ai programmi, con specifico riferimento, eventualmente, anche a nuove funzioni e qualificati servizi da fornire. Le predette richieste sono sottoposte all'esame del Consiglio dei Ministri, ai fini dell'adozione di delibere con cadenza semestrale, previa istruttoria da parte della Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica e del Ministero dell'economia e delle finanze. L'istruttoria e' diretta a riscontrare le effettive esigenze di reperimento di nuovo personale e l'impraticabilita' di soluzioni alternative collegate a procedure di mobilita' o all'adozione di misure di razionalizzazione interna.

### Art. 635. - Requisiti generali per il reclutamento

1. Per il reclutamento nelle Forze armate occorrono i seguenti requisiti generali:

- a) essere cittadino italiano;
- b) essere in possesso di adeguato titolo di studio;
- c) essere in possesso dell'idoneita' psicofisica e attitudinale al servizio militare incondizionato;
- d) rientrare nei parametri fisici correlati alla composizione corporea, alla forza muscolare e alla massa metabolicamente attiva, secondo le tabelle stabilite dal regolamento;
- e) godere dei diritti civili e politici;
- f) non essere stati destituiti, dispensati o dichiarati decaduti dall'impiego in una pubblica amministrazione, licenziati dal lavoro alle dipendenze di pubbliche amministrazioni a seguito di procedimento disciplinare, ovvero prosciolti, d'autorita' o d'ufficio, da precedente arruolamento nelle Forze armate o di polizia, a esclusione dei proscioglimenti per inidoneita' psico-fisica ((e di quelli disposti in applicazione dell'articolo 957, comma 1, lettere b) ed e-bis) ));
- g) non essere stati condannati per delitti non colposi, anche con sentenza di applicazione della pena su richiesta, a pena condizionalmente sospesa o con decreto penale di condanna((...));
- g-bis) non essere in atto imputati in procedimenti penali per delitti non colposi;
- h) non essere stati sottoposti a misure di prevenzione;
- i) avere tenuto condotta incensurabile;
- l) non aver tenuto comportamenti nei confronti delle istituzioni democratiche che non diano sicuro affidamento di scrupolosa fedelta' alla Costituzione repubblicana e alle ragioni di sicurezza dello Stato;
- m) avere compiuto il 18° anno di eta', fermo restando: 1) quanto previsto dall'articolo 711; 2) la possibilita' di presentare la domanda di partecipazione al concorso da parte del minore che ha compiuto il 17° anno di eta', acquisito il consenso di chi esercita la potesta';
- n) esito negativo agli accertamenti diagnostici per l'abuso di alcool, per l'uso, anche saltuario od occasionale, di sostanze stupefacenti, nonche' per l'utilizzo di sostanze psicotrope a scopo non terapeutico.

((

1-bis. In relazione al requisito di cui al comma 1, lettera c), la patologia che ha determinato la permanente non idoneita' in modo parziale al servizio militare incondizionato a seguito di ferite o lesioni dipendenti da causa di servizio non costituisce causa di esclusione dai concorsi interni per il reclutamento dei volontari in servizio permanente, dei sergenti, dei marescialli e degli ufficiali dei ruoli speciali.

1-ter. I tatuaggi e le altre permanenti alterazioni volontarie dell'aspetto fisico non conseguenti a interventi di natura comunque sanitaria, se lesivi del decoro dell'uniforme o della dignita' della condizione del militare di cui al regolamento, costituiscono causa di esclusione dal concorso secondo quanto stabilito dal bando.

))

2. I requisiti di cui al comma 1, lettere c), d), i), l) e n), sono accertati d'ufficio dall'amministrazione. Il requisito di cui al comma 1, lettera d), non e' nuovamente accertato nei confronti del personale militare in servizio in possesso dell'idoneita' incondizionata al servizio militare che partecipa a concorsi delle Forze armate.

((

2-bis. Se il procedimento penale di cui al comma 1, lettera g-bis), non si conclude con sentenza irrevocabile di assoluzione perche' il fatto non sussiste ovvero perche' l'imputato non lo ha commesso, pronunciata ai sensi dell'articolo 530 del codice di procedura penale, il militare puo' partecipare ai concorsi nelle Forze armate soltanto successivamente alla definizione del conseguente procedimento disciplinare.

))

3. Requisiti ulteriori sono previsti dalle norme del presente codice o dai singoli bandi, in relazione al reclutamento delle varie categorie di militari, fra cui quelli previsti per il personale dell'Arma dei carabinieri dall'articolo 33 del decreto del Presidente della Repubblica 15 luglio 1988, n. 574.

### Art. 636. - Obiettori di coscienza

1. Agli obiettori di coscienza che sono stati ammessi a prestare servizio civile e' vietato partecipare ai concorsi per qualsiasi impiego che comporti l'uso delle armi e comunque partecipare a qualsiasi procedura per l'arruolamento nelle Forze armate e nelle Forze di polizia a ordinamento militare o per l'assunzione nelle Forze di polizia a ordinamento civile.

2. Le disposizioni di cui al comma 1 non si applicano ai cittadini che hanno rinunciato allo status di obiettore di coscienza ai sensi del comma 3.

3. L'obiettore ammesso al servizio civile, decorsi almeno cinque anni dalla data in cui e' stato collocato in congedo secondo le norme previste per il servizio di leva, puo' rinunciare allo status di obiettore di coscienza, presentando apposita dichiarazione irrevocabile presso l'Ufficio nazionale per il servizio civile che provvede a darne tempestiva comunicazione alla ((Direzione generale della previdenza militare e della leva)).

### Art. 637. - Divieto di discriminazione

1. Fatto salvo il possesso dei requisiti generali e speciali previsti dal presente codice, e' vietata in sede di reclutamento ogni forma di discriminazione, secondo quanto disposto dall'articolo 1468.

### Art. 638. - Mancanza dei requisiti

1. I requisiti generali e speciali, devono essere posseduti dalla data indicata nel bando e sino a quella dell'effettiva incorporazione o, limitatamente ai militari in servizio, a quella dell'inizio del relativo corso di formazione, o fino alla nomina a ufficiale in servizio permanente nei concorsi a nomina diretta, a eccezione del limite massimo di eta' che puo' essere superato al momento dell'effettiva incorporazione o dell'inizio del corso di formazione.

2. L'accertamento, successivo al reclutamento, della mancanza di uno dei predetti requisiti, sia per condotta dolosa sia per condotta incolpevole dell'interessato, comporta la decadenza di diritto dall'arruolamento volontario.

### Art. 639. - Reclutamento volontario femminile

1. Il reclutamento del personale militare femminile e' effettuato su base volontaria secondo le disposizioni vigenti per il personale maschile, salvo quanto previsto per l'accertamento dell'idoneita' al servizio dalle norme contenute nel regolamento e salve le aliquote d'ingresso eventualmente previste, in via eccezionale, con il decreto adottato ai sensi del comma 2.

2. Ferme restando le consistenze organiche complessive, il Ministro della difesa puo' prevedere limitazioni all'arruolamento del personale militare femminile soltanto in presenza di motivate esigenze connesse alla funzionalita' di specifici ruoli, corpi, categorie, specialita' e specializzazioni di ciascuna Forza armata, se in ragione della natura o delle condizioni per l'esercizio di specifiche attivita' il sesso rappresenta un requisito essenziale. Il relativo decreto e' adottato su proposta del Capo di stato maggiore della difesa, acquisito il parere della Commissione per le pari opportunita' tra uomo e donna, d'intesa con i Ministri delle infrastrutture e dei trasporti e per le pari opportunita'.

### Art. 640. - Accertamento dell'idoneita' psicofisica

1. Gli aspiranti agli arruolamenti nelle Forze armate devono essere in possesso di uno specifico profilo psicofisico da accertare, esclusivamente e in deroga a ogni altra disposizione di legge, in base alle norme per l'accertamento dell'idoneita' al servizio militare contenute nel regolamento e adottate dal Ministro della difesa, sentiti, per quanto concerne il personale femminile, il Ministro per le pari opportunita', la Commissione per le pari opportunita' tra uomo e donna, nonche' il Ministro delle infrastrutture e dei trasporti per il personale del Corpo delle capitanerie di porto.

((

1-bis. Le aspiranti agli arruolamenti nelle Forze armate che si trovano in stato di gravidanza e non possono essere sottoposte agli accertamenti per l'idoneita' fisio-psico-attitudinale al servizio militare ai sensi del regolamento, sono ammesse d'ufficio, anche in deroga, per una sola volta, ai limiti di eta', a svolgere i predetti accertamenti nell'ambito del primo concorso utile successivo alla cessazione di tale stato di temporaneo impedimento. Il provvedimento di rinvio puo' essere revocato, su istanza di parte, quando il suddetto stato di temporaneo impedimento cessa in data compatibile con i tempi necessari per la definizione della graduatoria. Fermo restando il numero delle assunzioni annualmente autorizzate, le candidate rinviate risultate idonee e nominate vincitrici nella graduatoria finale di merito del concorso per il quale hanno presentato istanza di partecipazione sono avviate alla frequenza del primo corso di formazione utile in aggiunta ai vincitori di concorso cui sono state rinviate.

1-ter. Le vincitrici dei concorsi rinviate ai sensi del comma 1-bis sono immesse in servizio con la medesima anzianita' assoluta, ai soli fini giuridici, dei vincitori del concorso per il quale originariamente hanno presentato domanda. La relativa posizione di graduatoria nell'ambito del corso originario viene determinata, ove previsto, sulla base del punteggio ottenuto nella graduatoria finale al termine del periodo di formazione. Gli effetti economici della nomina decorrono, in ogni caso, dalla data di effettivo incorporamento.

))

### Art. 641. - Accertamento dell'idoneita' attitudinale

1. Gli aspiranti agli arruolamenti nelle Forze armate devono essere in possesso di uno specifico profilo attitudinale da accertare, esclusivamente e in deroga a ogni altra disposizione di legge, in base alle norme per l'accertamento dell'idoneita' al servizio militare previste dal regolamento. A tale fine, possono essere impiegati anche ufficiali periti selettori in possesso di specifica qualifica conferita a cura della competente struttura del Ministero della difesa, previo superamento di apposito corso.

((

1-bis. Ferma restando la competenza del Ministero della difesa nel conferimento della qualifica di perito selettore di cui al comma 1, secondo periodo l'Arma dei carabinieri svolge in autonomia i relativi corsi.

))

### Art. 642. - Revoca e sospensione dei concorsi

1. L'amministrazione, per sopravvenute esigenze di interesse pubblico, ha facolta' di:

- a) revocare il bando di concorso;
- b) sospendere o rinviare le prove concorsuali;
- c) modificare il numero dei posti messi a concorso;
- d) sospendere l'ammissione ai corsi di formazione iniziale.

### Art. 643. - Conferimento di posti disponibili agli idonei

1. L'amministrazione militare ha facolta' di conferire, nel limite delle risorse finanziarie previste, oltre i posti messi a concorso, anche quelli che risultano disponibili alla data di approvazione della graduatoria.

2. Detti posti, da conferire secondo l'ordine della graduatoria, non possono superare il decimo di quelli messi a concorso per il reclutamento degli ufficiali e il quinto per il reclutamento delle altre categorie di militari.

3. Se alcuni posti messi a concorso restano scoperti per rinuncia, decadenza o dimissioni dei vincitori, l'amministrazione militare ha facolta' di procedere, nel termine di un anno dalla data di approvazione della graduatoria e salvo diverse disposizioni del presente codice, ad altrettante nomine secondo l'ordine della graduatoria stessa, fermo restando l'accertamento dell'ulteriore possesso dei requisiti.

4. Nei concorsi per la nomina a ufficiale e sottufficiale in servizio permanente, se alcuni dei posti messi a concorso risultano scoperti per rinuncia o decadenza, entro trenta giorni dalla data di inizio dei corsi, possono essere autorizzate altrettante ammissioni ai corsi stessi secondo l'ordine della graduatoria. Se la durata del corso e' inferiore a un anno, detta facolta' puo' essere esercitata entro 1/12 della durata del corso stesso.

((

4-bis. Nei concorsi per il reclutamento del personale delle Forze armate, i termini di validita' delle graduatorie finali approvate, ai fini dell'arruolamento di candidati risultati idonei ma non vincitori, sono prorogabili solo nei casi e nei termini previsti dal presente codice.

))

### Art. 644. - Commissioni di concorso

1. Le commissioni esaminatrici per i concorsi per il reclutamento dei militari sono presiedute e formate da personale in servizio della rispettiva Forza armata, con l'intervento, se necessario, di uno o piu' esperti nelle materie o prove oggetto di valutazione, salvo quanto diversamente disposto dal bando.

### Art. 645.

Posti riservati a particolari categorie ((nei concorsi pubblici))

1. Fermi restando gli ulteriori benefici previsti dal codice, fino al venticinque per cento dei posti messi a concorso per il reclutamento degli ufficiali e degli appartenenti ai ruoli dei marescialli delle Forze armate e degli ispettori dell'Arma dei carabinieri e' riservato al coniuge e ai figli superstiti, ovvero ai parenti in linea collaterale di secondo grado se unici superstiti, del personale delle Forze armate e delle Forze di polizia deceduto in servizio e per causa di servizio, in possesso dei requisiti prescritti.

### Art. 645-bis. - (( (Disposizioni ulteriori sui concorsi nell'Arma dei carabinieri).))

((

1. L'Arma dei carabinieri, per esigenze organizzative e logistiche che non consentono di ospitare tutti i vincitori dello stesso concorso presso i propri istituti di istruzione, puo' articolare i corsi di formazione in piu' cicli aventi il medesimo piano di studi. A tutti i frequentatori, ove non sia diversamente disposto, e' riconosciuta, previo superamento degli esami finali del ciclo addestrativo frequentato, la stessa decorrenza giuridica ed economica dei frequentatori del primo ciclo. Al termine dell'ultimo ciclo, l'anzianita' relativa di iscrizione in ruolo di tutti i frequentatori sara' rideterminata sulla base degli esiti degli esami sostenuti a conclusione di ciascun ciclo.

2. Qualora la facolta' di cui al comma 1 sia esercitata per i corsi formativi per allievo carabiniere di cui all'articolo 783 del presente codice ovvero di cui all'articolo 957 del regolamento, a tutti i frequentatori e' riconosciuta, ai soli fini giuridici, la data di arruolamento piu' favorevole degli incorporati del primo ciclo, da cui decorre la ferma volontaria prevista dall'articolo 784.

))

## CAPO II - UFFICIALI IN SERVIZIO PERMANENTE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 646. - Requisiti speciali

1. Per il reclutamento degli ufficiali in servizio permanente delle Forze armate e' necessario possedere i seguenti ulteriori requisiti:

- a) non aver superato l'eta' massima stabilita per ciascun ruolo dal presente codice;
- b) essere in possesso di diploma di istruzione secondaria di secondo grado ovvero di diploma di laurea;
- c) essere riconosciuti in possesso della idoneita' psicofisica e attitudinale al servizio incondizionato quale ufficiale in servizio permanente.

#### Art. 647. - Norme generali sui concorsi

1. Con distinti decreti del Ministro della difesa, di concerto con il Ministro delle infrastrutture e dei trasporti per i concorsi a ufficiale del Corpo delle capitanerie di porto ((e con il Ministro dell'istruzione, dell'universita' e della ricerca per la parte di cui alla lettera a) del presente comma)), sono indicati per ciascuna Forza armata:

- a) i titoli di studio di istruzione secondaria di secondo grado richiesti per l'ammissione ai singoli corsi delle accademie militari, nonche' quelli validi per i concorsi per la nomina a ufficiale in servizio permanente, ed eventuali ulteriori requisiti ((, fermo restando che, per il reclutamento nei Corpi sanitari tramite i corsi normali delle accademie, i concorrenti devono sostenere una specifica prova di selezione su argomenti attinenti a materie indicate dal Ministero dell'istruzione, dell'universita' e della ricerca, superata la quale, ove risultino vincitori di concorso per l'accesso nelle accademie, acquisiscono titolo all'ammissione ai corsi di laurea magistrale nei limiti numerici programmati a livello nazionale, che tengono conto delle esigenze numeriche della Difesa));
- b) le tipologie e le modalita' di svolgimento dei concorsi, delle prove di esame e della formazione delle relative graduatorie di merito, prevedendo, se necessario, programmi differenziati in relazione ai titoli di studio richiesti;
- c) la composizione delle commissioni esaminatrici.

2. Le riserve di posti previste da leggi speciali in favore di particolari categorie di cittadini non possono complessivamente superare un terzo dei posti messi a concorso.

3. Per la partecipazione ai concorsi finalizzati all'immissione nei ruoli degli ufficiali non si applicano gli aumenti dei limiti di eta' eventualmente previsti per l'ammissione ai pubblici impieghi.

#### Art. 648. - Eta' per la partecipazione ai concorsi per le accademie militari

1. L'eta' per la partecipazione ai concorsi per l'ammissione alle accademie militari non puo' essere superiore a 22 anni alla data indicata nel bando di concorso. Fatta eccezione per il ruolo naviganti normale dell'Aeronautica militare, il limite massimo e' elevato di un periodo pari all'effettivo servizio prestato, comunque non superiore a tre anni, a favore dei cittadini italiani che prestano o hanno prestato servizio militare nelle Forze armate.

2. L'eta' massima per la partecipazione al concorso per l'ammissione all'accademia dell'Arma dei carabinieri, da parte degli appartenenti ai ruoli ispettori e sovrintendenti, e' stabilita in 28 anni.

#### Art. 649. - Posti riservati nelle accademie

1. Nei concorsi per il reclutamento degli allievi delle accademie militari sono appositamente riservati alcuni posti per gli allievi delle scuole militari, nel limite massimo complessivo del 30 per cento dei posti disponibili.

2. Per specifiche esigenze di ciascuna Forza armata nei bandi di concorso per l'ammissione alle accademie militari, oltre alle riserve di posti di cui al comma 1, possono essere previste anche riserve di posti a favore di particolari categorie di personale militare in servizio nella relativa Forza armata. Ciascuna Forza armata puo' bandire concorsi per l'ammissione alle accademie riservati al proprio personale nella misura massima del 30 per cento dei posti disponibili.

((

3. I posti riservati agli allievi delle scuole militari che non vengono ricoperti possono essere devoluti, secondo la percentuale massima stabilita nel bando di concorso, nell'ordine della graduatoria di merito, ai concorrenti idonei che sono alle armi in qualita' di ufficiali inferiori, di sottufficiali o di militari di truppa in ferma volontaria o rafferma con almeno un anno di servizio effettivamente svolto.

))

#### Art. 650. - Titoli di preferenza per i concorsi nelle accademie

1. I posti a concorso per l'ammissione alle accademie militari, ferma restando la riserva dei posti di cui all'articolo 649, sono assegnati, nell'ordine della graduatoria di merito e a parita' di punteggio, con precedenza ai concorrenti in servizio o in congedo in qualita' di:

- a) ufficiali inferiori con almeno quindici mesi di effettivo servizio;
- b) sottufficiali con almeno quindici mesi di effettivo servizio;
- c) allievi delle scuole militari;
- d) volontari in ferma che hanno completato la predetta ferma senza demerito, sono in possesso dei requisiti prescritti e presentano domanda entro dodici mesi dal termine della ferma.
- d-bis) assistiti dall'Opera nazionale di assistenza per gli orfani dei militari di carriera dell'Esercito italiano, dall'Istituto Andrea Doria per l'assistenza dei familiari e degli orfani del personale della Marina militare, dall'Opera nazionale per i figli degli aviatori e dall'Opera nazionale di assistenza per gli orfani dei militari dell'Arma dei carabinieri.

2. Per l'ammissione alle Accademie militari, a parita' di merito, ha precedenza, tra il personale di cui alle lettere a) e b) del comma 1, quello appartenente alla rispettiva Forza armata.

#### Art. 651.

Alimentazione ordinaria dei ruoli normali ((dell'Esercito italiano, della Marina militare e dell'Aeronautica militare))

1. Gli ufficiali dei ruoli normali ((dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)) in servizio permanente sono tratti, con il grado di sottotenente, da coloro che hanno frequentato le accademie militari, e che hanno completato con esito favorevole il ciclo formativo previsto dal regolamento.

#### Art. 651-bis. - (Alimentazione ordinaria del ruolo normale dell'Arma dei carabinieri)

1. Gli ufficiali del ruolo normale dell'Arma dei carabinieri in servizio permanente sono tratti, con il grado di sottotenente:

- a) da coloro che hanno frequentato l'accademia militare e che hanno completato con esito favorevole il ciclo formativo previsto dal regolamento;
- b) mediante concorso per titoli ed esami, dai luogotenenti in servizio permanente dell'Arma dei carabinieri, in possesso di laurea magistrale in giurisprudenza, che hanno riportato nell'ultimo quinquennio la qualifica finale non inferiore a «eccellente» e che non hanno superato il cinquantacinquesimo anno di eta';
- c) mediante concorso per titoli ed esami, dai militari in servizio permanente dei ruoli ((degli ispettori, dei sovrintendenti, degli appuntati e carabinieri)) dell'Arma dei carabinieri, in possesso di laurea triennale a indirizzo giuridico definita con determinazione dirigenziale, che hanno riportato nell'ultimo biennio la qualifica finale non inferiore a «eccellente», che hanno almeno cinque anni di servizio e che non hanno superato il quarantesimo anno di eta'.

2. I vincitori dei concorsi di cui al comma 1 lettere b) e c), sono:

- a) nominati sottotenenti, secondo l'ordine di precedenza fissato dal comma 1, con anzianita' relativa stabilita in base all'ordine della rispettiva graduatoria di merito;
- b) iscritti in ruolo dopo l'ultimo dei pari grado provenienti dai corsi regolari dell'accademia militare nominati sottotenenti in servizio permanente nello stesso anno;
- c) ammessi a frequentare un corso applicativo.

((

3. I posti eventualmente rimasti scoperti in uno dei concorsi di cui al comma 1, lettere b) e c), possono essere devoluti in favore dei concorrenti risultati idonei, ma non vincitori dell'altro concorso.

))

#### Art. 652. - Alimentazione straordinaria dei ruoli normali

1. Gli ufficiali in servizio permanente dei ruoli normali possono anche essere tratti con il grado di tenente, mediante concorso per titoli ed esami, dai cittadini in possesso di una delle lauree magistrali definite per ciascun ruolo con i decreti di cui all'articolo 647, che non hanno superato il 35° anno di eta' alla data indicata nel bando di concorso.

2. Salvo quanto stabilito nel comma 1, gli ufficiali del ruolo normale del Corpo delle capitanerie di porto possono essere tratti, con il grado di guardiamarina, anche dai giovani in possesso del titolo di primo ufficiale di coperta su navi di stazza pari o superiori a 3000 GT o primo ufficiale di macchina su navi con apparato motore principale pari o superiore a 3000 KW.

2-bis. In caso di carenza di specifiche professionalita' ((...)), gli ufficiali ((...)) in servizio permanente possono essere tratti con il grado di capitano mediante concorso per titoli ed esami, tra i cittadini di eta' non superiore a 38 anni in possesso ((di una delle lauree magistrali e dei titoli)) indicati nel bando di concorso. ((110))

3. Il presente codice stabilisce quando possono essere banditi i concorsi di cui al comma 1.

--------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 653. - Partecipazione degli ufficiali ausiliari ai concorsi straordinari per i ruoli normali

1. Gli ufficiali in ferma prefissata, che hanno completato un anno di servizio e che sono in possesso di ((laurea magistrale)), e gli ufficiali inferiori delle forze di completamento ((in possesso di laurea magistrale)) possono partecipare ai concorsi per il reclutamento degli ufficiali dei ruoli normali di cui all'articolo 652, sempre che gli stessi non superino:

- a) il 40° anno d'eta', se ufficiali dell'Esercito italiano, della Marina militare o dell'Aeronautica militare;
- b) il 34° anno di eta' se ufficiali dell'Arma dei carabinieri.

2. Il servizio prestato in qualita' di ufficiale in ferma prefissata costituisce titolo ai fini della formazione delle graduatorie di merito.

3. COMMA ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20.

### SEZIONE II - UFFICIALI DELL'ESERCITO ITALIANO, DELLA MARINA MILITARE E DELL'AERONAUTICA MILITARE

#### Art. 654. - Condizioni per il reclutamento straordinario nei ruoli normali

1. I concorsi di cui all'articolo 652 possono essere banditi se il prevedibile numero dei frequentatori delle accademie, che concludono nell'anno il ciclo formativo per essi previsto per un determinato ruolo, risulta inferiore a ((7/5)) del numero delle promozioni a scelta al grado di maggiore stabilito per il medesimo ruolo dalle norme del presente codice.

#### Art. 655. - Alimentazione dei ruoli speciali

1. Gli ufficiali dei ruoli speciali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, fatta eccezione per gli ufficiali del ruolo naviganti speciale, possono essere tratti:

- a) per concorso per titoli ed esami con il grado di sottotenente: 1) prevalentemente dal personale appartenente al ruolo dei marescialli, in possesso di un titolo di studio non inferiore alla laurea che non ha superato il 35° anno di eta' e che all'atto dell'immissione nel ruolo degli ufficiali ha almeno 5 anni di anzianita' nel ruolo di provenienza se reclutato ai sensi dell'articolo 679, comma 1, lettera a), ovvero 3 anni di anzianita' nel ruolo di provenienza se reclutato ai sensi dell'articolo 679, comma 1, lettera b); 2) dagli ufficiali di complemento un titolo di studio non inferiore alla laurea che all'atto di immissione nel ruolo speciale hanno completato senza demerito la ferma biennale e non hanno superato il 35° anno di eta'; 3) dal personale giudicato idoneo e non vincitore dei concorsi per la nomina a ufficiale in servizio permanente effettivo dei ruoli normali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e che non ha superato il 35° anno di eta'; 4) dai frequentatori dei corsi normali delle accademie militari che non hanno completato il secondo o il terzo anno del previsto ciclo formativo, ((e non hanno superato il 30° anno di eta', purche' in possesso dell'idoneita' in attitudine militare e)) di un titolo di studio non inferiore alla laurea; 4-bis) dai frequentatori dei corsi normali delle accademie militari iscritti ai corsi universitari quinquennali a ciclo unico che hanno superato gli esami del terzo anno ((, non hanno superato il 30° anno di eta')) e sono idonei in attitudine militare; 5) dal personale del ruolo dei sergenti in possesso di un titolo di studio non inferiore alla laurea che, all'atto della presentazione della domanda al concorso, non ha superato il 35° anno di eta' e ha maturato almeno tre anni di anzianita' nel ruolo di appartenenza; 5-bis) dai volontari in servizio permanente in possesso di un titolo di studio non inferiore alla laurea che, all'atto della presentazione della domanda al concorso, non hanno superato il 35° anno di eta' e hanno maturato almeno cinque anni di anzianita' nel ruolo di appartenenza;
- b) per concorso per titoli ed esami, con il grado ((di sottotenente)), dagli ufficiali inferiori delle forze di completamento in possesso di un titolo di studio non inferiore alla laurea che hanno aderito ai richiami in servizio per le esigenze correlate con le missioni internazionali ovvero sono impiegati in attivita' addestrative, operative e logistiche sia sul territorio nazionale sia all'estero e che non hanno superato il 40° anno d'eta';
- c) per concorso per titoli ed esami con il grado ((di sottotenente)) dagli ufficiali in ferma prefissata in possesso di un titolo di studio non inferiore alla laurea che hanno completato un anno di servizio complessivo;
- d) a domanda, mantenendo il grado, l'anzianita' e la ferma precedentemente contratta, dagli ufficiali frequentatori dei corsi normali delle accademie militari ((iscritti in quanto tali ai corsi universitari quinquennali a ciclo unico ovvero)) in possesso di un titolo di studio non inferiore alla laurea, ((...)) che non hanno completato il previsto ciclo formativo, previo parere favorevole della competente commissione ordinaria di avanzamento che indica il ruolo di transito, valutati i titoli di studio, le attitudini evidenziate e la situazione organica dei ruoli.

1-bis. Gli ufficiali di cui al comma 1, lettera a), numero 4-bis) e lettera d), che partecipano al concorso senza aver conseguito la laurea devono conseguire tale titolo di studio entro l'anno di inserimento in aliquota per la promozione a capitano.

2. Gli ufficiali del ruolo naviganti speciale dell'Aeronautica militare, nonche' gli ufficiali piloti dei ruoli speciali del Corpo di stato maggiore della Marina e del Corpo delle capitanerie di porto sono tratti:

- a) per concorso per titoli ed esami, con il grado di sottotenente: 1) prevalentemente, dal personale appartenente al ruolo dei marescialli in possesso di un titolo di studio non inferiore alla laurea, reclutato ai sensi dell'articolo 679, comma 1, lettera a), previo superamento del concorso e successivo corso finalizzato al conseguimento del brevetto di pilota o navigatore militare, che non ha superato il ventiseiesimo anno di eta'; 2) dagli ufficiali di complemento in possesso di un titolo di studio non inferiore alla laurea del ruolo naviganti, del Corpo di stato maggiore della Marina e del Corpo delle capitanerie di porto muniti di brevetto di pilota o di navigatore militare che non hanno superato il ventottesimo anno di eta' e hanno almeno due anni di servizio;
- b) d'autorita', previo parere della competente commissione ordinaria di avanzamento, dagli ufficiali del ruolo naviganti normale che, non avendo completato gli studi dell'ultimo anno di corso, conseguono comunque il brevetto di pilota o di navigatore militare. Gli stessi mantengono la ferma precedentemente contratta.

3. Gli ufficiali di complemento e il personale appartenente al ruolo dei marescialli possono partecipare ai concorsi di cui al comma 1 limitatamente a quelli concernenti il corpo o il ruolo o la categoria o la specialita' di appartenenza. Con decreto del Ministro della difesa sono definite le corrispondenze occorrenti per la partecipazione ai precedenti concorsi.

4. I candidati utilmente collocati nella graduatoria di merito dei concorsi di cui al comma 1 sono nominati sottotenenti e ammessi a frequentare un corso applicativo.

5. ((COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173)).

5-bis. Gli ufficiali dei ruoli speciali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare sono tratti anche dagli ufficiali dei rispettivi ruoli normali ai sensi degli articoli 726, 728, 729, 732, 833, comma 1-ter, 1100 e 1137-bis.

#### Art. 655-bis. - (Concorso per titoli ed esami nel ruolo speciale riservato ai primi marescialli e ai luogotenenti)

1. Gli ufficiali dei ruoli speciali di cui all'articolo 655, comma 1, possono essere tratti, con il grado di sottotenente, nel limite massimo del 30 per cento dei posti messi annualmente a concorso per ciascuna Forza armata, anche tramite concorso per titoli ed esami dal personale del ruolo dei marescialli che riveste il grado di primo maresciallo e di luogotenente in possesso di un titolo di studio non inferiore alla laurea e dei requisiti previsti per la nomina ad ufficiale in servizio permanente.

2. Ai fini della partecipazione al concorso di cui al comma 1, non vigono i limiti di eta' previsti dall'articolo 655.

3. Le modalita' per lo svolgimento del concorso di cui al comma 1, compresa la definizione dei titoli e delle prove, la loro valutazione, la nomina delle commissioni e la formazione delle graduatorie, sono stabilite con decreto del Ministro della difesa.

((

3-bis. I primi marescialli e i luogotenenti possono partecipare ai concorsi di cui al comma 1, limitatamente a quelli concernenti la categoria, la specialita' ovvero l'abilitazione di appartenenza, secondo le corrispondenze definite dal decreto di cui all'articolo 655, comma 3.

))

#### Art. 656.

(( (Posti destinati al personale appartenente ai ruoli dei marescialli, dei sergenti e dei volontari in servizio permanente).)) ((

1. Nei concorsi per il reclutamento nei ruoli speciali di cui all'articolo 655, comma 1, sono stabilite le seguenti riserve di posti:

- a) per il personale appartenente al ruolo dei marescialli, di cui alla lettera a), numero 1), in misura non inferiore al 50 per cento;
- b) per il personale appartenente al ruolo dei sergenti, di cui alla lettera a), numero 5), in misura pari al 5 per cento;
- c) per il personale appartenente al ruolo dei volontari al servizio permanente, di cui alla lettera a), numero 5-bis), in misura pari al 5 per cento.

2. I posti eventualmente rimasti scoperti sono devoluti in aumento a quelli destinati alle categorie non riservatarie.

#### Art. 657. - Alimentazione straordinaria del ruolo speciale delle armi dell'Aeronautica militare

1. Ferme restando le dotazioni organiche stabilite nel presente codice, il Ministero della difesa ha facolta' di indire annualmente concorsi per titoli ed esami per l'immissione degli ufficiali di complemento, esonerati dal pilotaggio o dalla navigazione aerea ai sensi dell'articolo 943, comma 2, nel ruolo speciale delle armi dell'Aeronautica militare. I concorsi sono espletati secondo le modalita' di cui alla sezione IV del presente capo.

2. All'atto del transito nel ruolo speciale delle armi dell'Aeronautica militare degli ufficiali di cui al comma 1, e' applicata una detrazione d'anzianita' di due anni, senza effetto sul trattamento economico percepito. I vincitori dei concorsi sono iscritti in ruolo, con l'anzianita' di grado rideterminata e a parita' di anzianita' secondo l'ordine della graduatoria concorsuale, dopo i pari grado dei ruoli speciali aventi uguale o maggiore anzianita' di grado.

#### Art. 658. - Alimentazione straordinaria dei ruoli speciali

1. Sulla base delle esigenze di ciascuna Forza armata, se nei rispettivi ruoli speciali non risultano ricoperte particolari posizioni organiche, possono essere indetti annualmente concorsi straordinari per titoli ed esami per il reclutamento di ufficiali nei citati ruoli da trarre dai giovani che non hanno superato il ((35°)) anno di eta' alla data indicata dal bando di concorso e sono in possesso di uno dei diplomi di laurea previsti ai sensi dell'articolo 647, comma 1.

#### Art. 659.

Partecipazione degli ufficiali ausiliari ai concorsi per ufficiali dei ruoli speciali

1. Gli ufficiali in ferma prefissata che hanno completato un anno di servizio e gli ufficiali inferiori delle forze di completamento possono partecipare, in relazione al titolo di studio posseduto e senza aver superato il 40° anno d'eta', ai concorsi per il reclutamento degli ufficiali dei ruoli speciali.

2. Il servizio prestato in qualita' di ufficiale in ferma prefissata costituisce titolo ai fini della formazione delle graduatorie di merito.

3. ((COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173)).

#### Art. 660. - Immissioni in ruolo

1. Per le immissioni in ruolo degli ufficiali si tiene conto delle vacanze complessive esistenti nei ruoli normali e speciali di ciascuna Forza armata.

2. Il numero degli ufficiali da immettere annualmente nei ruoli normali e speciali non puo' superare in ogni caso, per ciascun ruolo, le vacanze esistenti nell'organico complessivo degli ufficiali inferiori ne' eccedere, comunque, rispettivamente un nono e un decimo del predetto organico.

#### Art. 661. - Ripartizione in specialita' degli ufficiali della Marina militare e dell'Aeronautica militare

1. Nei bandi di concorso i posti messi a concorso per gli ufficiali appartenenti ai ruoli della Marina militare e dell'Aeronautica militare possono essere ripartiti tra le varie specialita'.

### SEZIONE III - UFFICIALI DELL'ARMA DEI CARABINIERI

#### Art. 662. - Condizioni per il reclutamento straordinario nel ruolo normale

1. Il concorso di cui all'articolo 652, puo' essere bandito se il prevedibile numero dei sottotenenti che concludono nell'anno il corso di applicazione per essi previsto risulta inferiore a ((1/26)) della consistenza organica degli ufficiali inferiori del ruolo normale.

2. I candidati utilmente collocati nella graduatoria di merito frequentano il corso applicativo di cui all'articolo 722, comma 1, lettera b).

#### Art. 663.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

#### Art. 664. - Alimentazione del ruolo tecnico

1. Il reclutamento degli ufficiali delle varie specialita' del ruolo tecnico dell'Arma dei carabinieri avviene mediante pubblico concorso, per titoli ed esami, al quale possono partecipare:

- a) i cittadini italiani che non hanno superato il trentaduesimo anno di eta' e che sono in possesso dei requisiti generali previsti per gli ufficiali in servizio permanente dell'Arma dei carabinieri, nonche' del diploma di laurea richiesto dal bando di concorso pertinente alla specifica professionalita' del ruolo;
- b) con riserva non superiore al venti per cento dei posti disponibili, i militari in servizio permanente dell'Arma dei carabinieri appartenenti ai ruoli ((degli ispettori, dei sovrintendenti, degli appuntati e carabinieri)) che non hanno superato il ((quarantacinquesimo)) anno di eta', che hanno almeno cinque anni di servizio, che hanno riportato nell'ultimo biennio la qualifica finale non inferiore a «eccellente» e sono in possesso del diploma di laurea magistrale o specialistica richiesto dal bando di concorso.

2. I vincitori del concorso sono:

- a) nominati tenenti con anzianita' relativa stabilita in base all'ordine della graduatoria di merito;
- b) ammessi a frequentare un corso formativo.

#### Art. 664-bis. - (Alimentazione del ruolo forestale)

1. Il reclutamento degli ufficiali del ruolo forestale dell'Arma dei carabinieri avviene mediante pubblico concorso, per titoli ed esami, al quale possono partecipare:

- a) i cittadini italiani che non hanno superato il trentaduesimo anno di eta' e che sono in possesso dei requisiti generali previsti per gli ufficiali in servizio permanente dell'Arma dei carabinieri, nonche' del diploma di laurea magistrale o specialistica richiesto dal bando di concorso pertinente alla specifica professionalita' del ruolo;
- b) con riserva non superiore al venti per cento dei posti disponibili, i militari in servizio permanente dell'Arma dei carabinieri appartenenti ai ruoli ((degli ispettori, dei sovrintendenti, degli appuntati e carabinieri)) che non hanno superato il quarantesimo anno di eta', che hanno riportato nell'ultimo biennio la qualifica finale non inferiore a «eccellente» e sono in possesso del diploma di laurea magistrale o specialistica richiesto dal bando di concorso.

2. I vincitori del concorso sono:

- a) nominati tenenti con anzianita' relativa stabilita in base all'ordine della graduatoria di merito;
- b) ammessi a frequentare un corso di formazione.

#### Art. 665. - Partecipazione degli ufficiali ausiliari ai concorsi

1. Gli ufficiali in ferma prefissata che hanno completato un anno di servizio e gli ufficiali inferiori delle forze di completamento possono partecipare, in relazione al titolo di studio posseduto e senza aver superato il 34° anno di eta', ai concorsi per il reclutamento degli ufficiali del ruolo ((forestale)) e del ruolo ((tecnico)).

2. Il servizio prestato in qualita' di ufficiale in ferma prefissata costituisce titolo ai fini della formazione delle graduatorie di merito.

3. Al termine dei prescritti corsi formativi, gli ufficiali inferiori delle forze di completamento sono iscritti in ruolo, con il grado rivestito, dopo l'ultimo dei parigrado in ruolo.

#### Art. 666. - Immissioni in ruolo

1. Per le immissioni in ruolo degli ufficiali si tiene conto delle vacanze complessive esistenti nei ruoli normale, forestale e tecnico.

2. Il numero di posti da mettere annualmente a concorso per l'immissione nel ruolo normale non puo' in ogni caso superare un tredicesimo della consistenza organica degli ufficiali inferiori del medesimo ruolo.

3. Il numero dei posti da mettere annualmente a concorso per l'immissione nel ruolo tecnico non puo' in ogni caso superare un ((ventiseiesimo)) della consistenza organica degli ufficiali del medesimo ruolo aventi il grado da tenente a tenente colonnello compresi.

3-bis. Il numero di posti da mettere annualmente a concorso per l'immissione nel ruolo forestale non puo' in ogni caso superare un nono della consistenza organica degli ufficiali inferiori del medesimo ruolo.

### SEZIONE IV - CONCORSI RISERVATI AGLI UFFICIALI PILOTI E NAVIGATORI DI COMPLEMENTO

#### Art. 667. - (Concorsi straordinari).

1. Possono essere banditi concorsi per titoli per il reclutamento di capitani e gradi corrispondenti in servizio permanente nel ruolo speciale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni dell'Esercito italiano, nel ruolo speciale del Corpo di stato maggiore della Marina, nel ruolo speciale del Corpo delle capitanerie di porto e nel ruolo naviganti speciale dell'Arma aeronautica ((...)).

((

2. Ai concorsi di cui al comma 1, nei limiti delle vacanze in organico, possono partecipare gli ufficiali di complemento di cui all'articolo 676, in possesso del diploma di istruzione secondaria di secondo grado e dei requisiti prescritti per la nomina ad ufficiale in servizio permanente che alla data di scadenza dei termini di presentazione della domanda hanno prestato almeno undici anni di servizio decorrenti dalla data di inizio della ferma.

))

3. All'atto del transito nei ruoli speciali, ai vincitori dei concorsi di cui al comma 1 e' applicata una detrazione di anzianita' di due anni senza effetto sul trattamento economico percepito. Effettuati gli avanzamenti ordinari dell'anno di riferimento, i vincitori dei concorsi sono iscritti in ruolo, con l'anzianita' di grado rideterminata e, a parita' di anzianita', secondo l'ordine della graduatoria concorsuale, dopo i pari grado dei ruoli speciali aventi uguale o maggiore anzianita' di grado, ovvero dopo l'ufficiale del ruolo speciale avente uguale o maggiore anzianita' di servizio.

4. Nei confronti degli ufficiali transitati nei ruoli speciali con i concorsi di cui al comma 1 non hanno effetto le ricostruzioni di carriera operate a favore degli ufficiali dei ruoli a esaurimento in servizio permanente.

5. I concorsi sono espletati secondo le modalita' di cui di cui agli articoli 668 e 669. Nella graduatoria di merito e' attribuito un punto per ogni anno di servizio prestato senza demerito nella ferma contratta all'atto dell'ammissione ai corsi di pilotaggio aereo o ai corsi per navigatori militari.

#### Art. 668. - Commissioni di concorso

1. Le commissioni giudicatrici dei concorsi sono nominate con decreto del Ministro della difesa e sono composte come segue:

- a) per l'Esercito italiano da: 1) un ufficiale proveniente dal ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni di grado non inferiore a ((colonnello)) - presidente; 2) due ufficiali del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni di grado non inferiore a tenente colonnello - membri; 3) un funzionario della carriera direttiva di qualifica non superiore a direttore di sezione - segretario senza diritto di voto;
- b) per la Marina militare da: 1) un ufficiale di stato maggiore di grado non inferiore a ((capitano di vascello)) - presidente; 2) due ufficiali di stato maggiore di grado non inferiore a capitano di fregata - membri, se i giudicandi appartengono al Corpo di stato maggiore; 3) due ufficiali delle capitanerie di porto di grado non inferiore a capitano di fregata - membri, se i giudicandi appartengono al Corpo delle capitanerie di porto; 4) un funzionario della carriera direttiva di qualifica non superiore a direttore di sezione - segretario senza diritto di voto;
- c) per l'Aeronautica militare da: 1) un ufficiale dell'Arma aeronautica, ruolo naviganti, di grado non inferiore a ((colonnello)) - presidente; 2) due ufficiali dell'Arma aeronautica, ruolo naviganti normale, di grado non inferiore a tenente colonnello - membri; 3) un funzionario della carriera direttiva di qualifica non superiore a direttore di sezione - segretario senza diritto di voto;
- d) LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95.

#### Art. 669. - Elementi di valutazione

1. Le commissioni giudicatrici di cui all'articolo 668 valutano:

- a) i titoli relativi alle qualita' militari e professionali;
- b) ogni altro titolo, ricompensa e benemerenza risultante dallo stato di servizio, dal libretto personale, dalla pratica personale o dai documenti presentati dai concorrenti tra quelli indicati nel bando di concorso.

2. Per la valutazione dei titoli sopra indicati, che devono essere posseduti dai candidati alla data del bando di concorso, e' assegnato un massimo di 45 punti, ripartiti nel seguente modo:

- a) 30 punti per i titoli di cui alla lettera a) del comma 1;
- b) 15 punti per i titoli di cui alla lettera b) del comma 1.

3. Coloro che non hanno riportato almeno 15 punti per i titoli di cui alla lettera a) del comma 1 sono dichiarati non idonei.

4. Ogni componente della commissione giudicatrice dispone, per ciascuno dei titoli di cui alle lettere a) e b) del comma 1, soltanto di un terzo del punteggio massimo per le medesime stabilito.

5. La graduatoria del concorso e' formata in base al punteggio risultante dalla valutazione dei titoli di cui alle lettere a) e b) del comma 1.

#### Art. 670. - Nomina nel servizio permanente

1. Gli ufficiali idonei, che nella graduatoria sono compresi nel numero dei posti messi a concorso per ciascun ruolo, sono dichiarati vincitori del concorso stesso e nominati, rispettivamente ((...)), capitani in servizio permanente effettivo del ruolo speciale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni, tenenti di vascello in servizio permanente effettivo del ruolo speciale del Corpo di stato maggiore o del Corpo delle capitanerie di porto, capitani in servizio permanente effettivo dell'Aeronautica militare del ruolo naviganti speciale.

2. I vincitori del concorso assumono una anzianita' assoluta pari a quella posseduta nel grado di capitano o di tenente di vascello alla data del decreto di nomina in servizio permanente effettivo, diminuita di due anni, e prendono posto nei rispettivi ruoli, in relazione a detta anzianita' assoluta, nell'ordine della graduatoria del concorso, dopo l'ultimo pari grado avente la stessa anzianita' assoluta.

3. I servizi precedentemente prestati dagli ufficiali reclutati nel servizio permanente effettivo, a norma del presente articolo, possono essere riscattati, a domanda degli interessati, ai fini della liquidazione dell'indennita' di buonuscita INPDAP e dell'indennita' supplementare di cui all'articolo 1914.

#### Art. 671.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

## CAPO III - UFFICIALI AUSILIARI

### SEZIONE I - UFFICIALI IN FERMA PREFISSATA

#### Art. 672. - Requisiti speciali

1. Gli ufficiali in ferma prefissata sono reclutati tra coloro che hanno superato con esito favorevole gli appositi corsi formativi. Ai predetti corsi si accede tramite pubblico concorso al quale possono partecipare coloro che:

- a) non hanno superato il 38° anno d'eta';
- b) non sono gia' in servizio quali ufficiali ausiliari in ferma prefissata o si trovano nella posizione di congedo per aver completato la ferma quali ufficiali ausiliari in ferma prefissata;
- c) sono in possesso di diploma di istruzione secondaria di secondo grado ovvero di diploma di laurea.

2. Ai corsi di cui al comma 1, per l'Arma dei carabinieri, si accede tramite pubblico concorso al quale possono partecipare coloro che:

- a) non hanno superato il 32° anno d'eta';
- b) non sono gia' in servizio quali ufficiali ausiliari in ferma prefissata o si trovano nella posizione di congedo per aver completato la ferma quali ufficiali ausiliari in ferma prefissata;
- c) sono in possesso di diploma di istruzione secondaria di secondo grado ovvero di diploma di laurea.

#### Art. 673. - Norme generali sui concorsi

1. Con decreto del Ministro della difesa sono stabiliti:

- a) i titoli di studio richiesti per l'ammissione ai singoli corsi, ed eventualmente ulteriori requisiti, le tipologie e le modalita' dei concorsi, inclusa la composizione delle commissioni, le eventuali prove di esame, prevedendo, se necessario, programmi differenziati in relazione ai titoli di studio richiesti, nonche' la durata dei corsi; le modalita' per lo svolgimento dei rispettivi corsi di formazione e relativi programmi sono determinati dai rispettivi Stati maggiori o Comando generale;
- b) i requisiti psico-fisici e attitudinali richiesti ai fini dell'esercizio delle mansioni previste per gli ufficiali in ferma prefissata.

2. I bandi di concorso per il reclutamento degli ufficiali in ferma prefissata possono prevedere:

- a) riserve di posti a favore dei diplomati presso le scuole militari, e dei figli di militari deceduti in servizio, nel limite massimo complessivo del trenta per cento dei posti disponibili;
- b) la ripartizione dei posti messi a concorso per armi, ((corpi,)) specialita' o specializzazioni.

### SEZIONE II - UFFICIALI DI COMPLEMENTO

#### Art. 674. - Conferimento diretto del grado di ufficiale di complemento

1. La nomina a ufficiale di complemento, senza concorso e in via eccezionale, puo' essere conferita ai cittadini italiani in possesso di spiccata professionalita' che danno ampio affidamento di prestare opera proficua nelle Forze armate.

2. Puo' essere conferito senza concorso il grado di tenente colonnello di complemento o corrispondente ai cittadini che godono di fama indiscussa in materie attinenti ai servizi delle Forze armate.

3. Per comprovata alta competenza in discipline nautiche, aeronautiche o tecniche, da valutarsi caso per caso, nelle nomine di cui al comma 1 si puo' prescindere anche dal prescritto titolo di studio, salvo che per la nomina a ufficiale di complemento nei corpi sanitari o nel comparto sanitario del ruolo tecnico ((...)) dell'Arma dei carabinieri.

4. La nomina e' conferita previo giudizio della competente commissione ordinaria d'avanzamento, che stabilisce il grado e il ruolo d'assegnazione, sentiti i rispettivi Capi di stato maggiore o Comandante generale.

5. Con decreto del Ministro della difesa sono individuate in relazione alle specifiche esigenze di ciascuna Forza armata:

- a) le professionalita' e i gradi conferibili, ai sensi del presente articolo;
- b) le procedure da seguirsi;
- c) gli eventuali ulteriori requisiti per la nomina.

#### Art. 675. - Reclutamento in servizio di prima nomina

1. Il reclutamento degli ufficiali di complemento in servizio di prima nomina, in adempimento degli obblighi di leva, avviene esclusivamente nelle ipotesi di ripristino del servizio militare obbligatorio di cui all'articolo 1929, comma 2.

2. I criteri e le modalita' per l'arruolamento degli ufficiali di complemento delle Forze armate, sono stabiliti con decreto del Ministro della difesa, il quale deve indicare, in particolare, i titoli di studio richiesti per l'ammissione ai diversi corsi, nonche' i requisiti somatico-funzionali e psicoattitudinali necessari anche in relazione agli incarichi da espletare.

3. I bandi di concorso o di arruolamento per l'ammissione ai corsi allievi ufficiali di complemento delle Forze armate e le graduatorie degli ammessi sono pubblicati sul Giornale ufficiale del Ministero della difesa. Della pubblicazione e' dato immediato avviso nella Gazzetta Ufficiale e copia della graduatoria e' posta in visione presso le stazioni dei carabinieri e le capitanerie di porto.

4. Avverso le suddette graduatorie e' ammesso ricorso al Ministro della difesa entro 90 giorni dalla pubblicazione.

5. La durata della ferma di leva per gli ufficiali di complemento di prima nomina e' di 14 mesi.

### SEZIONE III - UFFICIALI PILOTI E NAVIGATORI DI COMPLEMENTO

#### Art. 676. - Reclutamento

1. Gli ufficiali piloti e navigatori di complemento dell'Esercito italiano, della Marina militare ((e dell'Aeronautica militare)) sono reclutati mediante corsi di pilotaggio aereo o corsi per navigatori militari, previa sottoscrizione di una ferma di anni dodici.

2. I requisiti per essere ammessi ai suddetti corsi sono i seguenti:

- a) non aver superato il ventitreesimo anno di eta';
- b) aver conseguito un diploma di istituito di istruzione secondaria di secondo grado;
- c) possedere le qualita' fisiche e psico-attitudinali, accertate presso appositi organi dell'Aeronautica militare, necessarie per effettuare la navigazione aerea, in qualita' di piloti militari o di navigatori militari.

2-bis. Fermo restando il numero massimo degli ufficiali piloti e navigatori di complemento determinato annualmente con la legge di approvazione del bilancio di previsione dello Stato, in relazione ai risultati conseguiti nei reclutamenti pianificati negli anni precedenti, su richiesta della Forza armata interessata possono essere ammessi ai corsi di pilotaggio aereo o ai corsi per navigatori militari i giovani che non abbiano superato il venticinquesimo anno di eta' alla data di emanazione del bando di concorso.

#### Art. 677.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### SEZIONE IV - DISPOSIZIONI FINALI

#### Art. 678. - Incentivi per il reclutamento degli ufficiali ausiliari

1. L'assunzione in servizio quale ufficiale ausiliario sospende il rapporto di lavoro per tutto il periodo della ferma o della rafferma e il lavoratore ha diritto alla conservazione del posto. Entro trenta giorni dal congedo, il lavoratore deve porsi a disposizione del datore di lavoro per riprendere servizio. In mancanza, il rapporto di lavoro e' risolto.

2. Agli ufficiali ausiliari si applicano le disposizioni dell'articolo 990.

3. I periodi di servizio prestati quale ufficiale ausiliario sono valutati nei pubblici concorsi con un punteggio incrementale non inferiore a quello che le commissioni esaminatrici attribuiscono per i servizi prestati negli impieghi civili presso enti pubblici.

4. Per gli ufficiali ausiliari che hanno prestato servizio senza demerito ((per almeno 18 mesi)) nell'Esercito italiano, nella Marina militare e nell'Aeronautica militare sono previste riserve di posti fino all'80 per cento dei posti annualmente disponibili per la partecipazione ai concorsi per gli ufficiali in servizio permanente dei ruoli normali a nomina diretta, di cui all'articolo 652.

5. Per gli ufficiali in ferma prefissata con almeno diciotto mesi di servizio e per gli ufficiali di complemento e gli ufficiali delle forze di completamento, che hanno prestato servizio senza demerito nell'Arma dei carabinieri sono previste riserve di posti fino all'80 per cento dei posti annualmente disponibili per l'accesso al ruolo tecnico dell'Arma dei carabinieri.

6. COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95.

7. Le disposizioni di cui all'articolo 1013 si applicano anche agli ufficiali ausiliari, che hanno prestato servizio senza demerito.

8. La struttura ministeriale deputata all'inserimento dei volontari congedati nel mondo del lavoro svolge le attivita' di propria competenza anche a beneficio degli ufficiali ausiliari.

9. Le riserve di posti di cui all'articolo 1014, si applicano anche agli ufficiali di complemento in ferma biennale e agli ufficiali in ferma prefissata che hanno completato senza demerito la ferma contratta.

## CAPO IV - MARESCIALLI E ISPETTORI

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 679. - Modalita' di reclutamento dei marescialli e degli ispettori

1. Il reclutamento nei ruoli marescialli, in relazione ai posti disponibili in organico, avviene:

- a) per il 70 per cento dei posti mediante pubblico concorso;
- b) per il 30 per cento dei posti mediante concorso interno, riservato agli appartenenti ai ruoli sergenti e agli appartenenti ai rispettivi ruoli iniziali in servizio permanente.

2. Gli articoli successivi stabiliscono eventuali requisiti speciali per la partecipazione ai predetti concorsi e le ulteriori quote di ripartizione dei posti messi a concorso.

2-bis. Il reclutamento nel ruolo ispettori dell'Arma dei carabinieri, in relazione ai posti disponibili in organico, avviene:

- a) per il 70 per cento dei posti mediante pubblico concorso;
- c) per il 10 per cento dei posti mediante concorso interno, riservato al ruolo appuntati e carabinieri ((in servizio permanente)).

((

2-ter. La posizione di stato di cui al comma 2-bis, lettere b) e c), deve essere mantenuta fino al termine del relativo corso di formazione.

))

#### Art. 680. - Limiti di eta'

1. Gli aumenti dei limiti di eta' previsti per l'ammissione ai concorsi per pubblici impieghi non si applicano ai limiti massimi di eta' stabiliti per il reclutamento nei ruoli marescialli e ispettori.

#### Art. 681. - Posti riservati a particolari categorie per i concorsi dei ruoli marescialli e ispettori

1. La quota dei posti relativi al reclutamento del personale dei ruoli dei marescialli delle Forze armate e degli ispettori dell'Arma dei carabinieri, di cui all'articolo 645, e' altresi' riservata ai diplomati presso le scuole militari e agli assistiti dall'Opera nazionale di assistenza per gli orfani dei militari di carriera dell'Esercito italiano, dall'Istituto Andrea Doria per l'assistenza dei familiari e degli orfani del personale della Marina militare, dall'Opera nazionale per i figli degli aviatori e dall'Opera nazionale di assistenza per gli orfani dei militari dell'Arma dei carabinieri, in possesso dei requisiti prescritti.

### SEZIONE II - MARESCIALLI DELL'ESERCITO ITALIANO, DELLA MARINA MILITARE E DELL'AERONAUTICA MILITARE

#### Art. 682. - Alimentazione dei ruoli dei marescialli

1. Il personale del ruolo dei marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare reclutato tramite concorso pubblico contrae una ferma biennale ed e' immesso in ruolo al superamento del corso di formazione previsto all'articolo 760, comma 1.

2. Il personale reclutato tramite concorso interno e' immesso in ruolo al superamento di uno dei corsi previsti dall'articolo 760, commi 1 e 1-bis.

3. I posti di cui all'articolo 679, comma 1, lettera b), eventualmente rimasti scoperti, possono essere devoluti in aumento al numero dei posti previsti alla lettera a) del medesimo articolo.

4. Ai concorsi di cui all'articolo 679, comma 1, lettera a), possono partecipare:

- a) i giovani che: 1) sono riconosciuti in possesso della idoneita' agli incarichi, specializzazioni, categorie e specialita' di assegnazione; 2) non hanno compiuto il 26° anno di eta'. Per coloro che hanno gia' prestato servizio militare obbligatorio o volontario il limite massimo e' elevato a 28 anni, qualunque grado rivestono; 3) sono in possesso del diploma di corso quinquennale di istruzione secondaria di secondo grado o lo conseguono ((entro l'anno solare in cui e' bandito il concorso o, se successivo, entro il temine previsto dal bando per la presentazione delle domande)), fermo restando che, per il reclutamento delle professioni sanitarie, i concorrenti devono sostenere una specifica prova di selezione su argomenti attinenti a materie indicate dal Ministero dell'istruzione, dell'universita' e della ricerca, superata la quale, ove risultino vincitori di concorso, acquisiscono titolo all'ammissione ai corsi di laurea nei limiti numerici programmati a livello nazionale, che tengono conto delle esigenze numeriche della Difesa;
- b) gli appartenenti ai ruoli dei sergenti e dei volontari in servizio permanente, i volontari in ferma o i militari di leva in servizio che, alla data prevista dal bando: 1) sono in possesso del diploma di corso quinquennale di istruzione secondaria di secondo grado o lo conseguono ((entro l'anno solare in cui e' bandito il concorso o, se successivo, entro il temine previsto dal bando per la presentazione delle domande)), fermo restando che, per il reclutamento delle professioni sanitarie, i concorrenti devono sostenere una specifica prova di selezione su argomenti attinenti a materie indicate dal Ministero dell'istruzione, dell'universita' e della ricerca, superata la quale, ove risultino vincitori di concorso, acquisiscono titolo all'ammissione ai corsi di laurea nei limiti numerici programmati a livello nazionale, che tengono conto delle esigenze numeriche della Difesa; 2) non hanno superato il ventottesimo anno di eta'; 3) non hanno riportato sanzioni disciplinari piu' gravi della consegna nell'ultimo biennio o nel periodo di servizio prestato se inferiore a due anni; 4) sono in possesso della qualifica non inferiore a «superiore alla media» o giudizio corrispondente nell'ultimo biennio o nel periodo di servizio prestato se inferiore a due anni.

5. Ai concorsi di cui all'articolo 679, comma l, lettera b), possono partecipare: ((62))

- a) gli appartenenti al ruolo sergenti nel limite minimo del 30 per cento dei posti disponibili mediante: 1) concorso per titoli, nel limite massimo del 50 per cento dei posti di cui all'alinea della presente lettera a), per i sergenti maggiori capo che alla data prevista nel bando di concorso: 1.1) non hanno superato il 48° anno di eta'; 1.2) hanno riportato nell'ultimo ((triennio)) in servizio permanente la qualifica di almeno «superiore alla media» o giudizio corrispondente; 1.3) non hanno riportato sanzioni disciplinari piu' gravi della consegna nell'ultimo biennio; 1.4) sono in possesso del diploma quinquennale di istruzione secondaria di secondo grado o lo conseguono ((entro l'anno solare in cui e' bandito il concorso o, se successivo, entro il temine previsto dal bando per la presentazione delle domande)); 2) concorso per titoli ed esami, nel limite minimo del 50 per cento dei posti di cui all'alinea della presente lettera a), per gli appartenenti al ruolo sergenti in possesso dei requisiti di cui ai numeri 1.2), 1.3) e 1.4), che non hanno superato il ((45°)) anno di eta';
- b) gli appartenenti al ruolo dei volontari in servizio permanente nel limite massimo del 70 per cento dei posti disponibili, mediante concorso per titoli ed esami, che alla data prevista nel bando di concorso non hanno superato il 45° anno di eta', hanno compiuto ((sette)) anni di servizio di cui almeno ((tre)) in servizio permanente e sono in possesso dei requisiti di cui alla lettera a), numeri 1.2), 1.3) e 1.4).

5-bis. Per specifiche esigenze delle singole Forze armate, possono essere altresi' banditi, nei limiti delle risorse finanziarie disponibili, concorsi per titoli ed esami per trarre, con il grado di maresciallo e corrispondenti, giovani:

- a) in possesso di laurea definita con decreto del Ministro della difesa, di concerto con il Ministro delle infrastrutture e dei trasporti per i concorsi relativi al Corpo delle capitanerie di porto;
- b) di eta' non superiore a 32 anni alla data indicata nel bando di concorso.

((6. Le norme per lo svolgimento dei concorsi di cui ai commi 4, 5 e 5-bis, compresa la definizione degli eventuali ulteriori requisiti, dei titoli e delle prove, la loro valutazione, la nomina delle commissioni e la formazione delle graduatorie, sono stabilite con decreto del Ministro della difesa, acquisito il concerto del Ministro delle infrastrutture e dei trasporti per la parte riferita al Corpo delle capitanerie di porto.))

-------------- AGGIORNAMENTO (62) Il D.Lgs. 27 dicembre 2019, n. 173, ha disposto (con l'art. 4, comma 1, lettera b)) che al comma 5 del presente articolo, nell'alinea "le parole «comma 11» sono sostituite dalle seguenti: «comma 1»".

### SEZIONE III - ISPETTORI DELL'ARMA DEI CARABINIERI

#### Art. 683. - (Alimentazione del ruolo degli ispettori)

1. Il personale del ruolo ispettori reclutato mediante pubblico concorso e' immesso in ruolo al superamento di apposito corso della durata di 2 anni accademici.

2. Il personale reclutato tramite concorsi interni e' immesso in ruolo al superamento ((del corso di cui all'articolo 685)).

3. I posti rimasti scoperti in uno dei concorsi di cui all'articolo 679, comma 2-bis, ((lettera b) )), sono devoluti in favore dei concorrenti risultati idonei ma non vincitori dell'altro concorso. ((I posti rimasti scoperti nei concorsi di cui all'articolo 679, comma 2-bis, lettera b), sono devoluti in favore dei concorrenti risultati idonei ma non vincitori del concorso di cui all'articolo 679, comma 2-bis, lettera c) e viceversa.))

((

3-bis. I brigadieri che vengono promossi al grado superiore dopo il termine per la presentazione delle domande al concorso previsto dall'articolo 679, comma 2-bis, lettera b), numero 1), possono partecipare al concorso previsto dall'articolo 679, comma 2-bis, lettera b), numero 2), bandito nel medesimo anno solare.

))

4. Possono partecipare ai concorsi di cui al comma 3 gli appartenenti al ruolo dei sovrintendenti e al ruolo degli appuntati e carabinieri che alla data di scadenza dei termini per la presentazione delle domande:

- a) hanno prestato servizio nel ruolo per almeno 4 anni;
- b) sono idonei al servizio militare incondizionato. Coloro che temporaneamente non sono idonei sono ammessi al concorso con riserva fino alla visita medica prevista dall'articolo 686, ((comma 2, lettera d) ));
- c) non hanno riportato, nell'ultimo biennio, o nel periodo di servizio prestato, se inferiore a due anni, sanzioni disciplinari piu' gravi della «consegna»;
- d) sono in possesso della qualifica non inferiore a «nella media» o giudizio corrispondente nell'ultimo biennio, o nel periodo di servizio prestato se inferiore a due anni;
- e) non sono stati comunque gia' dispensati d'autorita' dal corso per allievo maresciallo;
- f) non sono stati giudicati non idonei all'avanzamento al grado superiore nell'ultimo biennio.

5. Il titolo di studio per la partecipazione ai concorsi previsti dall'articolo 679 e':

- a) il diploma di istruzione secondaria di secondo grado, per il personale di cui al comma 2-bis, lettera b) del medesimo articolo 679;
- b) la laurea triennale a indirizzo giuridico, per il personale di cui al comma 2-bis, lettera c) del medesimo articolo 679.

6. Le modalita' di svolgimento dei concorsi di cui all'articolo 679, comma 2-bis, l'individuazione e la valutazione dei titoli, il numero dei posti da mettere a concorso nel limite delle vacanze nell'organico del ruolo sono stabilite nei relativi bandi di concorso, emanati con decreto ministeriale.

7. Al fine di soddisfare le esigenze in materia di sicurezza e tutela ambientale, forestale e agroalimentare, e' stabilito nei relativi bandi di concorso, emanati con decreto ministeriale:

- a) per il concorso di cui all'articolo 679, comma 2-bis, lettera a), il numero dei posti degli ispettori da formare nelle relative specializzazioni in misura, comunque, non inferiore al 4 per cento dei posti da mettere a concorso;
- b) nell'ambito di ciascun concorso di cui all'articolo 679, comma 2-bis, lettere b) e c), il numero dei posti da riservare al personale gia' in possesso delle relative specializzazioni, in misura comunque non inferiore al 4 per cento dei posti da mettere a concorso. Il personale specializzato che concorre per tale riserva di posti non puo' concorrere, nel medesimo anno di riferimento, per la rimanente parte di posti disponibili.

8. Per il reclutamento degli ispettori della banda dell'Arma dei carabinieri si applicano le norme contenute nel regolamento.

9. Il reclutamento degli ispettori del Reggimento Corazzieri avviene con le modalita' stabilite al capo VI del presente titolo.

#### Art. 684. - Ammissione al corso biennale

1. L'ammissione al corso previsto dall'articolo 683, comma 1, ha luogo sulla base di una graduatoria formata con i punti di merito delle prove d'esame previste dall'articolo 686, comma 1, lettere b) e c), e i punti attribuiti per gli eventuali titoli ((...)) la cui individuazione e valutazione sono stabilite nel bando di concorso.

2. Possono partecipare al concorso:

- a) gli appartenenti al ruolo dei sovrintendenti e al ruolo degli appuntati e carabinieri, gli allievi carabinieri, nonche' gli ufficiali di complemento dell'Arma che alla data di scadenza dei termini per la presentazione delle domande: 1) sono idonei al servizio militare incondizionato. Coloro che temporaneamente non sono idonei sono ammessi al concorso con riserva fino alla visita medica prevista dall'articolo 686, comma 1, lettera e); 2) sono in possesso del diploma di istruzione secondaria di secondo grado, o lo conseguono nell'anno solare in cui e' bandito il concorso, che consente l'iscrizione ai corsi per il conseguimento del diploma universitario o laurea breve previsti nel bando di concorso; 3) non hanno superato il trentesimo anno di eta'; 4) non hanno riportato, nell'ultimo biennio, o nel periodo di servizio prestato, se inferiore a due anni, sanzioni disciplinari piu' gravi della <<consegna>>; 5) sono in possesso della qualifica non inferiore a <<nella media>> o giudizio corrispondente nell'ultimo biennio, o nel periodo di servizio prestato se inferiore a due anni; 6) non sono stati giudicati, se appartenenti ai ruoli sovrintendenti e appuntati e carabinieri, non idonei all'avanzamento al grado superiore nell'ultimo biennio;
- b) i cittadini italiani che: 1) sono in possesso del diploma di istruzione secondaria di secondo grado o lo conseguono nell'anno solare in cui e' bandito il concorso, che consente l'iscrizione ai corsi per il conseguimento del diploma universitario o laurea breve previsti nel bando di concorso; 2) non hanno superato il ventiseiesimo anno di eta'; per coloro che hanno gia' prestato servizio militare per una durata non inferiore alla ferma obbligatoria il limite di eta' e' elevato a 28 anni; 3) non si trovano in situazioni comunque non compatibili con l'acquisizione o conservazione dello stato di maresciallo dell'Arma dei carabinieri.

#### Art. 685. - (Ammissione al corso superiore di qualificazione)

((

1. Il corso superiore di qualificazione si compone di due fasi, la prima, della durata non inferiore a un mese, dedicata ai soli appartenenti al ruolo appuntati e carabinieri, e la seconda, della durata non inferiore a mesi sei, dedicata anche al personale del ruolo sovrintendenti.

))

2. L'ammissione al corso:

- a) ai sensi dell'articolo 679, comma 2-bis, lettera b), ((numero 1),)) avviene mediante un concorso per titoli, previo superamento degli adempimenti previsti dall'articolo 686, comma 2, lettere c) e d), al quale sono ammessi gli aspiranti utilmente collocati nella graduatoria finale di merito, approvata con decreto ministeriale;
- a-bis) ai sensi dell'articolo 679, comma 2-bis, lettera b), numero 2), ha luogo sulla base di una graduatoria formata con i punti di merito riportati nelle prove d'esame previste dall'articolo 686, comma 2, e i punti attribuiti per gli eventuali titoli la cui individuazione e valutazione e' stabilita nel bando di concorso;
- b) ai sensi dell'articolo 679, comma 2-bis, lettera c), ha luogo sulla base di una graduatoria formata con i punti di merito riportati nelle prove d'esame previste dall'articolo 686, comma 2, e i punti attribuiti per gli eventuali titoli la cui individuazione e valutazione e' stabilita nel bando di concorso.

3. Le modalita' di svolgimento dei concorsi, la nomina della commissione di cui all'articolo 687, l'individuazione e la valutazione dei titoli, il numero dei posti da mettere a concorso nel limite delle vacanze nell'organico del ruolo e i criteri per la formazione delle graduatorie sono stabiliti con decreto ministeriale. Tra i titoli di merito assume particolare rilevanza, per quanto concerne l'attribuzione del relativo punteggio, l'aver retto in sede vacante, senza demerito, il comando di stazione territoriale, per un periodo almeno pari a quello necessario per la redazione del rapporto informativo di cui all'articolo 1025, comma 3.

#### Art. 686. - Prove concorsuali

1. Gli esami per l'ammissione al corso di cui all'articolo 684, sono costituiti da:

- a) una prova di efficienza fisica;
- b) una prova scritta intesa ad accertare il grado di conoscenza della lingua italiana;
- c) una prova orale sulle materie indicate nel bando di concorso;
- d) un accertamento attitudinale di idoneita' al servizio nell'Arma quale maresciallo del ruolo ispettori dei carabinieri, da parte del centro nazionale di selezione e reclutamento dei carabinieri. Il giudizio espresso in sede di detto accertamento e' definitivo;
- e) una visita medica da parte di una commissione, costituita da un ufficiale medico di grado non inferiore a tenente colonnello quale presidente e da due ufficiali medici quali componenti, dei quali il meno anziano in ruolo svolge anche funzioni di segretario, il cui giudizio e' definitivo. Per il concorrente gia' in servizio nell'Arma, a eccezione degli allievi carabinieri, l'accertamento e' limitato alla verifica dell'assenza di infermita' invalidanti in atto.

2. Gli esami di concorso per l'ammissione al corso di cui all'articolo 685, sono costituiti da:

- a) una prova scritta attinente ai servizi d'istituto;
- b) una prova orale su argomenti riguardanti i servizi di istituto e la cultura generale;
- c) un accertamento attitudinale di idoneita' al servizio nell'Arma quale maresciallo del ruolo ispettori dei carabinieri, da parte del centro nazionale di selezione e reclutamento dei carabinieri. Il giudizio espresso in sede di detto accertamento e' definitivo;
- d) una visita medica da parte di una commissione, composta da un ufficiale medico di grado non inferiore a tenente colonnello quale presidente e da due ufficiali medici quali membri, dei quali il meno anziano in ruolo svolge anche funzioni di segretario, tendente ad accertare l'assenza di infermita' invalidanti in atto. Per gli appartenenti ai ruoli sovrintendenti e appuntati e carabinieri, che sono stati giudicati permanentemente non idonei in modo parziale al servizio d'istituto, la visita medica e' finalizzata ad accertare l'assenza di ulteriori infermita' invalidanti in atto.

3. Le prove di esame e gli accertamenti fisici e attitudinali di cui ai commi 1 e 2 possono essere preceduti da una prova preliminare a carattere generale svolta mediante idonei test, il cui superamento costituisce requisito indispensabile per l'ammissione alle ulteriori prove concorsuali.

4. La successione, le modalita' e i tempi di svolgimento delle prove di efficienza fisica, di quelle scritta e orale, della visita medica e dell'accertamento attitudinale, di cui ai commi 1 e 2, saranno stabiliti nei relativi bandi di concorso.

#### Art. 687. - Commissione d'esame

1. La commissione esaminatrice dei concorsi per l'ammissione ai corsi di cui all'articolo 684, e' composta da:

- a) un ufficiale generale dell'Arma dei carabinieri, presidente;
- b) un ufficiale superiore dell'Arma dei carabinieri, membro;
- c) un insegnante di italiano in possesso del prescritto titolo accademico, membro;
- d) un luogotenente, segretario senza diritto al voto.

2. Se il numero dei concorrenti ammessi ai concorsi previsti ((dagli articoli 684 e 685)) e' rilevante, la commissione di cui al comma 1 puo' essere integrata da un numero di componenti tali che permetta, unico restando il presidente, la suddivisione in sottocommissioni, costituite ciascuna da un numero di componenti pari a quello della commissione originaria.

3. La commissione e le sottocommissioni di cui ai commi 1 e 2 sono nominate con decreto ministeriale.

#### Art. 688. - Valutazione delle prove scritta e orale e formazione della graduatoria di merito

1. La commissione di cui all'articolo 687, assegna alla prova scritta giudicata sufficiente un punto di merito da diciotto a trenta trentesimi.

2. Il concorrente che ha riportato la sufficienza nella prova scritta e che e' stato giudicato idoneo alla visita medica e agli accertamenti attitudinali nonche' alla prova di efficienza fisica e' ammesso a sostenere la prova orale.

3. La commissione assegna a ciascun concorrente per la prova orale un punto di merito espresso in trentesimi. E' idoneo il concorrente che riporta un punto di merito di almeno diciotto trentesimi.

4. La media aritmetica dei punti riportati nella prova scritta e nella prova orale costituisce il punto da attribuire a ciascun concorrente ai fini della formazione della graduatoria di merito, maggiorato dagli incrementi per gli eventuali titoli stabiliti nel bando di concorso.

5. A parita' di merito e' data la precedenza agli orfani di guerra ed equiparati, ai figli di decorati al valor militare, di medaglia d'oro al valore dell'Arma dei carabinieri, al valore dell'Esercito, al valor di Marina, al valor Aeronautico o al valor civile, nonche' ai figli di vittime del dovere.

6. I concorrenti utilmente compresi nella graduatoria di merito sono ammessi al corso allievi marescialli presso la scuola marescialli dell'Arma dei carabinieri nell'ordine della graduatoria stessa fino alla concorrenza dei posti messi a concorso.

7. I termini di validita' della graduatoria dei candidati risultati idonei ma non vincitori del concorso per l'ammissione al corso biennale di cui all'articolo 684 possono essere prorogati con motivata determinazione ministeriale, in caso di successivi e analoghi concorsi banditi entro diciotto mesi dall'approvazione della stessa.

#### Art. 689. - Prova facoltativa

1. Il concorrente che ne fa richiesta in sede di domanda di ammissione al concorso e riporta l'idoneita' nelle altre prove d'esame, negli accertamenti e nelle visite mediche di cui all'articolo 686, e' sottoposto all'esame delle lingue estere ((ovvero, in aggiunta o in alternativa, all'esame delle materie di interesse professionale)) prescelte tra quelle indicate nel bando di concorso, secondo i programmi in esso stabiliti.

2. La commissione esaminatrice delle ((prove di cui al comma 1)) e' quella di cui all'articolo 687, sostituito all'insegnante di lingua italiana un insegnante della lingua estera ((o della materia di interesse professionale)) oggetto dell'esame, in possesso del prescritto titolo accademico, o, in mancanza, un ufficiale qualificato conoscitore della lingua ((o della materia)) stessa.

3. La commissione assegna ((per ciascuna prova facoltativa)) un punto di merito espresso in trentesimi. L'idoneita' si consegue riportando il punteggio di almeno diciotto trentesimi. Il concorrente che consegua l'idoneita' ottiene nel punteggio della graduatoria finale di merito le maggiorazioni stabilite nel bando di concorso.

## CAPO V - SERGENTI E SOVRINTENDENTI

### Art. 690. - (Modalita' di reclutamento dei sergenti e dei sovrintendenti)

1. Il reclutamento nei ruoli sergenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare avviene mediante concorsi interni ((e successivo corso di formazione basico,)), riservati:

- a) ((nel limite massimo del 60 per cento)) dei posti disponibili mediante concorso per titoli ed esami riservato agli appartenenti ai ruoli dei volontari in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare;
- b) ((nel limite minimo del 40 per cento)) dei posti disponibili mediante concorso per titoli riservato al personale appartenente ai ruoli dei volontari in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare con un'anzianita' minima di dieci anni nel ruolo.

2. I posti di cui al comma 1, lettera a) rimasti scoperti possono essere devoluti in aumento al numero dei posti di cui alla lettera b) e viceversa.

((

3. Le modalita' per lo svolgimento dei concorsi di cui al comma 1, compresa la definizione degli eventuali ulteriori requisiti, dei titoli e delle prove, la loro valutazione, la composizione delle commissioni e la formazione delle graduatorie, sono stabilite con decreto del Ministro della difesa, acquisito il concerto del Ministro delle infrastrutture e dei trasporti per la parte riferita al Corpo delle capitanerie di porto.

))

4. Il reclutamento nel ruolo sovrintendenti, in relazione ai posti disponibili in organico, avviene esclusivamente mediante concorsi interni riservati:

- a) nel limite massimo del 60 per cento dei posti disponibili agli appartenenti ai ruoli iniziali in servizio permanente che ricoprano il grado apicale;
- b) nel limite minimo del 40 per cento agli appartenenti ai ruoli iniziali in servizio permanente che rivestono il grado di appuntato, carabiniere scelto e carabiniere.

### Art. 691.

((ARTICOLO ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173))

### Art. 692. - Alimentazione del ruolo dei sovrintendenti

1. Per il reclutamento dei sovrintendenti, ai sensi dell'articolo 690, comma 4, lettera a), e' bandito un concorso per titoli riservato agli appuntati scelti per l'ammissione al corso di formazione professionale, previsto dall'articolo 775, al quale sono ammessi gli aspiranti utilmente collocati nella graduatoria finale di merito, approvata con decreto ministeriale. ((Tra i titoli di merito assume particolare rilevanza, per quanto concerne l'attribuzione del relativo punteggio, l'aver prestato servizio al comando stazione territoriale per un periodo almeno pari a quello necessario per la redazione del rapporto informativo di cui all'articolo 1025, comma 3.))

2. Per il reclutamento dei sovrintendenti, ai sensi dell' articolo 690, comma 4, lettera b), e' previsto un concorso per titoli ed esami, riservato agli appuntati, ai carabinieri scelti e ai carabinieri in servizio permanente con almeno quattro anni di servizio, e il superamento del corso di qualificazione, previsto dall'articolo 776.

((

2-bis. I concorsi di cui ai commi 1 e 2 prevedono:

- a) un accertamento attitudinale di idoneita' al servizio nell'Arma quale vice brigadiere del ruolo sovrintendenti dei carabinieri, da parte del centro nazionale di selezione e reclutamento dei carabinieri. Il giudizio espresso in sede di detto accertamento e' definitivo;
- b) una visita medica da parte di una commissione, composta da un ufficiale medico di grado non inferiore a tenente colonnello quale presidente e da due ufficiali medici quali membri, dei quali il meno anziano in ruolo svolge anche funzioni di segretario, tendente ad accertare l'assenza di infermita' invalidanti in atto. Per gli appartenenti al ruolo appuntati e carabinieri, che sono stati giudicati permanentemente non idonei in modo parziale al servizio d'istituto, la visita medica e' finalizzata ad accertare l'assenza di ulteriori infermita' invalidanti in atto.

))

3. Gli esami di cui al comma 2 sono volti ad accertare il grado di preparazione culturale e professionale degli aspiranti.

4. Le modalita' di svolgimento dei concorsi, la nomina delle commissioni, l'individuazione e la valutazione dei titoli, il numero dei posti da mettere a concorso nel limite delle vacanze nell'organico del ruolo e i criteri per la formazione delle graduatorie sono stabiliti con decreti ministeriali.

4-bis. COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95.

5. COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95.

6. E' ammesso ai concorsi di cui ai commi 1 e 2 il personale che, alla data di scadenza dei termini per la presentazione delle domande:

- a) ((LETTERA SOPPRESSA DAL D.LGS. 5 OTTOBRE 2018, N. 126));
- b) ha riportato, nell'ultimo biennio, in sede di valutazione caratteristica, una qualifica non inferiore a <<nella media>> o giudizio equivalente;
- c) non ha riportato, nell'ultimo biennio, sanzioni disciplinari piu' gravi della <<consegna>>;
- d) non e' sottoposto a procedimento disciplinare da cui puo' derivare una sanzione di stato, ne' e' sospeso dal servizio, o si trova in aspettativa per qualsiasi motivo per una durata non inferiore a 60 giorni;
- e) non e' stato giudicato, nell'ultimo biennio, non idoneo all'avanzamento al grado superiore;
- e-bis) ((LETTERA SOPPRESSA DAL D.LGS. 5 OTTOBRE 2018, N. 126)).

7. I posti rimasti scoperti nel concorso di cui al comma 2, sono devoluti, fino alla data di inizio del relativo corso, ai partecipanti del concorso di cui al comma 1, risultati idonei in relazione ai punteggi conseguiti. ((7.1. Gli appuntati che vengono promossi al grado superiore dopo il termine per la presentazione delle domande al concorso previsto dall'articolo 690, comma 4, lettera a), possono partecipare al concorso previsto dall'articolo 690, comma 4 lettera b), bandito nel medesimo anno solare.))

7-bis. Al fine di soddisfare le esigenze in materia di sicurezza e tutela ambientale, forestale e agroalimentare, e' stabilito nei bandi di concorso di cui ai commi 1 e 2, il numero dei posti da riservare al personale gia' in possesso delle relative specializzazioni, in misura comunque non inferiore al 4 per cento dei posti. Il personale specializzato che concorre per tale riserva di posti non puo' concorrere, nel medesimo anno di riferimento, per la rimanente parte di posti disponibili.

## CAPO VI - ISPETTORI E SOVRINTENDENTI DEL REGGIMENTO CORAZZIERI

### Art. 693. - Reclutamento dei sovrintendenti del Reggimento Corazzieri

1. I sovrintendenti del Reggimento Corazzieri sono tratti mediante concorso interno per titoli ed esami, dal personale dello stesso Reggimento appartenente al ruolo appuntati e carabinieri.

2. E' ammesso al concorso di cui al comma 1 il personale che alla scadenza dei termini di presentazione delle domande:

- a) e' idoneo al servizio militare incondizionato o e' giudicato permanentemente non idoneo in modo parziale al servizio d'istituto; coloro che temporaneamente non sono idonei sono ammessi al concorso con riserva di accertamento del possesso della suddetta idoneita' alla data d'inizio del corso previsto dal comma 5;
- b) ha riportato, nell'ultimo biennio, in sede di valutazione caratteristica, una qualifica non inferiore a <<nella media>> o giudizio equivalente;
- c) non ha riportato, nell'ultimo biennio, sanzioni disciplinari piu' gravi della consegna;
- d) non e' sottoposto a procedimento disciplinare da cui puo' derivare una sanzione di stato, o e' sospeso dal servizio o si trova in aspettativa per qualsiasi motivo per una durata non inferiore a 60 giorni;
- e) non e' stato comunque gia' dispensato d'autorita' dal corso per la nomina a vice brigadiere.

3. Ai fini della formazione della graduatoria del concorso, a pari punteggio prevalgono, nell'ordine: il grado, l'anzianita' di grado, l'anzianita' di servizio e la minore eta'.

4. Le modalita' di svolgimento del concorso, l'individuazione e la valutazione dei titoli e il numero dei posti sono stabiliti con il decreto ministeriale che bandisce il relativo concorso.

5. I vincitori del concorso frequentano un corso di qualificazione, che puo' essere ripetuto una sola volta, della durata di norma non inferiore a tre mesi.

6. I programmi e le modalita' di svolgimento del corso, nonche' la composizione della commissione di fine corso sono stabiliti con determinazione del Comandante generale dell'Arma dei carabinieri o dell'autorita' da questi delegata.

7. E' dimesso dal corso e restituito al Reggimento Corazzieri, col grado rivestito e senza detrazione di anzianita', il personale che:

- a) dichiara di rinunciare al corso;
- b) dimostra in qualsiasi momento di non possedere le qualita' necessarie per bene esercitare le funzioni del nuovo grado;
- c) non supera gli esami finali dopo aver gia' ripetuto il corso;
- d) e' stato per qualsiasi motivo assente dal corso per piu' di trenta giorni, anche se non continuativi;
- e) si trova nelle condizioni previste dal regolamento.

8. Nelle ipotesi di esclusione per infermita' o altre cause indipendenti dalla volonta' del frequentatore lo stesso e' ammesso per una sola volta a partecipare di diritto al primo corso successivo al cessare della causa impeditiva senza essere considerato ripetente.

9. I provvedimenti di dimissione e di dispensa dal corso sono adottati con determinazione del Comandante generale dell'Arma dei carabinieri su proposta del Comandante dell'istituto d'istruzione.

10. Agli ammessi ai corsi per la nomina a vice brigadiere, ai quali continuano ad applicarsi le vigenti norme sullo stato giuridico degli appuntati e carabinieri, si applicano anche quelle contenute nel regolamento.

### Art. 694. - Commissione d'esame

1. La commissione giudicatrice degli esami per il reclutamento degli ispettori e quella per il reclutamento dei sovrintendenti e' composta da:

- a) un ufficiale generale dell'Arma dei carabinieri, presidente;
- b) il Comandante del Reggimento Corazzieri;
- c) un ufficiale del Reggimento Corazzieri, membro;
- d) ((...)) luogotenente, segretario senza diritto di voto.

### Art. 695. - Nomina a vice brigadiere

1. Coloro che al termine del corso di cui all'articolo 693, sono dichiarati idonei conseguono la nomina a vice brigadiere nell'ordine determinato dalla graduatoria finale del corso, con decorrenza dalla data di fine corso.

2. Coloro che non superano il corso permangono nel grado rivestito senza detrazione di anzianita', sono restituiti al Reggimento Corazzieri e sono ammessi, a domanda, alla frequenza del corso successivo, purche' continuino a possedere i requisiti di cui all'articolo 693, comma 2.

### Art. 696. - Reclutamento degli ispettori del Reggimento Corazzieri

1. Gli ispettori del Reggimento Corazzieri sono tratti mediante concorso interno per esami, costituito da una prova scritta di cultura generale e da una prova orale sulle materie professionali, riservato al personale del ruolo dei sovrintendenti e a quello del ruolo appuntati e carabinieri dello stesso Reggimento che, alla data indicata dal bando, sono in possesso dei requisiti di cui all' articolo ((683, comma 4)).

2. I vincitori del concorso per conseguire la nomina a maresciallo devono superare un corso di qualificazione professionale, della durata non inferiore a sei mesi, da definire con determinazione del Comandante generale dell'Arma dei carabinieri.

3. Coloro che al termine del corso sono dichiarati idonei conseguono la nomina a maresciallo nell'ordine determinato dalla graduatoria finale del corso, con decorrenza ((dal giorno successivo alla data di)) fine corso.

4. Coloro che non superano il corso permangono nel grado rivestito senza detrazione di anzianita' e sono restituiti al Reggimento Corazzieri.

5. Si osservano le disposizioni dell'articolo 693, commi 4, 5, 6, 7, 8 e 9.

## CAPO VII - RECLUTAMENTO DEI VOLONTARI ((SEZIONE 0I)) ((VOLONTARI IN FERMA PREFISSATA))

### Art. 696-bis. - (( (Denominazione e durata delle ferme). ))

((

1. I volontari in ferma prefissata si distinguono in:

- a) volontari in ferma prefissata iniziale;
- b) volontari in ferma prefissata triennale.

2. Ciascuna delle ferme di cui al comma 1 ha durata pari a tre anni.

3. La durata delle ferme di cui al comma 2 puo' essere prolungata, con il consenso degli interessati, per il tempo strettamente necessario al completamento, rispettivamente, dell'iter concorsuale di coloro che hanno presentato domanda per il reclutamento come volontari in ferma triennale ovvero delle procedure per il transito nei ruoli dei volontari in servizio permanente ai sensi dell'articolo 704))

### SEZIONE I - ((VOLONTARI IN FERMA PREFISSATA INIZIALE))

#### Art. 697. - (( (Requisiti). ))

((

1. Possono partecipare alle procedure selettive per il reclutamento dei volontari in ferma prefissata iniziale i cittadini in possesso dei requisiti di cui all'articolo 635 e dei seguenti ulteriori requisiti:

- a) eta' non superiore a ventiquattro anni;
- b) diploma di istruzione secondaria di primo grado;
- c) idoneita' fisio-psico-attitudinale per il reclutamento nelle Forze armate in qualita' di volontario in servizio permanente.

2. I vincitori delle procedure selettive di cui al comma 1 sono ammessi alla ferma prefissata iniziale in qualita' di soldato, per l'Esercito italiano, comune di 2ª classe, per la Marina militare, o aviere, per l'Aeronautica militare))

#### Art. 698.

Modalita' di reclutamento dei volontari in ferma prefissata ((iniziale))

1. Le modalita' di reclutamento dei volontari in ferma prefissata ((iniziale)) sono disciplinate con decreto del Ministro della difesa.

#### Art. 699. - Incentivi per il reclutamento volontario

1. Le disposizioni che prevedono l'attribuzione di benefici non economici conseguenti all'avere effettuato il servizio militare di leva si applicano, in quanto compatibili, senza nuovi o maggiori oneri a carico dello Stato, anche con riferimento alla effettuazione del servizio militare volontario in ferma prefissata ((per almeno dodici mesi)).

### SEZIONE II - ((VOLONTARI IN FERMA PREFISSATA TRIENNALE))

#### Art. 700. - (( (Requisiti). ))

((

1. Possono partecipare ai concorsi per il reclutamento dei volontari in ferma prefissata triennale i volontari in ferma prefissata iniziale, ovvero in rafferma annuale, in servizio da almeno ventiquattro mesi o in congedo da non oltre dodici mesi, in possesso dei requisiti di cui all'articolo 635 e dei seguenti ulteriori requisiti:

- a) idoneita' fisio-psico-attitudinale per l'impiego nelle Forze armate in qualita' di volontario in servizio permanente;
- b) eta' non superiore a ventotto anni compiuti, elevata a ventinove per i volontari in rafferma annuale, in servizio o in congedo;
- c) superamento con esito positivo del corso basico di formazione iniziale.

2. Nei concorsi di cui al comma 1, i posti annualmente disponibili sono riservati:

- a) ai volontari in ferma prefissata iniziale in servizio ovvero in rafferma annuale, in misura non inferiore al 70 per cento;
- b) ai volontari in ferma prefissata iniziale in congedo da non oltre dodici mesi, che abbiano completato la ferma iniziale, in misura non superiore al 30 per cento.

3. Al fine di soddisfare specifiche esigenze operative delle Forze armate, possono essere banditi concorsi straordinari per il reclutamento di volontari in ferma prefissata triennale riservati:

- a) ai volontari in ferma prefissata iniziale in servizio ovvero in congedo in possesso di specifici requisiti stabiliti con il decreto di cui all'articolo 701;
- b) ai volontari in ferma prefissata iniziale in congedo, che abbiano completato la relativa ferma da piu' di dodici mesi, di eta' non superiore a trenta anni compiuti.

4. Ai volontari di cui al comma 3, lettera a), non si applicano le disposizioni sul periodo minimo di servizio di cui al comma 1, alinea.

5. I vincitori dei concorsi di cui al presente articolo sono ammessi alla ferma prefissata triennale con il grado di caporale, per l'Esercito italiano, comune di 1ª classe, per la Marina militare, o aviere scelto, per l'Aeronautica militare))

#### Art. 701. - (( (Modalita' di reclutamento dei volontari in ferma prefissata triennale). ))

((1. Le modalita' di reclutamento dei volontari in ferma prefissata triennale sono disciplinate con decreto del Ministro della difesa))

### SEZIONE III - NORME COMUNI AL RECLUTAMENTO DEI VOLONTARI IN FERMA PREFISSATA

#### Art. 702. - Riservatari

1. I bandi di concorso per il reclutamento dei volontari in ferma prefissata ((iniziale e triennale)) possono prevedere, nel limite massimo del 10 per cento dei posti disponibili, riserve a favore di:

- a) diplomati presso le scuole militari;
- b) assistiti dall'Opera nazionale di assistenza per gli orfani dei militari di carriera dell'Esercito italiano;
- c) assistiti dell'Istituto Andrea Doria, per l'assistenza dei familiari e degli orfani del personale della Marina militare;
- d) assistiti dall'Opera nazionale figli degli aviatori;
- e) assistiti dall'Opera nazionale di assistenza per gli orfani dei militari dell'Arma dei carabinieri;
- f) figli di militari deceduti in servizio.

#### Art. 703. - Concorsi nelle carriere iniziali delle Forze di polizia e del Corpo nazionale dei vigili del fuoco

1. Nei concorsi relativi all'accesso nelle carriere iniziali dei seguenti Corpi e nell'Arma dei carabinieri, le riserve di posti per i volontari in ferma prefissata, in servizio o in congedo, di eta' non superiore a venticinque anni compiuti, i quali abbiano completato almeno dodici mesi di servizio in qualita' di volontario in ferma prefissata iniziale e siano in possesso degli ulteriori requisiti per l'accesso alle predette carriere previsti dai rispettivi ordinamenti, sono cosi determinate:

- a) Arma dei carabinieri: 70 per cento;
- b) Corpo della Guardia di Finanza: 70 per cento;
- c) Polizia di Stato: 45 per cento;
- d) Corpo di polizia penitenziaria: 60 per cento;
- e) Corpo nazionale dei vigili del fuoco: 45 per cento;
- f) LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95.

1-bis. I posti riservati di cui al comma 1, eventualmente non ricoperti per insufficienza di candidati idonei, sono devoluti in aggiunta ai restanti posti messi a concorso.

2. COMMA ABROGATO DALLA L. 5 AGOSTO 2022, N. 119.

3. Nella formazione delle graduatorie le amministrazioni tengono conto, quali titoli di merito, del periodo di servizio svolto e delle relative caratterizzazioni riferite a contenuti, funzioni e attivita' affini a quelli propri della carriera per cui e' stata fatta domanda di accesso nonche' delle specializzazioni acquisite durante la ferma prefissata, considerati utili. (46) (62) ((101))

-------------- AGGIORNAMENTO (46) Il D.Lgs. 12 maggio 1995, n. 199, come modificato dal D.Lgs. 29 maggio 2017, n. 95, ha disposto (con l'art. 7, comma 2) che "Al fine di accrescere l'efficienza del Servizio di soccorso alpino del Corpo della guardia di finanza, in deroga agli articoli 703 e 2199 del decreto legislativo 15 marzo 2010, n. 66, le riserve di cui ai medesimi articoli 703 e 2199 non operano per i posti messi a concorso per il predetto Servizio". -------------- AGGIORNAMENTO (62) Il D.Lgs. 12 maggio 1995, n. 199, come modificato dal D.Lgs. 27 dicembre 2019, n. 172, ha disposto (con l'art. 7, comma 2) che "Al fine di accrescere l'efficienza del Servizio di soccorso alpino e della componente specialistica Anti Terrorismo e Pronto Impiego (A.T.P.I.) del Corpo della guardia di finanza, in deroga agli articoli 703 e 2199 del decreto legislativo 15 marzo 2010, n. 66, le riserve di cui ai medesimi articoli 703 e 2199 non operano per i posti messi a concorso per le predette specialita' nel limite massimo di 180 unita' annuali, ferma restando la dotazione organica di cui all'articolo 3". -------------- AGGIORNAMENTO (101) Il D.L. 22 aprile 2023, n. 44 nel modificare l'art. 7, comma 2 del D.Lgs. 12 maggio 1995, n. 199, ha conseguentemente disposto (con l'art. 15, comma 11, lettera b)) che "Per le esigenze di potenziamento degli organici del Corpo della guardia di finanza: [...] b) al fine di accrescere l'efficienza della componente specialistica Antiterrorismo e pronto impiego del Corpo della guardia di finanza, il limite massimo annuale di cui all'articolo 7, comma 2, del decreto legislativo 12 maggio 1995, n. 199, e' incrementato di 24 unita' per ciascuno degli anni dal 2023 al 2026".

### SEZIONE IV - VOLONTARI IN SERVIZIO PERMANENTE

#### Art. 704. - (( (Modalita' di reclutamento dei volontari in servizio permanente). ))

((

1. Sono immessi nei ruoli dei volontari in servizio permanente, salva espressa rinuncia, i volontari in ferma prefissata triennale al termine della ferma, in possesso dei requisiti di cui all'articolo 635 e dei seguenti ulteriori requisiti:

- a) non essere sottoposti a procedimento disciplinare da cui possa derivare una sanzione di stato;
- b) aver riportato una qualifica non inferiore a "nella media" o giudizio corrispondente, negli ultimi dodici mesi di servizio.

2. Con decreto del Ministro della difesa sono stabiliti gli eventuali ulteriori requisiti e le modalita' di transito nei ruoli dei volontari in servizio permanente.

3. I volontari di cui al comma 1 sono immessi nei ruoli dei volontari in servizio permanente con decorrenza dal giorno successivo al termine della ferma triennale e sono iscritti in ruolo secondo l'ordine di iscrizione nel ruolo di provenienza. Dopo l'iscrizione in ruolo, l'anzianita' relativa e' rideterminata sulla base dei titoli acquisiti e del rendimento complessivo nel periodo di servizio prestato in qualita' di volontario in ferma prefissata triennale, secondo modalita' e criteri definiti con il decreto di cui al comma 2.

4. I volontari in ferma prefissata triennale, che non possono essere ammessi al transito in servizio permanente in quanto temporaneamente non idonei al servizio militare incondizionato o perche' imputati in un procedimento penale per delitto non colposo o sottoposti a procedimento disciplinare da cui possa derivare una sanzione di stato, anche se sospesi dal servizio, possono chiedere di permanere nella ferma prefissata fino ai termini di seguito indicati:

- a) data di scadenza del periodo massimo di licenza di convalescenza, per il militare temporaneamente non idoneo al servizio militare incondizionato, salvo quanto previsto dall'articolo 955;
- b) data di definizione del procedimento, per il militare sottoposto a procedimento penale o disciplinare.

5. I volontari in ferma prefissata triennale di cui al comma 4 possono presentare domanda di ammissione al transito in servizio permanente con decorrenza dal giorno successivo al termine della ferma triennale nei seguenti casi ed entro i termini per ciascuno indicati:

- a) se hanno riacquistato l'idoneita' fisica al servizio militare incondizionato, entro sessanta giorni dalla data di comunicazione del relativo giudizio;
- b) se e' stata disposta l'archiviazione ovvero se il procedimento penale si e' concluso con sentenza irrevocabile che dichiara che il fatto non sussiste o che l'imputato non lo ha commesso o che il fatto non costituisce reato, entro sessanta giorni dalla notificazione del relativo provvedimento;
- c) se il procedimento disciplinare si e' concluso senza l'applicazione di una sanzione di stato, entro sessanta giorni dalla notificazione del relativo provvedimento.

6. I volontari in ferma prefissata triennale, che allo scadere del termine di cui al comma 4, lettera a), non hanno riacquistato l'idoneita' al servizio militare incondizionato o sono riconosciuti temporaneamente non idonei, sono collocati in congedo con decorrenza dal giorno successivo a quello della data di comunicazione del relativo giudizio.

7. I volontari in ferma prefissata triennale, che non sono ammessi al transito in servizio permanente, cessano dalla ferma e sono collocati in congedo. Il periodo di tempo eventualmente trascorso in servizio oltre il termine di scadenza della ferma e' considerato come servizio prestato in ferma prefissata triennale))

#### Art. 705. - (( (Particolari categorie protette per il reclutamento nell'Esercito italiano, nella Marina militare e nell'Aeronautica militare).))

((

1. Possono essere immessi nei ruoli dei volontari in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare il coniuge, i figli e i fratelli dei militari appartenenti a tali Forze armate deceduti o divenuti permanentemente inabili al servizio con invalidita' non inferiore all'ottanta per cento, per effetto di ferite o lesioni riportate nell'espletamento di missioni internazionali di pace ovvero in attivita' operative, individuate con decreto del Ministro della difesa, in esecuzione dei compiti di cui agli articoli 87, 89 e 92, comma 1:

- a) nei limiti delle vacanze organiche;
- b) previo superamento di un corso propedeutico svolto con modalita' definite dal relativo Capo di Stato Maggiore;
- c) previo accertamento del possesso dei requisiti per il reclutamento in servizio permanente di cui agli articoli 635 e 640.

))

## CAPO VIII - CARABINIERI

### Art. 706. - Alimentazione del ruolo

1. Il reclutamento del personale appartenente al ruolo appuntati e carabinieri e' disposto annualmente, nel limite delle prevedibili vacanze nell'organico del ruolo, con il bando di arruolamento di cui all'articolo 708.

2. ((COMMA ABROGATO DALLA L. 5 AGOSTO 2022, N. 119)).

### Art. 707. - Requisiti speciali

1. Gli aspiranti agli arruolamenti volontari di cui all'articolo 706 devono possedere i seguenti requisiti: ((a) non aver superato il ventiquattresimo anno di eta', salvo quanto previsto dall'articolo 703 per i volontari in ferma prefissata)); b) diploma di istruzione secondaria di secondo grado che consente l'iscrizione ai corsi per il conseguimento del diploma universitario; c) non trovarsi in situazioni comunque non compatibili con l'acquisizione o la conservazione dello stato di carabiniere.

1-bis. Il titolo di studio richiesto per l'arruolamento nei gruppi sportivi di cui all'articolo 1524 e' il diploma di istruzione secondaria di primo grado.

### Art. 708. - Bandi di arruolamento

1. Le procedure di arruolamento, la data di scadenza dei termini per la presentazione delle domande di ammissione all'arruolamento, le prove di selezione e concorsuali, le modalita' di accertamento del possesso dei requisiti richiesti, la durata dei corsi, il numero complessivo e le riserve di posti, l'individuazione e la valutazione dei titoli preferenziali, sono stabiliti con determinazione del Comandante generale dell'Arma dei carabinieri, pubblicata nella Gazzetta Ufficiale della Repubblica italiana.

1-bis. Al fine di soddisfare le esigenze in materia di sicurezza e tutela ambientale, forestale e agroalimentare, e' stabilito nei relativi bandi di concorso, emanati con determinazione del Comandante generale dell'Arma dei carabinieri, il numero di posti dei carabinieri da formare nelle relative specializzazioni in misura, comunque, non inferiore al 4 per cento dei posti da mettere a concorso. ((PERIODO SOPPRESSO DAL D.LGS. 29 MAGGIO 2017, N. 95)).

2. I termini di validita' della graduatoria dei candidati risultati idonei ma non vincitori per il reclutamento di cui all'articolo 706, possono essere prorogati con motivata determinazione del Comandante generale dell'Arma dei carabinieri in caso di successive e analoghe procedure di reclutamento avviate entro diciotto mesi dall'approvazione della stessa.

### Art. 709. - Particolari categorie protette per il reclutamento nell'Arma dei carabinieri

1. Possono essere ammessi al primo corso utile per allievo carabiniere di cui all'articolo 783, nel limite della vacanze organiche, il coniuge e i figli superstiti, nonche' i fratelli, se unici superstiti, del personale delle Forze di polizia deceduto o reso permanentemente invalido al servizio, con invalidita' non inferiore all'ottanta per cento della capacita' lavorativa, a causa delle azioni criminose di cui all'articolo 82, comma 1, della legge 23 dicembre 2000, n. 388, ovvero per effetto di ferite o lesioni nell'espletamento di servizi di polizia o di soccorso pubblico, i quali ne facciano richiesta, purche' in possesso dei prescritti requisiti per il reclutamento dei carabinieri. ((14))

2. Le disposizioni di cui al comma 1 si applicano, altresi', al coniuge e ai figli superstiti nonche' ai fratelli, se unici superstiti, del personale dell'Arma dei carabinieri deceduto o reso permanentemente invalido al servizio, con invalidita' non inferiore all'ottanta per cento della capacita' lavorativa, per effetto di ferite o lesioni riportate nell'espletamento di missioni internazionali di pace ovvero in attivita' operative individuate con decreto del Ministro della difesa che comportino, in conseguenza dell'impiego di mezzi o attrezzature esclusivamente militari, una particolare esposizione al rischio. --------------- AGGIORNAMENTO (14) Il D.Lgs. 24 febbraio 2012, n. 20 ha disposto (con l'art. 4, comma 1, lettera i)) che nel comma 1 del presente articolo le parole "della vacanza" sono sostituite dalle seguenti: "delle vacanze".

## CAPO IX - ALLIEVI DELLE SCUOLE MILITARI

### Art. 710. - Ammissione alle scuole militari

1. Le ammissioni alle scuole militari si effettuano mediante concorso per esami, esclusivamente al primo anno del liceo classico, ovvero al terzo anno del liceo scientifico.

2. Il ((Ministero)) della difesa stabilisce ogni anno il numero dei posti da mettere a concorso. Stabilisce, altresi', il numero massimo dei posti che possono essere ricoperti dai giovani di cui all'articolo 714.

### Art. 711. - Requisiti per l'ammissione

1. Salvo quanto disposto dall'articolo 714 possono partecipare ai concorsi di ammissione coloro che:

- a) ((al 31 dicembre dell'anno di ammissione alla scuola militare,)) hanno compiuto il 15° anno di eta' e non superato il 17°;
- b) ((alla data di effettiva ammissione alla scuola militare,)) sono in possesso del titolo di promozione o di idoneita' rispettivamente alla prima classe del liceo classico o alla terza del liceo scientifico;
- c) hanno sempre tenuto regolare condotta morale e civile e non sono stati espulsi da istituti di educazione o di istruzione dello Stato;
- d) sono riconosciuti in possesso dell'idoneita' fisica quali allievi delle scuole militari.

### Art. 712. - Svolgimento del concorso

1. I candidati risultati idonei alla visita medica sono sottoposti a un accertamento psico-fisico consistente nello svolgimento di un colloquio psico-attitudinale e in una prova di educazione fisica, secondo le modalita' e i programmi fissati con disposizione ministeriale. L'accertamento psico-fisico si conclude con voto unico.

2. I giovani che conseguono il voto di almeno sei decimi negli esami di cui al comma 1 sono ammessi a sostenere una prova di cultura generale sulle materie del ginnasio superiore se aspiranti al primo anno del liceo classico o sulle materie del primo e secondo anno del liceo scientifico, se aspiranti al 3° anno di detto liceo.

3. La prova di cultura generale puo' anche consistere in test a risposta multipla.

4. La prova di cultura generale non si intende superata se il candidato non ha ottenuto almeno la votazione dei sei decimi.

5. Le commissioni esaminatrici per le prove e gli accertamenti di cui al presente articolo sono nominate dal Direttore generale della Direzione generale per il personale militare.

### Art. 713. - Graduatorie di merito

1. Gli idonei sono iscritti in due distinte graduatorie, una per gli aspiranti al liceo classico e una per gli aspiranti al liceo scientifico, nell'ordine determinato dalla media dei voti riportati nell'accertamento psico-fisico e nella prova di cultura generale.

2. A parita' di punti hanno la precedenza nell'ordine:

- a) i figli dei decorati dell'Ordine militare d'Italia o dei decorati di medaglia d'oro al valor militare;
- b) i figli dei mutilati e degli invalidi di guerra per lesioni o infermita' ascrivibili alle prime quattro categorie elencate nella tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915;
- c) i figli di militari di carriera, di ufficiali e sottufficiali di complemento richiamati in temporaneo servizio che per il servizio prestato hanno acquistato il diritto al trattamento di quiescenza, di dipendenti civili dello Stato in servizio e di titolari di pensioni ordinarie civili o militari dello Stato;
- d) i candidati che hanno conseguito il titolo di promozione in sede di scrutinio finale o di idoneita' in unica sessione, estiva o autunnale, rispettivamente alla prima classe del liceo classico o alla terza classe del liceo scientifico; tra questi hanno la precedenza i figli di ufficiali di complemento;
- e) i piu' giovani di eta'.

3. Dei posti messi a concorso, per ciascun ordine di studi, il 50 per cento e' riservato ai candidati idonei che sono orfani di guerra (o equiparati) e agli orfani dei dipendenti civili e militari dello Stato deceduti per ferite, lesioni o infermita' riportate in servizio e per causa di servizio. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 714. - Allievi stranieri

1. E' consentita l'ammissione alle scuole militari di giovani stranieri che conoscano la lingua italiana e sono in possesso di un titolo di studio riconosciuto equipollente a quelli prescritti dall'articolo 711, lettera b).

## TITOLO III FORMAZIONE ((E ADDESTRAMENTO)) CAPO I DISPOSIZIONI GENERALI

### Art. 715. - ((Formazione e addestramento))

((

1. La formazione, iniziale o di base se riferita al complesso delle attivita' formative svolte al fine dell'immissione o della stabilizzazione in ruolo del militare ovvero successiva o permanente, e' il complesso delle attivita' con cui si educano, si migliorano e si indirizzano le risorse umane attraverso la preparazione culturale, etica, morale e tecnico professionale orientata all'acquisizione di competenze che consentono al singolo militare di svolgere adeguatamente il proprio ruolo professionale. Questo processo si realizza attraverso la maturazione delle caratteristiche personali e la creazione di competenze.

2. L'addestramento e' il processo attraverso il quale si sviluppano negli individui, organi di staff, Comandi e Unita', le abilita' e le capacita' di assolvere specifici compiti e funzioni, in specifici ambienti operativi per il tramite di esercitazioni, collettive e individuali, nonche' di attivita' di abilitazione, qualificazione e specializzazione condotte ai fini dell'assolvimento dei compiti istituzionalmente assegnati alle Forze armate e allo sviluppo, mantenimento e miglioramento della prontezza operativa desiderata.

))

### Art. 716. - Personale femminile in formazione

1. Al personale femminile che frequenta i corsi regolari delle accademie e delle scuole allievi marescialli e allievi sergenti e i corsi di formazione iniziale degli istituti e delle scuole delle Forze armate, nonche' al personale femminile volontario in fase di addestramento e specializzazione iniziale, si applica l'articolo 1494.

2. Le amministrazioni interessate disciplinano gli specifici ordinamenti dei corsi presso le accademie, gli istituti e le scuole di formazione in relazione all'ammissione ai corsi stessi del personale femminile.

### Art. 717. - Corsi di formazione militare

1. Il regolamento disciplina i corsi di formazione per l'accesso ai ruoli delle Forze armate, nonche' le relative graduatorie di merito, cause e procedure di rinvio e di espulsione.

### Art. 718. - (( (Ammissione ai corsi di militari stranieri). ))

((

1. Il Ministro della difesa e' autorizzato ad ammettere personale militare straniero a frequentare corsi presso istituti, scuole e altri enti militari, con le modalita' di cui all'articolo 573.

))

## CAPO II - UFFICIALI IN SERVIZIO PERMANENTE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 719. - Formazione universitaria degli ufficiali

1. Con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, di concerto con i Ministri della difesa e dell'economia e delle finanze, sono definiti, ai sensi dell'articolo 17, comma 95 della legge 15 maggio 1997, n. 127, i criteri generali per la definizione, da parte delle universita', degli ordinamenti didattici di corsi di diploma universitario, di laurea e di specializzazione, di cui agli articoli 2, 3 e 4 della legge 19 novembre 1990, n. 341, adeguati alla formazione degli ufficiali delle Forze armate e del Corpo della Guardia di finanza. Le universita', in conformita' ai predetti criteri, definiscono gli ordinamenti didattici d'intesa con le accademie militari per gli ufficiali e con gli altri istituti militari d'istruzione superiore. Ai fini dell'attivazione e della gestione dei corsi di cui al presente articolo, le universita', cui compete il rilascio dei titoli e la responsabilita' didattica dei corsi, stipulano apposite convenzioni con le predette accademie e istituti. Tali convenzioni prevedono l'organizzazione delle attivita' didattiche anche utilizzando le strutture e, per specifici insegnamenti, i docenti delle accademie e degli istituti. I Ministri della difesa, dell'economia e delle finanze e dell'istruzione, dell'universita' e della ricerca definiscono opportune modalita' e strumenti per agevolare la stipula delle convenzioni di cui al presente articolo.

2. Le convenzioni di cui al presente articolo prevedono anche le modalita' di riconoscimento degli studi compiuti e di rilascio dei titoli di diploma universitario, di laurea e di specializzazione riguardanti gli ufficiali delle Forze armate e del Corpo della Guardia di finanza in servizio ovvero in congedo che, in possesso del diploma di scuola media superiore richiesto all'epoca per l'ammissione alle accademie militari, hanno superato il previsto ciclo di studi presso le rispettive accademie e le scuole di applicazione ovvero la Scuola ufficiali carabinieri o la Scuola di applicazione della Guardia di finanza. Per gli ufficiali in congedo le modalita' di riconoscimento sono definite anche con riferimento ai cicli di studi frequentati dal personale in servizio. I riconoscimenti hanno luogo dando la precedenza alle procedure riguardanti gli ufficiali in servizio.

#### Art. 720. - Formazione degli ufficiali dei ruoli normali

1. I vincitori dei concorsi per il reclutamento ordinario degli ufficiali dei ruoli normali sono ammessi nelle accademie militari, in qualita' di allievi ufficiali, per svolgere il previsto ciclo formativo.

2. Coloro che hanno completato con esito favorevole il ciclo formativo presso le accademie militari sono nominati sottotenenti e immessi nei rispettivi ruoli normali.

3. Le accademie militari sono deputate anche alla formazione degli ufficiali dei corpi sanitari, secondo quanto stabilito nel regolamento.

#### Art. 721. - Prosecuzione degli studi universitari

1. Se il personale militare che frequenta i corsi di diploma universitario, di laurea o di specializzazione, previsti dagli ordinamenti didattici e definiti dalle universita' d'intesa con le accademie militari e gli altri istituti militari d'istruzione superiore, non consegue il titolo universitario nel periodo di frequenza dell'accademia o di altro istituto militare di istruzione superiore, e' consentita la prosecuzione degli studi, con il riconoscimento degli esami sostenuti con esito positivo, anche presso altre universita' che hanno attivato corsi corrispondenti.

#### Art. 722. - Formazione degli ufficiali a nomina diretta dei ruoli normali

1. I candidati utilmente collocati nelle graduatorie di merito dei concorsi straordinari per ufficiali dei ruoli normali a nomina diretta:

- a) se appartenenti all'Esercito italiano, alla Marina militare e all'Aeronautica militare frequentano corsi applicativi di durata non superiore a un anno accademico le cui modalita' sono disciplinate con determinazione dei rispettivi Capi di stato maggiore;
- b) se appartenenti all'Arma dei carabinieri frequentano un corso applicativo della durata non inferiore a ((due anni)), le cui modalita' sono disciplinate con determinazione del Comandante generale dell'Arma dei carabinieri.

2. L'anzianita' relativa dei predetti ufficiali e' rideterminata, a seguito del superamento degli esami di fine corso, dalla media del punteggio della graduatoria del concorso e di quello conseguito al termine del corso stesso. Gli stessi sono iscritti in ruolo ((, se appartenenti all'Esercito italiano, alla Marina militare e all'Aeronautica militare)) dopo i pari grado provenienti dai corsi regolari delle rispettive accademie militari che terminano il ciclo formativo nello stesso anno ((, se appartenenti all'Arma dei carabinieri, dopo i pari grado provenienti dai corsi ordinari che terminano il ciclo formativo nello stesso anno)).

3. I candidati che non superino il corso applicativo sono collocati in congedo, se non devono assolvere o completare gli obblighi di leva, ovvero sono restituiti ai ruoli di provenienza. Il periodo di durata del corso e' computato per intero ai fini dell'anzianita' di servizio per i militari in servizio permanente e per il restante personale non e' computabile ai fini dell'assolvimento degli obblighi di leva.

#### Art. 723. - Corsi applicativi per ufficiali dei ruoli speciali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. I corsi applicativi per gli ufficiali dei ruoli speciali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare hanno durata non inferiore a tre mesi.

2. L'anzianita' relativa dei predetti ufficiali e' rideterminata in base alla media del punteggio ottenuto nella graduatoria del concorso e di quello conseguito nella graduatoria di fine corso.

3. I frequentatori che non superino i corsi applicativi:

- a) se provenienti dal ruolo dei marescialli o dal ruolo dei sergenti, ((ovvero dal ruolo dei volontari in servizio permanente,)) rientrano nella categoria di provenienza. Il periodo di durata del corso e' in tali casi computato per intero ai fini dell'anzianita' di servizio;
- b) se gia' ufficiali ausiliari, completano la ferma eventualmente contratta ovvero sono ricollocati in congedo;
- c) se provenienti dai frequentatori dei corsi normali, completano la ferma eventualmente contratta ovvero, se ne erano stati prosciolti, sono collocati in congedo;
- d) se provenienti dalla vita civile, sono collocati in congedo, se non devono assolvere o completare gli obblighi di leva.

4. COMMA SOPPRESSO DAL D.LGS. 5 OTTOBRE 2018, N. 126.

#### Art. 724. - Obblighi di servizio degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. Gli allievi delle accademie militari all'atto dell'ammissione ai corsi sono vincolati a una ferma di tre anni.

2. All'atto dell'ammissione al terzo anno di corso i frequentatori dei corsi normali dell'Accademia dell'Esercito italiano, della Marina militare e dell'Aeronautica militare sono vincolati a una ferma di nove anni che assorbe quella da espletare.

3. La ferma di cui al comma 2 e' elevata a:

- a) dieci anni per gli iscritti a corsi di laurea di cinque anni di durata;
- b) ((quindici)) anni per gli iscritti a corsi di laurea di sei anni di durata;
- c) sedici anni per gli appartenenti al ruolo naviganti normale dell'Aeronautica militare.

4. I frequentatori dei corsi normali delle accademie, se fruiscono delle eventuali proroghe per il completamento del ciclo formativo, sono vincolati a una ulteriore ferma di durata pari al periodo di proroga concesso.

5. Gli ufficiali reclutati a nomina diretta del ruolo normale e gli ufficiali dei ruoli speciali, ammessi ai rispettivi corsi applicativi, al superamento dei corsi stessi sono vincolati a una ferma di cinque anni decorrente dall'inizio del corso ovvero dalla scadenza della precedente ferma.

6. Gli ufficiali della Marina militare in servizio permanente effettivo, all'atto dell'ammissione ai corsi di pilotaggio aereo contraggono il vincolo ad una ferma volontaria di quattordici anni; gli ufficiali che non portano a termine o non superano il corso di pilotaggio sono prosciolti dalla predetta ferma, salvo l'obbligo di completare la ferma precedentemente contratta. Gli ufficiali del ruolo naviganti speciale dell'Aeronautica militare, nonche' gli ufficiali piloti dei ruoli speciali del Corpo di stato maggiore della Marina e del Corpo delle capitanerie di porto nominati sottotenenti a seguito dell'apposito concorso sono vincolati a una ferma di quattordici anni dall'inizio del previsto corso finalizzato al conseguimento del brevetto di pilota o navigatore militare che assorbe la ferma precedentemente contratta.

6-bis. Gli ufficiali della Marina militare in servizio permanente effettivo ammessi a frequentare master di 2° livello o corsi formativi equivalenti in materie idro-oceanografiche sono vincolati a una ferma di dodici anni decorrente dalla data di inizio del corso stesso. Tale ferma assorbe quella gia' contratta e non opera nel caso di mancato superamento o dimissioni dal corso.

7. Le ferme per dodici anni alle quali sono vincolati gli allievi o ufficiali piloti di complemento rimangono valide in caso di transito nei ruoli del servizio permanente effettivo.

8. Gli obblighi di servizio degli ufficiali dell'Arma dei carabinieri sono disciplinati dall'articolo 738.

### SEZIONE II - UFFICIALI DELL'ESERCITO ITALIANO

#### Art. 725. - Corso di applicazione

1. Per i sottotenenti e tenenti dei ruoli normali, delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni, dell'Arma dei trasporti e dei materiali e del Corpo di commissariato che superino i corsi delle scuole di applicazione, il nuovo ordine di anzianita' e' determinato, con decreto ministeriale, in base alla graduatoria stabilita secondo le norme previste nel regolamento.

1-bis. Le disposizioni di cui al comma 1 relative alla determinazione dell'anzianita' si applicano anche agli ufficiali dei ruoli normali del Corpo degli ingegneri e del Corpo sanitario.

2. Gli ufficiali di cui al comma 1 che non superino per una sola volta uno degli anni del corso di applicazione per essi previsto sono ammessi a ripeterlo ((e sono iscritti in ruolo dopo l'ultimo dei parigrado del corso cui sono aggregati, assumendone la stessa anzianita' assoluta)). Gli ufficiali di cui al comma 1 che superino il corso di applicazione con ritardo per motivi di servizio riconosciuti con determinazione ministeriale ovvero per motivi di salute, sono iscritti in ruolo al posto che a essi sarebbe spettato se avessero superato il corso al loro turno.

#### Art. 726. - Mancato superamento del corso di applicazione

1. Fermo restando quanto previsto dall'articolo 660, i sottotenenti e i tenenti di cui all'articolo 725, comma 1, che non superano i corsi di applicazione per essi prescritti e ottengono a domanda di permanere in servizio permanente, ai sensi dell'articolo 655, comma 1, lettera d), sono trasferiti, anche in soprannumero, nei ruoli speciali e sono iscritti in tali ruoli dopo i pari grado in possesso della stessa anzianita' assoluta.

((

1-bis. Gli ufficiali che non superano l'anno di corso perche' non idonei in attitudine militare sono posti in congedo secondo le modalita' previste dall'articolo 935, comma 1, lettera c-bis).

))

2. Gli ufficiali dei ruoli normali del Corpo degli ingegneri e del Corpo sanitario che non hanno completato il ciclo di studi per essi previsto per il conseguimento della laurea, possono ottenere con determinazione ministeriale, su proposta delle autorita' gerarchiche, la proroga fino a un massimo di due anni accademici. Se completano il ciclo di studi universitari entro la proroga concessa, subiscono una detrazione di anzianita' nel ruolo pari alla proroga concessa.

3. Agli ufficiali di cui al comma 2 che non conseguono il diploma di laurea nei limiti di tempo prescritti, compresa l'eventuale proroga, si applicano le disposizioni di cui al comma 1, con destinazione a uno dei ruoli speciali esistenti, individuati secondo le esigenze di Forza armata, nonche' una detrazione di anzianita' nel ruolo pari alla proroga concessa.

#### Art. 727. - Mancato transito nei ruoli speciali

1. Gli ufficiali che non hanno presentato domanda di transito nei ruoli speciali ai sensi dell'articolo 655, comma 1, lettera d), ovvero non vi possono transitare ai sensi del medesimo articolo:

- a) sono collocati nella categoria del complemento con obbligo di ultimare la ferma contratta ((, fatta eccezione per i casi di cui all'articolo 935, comma 1, lettera c-bis) ));
- b) possono essere trasferiti, a domanda o d'autorita', ad altra arma o corpo, sempre in funzione delle esigenze di Forza armata.

### SEZIONE III - UFFICIALI DELLA MARINA MILITARE

#### Art. 728.

Formazione degli ufficiali ((...)) dei ruoli normali

1. I frequentatori dell'Accademia navale che hanno completato con esito favorevole il terzo anno del ciclo formativo sono nominati guardiamarina in servizio permanente. Fino al completamento del ciclo formativo prescritto, l'anzianita' relativa degli ufficiali ((...)) e' rideterminata secondo le modalita' stabilite nel regolamento.

2. Gli ufficiali, che superano gli esami prescritti dal ciclo formativo oltre i termini previsti, sono iscritti in ruolo dopo i parigrado che hanno superato gli esami nelle sessioni ordinarie.

3. Gli ufficiali, che per motivi di servizio o per motivi di salute, riconosciuti con determinazione ministeriale, superano gli esami prescritti dal ciclo formativo con ritardo, sono iscritti in ruolo al posto che a essi sarebbe spettato se li avessero superati nei tempi previsti.

4. Gli ufficiali idonei in attitudine professionale che non hanno completato gli studi per uno degli anni del ciclo formativo sono ammessi a completarli nell'anno successivo, solo se non ne hanno gia' ripetuto uno negli anni precedenti. Se ammessi, transitano nel corso successivo e sono iscritti in ruolo dopo l'ultimo dei parigrado del corso cui sono aggregati, assumendone la stessa anzianita' assoluta.

5. Fermo restando quanto previsto dall' articolo 660, gli ufficiali che per la seconda volta non hanno completato gli studi prescritti per uno degli anni del ciclo formativo, o non sono stati ammessi a completarli nell'anno successivo per i motivi indicati al comma 4, possono essere trasferiti, purche' idonei in attitudine professionale, anche in soprannumero, con il proprio grado e con la propria anzianita', nel ruolo speciale dei rispettivi Corpi con le modalita' indicate dall'articolo 655, comma 1, lettera d). Essi sono iscritti in tali ruoli dopo i pari grado in possesso della stessa anzianita' assoluta.

5-bis. Gli ufficiali che non superano l'anno di corso perche' non idonei in attitudine professionale, sono dimessi dal corso e posti in congedo, secondo le modalita' previste dall'articolo 935, comma 1, lettera c-bis).

6. La nomina a guardiamarina decorre, ai soli fini giuridici, alla data di acquisizione del grado di aspirante.

#### Art. 729.

Conseguimento del diploma di laurea da parte ((degli ufficiali)) dei ruoli normali

1. Gli ufficiali ((...)) dei ruoli normali devono conseguire il diploma di laurea prescritto e completare il periodo formativo secondo le modalita' ed entro il periodo definiti dall'ordinamento di Forza armata.

2. Gli ufficiali dei ruoli normali, per i quali e' previsto il completamento dell'iter di studi presso strutture universitarie, che non hanno conseguito il diploma di laurea entro il periodo prescritto possono avanzare circostanziata domanda intesa a ottenere una proroga di durata non superiore a dodici mesi. L'amministrazione ha facolta' di accogliere le domande, previo esame, da parte di una apposita commissione nominata con decreto ministeriale, del curriculum di studi e degli elementi desunti dalla documentazione valutativa. Gli ufficiali, se fruiscono di una proroga di durata superiore a tre mesi, transitano nel corso successivo e sono iscritti in ruolo dopo l'ultimo dei parigrado del corso cui sono aggregati, assumendone la stessa anzianita' assoluta.

3. Gli ufficiali che conseguono il diploma di laurea con ritardo per motivi di servizio o per motivi di salute riconosciuti con determinazione ministeriale sono iscritti in ruolo al posto che a essi sarebbe spettato se l'avessero conseguito nei tempi previsti.

4. Fermo restando quanto previsto dall'articolo 660 e dall'articolo 1137-bis, gli ufficiali, che non conseguono la laurea nel periodo prescritto o che non sono stati ammessi al periodo di proroga, possono essere trasferiti, anche in soprannumero, con il proprio grado e con la propria anzianita', nel ruolo speciale dei rispettivi Corpi in applicazione di quanto previsto dall'articolo 655, comma 1, lettera d). Essi sono iscritti in tali ruoli dopo i pari grado in possesso della stessa anzianita' assoluta.

5. Per i sottotenenti di vascello dei ruoli normali e' stabilito, con determinazione ministeriale, il nuovo ordine di anzianita' il giorno precedente al compimento dell'anzianita' minima prevista dal presente codice per l'avanzamento al grado superiore, in base all'attitudine professionale e al rendimento in servizio valutati per ciascun ufficiale dalla commissione ordinaria di avanzamento. Con apposito decreto ministeriale sono stabilite le modalita' della predetta valutazione.

#### Art. 730. - Mancato transito nei ruoli speciali

1. Gli ufficiali che non hanno presentato domanda di transito nei ruoli speciali ai sensi dell'articolo 655, comma 1, lettera d), ovvero non vi possono transitare ai sensi del medesimo articolo, o dell'articolo 728, comma 5, sono collocati nella categoria del complemento con obbligo di ultimare la ferma contratta ((, fatta eccezione per i casi di cui all'articolo 935, comma 1, lettera c-bis) )).

### SEZIONE IV - UFFICIALI DELL'AERONAUTICA MILITARE

#### Art. 731.

Formazione degli ufficiali ((...)) dei ruoli normali

1. I sottotenenti dei ruoli normali sono tratti dai frequentatori dell'Accademia aeronautica che hanno completato con esito favorevole il terzo anno di corso secondo le modalita' previste dal piano degli studi dell'Accademia aeronautica.

2. Gli ufficiali dei ruoli normali devono completare gli studi accademici e conseguire il diploma di laurea entro i periodi prescritti dal piano degli studi dell'Accademia aeronautica.

3. Per gli ufficiali dei ruoli normali che completano l'ultimo anno di corso entro il periodo prescritto dal piano degli studi dell'Accademia aeronautica il nuovo ordine di anzianita' e' determinato, con decreto ministeriale, in base alla somma del punto complessivo di classifica riportato per la nomina a sottotenente, e del punto attribuito all'ufficiale al completamento degli studi, entrambi ridotti in centesimi ed elaborati secondo le norme del regolamento.

4. Gli ufficiali che superano gli esami dell'ultimo anno del corso regolare nelle sessioni successive alla prima sono iscritti in ruolo dopo i pari grado che hanno superato detti esami nella precedente sessione.

5. Gli ufficiali che, per motivi di servizio riconosciuti con determinazione ministeriale o per motivi di salute, frequentano l'ultimo anno di corso con ritardo, se superano gli studi previsti, sono iscritti in ruolo al posto che a essi sarebbe spettato se avessero superato il corso al loro turno.

5-bis. Gli ufficiali che conseguono la laurea magistrale nella sessione straordinaria dell'ultimo anno del corso regolare, sono iscritti in ruolo dopo i pari grado che hanno conseguito il titolo nelle precedenti sessioni ordinarie fissate dal rispettivo piano di studi.

6. Gli ufficiali che non hanno completato gli studi al termine dell'ultimo anno di corso con le modalita' definite dal regolamento sono ammessi a completarli nell'anno successivo. In tale caso essi transitano al corso successivo a quello di appartenenza e sono iscritti in ruolo dopo l'ultimo pari grado appartenente al corso al quale sono transitati, assumendone la stessa anzianita' assoluta.

7. La nomina a sottotenente decorre, ai soli fini giuridici, dalla data di acquisizione della qualifica di aspirante.

#### Art. 732. - Mancato completamento degli iter formativi

1. Gli ufficiali dei ruoli normali che non completano gli studi sono trasferiti d'autorita', con il proprio grado e la propria anzianita', (( secondo le modalita' e i requisiti di cui all'articolo 655, comma 1, lettera d) )) previo parere favorevole della competente commissione ordinaria d'avanzamento:

- a) nel ruolo naviganti speciale, mantenendo gli obblighi di ferma contratti, se appartenenti al ruolo naviganti normale una volta conseguito il brevetto di pilota militare o di navigatore militare;
- b) nel ruolo speciale delle armi, se non hanno conseguito il brevetto di pilota militare o di navigatore militare, tramutando gli obblighi di ferma assunti in precedenza con quelli previsti dall'articolo 724, comma 2, con decorrenza dalla data di nomina ad aspiranti ufficiali;
- c) nei ruoli speciali, mantenendo gli obblighi di ferma contratti, se appartenenti ai ruoli delle armi e dei corpi.

2. Gli ufficiali del ruolo naviganti normale che hanno completato gli studi senza conseguire il brevetto di pilota militare o di navigatore militare sono trasferiti d'autorita', con il proprio grado e la propria anzianita', nel ruolo normale delle armi, tramutando la ferma di cui all'articolo 724, comma 2, in luogo di quella precedentemente assunta. L'ordine di precedenza rispetto ai pari grado e anzianita' iscritti in ruolo e' stabilito sulla base del punteggio di merito elaborato ai sensi dell'articolo 731, comma 3. Ai fini della promozione ad anzianita' si computa l'anzianita' complessiva maturata nel grado.

3. I frequentatori dei corsi regolari destinati al reclutamento degli ufficiali in servizio permanente del ruolo naviganti normale, divenuti non idonei al volo dopo l'inizio della prima sessione di esami del primo anno accademico, possono essere trasferiti a domanda, previo parere favorevole espresso da parte di un'apposita commissione, nei corrispondenti corsi regolari di accademia per ufficiali del ruolo normale delle armi ovvero dei ruoli normali dei corpi, in relazione alla corrispondenza degli esami sostenuti con quelli previsti per il nuovo corso.

4. Gli ufficiali di cui al comma 1, che non sono trasferiti nei ruoli speciali, cessano dal servizio permanente e sono collocati nella categoria del congedo in qualita' di ufficiali di complemento del ruolo di appartenenza ovvero del ruolo speciale delle armi, se non sono in possesso del brevetto di pilota o di navigatore militare.

4-bis. Gli ufficiali che non superano l'anno di corso perche' non idonei in attitudine militare e professionale sono posti in congedo secondo le modalita' previste dall'articolo 935, comma 1, lettera c-bis).

5. Fermo restando quanto previsto dall'articolo 660, se non esistono vacanze nei nuovi ruoli, gli ufficiali sono trasferiti in soprannumero e l'eccedenza e' riassorbita al verificarsi della prima vacanza. L'avanzamento nel nuovo ruolo non puo' avere decorrenza anteriore alla data di trasferimento.

#### Art. 733. - Mancato transito nei ruoli speciali

1. Gli ufficiali che non hanno presentato domanda di transito nei ruoli speciali ai sensi dell'articolo 655, comma 1, lettera d), ovvero non vi possono transitare ai sensi del medesimo articolo, o dell'articolo 732, comma 1, sono collocati nella categoria del complemento con obbligo di ultimare la ferma contratta ((, fatta eccezione per i casi di cui all'articolo 935, comma 1, lettera c-bis) )).

### SEZIONE V - UFFICIALI DELL'ARMA DEI CARABINIERI

#### Art. 734. - (( (Corso di applicazione e corso di perfezionamento).))

((

1. I sottotenenti del ruolo normale dell'Arma dei carabinieri che hanno frequentato l'accademia militare e completato con esito favorevole il biennio formativo, sono ammessi alla frequenza di un corso di applicazione della durata di due anni e di un successivo corso di perfezionamento della durata di un anno.

2. Per i sottotenenti di cui al comma 1 che superano i corsi di applicazione il nuovo ordine di anzianita' e' determinato, con decreto ministeriale, in base alla graduatoria stabilita secondo le norme previste dal regolamento.

3. Gli ufficiali di cui al comma 1 completano il ciclo formativo frequentando un corso di perfezionamento della durata di un anno, regolato dall'ordinamento della Scuola ufficiali carabinieri, al termine del quale l'anzianita' relativa e' rideterminata con decreto ministeriale, sulla base della graduatoria stabilita secondo le modalita' previste dal regolamento, fermo restando quanto stabilito dal comma 2, lettera b), dell'articolo 651-bis.

4. I sottotenenti che non superano per una sola volta uno dei due anni del corso di applicazione per essi previsto sono ammessi a ripeterlo e se lo superano sono promossi con l'anzianita' attribuita agli ufficiali unitamente ai quali hanno superato il predetto corso. Gli ufficiali che superano il corso di applicazione o il corso di perfezionamento con ritardo per motivi di servizio riconosciuti con determinazione ministeriale ovvero per motivi di salute, sono iscritti in ruolo al posto che a essi sarebbe spettato se avessero superato il corso al loro turno.

))

#### Art. 735. - Mancato superamento dei corsi di applicazione e di perfezionamento

1. I sottotenenti del ruolo normale che non superano il corso di applicazione per essi prescritto ((sono collocati nella categoria del complemento con obbligo di ultimare la ferma contratta.)):

- a) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95));
- b) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95));
- c) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95)).

1-bis. I tenenti del ruolo normale che non superano il corso di perfezionamento per essi prescritto non sono ammessi a ripeterlo e nella rideterminazione dell'anzianita', di cui all'articolo 734, comma ((3)), sono iscritti in ruolo dopo l'ultimo dei pari grado ((che ha frequentato l'accademia militare,)) avente la stessa anzianita'.

1-ter. Gli ufficiali che non superano l'anno di corso perche' non idonei in attitudine militare e professionale sono posti in congedo secondo le modalita' previste dall'articolo 935, comma 1, lettera c-bis).

#### Art. 736. - (( (Corso applicativo per ufficiali del ruolo normale).))

((

1. I sottotenenti del ruolo normale provenienti dai ruoli degli ispettori, sovrintendenti e appuntati e carabinieri sono ammessi a frequentare un corso applicativo:

- a) anche con modalita' telematica, di durata non inferiore a sei mesi se vincitori del concorso di cui alla lettera b) del comma 1 dell'articolo 651-bis;
- b) di durata non inferiore a due anni se vincitori del concorso di cui alla lettera c) del comma 1 dell'articolo 651-bis.

2. Per i sottotenenti di cui al comma 1 che superano i corsi applicativi per essi prescritti il nuovo ordine di anzianita' e' determinato, con decreto ministeriale, in base alla graduatoria stabilita secondo le norme previste dal regolamento, fermo restando quanto stabilito dal comma 2, lettere a) e b), dell'articolo 651-bis.

3. I sottotenenti di cui al comma 1, lettera b) che non superano per una sola volta uno dei due anni del corso applicativo per essi previsto sono ammessi a ripeterlo e se lo superano sono promossi con l'anzianita' attribuita agli ufficiali unitamente ai quali hanno superato il predetto corso.

4. I sottotenenti di cui al comma 1 che superano il corso applicativo per essi previsto con ritardo per motivi di servizio riconosciuti con determinazione ministeriale, ovvero per motivi di salute, sono iscritti in ruolo al posto che a essi sarebbe spettato se avessero superato il corso al loro turno.

5. I sottotenenti di cui al comma 1 che non superano il corso applicativo per essi previsto rientrano nella categoria di provenienza. Il periodo di durata del corso e' in tali casi computato per intero ai fini dell'anzianita' di servizio.

))

#### Art. 737. - Corso formativo per ufficiali del ruolo tecnico

1. I tenenti del ruolo tecnico sono ammessi a frequentare un corso formativo, della durata non inferiore a ((un anno)), al termine del quale e' determinata una nuova anzianita' relativa in base all'ordine della graduatoria finale del corso.

#### Art. 737-bis. - (Corso di formazione per ufficiali del ruolo forestale)

1. I tenenti del ruolo forestale sono ammessi a frequentare un corso di formazione, di durata non inferiore a ((un anno)), al termine del quale e' determinata una nuova anzianita' relativa in base all'ordine della graduatoria finale del corso.

#### Art. 738. - Obblighi di servizio

1. Gli allievi dell'Accademia all'atto dell'ammissione ai corsi sono vincolati a una ferma di tre anni. All'atto della nomina a sottotenente sono vincolati a una nuova ferma di nove anni, che assorbe quella da espletare.

((

2. Gli ufficiali reclutati nel ruolo normale a nomina diretta, all'atto dell'ammissione al corso applicativo di cui all'articolo 722, sono vincolati a una ferma di sette anni, decorrente dall'inizio del rispettivo corso applicativo, che assorbe ogni altra ferma precedentemente contratta.

))

3. I vincitori dei concorsi per la nomina a ufficiale del ruolo ((tecnico)) e del ruolo forestale, se non gia' in servizio permanente, sono vincolati a una ferma di sette anni, decorrente dall'inizio del rispettivo corso formativo, che assorbe ogni altra ferma precedentemente contratta.

## CAPO III - UFFICIALI AUSILIARI

### SEZIONE I - UFFICIALI IN FERMA PREFISSATA

#### Art. 739. - Corsi di formazione

1. La durata dei corsi di formazione per gli ufficiali in ferma prefissata e' stabilita con decreto del Ministro della difesa.

2. Le modalita' per lo svolgimento dei corsi di formazione e i relativi programmi sono determinati dai rispettivi Stati maggiori o Comando generale.

3. I vincitori dei concorsi per il reclutamento degli ufficiali in ferma prefissata sono ammessi ai corsi di formazione nella qualita' di allievi ufficiali in ferma prefissata.

4. Agli allievi ufficiali in ferma prefissata compete il trattamento economico previsto per gli allievi ufficiali delle accademie.

#### Art. 740. - Superamento dei corsi di formazione e nomina nel grado

1. Gli allievi che superano gli esami di fine corso sono nominati:

- a) sottotenenti o guardiamarina in ferma prefissata, ausiliari del corrispondente ruolo speciale della Forza armata d'appartenenza, se il titolo di studio richiesto dal bando di concorso e' il diploma di istruzione secondaria di secondo grado;
- b) tenenti o sottotenenti di vascello in ferma prefissata, ausiliari del corrispondente ruolo normale della Forza armata d'appartenenza, se il titolo di studio richiesto dal bando di concorso e' ((la laurea magistrale));
- c) tenenti dell'Arma dei carabinieri in ferma prefissata, ausiliari del corrispondente ruolo tecnico o forestale.

2. L'anzianita' relativa e' determinata dalla media del punteggio della graduatoria del concorso e di quello conseguito al termine del corso stesso.

#### Art. 741. - Mancato superamento degli esami di fine corso

1. Gli allievi che non superino gli esami di fine corso in prima sessione, sono ammessi a ripeterli in una sessione di riparazione trascorsi almeno trenta giorni dalla sessione ordinaria. In caso di superamento degli esami in tale sessione sono nominati ufficiali e sono iscritti in ruolo, dopo i pari grado che hanno superato tutti gli esami in prima sessione, con la medesima anzianita' assoluta.

2. Gli allievi che non superino gli esami in seconda sessione sono dimessi dal corso previa determinazione del Direttore generale del personale militare. A essi si applica l'articolo 742, comma 2.

#### Art. 742. - Dimissioni dai corsi

1. Gli allievi che dimostrino di non possedere il complesso delle qualita' e delle attitudini necessarie per bene assolvere le funzioni del grado o che si rendano colpevoli di gravi mancanze contro la disciplina, il decoro o la morale ovvero che non frequentino almeno ((due terzi)) delle lezioni ed esercitazioni sono dimessi dal corso previa determinazione del Direttore generale del personale militare.

2. Gli allievi comunque dimessi dal corso:

- a) se provenienti dai ruoli dei marescialli, rientrano nella categoria di provenienza. Il periodo di durata del corso e' in tali casi computato per intero ai fini dell'anzianita' di servizio;
- b) se provenienti dalla vita civile, sono collocati in congedo.

### SEZIONE II - UFFICIALI PILOTI E NAVIGATORI DI COMPLEMENTO

#### Art. 743. - Corsi di pilotaggio e di navigatore

1. I giovani, ammessi ai corsi di pilotaggio aereo o ai corsi di navigatore, sono assunti ((con la qualifica)) di allievo ufficiale di complemento per compiere la ferma di anni dodici, decorrente dalla data di inizio dei corsi suddetti.

2. Essi sono promossi caporali e gradi corrispondenti dopo un primo periodo di istruzione della durata di tre mesi e sergenti e gradi corrispondenti di complemento all'atto del conseguimento del brevetto di pilota di aeroplano.

3. Gli ufficiali di complemento e i sottufficiali, ammessi ai corsi di pilotaggio o ai corsi di navigatore, assumono la qualifica di allievo ufficiale. Se essi vengono dimessi dai corsi di pilotaggio o dai corsi di navigatore, ((sono reintegrati nel ruolo di provenienza con il grado)) originariamente posseduto e il periodo di frequenza dei corsi medesimi e' computato ai fini della anzianita' di grado.

((

3-bis. Nel caso di ammissione ai corsi di pilotaggio aereo o ai corsi per navigatore militare, al personale reclutato ai sensi dell'articolo 676, proveniente senza soluzione di continuita' dai ruoli del complemento, dal ruolo dei marescialli, dal ruolo dei sergenti ovvero dai volontari di truppa, si applica l'articolo 1780.

))

#### Art. 744. - Nomina

1. Al termine dei corsi, gli allievi, che hanno superato le prove prescritte per il conferimento del brevetto di pilota militare o del brevetto di navigatore militare e gli esami teorici, conseguono, se giudicati idonei ad assumere il grado, la nomina a sottotenente e grado corrispondente di complemento.

#### Art. 745. - Obblighi di servizio

1. Coloro che chiedono di essere ammessi ai corsi di pilotaggio o ai corsi di navigatore devono, all'atto della presentazione della domanda, impegnarsi a contrarre una ferma di anni dodici.

2. Per coloro che sono gia' incorporati ovvero hanno adempiuto gli obblighi di leva presso altra Forza armata, l'ammissione al corso resta condizionata al nulla osta della Forza armata di appartenenza.

#### Art. 746. - Mancato superamento del corso

1. Gli allievi che non hanno superato gli esami teorici o che sono stati giudicati non idonei ad assumere il grado di sottotenente e gradi corrispondenti di complemento, pur avendo superato le prove prescritte per il conferimento del brevetto di pilota militare o del brevetto di navigatore militare, conseguono la nomina a pilota militare o a navigatore militare. In tale qualita' sono tenuti a prestare servizio con il grado di sergente o corrispondente di complemento per un periodo di sei anni, decorrente dalla data d'inizio dei corsi di pilotaggio e dei corsi di navigatori.

#### Art. 747. - Dimissioni dal corso

1. Il Ministro della difesa, su proposta del Comandante della scuola di pilotaggio, ha facolta' di dimettere dai corsi gli allievi che, per motivi psico-fisici o per mancanza di attitudine al pilotaggio o di attitudine a espletare mansioni di navigatore o per motivi disciplinari, sono ritenuti non pienamente idonei a proseguire i corsi stessi.

#### Art. 748. - Reimpiego del personale che non supera il corso o ne e' dimesso

1. Fermo restando quanto previsto dall'articolo 743, comma 3, coloro che non conseguono il brevetto di pilota d'aeroplano o quello di pilota militare o di navigatore militare ovvero che sono dimessi dal corso per motivi psico-fisici o per mancanza di attitudine al pilotaggio o di attitudine a espletare mansioni di navigatore o per motivi disciplinari, perdono la qualifica di allievo ufficiale e, se hanno precedenti obblighi di servizio, completano la relativa ferma.

2. A eccezione di quelli dimessi per motivi disciplinari, i militari di cui al comma 1 possono, a domanda, partecipare, in relazione al titolo di studio posseduto, a uno dei corsi indetti per allievi ufficiali di complemento e, in attesa di iniziare tali corsi, possono essere inviati in licenza straordinaria senza assegni.

3. Il periodo di tempo trascorso alle armi in qualita' di allievo ufficiale e' considerato utile agli effetti dell'assolvimento degli obblighi di leva.

#### Art. 749.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

### SEZIONE III - UFFICIALI DI COMPLEMENTO

#### Art. 750. - Corsi di formazione

1. I corsi di formazione per gli allievi ufficiali di complemento sono attivati esclusivamente nelle ipotesi di ripristino del servizio obbligatorio di leva di cui all' articolo 1929, comma 2.

2. In relazione alle specifiche esigenze di ciascuna Forza armata, la durata dei corsi allievi ufficiali di complemento e' stabilita con decreto del Ministro della difesa.

3. I sottotenenti di complemento dell'Arma dei carabinieri sono tratti dai giovani che superano il corso allievi ufficiali di complemento presso la Scuola ufficiali carabinieri.

## CAPO IV - FORMAZIONE SUPERIORE DEGLI UFFICIALI

### SEZIONE I - CORSI DI STATO MAGGIORE

#### Art. 751. - Corso superiore di stato maggiore interforze

1. Presso l'Istituto superiore di stato maggiore interforze e' svolto il corso superiore di stato maggiore interforze cui possono partecipare anche gli ufficiali del Corpo della Guardia di finanza nonche' ufficiali delle Forze armate estere.

2. Il superamento del corso di cui al comma 1 e' valutato ai fini dell'avanzamento e dell'impiego degli ufficiali.

3. I criteri e le modalita' per la selezione dei candidati alla frequenza del corso di cui al comma 1, sono determinati con decreto del Ministro della difesa. Con determinazione del Comandante generale del Corpo della Guardia di finanza, sentito il Ministro della difesa, sono stabiliti i requisiti e le modalita' di ammissione al corso degli ufficiali del predetto Corpo.

4. Il Capo di stato maggiore della difesa, sentiti i Capi di stato maggiore di Forza armata, il Comandante generale dell'Arma dei carabinieri e, per quanto di interesse,((il Direttore nazionale degli armamenti e)) il Segretario generale della difesa, determina annualmente il numero dei frequentatori al corso di cui al comma 1.

#### Art. 752. - Ammissione degli ufficiali dell'Arma dei carabinieri al corso superiore di stato maggiore interforze

1. I maggiori e i tenenti colonnelli dell'Arma dei carabinieri possono essere ammessi al corso superiore di stato maggiore interforze, sulla base della disciplina prevista ai sensi dell'articolo 751, comma 4, ad avvenuto compimento del periodo di comando prescritto ai fini dell'avanzamento, anche se compiuto in tutto o in parte nel grado di capitano, e dopo aver superato il corso d'istituto di cui all'articolo 755.

2. L'elenco degli ufficiali utilmente collocati in graduatoria e' sottoposto dal Comandante generale dell'Arma dei carabinieri al Capo di stato maggiore della difesa per l'approvazione.

#### Art. 753. - Corsi dell'Istituto superiore di stato maggiore interforze per gli ufficiali dei Corpi e dei ruoli tecnici e logistici

1. In relazione alle prevedibili esigenze di impiego di ciascuna Forza armata, gli ufficiali dei Corpi e dei ruoli tecnici e logistici sono ammessi ai corsi dell'Istituto superiore di stato maggiore interforze secondo le procedure previste dall'articolo 751.

#### Art. 754. - Corsi di stato maggiore

1. Lo Stato maggiore dell'Esercito, annualmente, determina il numero di ufficiali da ammettere alla frequenza del corso di stato maggiore.

2. Nel regolamento sono disciplinati i corsi di formazione superiore per gli ufficiali dell'Esercito italiano, sulla base delle seguenti indicazioni:

- a) previsione dei corsi da svolgere e delle relative finalita' in armonia con le disposizioni relative al corso superiore di stato maggiore interforze;
- b) destinazione alla frequenza dei corsi degli ufficiali dei ruoli normali dell'Esercito italiano che hanno compiuto i periodi di comando o ai quali sono state conferite attribuzioni specifiche prescritte ai fini dell'avanzamento;
- c) determinazione dell'articolazione dei corsi, anche in relazione all'attuazione delle previsioni di cui all'articolo 719, e delle modalita' di valutazione degli ufficiali frequentatori;
- d) previsione dei casi di esonero e di dimissione dai corsi ovvero di rinuncia;
- e) destinazione a ricoprire incarichi connessi all'espletamento di funzioni di stato maggiore per gli ufficiali che superano i prescritti percorsi formativi e selettivi;
- f) determinazione da parte del Capo di stato maggiore dell'Esercito dei percorsi formativi e delle modalita' di svolgimento dei corsi, secondo le attribuzioni in materia di formazione del personale militare previste dal presente codice.

3. Analoghi corsi sono previsti per gli ufficiali della Marina militare e dell'Aeronautica militare.

### SEZIONE II - CORSO D'ISTITUTO PER UFFICIALI DELL'ARMA DEI CARABINIERI

#### Art. 755. - Corso d'istituto

Il corso d'istituto per gli ufficiali in servizio permanente effettivo dell'Arma dei carabinieri e' svolto presso la Scuola ufficiali carabinieri dai maggiori ((dei ruoli normale, forestale e tecnico)). Il corso tende all'affinamento della preparazione culturale, giuridica e tecnico-professionale dei frequentatori, anche attraverso ((il miglioramento)) di competenze e abilita' per l'assolvimento delle funzioni ((dirigenziali)) nel successivo sviluppo di carriera. 2. Le conoscenze e le capacita' acquisite nonche' le potenzialita' espresse dai frequentatori formano oggetto di specifiche valutazioni. Il corso si conclude con un esame sostenuto davanti ad apposita commissione, nominata dal Comandante generale dell'Arma dei carabinieri. Il punteggio di fine corso, determinato sulla base delle valutazioni e dell'esame conclusivo, e la relativa graduatoria, approvati dal Comandante generale dell'Arma dei carabinieri, sono comunicati agli interessati e pubblicati nel Giornale ufficiale del Ministero della difesa. 3. Nel regolamento sono stabilite la durata, le modalita' di ammissione, di svolgimento, di frequenza ((anche con modalita' telematica)), di rinvio, di valutazione dei frequentatori, nonche' le modalita' di funzionamento della commissione di cui al comma 2.

### SEZIONE III - MEDICI MILITARI

#### Art. 756. - Formazione specifica in medicina generale

1. Il medico militare in servizio permanente, iscritto ai corsi di formazione specifica in medicina generale della durata di tre anni, riservati ai laureati in medicina e chirurgia, abilitati all'esercizio professionale, per il conseguimento del relativo diploma, necessario per l'esercizio dell'attivita' di medico chirurgo di medicina generale, e' collocato, compatibilmente con le esigenze di servizio, in posizione di aspettativa senza assegni secondo le disposizioni legislative vigenti. Il periodo di aspettativa e' utile ai fini della progressione di carriera e del trattamento di quiescenza e di previdenza.

2. Al medico militare di cui al comma 1, si applicano le disposizioni di cui al titolo IV del decreto legislativo 17 agosto 1999, n. 368.

#### Art. 757. - Formazione specialistica

1. Per le esigenze di formazione specialistica dei medici, nell'ambito dei posti risultanti dalla programmazione di cui all'articolo 35, comma 1, del decreto legislativo n. 368 del 1999, e' stabilita, d'intesa con il Ministero della difesa, una riserva di posti complessivamente non superiore al 5 per cento per le esigenze di formazione specialistica della sanita' militare.

2. La ripartizione tra le singole scuole di specializzazione dei posti riservati, di cui all'articolo 35, commi 2 e 3, del decreto legislativo n. 368 del 1999, e' effettuata, sentito il Ministero della difesa, per gli aspetti relativi alla sanita' militare.

3. Al personale in formazione specialistica appartenente ai ruoli della sanita' militare si applicano le disposizioni di cui al titolo VI del decreto legislativo n. 368 del 1999, eccetto le disposizioni di cui agli articoli 37, 39, 40, comma 2, e 41, commi 1 e 2. Al personale di cui al presente comma continua ad applicarsi la normativa vigente sullo stato giuridico, l'avanzamento e il trattamento economico propria del personale militare. Lo stesso personale e' tenuto, ai sensi del decreto legislativo n. 368 del 1999, alla frequenza programmata delle attivita' didattiche formali e allo svolgimento delle attivita' assistenziali funzionali alla progressiva acquisizione delle competenze previste dall'ordinamento didattico delle singole scuole, e in particolare all'adempimento degli obblighi di cui all'articolo 38 del decreto legislativo n. 368 del 1999.

#### Art. 758. - Corsi di specializzazione per le esigenze dell'amministrazione

1. Gli ufficiali medici in servizio permanente delle Forze armate che sono ammessi, previa domanda, su designazione e per le esigenze dell'amministrazione, ai corsi di specializzazione delle facolta' mediche universitarie devono conseguire il diploma di specializzazione entro i limiti di tempo previsti per il rispettivo corso legale, con possibilita' di fruire dell'eventuale sessione straordinaria dell'ultimo anno accademico.

2. Il Ministro della difesa ha facolta' di concedere, su proposta della Direzione generale per il personale militare, all'ufficiale, che per motivi di salute o di forza maggiore non possa conseguire il diploma di specializzazione entro il termine di cui al comma 1, una proroga della durata di un anno accademico comprensivo dell'eventuale sessione straordinaria.

## CAPO V - MARESCIALLI DELL'ESERCITO ITALIANO, DELLA MARINA MILITARE E DELL'AERONAUTICA MILITARE

### Art. 759. - Assegnazione agli incarichi, alle specializzazioni, alle categorie e alle specialita'

1. ((. . .)) gli allievi marescialli sono assegnati agli incarichi, alle specializzazioni, alle categorie e specialita' ((secondo specifiche disposizioni della Forza armata,)) in base alle esigenze organiche, al risultato della selezione psico-fisica e attitudinale nonche' alle preferenze espresse dagli arruolandi.

2. Il Capo di stato maggiore di Forza armata ha facolta' di disporre modifiche alle assegnazioni di cui al comma 1 se le attitudini manifestate dai singoli durante il periodo formativo o le esigenze di servizio lo richiedono. Per gli allievi marescialli della Marina militare i provvedimenti sono adottati dalla Direzione generale per il personale militare ((,su proposta della Forza armata)).

3. Per i sottufficiali, i graduati e i militari di truppa dell'Esercito italiano e dell'Aeronautica militare, il Capo di stato maggiore di Forza armata, in relazione alle esigenze di servizio, ha facolta' di disporre di autorita' o a domanda cambi di categoria, di specializzazione, di specialita', ovvero la perdita delle specializzazioni o degli incarichi tecnici, prevedendo altresi' le necessarie riqualificazioni. Per il medesimo personale della Marina militare i provvedimenti sono adottati dalla Direzione generale per il personale militare ((,su proposta della Forza armata)).

### Art. 760. - Svolgimento dei corsi e nomina nel grado

1. Il personale vincitore del concorso di cui all'articolo 679, comma 1, lettere a) e b), e' tenuto a frequentare un corso di formazione e di specializzazione, nonche' il tirocinio complementare fino alla concorrenza dei due anni, presso ciascuna Forza armata, avuto riguardo alle assegnazioni, agli incarichi, alle specializzazioni, alle categorie e specialita', alle esigenze specifiche di Forza armata, al risultato della selezione psico-fisica e attitudinale, nonche' alle preferenze espresse dagli arruolati; al termine del periodo di formazione e istruzione nonche' dei periodi di tirocinio complementare, gli allievi sono sottoposti a esami e trattenuti d'ufficio per il periodo necessario all'espletamento delle prove.

1-bis. In relazione alle esigenze di ciascuna Forza armata, il personale vincitore del concorso di cui all'articolo 679, comma 1, lettera b), in alternativa al corso di cui al comma 1 del presente articolo, puo' essere avviato a frequentare un corso di formazione professionale di durata comunque non inferiore a ((tre mesi)). All'esito dei corsi di formazione, il medesimo personale puo' essere impiegato anche nella sede di servizio di provenienza, tenuto conto delle esigenze dell'amministrazione di cui alle direttive di impiego di ciascuna Forza armata e, ove possibile, delle preferenze espresse dal personale stesso.

2. Al superamento degli esami sono nominati, sulla base della graduatoria di merito, marescialli e gradi corrispondenti in servizio permanente, con decorrenza dal giorno successivo alla data in cui hanno avuto termine gli esami finali; gli allievi non idonei possono essere trattenuti a domanda per sostenere per una sola volta il primo esame utile.

3. Agli allievi si applicano le disposizioni previste dal regolamento per lo svolgimento dei corsi.

4. Gli allievi impediti da infermita' temporanea debitamente accertata o imputati in procedimento penale per delitto non colposo o sottoposti a procedimento disciplinare o sospesi dal servizio per motivi precauzionali o per altra comprovata causa di forza maggiore non possono partecipare agli esami finali per l'immissione nel servizio permanente. Essi proseguono il servizio mediante rafferma annuale rinnovabile, fino al cessare delle cause impeditive e, se le predette cause non comportano proscioglimento dalla ferma, sono ammessi alla prima sessione di esami utili. Coloro che superano gli esami sono promossi e immessi nel servizio permanente con la stessa decorrenza attribuita ai pari grado con i quali sarebbero stati valutati in assenza delle cause impeditive di cui sopra e con l'anzianita' relativa determinata dal posto che avrebbero occupato, in relazione al punteggio globale ottenuto, nella graduatoria di merito dei pari grado medesimi.

4-bis. Il personale vincitore del concorso interno per il reclutamento dei marescialli di cui all'articolo 679, comma 1, lettera b), che frequenta il corso di cui al comma 1 del presente articolo , al superamento degli esami e' nominato, sulla base della stessa graduatoria di merito del personale di cui all'articolo 679, comma 1, lettera a), maresciallo o grado corrispondente in servizio permanente, con decorrenza dal giorno successivo alla data in cui hanno avuto termine gli esami finali.

5. Il personale vincitore del concorso interno per il reclutamento dei marescialli di cui all'articolo 679, comma 1, lettera b), che frequenta il corso di qualificazione di cui al comma 1-bis, e' inserito nel ruolo dei marescialli con il grado di maresciallo e gradi corrispondenti con decorrenza dal giorno successivo alla data di nomina dell'ultimo maresciallo proveniente dal corso, di cui al comma 1, concluso nell'anno.

5-bis. I candidati utilmente collocati nelle graduatorie di merito dei concorsi di cui all'articolo 682, comma 5-bis, frequentano corsi applicativi di durata non superiore a un anno accademico le cui modalita' sono disciplinate con determinazione dei rispettivi Capi di stato maggiore.

5-ter. L'anzianita' relativa dei marescialli di cui al comma 5-bis e' rideterminata, a seguito del superamento degli esami di fine corso, dalla media del punteggio della graduatoria del concorso e di quello conseguito al termine del corso applicativo. Gli stessi sono iscritti in ruolo dopo i marescialli che hanno frequentato il corso di cui al comma 1 e comunque prima di quelli di cui al comma 5, iscritti in ruolo nello stesso anno.

5-quater. I candidati che non superano il corso applicativo di cui al comma 5-bis sono collocati in congedo, se non devono assolvere o completare gli obblighi di leva, ovvero reintegrati nel ruolo di provenienza se gia' in servizio, in tal caso il periodo svolto quale allievo e' riconosciuto come servizio effettivamente svolto. Il periodo di durata del corso non e' computabile ai fini dell'assolvimento degli obblighi di leva.

### Art. 761. - Speciali obblighi di servizio

1. La partecipazione a corsi di particolare livello tecnico, svolti durante la formazione iniziale, e' subordinata al vincolo di una ulteriore ferma di anni cinque, che permane anche dopo il passaggio nel servizio permanente e decorre dalla scadenza della precedente ferma. La ferma precedentemente contratta non rimane operante in caso di mancato superamento del corso o di dimissioni.

2. ((COMMA ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248)).

### Art. 762. - (( (Stato giuridico dei frequentatori).))

((

1. Il personale vincitore dei concorsi di cui all'articolo 679, comma 1, lettera a), durante la frequenza dei corsi formativi previsti assume la qualita' di allievo. Il personale militare di cui all'articolo 682, comma 4, lettera b), all'atto dell'assunzione della qualita' di allievo, perde il grado eventualmente rivestito. In caso di perdita della qualita' di allievo, il predetto personale e' reintegrato nel grado precedentemente rivestito ed e' restituito ai reparti ed enti di appartenenza, per il completamento degli eventuali obblighi di servizio, computando nei medesimi i periodi di tempo trascorsi presso la scuola.

2. Il personale proveniente dai civili assume lo stato giuridico di volontario in ferma per la durata del corso.

3. Al personale vincitore dei concorsi di cui all'articolo 679, comma 1, lettera b), durante la frequenza dei corsi formativi previsti si applicano le disposizioni sullo stato giuridico del ruolo di provenienza.

))

### Art. 763. - Cause di proscioglimento

1. Le cause di proscioglimento dalla ferma, conseguenti a provvedimenti di rinvio ((, espulsione)) o dimissione dai corsi, sono disciplinate nel regolamento.

### Art. 764. - Equipollenza dei titoli conseguiti

1. Con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, d'intesa con i Ministri della difesa, dell'economia e delle finanze e del lavoro e delle politiche sociali, e' stabilita, sulla base degli insegnamenti impartiti, l'equipollenza dei titoli conseguiti al termine dei corsi di formazione generale, professionale e di perfezionamento, frequentati dai volontari e dai sottufficiali, con quelli rilasciati dagli istituti professionali ivi compresi quelli conseguibili con la frequenza dei corsi sperimentali di cui al decreto del Presidente della Repubblica 19 marzo 1970, n. 253, anche ai fini dell'ammissione agli esami di maturita' professionale. In relazione al suddetto decreto sono rilasciati agli interessati i relativi titoli.

## CAPO VI - ISPETTORI

### Art. 765. - Formazione iniziale

1. Per la nomina a maresciallo dell'Arma dei carabinieri i vincitori dei concorsi di cui all'articolo 679 frequentano appositi corsi di formazione iniziale.

2. I vincitori del concorso pubblico di cui all'articolo 679, ((comma 2-bis)), lettera a), sono ammessi alla frequenza del corso biennale.

3. I vincitori del concorso interno di cui all'articolo 679, ((comma 2-bis, lettere b) e c) )), sono ammessi alla frequenza del corso ((superiore di qualificazione)).

4. Ai vincitori del concorso interno per il reclutamento degli ispettori del Reggimento Corazzieri, per la formazione iniziale, si applica l'articolo 696.

### Art. 765-bis.

(Corso di specializzazione ((e corso integrativo specialistico)) per ispettori dell'organizzazione per la tutela forestale, ambientale e agroalimentare).

1. Gli ispettori arruolati nella riserva prevista all'articolo 683, comma ((7, lettera a)), al termine dei corsi di formazione di base di cui agli articoli 767 e 771, comma 3-bis, sono ammessi a frequentare un corso di specializzazione della durata non inferiore a sei mesi.

((

1-bis. Gli ispettori di cui alla riserva prevista all'articolo 683, comma 7, lettera b), al termine del corso di cui all'articolo 685, sono avviati a un corso integrativo specialistico le cui modalita' di svolgimento e i relativi programmi sono stabiliti con determinazione del Comandante generale dell'Arma dei carabinieri.

))

### Art. 766. - Svolgimento del corso biennale

1. Il corso biennale allievi marescialli dell'Arma dei carabinieri si svolge secondo i programmi stabiliti ((con determinazione del Comandante generale dell'Arma dei carabinieri o dell'autorita' da questi delegata)). Sono ammessi al secondo anno di corso gli allievi marescialli che superano gli esami del primo anno.

2. Gli allievi che non superano gli esami alla fine del primo o del secondo anno di corso possono ripetere nell'intero biennio un solo anno di corso.

3. I provenienti dai civili, se non intendono ripetere il corso ma desiderano continuare a prestare servizio nell'Arma fino al compimento della ferma contratta, sono avviati ai comandi di corpo con determinazione del Comando generale dell'Arma; in caso contrario sono prosciolti dalla ferma contratta.

4. Agli ammessi ai corsi per la nomina a maresciallo si applicano le norme contenute nel regolamento.

### Art. 767. - Svolgimento del corso superiore di qualificazione

1. Il corso superiore di qualificazione per marescialli dell'Arma dei carabinieri, che puo' essere ripetuto una sola volta, si svolge secondo i programmi stabiliti ((con determinazione del Comandante generale dell'Arma dei carabinieri o dell'autorita' da questi delegata)). Conseguono l'idoneita' per la nomina a maresciallo gli allievi che hanno superato gli esami finali. Gli allievi che non hanno superato i predetti esami sono restituiti al normale servizio di istituto e sono ammessi alla frequenza del corso successivo.

2. Agli ammessi ai corsi per la nomina a maresciallo si applicano le nome contenute nel regolamento.

### Art. 768. - Stato giuridico dei frequentatori

1. Gli ammessi ai corsi per l'accesso al ruolo degli ispettori dei carabinieri:

- a) se provenienti dal ruolo dei sovrintendenti o da quello degli appuntati e carabinieri, conservano il grado rivestito all'atto dell'ammissione;
- b) se provenienti dagli allievi carabinieri conseguono la promozione a carabiniere nei termini previsti per gli arruolati volontari nell'Arma;
- c) se provenienti dagli ufficiali ausiliari dell'Arma, ottengono la commutazione della ferma gia' contratta in ferma quadriennale con decorrenza dalla data di arruolamento e sono nominati carabinieri effettivi;
- d) se provenienti dai civili, dai militari in servizio oppure in congedo appartenenti ad altre ((. . .)) Forze armate, o dal personale appartenente ad altre Forze di polizia, anche a ordinamento civile, conseguono la qualifica di allievo carabiniere e sono promossi con le modalita' e nei termini prescritti per gli arruolati volontari nell'Arma.

2. I militari in servizio e in congedo delle Forze armate e quelli in congedo dell'Arma dei carabinieri, nonche' il personale appartenente alle altre Forze di polizia, perdono il grado e la qualifica rivestiti all'atto dell'ammissione al corso.

### Art. 769. - Ferma quadriennale

1. Gli allievi marescialli dell'Arma dei carabinieri, all'atto dell'arruolamento, sono vincolati a una ferma volontaria della durata di anni quattro.

### Art. 770. - Dimissioni dai corsi

1. Sono dimessi dai corsi i frequentatori che si trovino nelle condizioni previste dal regolamento.

2. Nelle ipotesi di esclusione per infermita' o per altre cause indipendenti dalla volonta' del frequentatore, lo stesso e' ammesso per una sola volta a partecipare di diritto al primo corso successivo al cessare della causa impeditiva.

3. I provvedimenti di dimissione e di dispensa dai corsi, di cui ai commi precedenti sono adottati con determinazione del Direttore generale del personale militare o da altra autorita' da questi delegata, su proposta del Comandante dell'istituto di istruzione.

### Art. 771. - Nomina a maresciallo

1. Agli effetti della nomina a maresciallo, che si consegue con decreto ministeriale, gli allievi che hanno superato gli esami finali relativi ai corsi di cui agli articoli 766 e 767, sono iscritti in ruolo secondo l'ordine delle graduatoria di fine corso determinato dal punto di classificazione riportato da ciascuno di essi, in conformita' alle disposizioni contenute nel regolamento.

2. La nomina a maresciallo dei frequentatori del corso di cui all'articolo 766, che hanno superato gli esami finali al termine del secondo anno, ha decorrenza dal giorno successivo alla data in cui si concludono le previste sessioni di idoneita'.

3. La nomina a maresciallo dei frequentatori del corso di cui all'articolo 767, che hanno superato gli esami di fine corso, ha decorrenza dal giorno successivo alla data di conclusione del corso. La data di nomina e' comunque successiva a quella conferita al maresciallo classificatosi all'ultimo posto nell'ordine di graduatoria del corso di cui all' articolo 766, concluso nell'anno.

((

3-bis. I frequentatori che superano il corso biennale sono ammessi alla frequenza di un successivo corso di perfezionamento della durata di un anno, regolato dall'ordinamento della Scuola marescialli, al termine del quale l'anzianita' relativa viene rideterminata con decreto ministeriale sulla base della graduatoria stabilita secondo le modalita' previste dal regolamento.

3-ter. I frequentatori che non superano il corso di perfezionamento non sono ammessi a ripeterlo e sono iscritti in ruolo dopo l'ultimo dei pari grado avente la stessa anzianita', secondo l'ordine della graduatoria valida per la rideterminazione dell'anzianita' relativa. I frequentatori che superano il corso di perfezionamento con ritardo per motivi di servizio riconosciuti con determinazione ministeriale ovvero per motivi di salute, ottengono l'anzianita' relativa che a essi sarebbe spettata se avessero superato il corso al loro turno.

))

### Art. 772. - Sospensione dalla nomina a maresciallo

1. La nomina a maresciallo e' sospesa, fino al cessare delle cause impeditive, per coloro che, pur se giudicati idonei al termine del corso, si trovano in una delle seguenti condizioni:

- a) sono rinviati a giudizio o ammessi ai riti alternativi per delitto non colposo;
- b) sono sottoposti a procedimento disciplinare da cui possa derivare una sanzione di stato;
- c) sono sospesi dall'impiego o dalle funzioni del grado;
- d) si trovano in aspettativa per qualsiasi motivo per una durata non inferiore a 60 giorni.

## CAPO VII - SERGENTI

### Art. 773.

Corso di ((formazione basico))

1. I volontari in servizio permanente utilmente collocati nella graduatoria di merito del concorso per il reclutamento del personale del ruolo dei sergenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare frequentano un corso di ((formazione basico di durata non superiore)) a tre mesi.

2. Coloro che al termine del corso sono dichiarati idonei conseguono la nomina a sergente e sono inseriti in ruolo nell'ordine determinato dalla graduatoria finale del corso, con decorrenza dalla data di conclusione dello stesso.

### Art. 774. - (( (Stato giuridico dei frequentatori). ))

((

1. Agli ammessi ai corsi per la nomina a sergente si applicano le disposizioni sullo stato giuridico dei volontari in servizio permanente e quelle contenute nel regolamento.

))

## CAPO VIII - SOVRINTENDENTI

### Art. 775. - (Corso di formazione professionale)

1. Gli appuntati scelti vincitori del concorso per sovrintendenti dell'Arma dei carabinieri, di cui all'articolo 690, comma 4, lettera a) frequentano, anche con modalita' telematica, un corso di formazione professionale, di durata non inferiore a un mese. Il superamento del corso e' condizione per la nomina a vice brigadiere.

2. I programmi e le modalita' di svolgimento del corso, nonche' la composizione della commissione d'esame di fine corso, sono stabiliti con determinazione del Comandante generale dell'Arma dei carabinieri o dall'autorita' da questi delegata.

3. Nell'ambito dello stesso anno solare, i corsi di ((...)) formazione professionale hanno termine anteriormente ai corsi di qualificazione di cui all'articolo 776.

### Art. 776. - Corso di qualificazione

1. Gli appartenenti al ruolo appuntati e carabinieri vincitori del concorso per sovrintendenti dell'Arma dei carabinieri, di cui all'articolo 690, comma ((4)), lettera b) frequentano un corso di qualificazione, di durata non inferiore a tre mesi. Il superamento del corso, mediante idoneita', e' condizione per la nomina a ((vice brigadiere)).

2. I programmi e le modalita' di svolgimento del corso, che puo' essere ripetuto una sola volta, nonche' la composizione della commissione d'esame di fine corso, sono stabiliti con determinazione del Comandante generale dell'Arma dei carabinieri o dell'autorita' da questi delegata.

### Art. 776-bis.

(Corso ((integrativo specialistico)) per sovrintendenti dell'organizzazione per la tutela forestale, ambientale e agroalimentare).

1. I sovrintendenti ((arruolati nella)) riserva prevista all'articolo 692, comma ((7-bis)), al termine dei corsi di cui agli articoli 775 e 776, sono ((avviati ad un corso integrativo specialistico le cui modalita' di svolgimento e i relativi programmi sono stabiliti con determinazione del Comandante Generale)).

### Art. 777. - Stato giuridico dei frequentatori

1. Agli ammessi ai corsi per la nomina a vice brigadiere si applicano le disposizioni sullo stato giuridico degli appuntati e carabinieri e quelle contenute nel regolamento.

### Art. 778. - Dimissioni dai corsi

1. E' dimesso dai corsi di cui agli articoli precedenti e restituito al normale servizio d'istituto, col grado rivestito e senza detrazione di anzianita', il personale che:

- a) formalizza dichiarazione di rinuncia ai corsi;
- b) dimostra in qualsiasi momento di non possedere le qualita' necessarie per bene esercitare le funzioni del nuovo grado;
- c) non supera gli esami finali dopo aver gia' ripetuto il corso di qualificazione;
- d) non supera gli esami finali del corso di ((...)) formazione professionale;
- e) e' stato per qualsiasi motivo assente per piu' di trenta giorni, anche se non continuativi;
- f) si trova nelle condizioni previste dal regolamento.

2. Nelle ipotesi di esclusione per infermita' o per altre cause indipendenti dalla volonta' del frequentatore, lo stesso e' ammesso per una sola volta a partecipare di diritto al primo corso successivo al cessare della causa impeditiva.

3. I provvedimenti di dimissione e di dispensa dai corsi di cui alla presente sezione sono adottati con determinazione del Direttore generale del personale militare o da altra autorita' da questi delegata, su proposta del Comandante dell'istituto di istruzione.

### Art. 779. - Nomina nel grado

1. Coloro i quali, ai sensi delle disposizioni della presente sezione, conseguono la promozione al grado di vicebrigadiere, sono iscritti in ruolo con decorrenza dalla data di fine dei rispettivi corsi e nell'ordine delle rispettive, graduatorie finali, formalizzate con decreto ministeriale. Per la formazione delle medesime graduatorie, a parita' di punteggio prevalgono, nell'ordine: il grado, l'anzianita' di grado, l'anzianita' di servizio e la minore eta'.

### Art. 780. - Sospensione dalla nomina a vice brigadiere

1. La nomina a vice brigadiere e' sospesa, fino al cessare delle cause impeditive, per coloro che, pur se giudicati idonei al termine del corso, si trovano in una delle seguenti condizioni:

- a) sono rinviati a giudizio o ammessi ai riti alternativi per delitto non colposo;
- b) sono sottoposti a procedimento disciplinare da cui possa derivare una sanzione di stato;
- c) sono sospesi dall'impiego o dalle funzioni del grado;
- d) si trovano in aspettativa per qualsiasi motivo per una durata non inferiore a 60 giorni.

## CAPO IX - VOLONTARI IN FERMA PREFISSATA

### Art. 781. - Formazione dei volontari in ferma prefissata

1. I volontari in ferma prefissata seguono l'iter formativo stabilito dalla Forza armata di appartenenza.

((1-bis. I volontari in ferma prefissata della Marina militare conseguono le categorie, le specialita' o le qualificazioni a loro assegnate dalla Direzione generale per il personale militare in fase di reclutamento dopo il superamento del corso di formazione di base))

2. In tema di licenza ordinaria ai volontari in ferma prefissata che frequentano corsi di formazione si applicano le disposizioni previste all'articolo 592 del regolamento.

### Art. 782. - Speciali obblighi di servizio per i volontari

1. ((I volontari ammessi)) a corsi di specializzazione di particolare livello tecnico, individuati con determinazione del Capo di stato maggiore della difesa, ((hanno l'obbligo di)) commutare la ferma o rafferma assunta in una rafferma decorrente dalla data di scadenza di quella precedente e avente durata di cinque anni ((...)); tale obbligo permane anche per i volontari che nel frattempo sono transitati nel servizio permanente.

## CAPO X - CARABINIERI

### Art. 783. - Formazione dei carabinieri

1. Gli arruolati volontari di cui all'articolo 706 sono ammessi al corso per allievo carabiniere. Il predetto personale, dopo sei mesi dalla data di inizio del corso, consegue la nomina a carabiniere ((...)), previo superamento di esami, ed e' immesso in ruolo al grado di carabiniere al termine del corso secondo l'ordine della graduatoria finale.

2. I militari in servizio e in congedo delle Forze armate e quelli in congedo dell'Arma dei carabinieri, nonche' il personale appartenente alle altre Forze di polizia, perdono il grado e la qualifica rivestiti all'atto dell'ammissione al corso.

3. Agli ammessi ai corsi per allievo carabiniere si applicano le norme per le scuole allievi carabinieri, approvate con determinazione del Comandante generale dell'Arma dei carabinieri.

### Art. 783-bis. - (( (Corso di specializzazione per carabinieri dell'organizzazione per la tutela forestale, ambientale e agroalimentare).))

((

1. I carabinieri arruolati nella riserva prevista all'articolo 708, comma 1-bis, al termine dei corsi di formazione di cui all'articolo 783, sono ammessi a frequentare un corso di specializzazione, della durata non inferiore a tre mesi.

))

### Art. 784. - Ferma quadriennale degli allievi carabinieri

1. Gli allievi carabinieri, all'atto dell'arruolamento, contraggono una ferma volontaria della durata di anni quattro.

### Art. 785. - Sospensione dalla nomina a carabiniere

1. La nomina a carabiniere e' sospesa, fino al cessare delle cause impeditive, per coloro che, se pur giudicati idonei al termine del corso, si trovano in una delle seguenti condizioni:

- a) sono rinviati a giudizio o ammessi ai riti alternativi per delitto non colposo;
- b) sono sottoposti a procedimento disciplinare da cui possa derivare una sanzione di stato;
- c) sono sospesi dall'impiego o dalle funzioni del grado;
- d) si trovano in aspettativa per qualsiasi motivo per una durata non inferiore a 60 giorni.

## CAPO XI - ALLIEVI DELLE SCUOLE MILITARI

### Art. 786. - Corsi di studio

1. I corsi di studio seguiti presso le scuole militari sono di ordine classico e scientifico.

2. I programmi svolti presso le scuole militari corrispondono a quelli previsti per l'intero corso del liceo classico e per il terzo, quarto e quinto anno del liceo scientifico.

3. All'atto dell'ammissione dell'allievo, il genitore o il tutore si impegna ad accettare la normativa concernente la frequenza della scuola militare.

### Art. 787. - Retta annuale e spese di cancelleria

1. La misura della retta annuale e' stabilita, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

2. E' accordato il beneficio della retta intera gratuita agli orfani di guerra o equiparati e agli orfani di dipendenti militari e civili dello Stato deceduti per ferite, lesioni o infermita' riportate in servizio e per causa del servizio.

3. E' accordato il beneficio della mezza retta gratuita per benemerenze di famiglia:

- a) ai figli dei decorati dell'Ordine militare d'Italia o dei decorati di medaglia d'oro al valor militare;
- b) ai figli dei mutilati e degli invalidi di guerra per lesioni o infermita' ascrivibili alle prime quattro categorie elencate nella tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e successive modificazioni;
- c) ai figli di militari di carriera, di ufficiali di complemento richiamati in temporaneo servizio che per il servizio prestato hanno acquisito il diritto al trattamento di quiescenza, di dipendenti civili di ruolo dello Stato, di titolari di pensioni ordinarie civili e militari dello Stato.

4. E' accordato il beneficio della mezza retta gratuita per merito personale nel primo anno del liceo classico e nel terzo anno del liceo scientifico agli allievi compresi nei primi due decimi delle graduatorie di cui all'articolo 713, solo se hanno superato gli esami di ammissione con una media complessiva non inferiore agli otto decimi.

5. Uguale beneficio e' concesso agli allievi che negli scrutini annuali risultino classificati nei primi due decimi dei promossi al corso superiore, solo se hanno riportato una media complessiva non inferiore agli otto decimi.

6. Possono cumularsi a favore dello stesso allievo due mezze rette gratuite per benemerenze diverse, l'una per benemerenza di famiglia e l'altra per merito personale.

7. Il beneficio della gratuita' o semi gratuita' per benemerenze di famiglia non e' accordato durante il tempo in cui l'allievo ripete l'anno in corso per insuccesso negli esami.

8. Il genitore o il tutore si impegna al pagamento della retta annuale, delle spese complementari e di tutte quelle di cui l'allievo risulti debitore verso l'amministrazione della scuola.

### Art. 788. - Ferma speciale volontaria

1. Gli allievi, dal compimento del 15° anno di eta' e sino alla maggiore eta', sono arruolati a domanda e con il consenso di chi esercita la potesta', e contraggono una ferma speciale di anni 3 per il completamento del corso di studi prescelto; a tal fine, possono contrarre successive rafferme di un anno.((Al completamento del corso di studio, agli allievi si applicano le disposizioni di cui agli articoli 2050 e 2052.))

2. Gli allievi che non presentano domanda di arruolamento volontario cessano di appartenere all'istituto militare.

3. Gli allievi in ferma speciale volontaria non possono essere impiegati in attivita' operative.

4. Rimane ferma la giurisdizione del tribunale per i minorenni per i reati militari commessi dagli allievi.

5. Il genitore o il tutore dell'allievo minorenne, ovvero l'allievo maggiorenne, possono ottenere in qualunque momento dell'anno scolastico il ritiro dalla scuola, con il proscioglimento da ogni vincolo di ferma.

6. Agli allievi delle scuole militari e' corrisposta una paga netta giornaliera determinata con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze.

### Art. 789. - Cause di rinvio dalle scuole militari

1. Sono causa di rinvio dalle scuole militari:

- a) l'aver riportato un voto insufficiente in attitudine militare;
- b) l'aver ripetuto piu' di un anno durante l'intera permanenza nella scuola;
- c) le altre ipotesi disciplinate dal regolamento.

2. Gli allievi delle scuole militari sono giudicati annualmente in relazione all'idoneita' alla vita militare, secondo le modalita' stabilite nel regolamento, attraverso l'attribuzione di un voto in attitudine militare.

## TITOLO IV RUOLI CAPO I DISPOSIZIONI GENERALI

### SEZIONE I - NORME GENERALI SUI RUOLI

#### Art. 790. - Ruoli

1. Tutti i militari, a eccezione di quelli in congedo assoluto, sono inquadrati in distinti ruoli, all'interno dei quali sono inseriti nell'ordine determinato dall'anzianita' assoluta e dall'anzianita' relativa.

2. Per ciascuna Forza armata o Corpo armato sono definiti i ruoli che raggruppano i singoli appartenenti.

#### Art. 791. - Ruoli degli ufficiali in congedo

1. Gli ufficiali dell'ausiliaria, gli ufficiali di complemento, gli ufficiali della riserva nonche' quelli della riserva di complemento sono rispettivamente iscritti in ruoli corrispondenti a quelli del servizio permanente.

#### Art. 792. - Organici

1. Per ogni ruolo sono determinate dal presente codice le dotazioni organiche.

2. L'organico e' il numero massimo complessivo di personale ((stabilito per ciascun)) ruolo.

#### Art. 793. - Iscrizione in ruolo

1. Per il personale ufficiali, sottufficiali e graduati, l'iscrizione in ruolo si ha con l'atto di nomina nel grado o negli altri casi stabiliti dal presente codice.

2. Per i militari di truppa l'iscrizione in ruolo si ha:

- a) con l'atto di arruolamento, per coloro che sono obbligati al servizio militare;
- b) con l'atto di incorporazione per il personale volontario.

#### Art. 794. - Cancellazione dai ruoli

1. La cancellazione dai ruoli si ha esclusivamente nei casi determinati dal presente codice.

2. La cancellazione dai ruoli e' causa di perdita del grado come previsto dall'articolo 861.

#### Art. 795. - Riammissione in ruolo

1. Il militare che ha cessato di essere iscritto nei ruoli e che e' riammesso nei ruoli stessi subisce, all'atto della riammissione, una detrazione di anzianita' assoluta pari all'interruzione, salvo eventuale diritto, conferitogli da speciali disposizioni, a conservare parzialmente o integralmente l'anzianita' posseduta.

2. Il presente codice contempla i casi per i quali non si fa luogo alla detrazione di anzianita' per la riammissione in ruolo.

#### Art. 796. - Transito tra ruoli

1. Gli ufficiali in servizio permanente e gli appartenenti al ruolo musicisti possono transitare da un ruolo a un altro esclusivamente nei casi previsti per la Forza armata di appartenenza, disciplinati dal presente codice.

2. Le varie ipotesi di transito, anche in relazione alla determinazione dell'anzianita' assoluta e dell'anzianita' relativa, sono disciplinate dal presente codice. Il transito tra ruoli e' disposto con decreto ministeriale.

3. Al fine di fronteggiare specifiche esigenze funzionali e di assicurare continuita' nell'alimentazione del personale militare in servizio permanente, il Ministro della difesa definisce annualmente, con proprio decreto, i contingenti di volontari in ferma prefissata e in servizio permanente e di sergenti dell'Esercito, della Marina e dell'Aeronautica, eventualmente ripartiti per categorie e specialita', che possono transitare a domanda tra le medesime Forze armate. Il medesimo decreto definisce i criteri, i requisiti e le modalita' per accedere al transito. Ai fini della iscrizione in ruolo nella Forza armata ricevente, si applicano i commi 2 e 3 dell'articolo 797. Il transito e' disposto con decreto ((dirigenziale)). Dall'attuazione del presente comma non devono derivare nuovi o maggiori oneri a carico del bilancio dello Stato.

#### Art. 797. - Trasferimento tra ruoli

1. Il trasferimento da ruolo a ruolo e' previsto per il personale militare delle categorie in congedo. Per il personale in servizio permanente non e' previsto il trasferimento da ruolo a ruolo.

2. Nel trasferimento da ruolo a ruolo si conserva l'anzianita' posseduta prima del trasferimento.

3. Nei trasferimenti da ruolo a ruolo a parita' di anzianita' assoluta, l'ordine di precedenza e' determinato dall'eta', salvo il caso di militari provenienti dallo stesso ruolo, per i quali si osserva l'ordine di precedenza acquisito nel comune ruolo di provenienza. A parita' di eta' si raffrontano le anzianita' assolute successivamente nei gradi inferiori fino a quello in cui non si riscontra parita' di anzianita'. Se si riscontra parita' anche nell'anzianita' assoluta di nomina, e' considerato piu' anziano colui che ha maggior servizio effettivo.

3-bis. ((COMMA ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248)).

3-ter. ((COMMA ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248)).

### SEZIONE II - NORME GENERALI SUGLI ORGANICI

#### Art. 798. - Dotazioni organiche complessive dell'Esercito italiano, della Marina militare e dell'Aeronautica militare).

1. L'entita' complessiva delle dotazioni organiche del personale militare dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare e' fissata a ((160.000 unita')). ((110))

2. Ferme restando le dotazioni organiche complessive di ciascuna Forza armata fissate dall'articolo 798-bis, possono essere apportate, senza oneri aggiuntivi, con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, modifiche alle dotazioni organiche delle singole categorie di personale al fine di adeguarne la disponibilita' alle effettive esigenze funzionali da soddisfare.

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia". ------------- AGGIORNAMENTO (22a) Il D.P.C.M. 11 gennaio 2013 (in G.U. 3/4/2013, n. 78) ha disposto (con l'art. 1, comma 1) che "L'entita' complessiva delle dotazioni organiche del personale militare dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, di cui all'art. 798, comma 1, del decreto legislativo 15 marzo 2010, n. 66, e' ridotta a 170.000 unita'". ------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 798-bis. - (( (Ripartizione delle dotazioni organiche dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). ))

((

1. La ripartizione delle dotazioni organiche dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare e' determinata nelle seguenti unita':

- a) ufficiali: 1) 9.800 dell'Esercito italiano; 2) 4.741 della Marina militare; 3) 6.100 dell'Aeronautica militare;
- b) sottufficiali: 1) 18.300 dell'Esercito italiano, di cui 6.950 marescialli e 11.350 sergenti; 2) 11.034 della Marina militare, di cui 6.200 marescialli e 4.834 sergenti; 3) 17.325 dell'Aeronautica militare, di cui 8.475 marescialli e 8.850 sergenti;
- c) volontari: 1) 65.000 dell'Esercito italiano, di cui 40.000 in servizio permanente e 25.000 in ferma prefissata; 2) 14.275 della Marina militare, di cui 10.505 in servizio permanente e 3.770 in ferma prefissata; 3) 13.425 dell'Aeronautica militare, di cui 8.825 in servizio permanente e 4.600 in ferma prefissata.

2. Il totale generale degli organici delle Forze armate e' il seguente:

a) Esercito italiano: 93.100 unita';

b) Marina militare: 30.050 unita';

c) Aeronautica militare: 36.850 unita'.))

((110))

------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 799.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))((22a))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia". --------------- AGGIORNAMENTO (22a) Il D.P.C.M. 11 gennaio 2013 (in G.U. 3/4/2013, n. 78) ha disposto (con l'art. 2, comma 1) che "La ripartizione delle dotazioni organiche del personale militare dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, di cui all'art. 799 del decreto legislativo 15 marzo 2010, n. 66, e' rideterminata nelle seguenti unita': a) ufficiali: 1) 10.782 dell'Esercito italiano; 2) 4.150 della Marina militare; 3) 5.500 dell'Aeronautica militare; b) sottufficiali: 1) 21.554 dell'Esercito italiano, di cui 2.147 primi marescialli, 4.995 marescialli e 14.412 sergenti; 2) 12.695 della Marina militare, di cui 2.340 primi marescialli, 5.455 marescialli e 4.900 sergenti; 3) 23.515 dell'Aeronautica militare, di cui 3.000 primi marescialli, 6.480 marescialli e 14.035 sergenti; c) volontari: 1) 67.875 dell'Esercito italiano, di cui 50.357 in servizio permanente e 17.518 in ferma prefissata; 2) 13.576 della Marina militare, di cui 8.976 in servizio permanente e 4.600 in ferma prefissata; 3) 10.353 dell'Aeronautica militare, di cui 5.900 in servizio permanente e 4.453 in ferma prefissata. Ha inoltre disposto (con l'art. 2, comma 2) che "Il totale generale degli organici delle Forze armate e' il seguente: a) Esercito italiano: 100.211 unita'; b) Marina militare: 30.421 unita'; c) Aeronautica militare: 39.368 unita'.

#### Art. 800. - Consistenze organiche complessive dell'Arma dei carabinieri

1. La consistenza organica degli ufficiali in servizio permanente e' di 4.537 unita'.

2. La consistenza organica del ruolo ispettori e' di ((30.975 unita')).

3. La consistenza organica del ruolo sovrintendenti e' di 21.701 unita'.

4. La consistenza organica del ruolo appuntati e carabinieri e' di ((60.959 unita')).

5. La forza extraorganica dell'Arma dei carabinieri e' prevista nella sezione III del capo VI del presente titolo.

5-bis. Le dotazioni di cui al presente articolo possono essere rideterminate con decreto del Ministro della difesa di concerto con il Ministro per la semplificazione e la pubblica amministrazione e con il Ministro dell'economia e delle finanze, fermo restando il volume organico complessivo e senza nuovi o maggiori oneri a carico della finanza pubblica, al fine di adeguare la consistenza al piu' efficace soddisfacimento delle esigenze operative e di economicita' dell'azione amministrativa.

#### Art. 801. - (Ufficiali in soprannumero agli organici)

1. Il contingente massimo di ufficiali da collocare in soprannumero, fino a un massimo di ((271 unita')), e' stabilito annualmente con decreto dirigenziale del Capo di stato maggiore della difesa.

2. Nei limiti del contingente di cui al comma 1, con determinazione annuale del Capo di stato maggiore della difesa sono individuate le destinazioni presso le quali sono impiegati gli ufficiali da considerare in soprannumero agli organici.

3. Il collocamento in soprannumero degli ufficiali ha luogo il 1° luglio di ogni anno nel numero corrispondente agli ufficiali che, alla medesima data e con il grado posseduto, si trovano nelle destinazioni individuate ai sensi del comma 2.

4. Ai fini della determinazione di cui al comma 2, sono considerati in soprannumero:

- a) gli ufficiali che rivestono le cariche di Ministro o di Sottosegretario di Stato;
- b) gli ufficiali generali cui e' stata conferita la carica di consigliere militare del Presidente della Repubblica ovvero di consigliere del Presidente del Consiglio dei ministri;
- c) gli ufficiali impiegati presso altre amministrazioni dello Stato;
- d) gli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare distaccati presso le Forze di polizia a ordinamento militare;
- e) gli ufficiali dell'Esercito italiano impiegati presso le direzioni del genio militare per la Marina militare, di cui all'articolo 162 del regolamento;
- f) gli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare impiegati presso le sedi delle Rappresentanze diplomatiche italiane all'estero autorizzate dallo specifico decreto del Ministro della difesa di concerto con il Ministro degli affari esteri e della cooperazione internazionale e il Ministro dell'economia e delle finanze concernente lo schieramento degli addetti militari all'estero.

5. Gli ufficiali inferiori delle Forze armate e del Corpo della guardia di finanza in servizio permanente effettivo frequentatori di corsi di formazione, di durata non inferiore a un anno, presso le accademie militari o istituti universitari non sono computati nell'organico dei rispettivi ruoli.

6. Nel limite delle posizioni soprannumerarie di cui al comma 1, la determinazione prevista al comma 2 puo' indicare un contingente massimo di ((15 unita')) a favore di ufficiali dell'Arma dei carabinieri impiegati nelle posizioni di cui al comma 4, lettere a), b), ((b-bis),)) c), d) ed f).

#### Art. 802. - Modificazioni delle dotazioni organiche dei ruoli degli ufficiali

1. Ai sensi dell'articolo 17 della legge 23 agosto 1988, n. 400, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, fermi restando gli organici complessivi previsti per ciascuna Forza armata dal presente codice e i profili di carriera tra ruoli omologhi preposti a funzioni similari, possono essere apportate modifiche, senza oneri aggiuntivi, alle dotazioni organiche dei singoli ruoli degli ufficiali delle Forze armate, al fine di adeguarne le disponibilita' alle effettive esigenze operative e di funzionalita' del sostegno tecnico-logistico.

2. Relativamente al Corpo delle capitanerie di Porto, i decreti ministeriali sono adottati d'intesa con il Ministro delle infrastrutture e dei trasporti.

#### Art. 803. - Organici stabiliti con legge di bilancio

1. E' determinato annualmente con la legge di approvazione del bilancio di previsione dello Stato:

- a) il numero massimo delle singole categorie di ufficiali ausiliari da mantenere annualmente in servizio;
- b) la consistenza organica degli allievi ufficiali delle accademie delle Forze armate, compresa l'Arma dei carabinieri.
- b-bis) la consistenza organica degli allievi delle scuole sottufficiali delle Forze armate, esclusa l'Arma dei carabinieri;
- b-ter) la consistenza organica degli allievi delle scuole militari.
- b-quater) un eventuale contingente aggiuntivo di personale appartenente alla categoria dei militari di truppa in ferma prefissata, da reclutare in caso di specifiche esigenze funzionali delle Forze armate connesse alle emergenze operative derivanti da attivita' di concorso, soccorso e assistenza sul territorio nazionale e all'estero, specificamente nelle aree di crisi a garanzia della pace e della sicurezza, ovvero al controllo dei flussi migratori e al contrasto alla pirateria.

## CAPO II - RUOLI D'ONORE

### Art. 804. - Iscrizione nei ruoli d'onore

1. Sono iscritti d'ufficio nei ruoli d'onore istituiti per ciascuna Forza armata, previo collocamento in congedo assoluto, i militari che sono riconosciuti permanentemente non idonei al servizio militare:

- a) per mutilazioni o invalidita' riportate o aggravate per servizio di guerra, che hanno dato luogo a pensione vitalizia o ad assegno rinnovabile da ascriversi a una delle otto categorie previste dalla tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e successive modificazioni;
- b) per mutilazioni o invalidita' riportate in incidente di volo comandato, anche in tempo di pace, per cause di servizio e per le quali e' stato liquidato l'indennizzo privilegiato aeronautico di cui all'articolo 1898;
- c) per mutilazioni o invalidita' riportate in servizio e per causa di servizio, che hanno dato luogo a pensione privilegiata ordinaria delle prime otto categorie.

2. I militari iscritti nei ruoli d'onore possono essere richiamati in servizio, in tempo di pace e in tempo di guerra o di grave crisi internazionale, solo in casi particolari e col loro consenso, per essere impiegati in incarichi o servizi compatibili con le loro condizioni fisiche, escluso in ogni caso il comando di unita' o di reparto.

3. L'allievo ufficiale o l'aspirante che venga a trovarsi in una delle condizioni di cui alle lettere a), b) e c) del comma 1 e' nominato sottotenente di complemento, o ufficiale di grado corrispondente, nell'arma, corpo o servizio cui appartiene ed e' contemporaneamente collocato in congedo assoluto e iscritto nel ruolo d'onore. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 805. - Iscrizione di graduati e militari di truppa

1. I graduati e i militari di truppa, in godimento di pensione vitalizia o assegno rinnovabile di prima categoria con diritto agli assegni di superinvalidita' di cui alla lettera A e alla lettera A-bis, numeri 1 e 3, della tabella E), annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e successive modificazioni, che hanno conseguito la nomina di cui all'articolo 1318, possono, a domanda, essere iscritti, con il grado conferito, nei ruoli d'onore della Forza armata di appartenenza.

### Art. 806. - Personale militare iscritto nel ruolo d'onore decorato al valor militare o civile

1. Al personale militare iscritto nel ruolo d'onore, decorato al valor militare o al valor civile o con la croce d'onore di cui alla legge 10 ottobre 2005, n. 207, ovvero comunque iscritto in seguito a eventi traumatici verificatisi in servizio e per causa di servizio, anche in Patria, che ne hanno determinato l'invalidita' permanente pari o superiore all'80 per cento della capacita' lavorativa, e' attribuito il diritto, a domanda, di permanere o essere richiamato in servizio, fino ai limiti di eta' previsti per i gradi e i ruoli del servizio permanente.

2. Il trattenimento o il richiamo in servizio sono disposti con decreto del Ministero della difesa, di concerto con il Ministero dell'economia e delle finanze. ((46))

------------ AGGIORNAMENTO (46) Il D.Lgs. 29 maggio 2017, n. 95 ha disposto (con l'art. 36, comma 55) che "I militari appartenenti al ruolo d'onore della Guardia di finanza, trattenuti o richiamati in servizio ai sensi dell'articolo 806 del decreto legislativo 15 marzo 2010, n. 66, cessano dal trattenimento o dal richiamo entro trenta giorni dalla data di entrata in vigore del presente decreto. Le istanze di trattenimento o richiamo in servizio presentate ai sensi del predetto articolo 806, ancora in essere alla stessa data, sono archiviate".

### Art. 807. - Personale al quale e' riconosciuto il trattamento pensionistico di guerra

1. I sottufficiali, i graduati e i militari di truppa ai quali e' stato riconosciuto il trattamento pensionistico di guerra possono essere iscritti nel ruolo d'onore anche se il relativo decreto e' stato emanato dopo la cessazione dal servizio permanente per raggiunti limiti di eta', a condizione che la domanda di concessione sia antecedente alla predetta cessazione dal servizio permanente.

## CAPO III - ESERCITO ITALIANO

### Art. 808. - Militari dell'Esercito italiano

1. Appartengono all'Esercito italiano i militari inseriti nei ruoli previsti dagli articoli seguenti.

2. All'interno di ciascun ruolo i militari dell'Esercito italiano possono essere ripartiti in armi e specialita'.

### Art. 809. - Ruoli del personale in servizio permanente

1. I ruoli nei quali sono iscritti gli ufficiali del servizio permanente sono i seguenti:

- a) ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni;
- b) ruolo normale dell'Arma dei trasporti e dei materiali;
- c) ruolo normale del Corpo degli ingegneri;
- d) ruolo normale del Corpo sanitario;
- e) ruolo normale del Corpo di commissariato;
- f) ruolo speciale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni;
- g) ruolo speciale dell'Arma dei trasporti e dei materiali;
- h) ruolo speciale del Corpo sanitario;
- i) ruolo speciale del Corpo di commissariato.

2. I ruoli dei sottufficiali in servizio permanente sono i seguenti:

- a) ruolo dei marescialli;
- b) ruolo dei musicisti;
- c) ruolo dei sergenti.

3. I graduati in servizio permanente sono inseriti nel ruolo dei volontari in servizio permanente dell'Esercito italiano.

### Art. 809-bis. - (Dotazioni organiche dei generali e dei colonnelli).

1. Le dotazioni organiche complessive per i gradi di generale e colonnello sono le seguenti:

- a) generali di corpo d'armata e corrispondenti: ((18)); ((110))
- b) generali di divisione e corrispondenti: ((48)); ((110))
- c) generali di brigata e corrispondenti: ((117)); ((110))
- d) colonnelli: ((847)). ((110))

------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

### Art. 810.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## CAPO IV - MARINA MILITARE

### SEZIONE I - RUOLI E ORGANICI

#### Art. 811. - Militari della Marina militare

1. Appartengono alla Marina militare i militari inseriti nei ruoli previsti dagli articoli seguenti.

2. All'interno di ciascun ruolo della Marina militare:

- a) gli ufficiali possono essere ripartiti in specialita' ai fini dell'impiego e in relazione alle esigenze di servizio;
- b) i sottufficiali, i graduati e i militari di truppa del Corpo degli equipaggi militari marittimi (CEMM) sono distinti per ((categorie, specialita' o qualificazioni)) e le relative procedure per l'avanzamento al grado superiore si effettuano distintamente nell'ambito di ciascuna categoria e specialita'. (14)

3. Per il personale del Corpo delle capitanerie di porto la ripartizione in specialita' e' determinata d'intesa con il Ministero delle infrastrutture e dei trasporti.

------------- AGGIORNAMENTO (14) Il D.Lgs. 24 febbraio 2012, n. 20 ha disposto (con l'art. 10, comma 7) che "L'articolo 811, comma 2, lettera b), del decreto legislativo 15 marzo 2010, n. 66, come modificato dall'articolo 4, comma 1, lettera s), del presente decreto, si applica anche alle procedure di avanzamento al grado superiore relative all'anno 2011".

#### Art. 812. - Ruoli del personale in servizio permanente

1. I ruoli nei quali sono iscritti gli ufficiali del servizio permanente sono i seguenti:

- a) ruolo normale del Corpo di stato maggiore;
- b) ruolo normale del Corpo del genio della Marina, suddiviso nelle specialita' genio navale, armi navali e infrastrutture;(37)
- c) ((LETTERA SOPPRESSA DAL D.LGS. 26 APRILE 2016, N. 91));
- d) ruolo normale del Corpo sanitario militare marittimo;
- e) ruolo normale del Corpo di commissariato militare marittimo;
- f) ruolo normale del Corpo delle capitanerie di porto;
- g) ruolo speciale del Corpo di stato maggiore;
- h) ruolo speciale del Corpo del genio genio della Marina, suddiviso nelle specialita' genio navale, armi navali e infrastrutture;(37)
- i) ((LETTERA SOPPRESSA DAL D.LGS. 26 APRILE 2016, N. 91));
- l) ruolo speciale del Corpo sanitario militare marittimo;
- m) ruolo speciale del Corpo di commissariato militare marittimo;
- n) ruolo speciale del Corpo delle capitanerie di porto.

2. I ruoli dei sottufficiali in servizio permanente sono i seguenti:

- a) ruolo dei marescialli;
- b) ruolo dei marescialli del Corpo delle capitanerie di porto;
- c) ruolo dei musicisti;
- d) ruolo dei sergenti;
- e) ruolo dei sergenti del Corpo delle capitanerie di porto.

3. I graduati in servizio permanente sono inseriti nel ruolo dei volontari in servizio permanente della Marina militare e del Corpo delle capitanerie di porto.

--------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che le presenti modifiche si applicano a decorrere dal 1° gennaio 2017.

#### Art. 812-bis. - (Dotazioni organiche degli ammiragli e dei capitani di vascello)

1. Le dotazioni organiche complessive per i gradi di ammiraglio e capitano di vascello sono le seguenti:

- a) ammiragli di squadra e corrispondenti: 10; (110)
- b) ammiragli di divisione e corrispondenti: ((28)); (110)
- c) contrammiragli: (65); (110)
- d) capitani di vascello: (490). (101) (110)

2. Nelle dotazione organiche di cui al comma 1, sono comprese le dotazioni organiche per i gradi di ammiraglio e capitano di vascello del Corpo delle capitanerie di porto di cui all'articolo 814, comma 1-bis.

--------------- AGGIORNAMENTO (101) Il D.L. 22 aprile 2023, n. 44, ha disposto (con l'art. 17, comma 1, alinea) che la presente modifica decorre dal 1° gennaio 2024. ------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 813.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### SEZIONE II - ORGANICI DEL CORPO DELLE CAPITANERIE DI PORTO

#### Art. 814. - Organici degli ufficiali e dei sottufficiali

1. La dotazione organica complessiva degli ufficiali del Corpo e' di ((1070)) unita', di cui ((757)) del ruolo normale e 313 del ruolo speciale.(101)

1-bis. Nell'ambito della dotazione organica complessiva di cui al comma 1, la dotazione organica complessiva per i gradi di ammiraglio e capitano di vascello e' la seguente:

- a) ammiragli ispettori: ((6));
- b) contrammiragli: 17;
- c) capitani di vascello: 127.(101)

2. La dotazione organica complessiva dei marescialli del Corpo e' di 2.000 unita', di cui 600 primi marescialli.

3. La dotazione organica complessiva dei sergenti del Corpo e' di 2.100 unita' sino all'anno 2023, 2120 unita' per l'anno 2024, 2140 unita' per l'anno 2025, 2160 unita' per l'anno 2026, 2180 unita' per l'anno 2027 e 2200 unita' dall'anno 2028.(101)

--------------- AGGIORNAMENTO (101) Il D.L. 22 aprile 2023, n. 44, ha disposto (con l'art. 17, comma 1, alinea) che le presenti modifiche decorrono dal 1° gennaio 2024.

#### Art. 815. - Dotazioni organiche dei volontari del Corpo delle capitanerie di porto

1. Le dotazioni organiche dei volontari del Corpo delle capitanerie di porto, sono cosi' determinate:

- a) 3.500 sino all'anno 2020, 3.600 per l'anno 2021, 3.730 per l'anno 2022, 3.880 per l'anno 2023, 4.080 per l'anno 2024, 4.280 per l'anno 2025, 4.380 per l'anno 2026, 4.450 per l'anno 2027 e 4.500 dall'anno 2028 in servizio permanente; (101)
- b) ((1.775 fino all'anno 2024, 1.800 per l'anno 2025, 1.825 per l'anno 2026 e 1.850 dall'anno 2027, in ferma ovvero in rafferma)).

--------------- AGGIORNAMENTO (101) Il D.L. 22 aprile 2023, n. 44, convertito, con modificazioni, dalla L. 21 giugno 2023, n. 74 ha disposto (con l'art. 17, comma 1, alinea) che la presente modifica decorre dal 1° gennaio 2024.

## CAPO V - AERONAUTICA MILITARE

### Art. 816. - Militari dell'Aeronautica militare

1. Appartengono all'Aeronautica militare i militari inseriti nei ruoli previsti dagli articoli seguenti.

2. All'interno di ciascun ruolo i militari dell'Aeronautica militare possono essere ripartiti in ((categorie e)) specialita'.

### Art. 817. - Ruoli del personale in servizio permanente

1. I ruoli nei quali sono iscritti gli ufficiali del servizio permanente sono i seguenti:

- a) ruolo naviganti normale dell'Arma aeronautica;
- b) ruolo normale delle armi dell'Arma aeronautica;
- c) ruolo normale del Corpo del genio aeronautico;
- d) ruolo normale del Corpo di commissariato aeronautico;
- e) ruolo normale del Corpo sanitario aeronautico;
- f) ruolo naviganti speciale dell'Arma aeronautica;
- g) ruolo speciale delle armi dell'Arma aeronautica;
- h) ruolo speciale del Corpo del genio aeronautico;
- i) ruolo speciale del Corpo di commissariato aeronautico;
- l) ruolo speciale del Corpo sanitario aeronautico.

2. I ruoli dei sottufficiali in servizio permanente sono i seguenti:

- a) ruolo dei marescialli;
- b) ruolo dei musicisti;
- c) ruolo dei sergenti.

3. I graduati in servizio permanente sono inseriti nel ruolo dei volontari in servizio permanente dell'Aeronautica militare.

### Art. 818. - Disposizioni speciali per alcuni ruoli

1. Le speciali funzioni degli ufficiali dei ruoli delle armi dell'Aeronautica militare e le disposizioni particolari riguardanti la specialita' di navigatore militare degli ufficiali dei ruoli naviganti sono riportate nel regolamento.

### Art. 818-bis. - (Dotazioni organiche dei generali e dei colonnelli)

1. Le dotazioni organiche complessive per i gradi di generale e colonnello sono le seguenti:

- a) generali di squadra aerea e corrispondenti: ((10)); ((110))
- b) generali di divisione aerea e corrispondenti: ((22)); ((110))
- c) generali di brigata aerea e corrispondenti: ((54)); ((110))
- d) colonnelli: ((436)). ((110))

------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

### Art. 819.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## CAPO VI - ARMA DEI CARABINIERI

### SEZIONE I - RUOLI

#### Art. 820. - Militari dell'Arma dei carabinieri

1. Appartengono all'Arma dei carabinieri i militari inseriti nei ruoli previsti dagli articoli seguenti.

2. All'interno di ciascun ruolo i militari dell'Arma dei carabinieri possono essere ripartiti in specialita'.

#### Art. 821. - Ruoli del personale in servizio permanente

1. I ruoli nei quali sono iscritti gli ufficiali del servizio permanente sono i seguenti:

- a) ruolo normale;
- b) ruolo ((forestale));
- c) ruolo ((tecnico)).
- c-bis) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95)).

2. Il ruolo ((tecnico)) degli ufficiali in servizio permanente e' articolato nei seguenti comparti e specialita':

- a) comparto amministrativo: specialita' amministrazione ((e)) commissariato;
- b) comparto tecnico-scientifico ((...)): specialita' investigazioni scientifiche, specialita' telematica, specialita' genio ((...));
- c) comparto sanitario ((e psicologico)): specialita' sanita' (medicina/farmacia), specialita' veterinaria ((, specialita' psicologia)).

3. I ruoli dei sottufficiali in servizio permanente sono i seguenti:

- a) ruolo degli ispettori;
- b) ruolo dei musicisti;
- c) ruolo dei sovrintendenti.

4. I graduati in servizio permanente sono inseriti nel ruolo degli appuntati e carabinieri.

#### Art. 822.

Modifiche al ruolo ((tecnico))

1. Fermi restando l'organico complessivo e il numero delle promozioni annuali previsto dal presente codice per il ruolo ((tecnico)), possono essere disposte, senza oneri aggiuntivi, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, modifiche all'articolazione del predetto ruolo, mediante soppressione, accorpamento, o istituzione di nuovi comparti o di nuove specialita', al fine di adeguarla alle effettive esigenze di sostegno ((tecnico)).

### SEZIONE II - ORGANICI

#### Art. 823. - (( (Organici dei generali e dei colonnelli). ))

((1. Le dotazioni organiche complessive per i gradi di generale e colonnello sono le seguenti: a) generali di corpo d'armata: 11; b) generali di divisione: 29; c) generali di brigata: 96; d) colonnelli: 538))

#### Art. 824. - Organici del ruolo dei sovrintendenti

1. Le eventuali vacanze organiche nel ruolo dei sovrintendenti possono essere devolute in aumento all'organico del ruolo degli appuntati e carabinieri.

### SEZIONE III - FORZA EXTRAORGANICA

#### Art. 825. - Contingente per la Presidenza del Consiglio dei Ministri

1. Con decreto del Presidente del Consiglio dei Ministri adottato di concerto con i Ministri dell'interno e dell'economia e delle finanze, e' fissato il contingente del personale appartenente all'Arma dei carabinieri assegnato alla Presidenza del Consiglio dei Ministri per l'assolvimento dei compiti previsti dall'articolo 10, comma 11-bis, del decreto legislativo 30 luglio 1999, n. 303.

#### Art. 826. - Contingente per la tutela del lavoro

1. Per i servizi di vigilanza per l'applicazione delle leggi sul lavoro, sulla previdenza e sull'assistenza sociale, sono assegnati al Ministero del lavoro e delle politiche sociali i seguenti militari dell'Arma dei carabinieri, per un contingente complessivo di ((710 unita')) in soprannumero ai ruoli organici dei rispettivi gradi o ruoli: (82) ((114))

- a) generali di divisione o di brigata: 1;
- b) tenenti colonnelli/maggiori: (8);
- c) LETTERA ABROGATA DAL D.L. 21 OTTOBRE 2021, N. 146;
- d) ispettori: 271;
- e) sovrintendenti: 176;
- f) appuntati e carabinieri: 254;

2. Del contingente complessivo di cui al comma 1, 84 unita' sono distaccate per lo svolgimento dell'attivita' di vigilanza propria dell'Assessorato del lavoro, della previdenza sociale, della formazione professionale e dell'emigrazione della Regione siciliana per l'applicazione delle leggi sulla legislazione sociale, sulla previdenza e sull'assistenza.

------------- AGGIORNAMENTO (82) Il D.L. 21 ottobre 2021, n. 146, ha disposto (con l'art. 13, comma 3) che "Al fine di rafforzare l'attivita' di vigilanza sull'applicazione delle norme in materia di diritto del lavoro, legislazione sociale e sicurezza sui luoghi di lavoro, il contingente di personale dell'Arma dei carabinieri di cui all'articolo 826, comma 1, del codice dell'ordinamento militare di cui al decreto legislativo 15 marzo 2010, n. 66, e' incrementato di 90 unita' in soprannumero rispetto all'organico attuale a decorrere dal 1° gennaio 2022". ------------- AGGIORNAMENTO (114) Il D.L. 2 marzo 2024, n. 19, ha disposto (con l'art. 31, comma 5) che "A decorrere dal 1° settembre 2024, il contingente di personale dell'Arma dei carabinieri, di cui all'articolo 826, comma 1, del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, e' incrementato di 50 unita' in soprannumero rispetto all'organico attuale".

#### Art. 827. - Contingente per la tutela del patrimonio culturale

1. E' costituito un contingente di personale dell'Arma dei carabinieri, per un totale di ((168)) unita', da collocare in soprannumero rispetto all'organico per il potenziamento del Comando carabinieri per la tutela del patrimonio culturale. Il predetto contingente e' cosi' determinato:

- a) generali di divisione o di brigata: 1;
- b) colonnelli: 1;
- c) tenenti colonnelli: ((10));
- d) ufficiali inferiori: ((16));
- e) ispettori: ((44));
- f) sovrintendenti: ((33));
- g) appuntati e carabinieri: ((63)). ((124))

2. Le disponibilita' di bilancio destinate al potenziamento di personale e mezzi del Comando carabinieri per la tutela del patrimonio culturale sono allocate, con decreto del Ministro dell'economia e delle finanze, su appositi capitoli di bilancio del Ministero per i beni e le attivita' culturali.

--------------- AGGIORNAMENTO (124) La L. 4 aprile 2025, n. 42, ha disposto (con l'art. 6, comma 1, alinea) che "Al fine di rafforzare l'attivita' del Comando carabinieri per la tutela del patrimonio culturale in materia di prevenzione e repressione delle violazioni della legislazione di tutela dei beni culturali e paesaggistici, il contingente di personale dell'Arma dei carabinieri di cui all'articolo 827, comma 1, del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, e' incrementato di 40 unita' di personale in soprannumero rispetto all'organico".

#### Art. 828. - Contingente per la tutela dell'ambiente

1. E' costituito un contingente di personale dell'Arma dei carabinieri, per un totale trecentonovantanove unita', da collocare in soprannumero rispetto all'organico per il potenziamento del Comando carabinieri per la tutela ambientale ((e la sicurezza energetica)). Il predetto contingente e' cosi' determinato:

- a) generali di divisione o di brigata: 1;
- b) colonnelli: 1;
- c) tenenti colonnelli: 1;
- d) maggiori: 1;
- e) capitani: 3;
- f) ufficiali inferiori: 25;
- g) ispettori: 244;
- h) sovrintendenti: 39;
- i) appuntati e carabinieri: ottantaquattro.

2. Sono a carico del Ministero dell'ambiente e della tutela del territorio e del mare gli oneri connessi al trattamento economico, alla motorizzazione, all'accasermamento, al casermaggio e al vestiario.

#### Art. 828-bis. - (Contingente per la tutela agroalimentare)

1. E' costituito un contingente di personale dell'Arma dei carabinieri, per un totale di ((170 unita')), da collocare in soprannumero rispetto all'organico, per il potenziamento del Comando carabinieri per la tutela agroalimentare di cui all'articolo 174-bis, comma 2-bis. Il predetto contingente e' cosi' determinato:

- a) generali di brigata: 0;
- b) colonnelli: 0;
- c) tenenti colonnelli: 0;
- d) maggiori: 0;
- e) capitani: 0;
- f) ufficiali inferiori: 0;
- g) ((ispettori: 110));
- h) sovrintendenti: 0;
- i) ((appuntati e carabinieri: 60)).

((1-bis. Sono a carico del Ministero dell'agricoltura, della sovranita' alimentare e delle foreste gli oneri connessi al trattamento economico, alla motorizzazione, all'accasermamento, al casermaggio e al vestiario))

#### Art. 829. - Contingente per la tutela della salute

1. E' costituito un contingente di personale dell'Arma dei carabinieri, per un totale di ((124 unita')), da collocare in soprannumero rispetto all'organico, per il potenziamento del Comando carabinieri per la tutela della salute. Il predetto contingente e' cosi' determinato:

- a) generale di divisione o brigata: 1;
- b) ufficiali inferiori: 17.
- b-ter) appuntati e carabinieri: 3

2. Gli oneri connessi al trattamento economico fisso e accessorio, compreso lo straordinario, del personale di cui al comma 1 sono a carico del Ministero della salute, che provvedera' al versamento dei relativi oneri sociali.

#### Art. 830. - Contingente per la Banca d'Italia

1. E' costituito un contingente di personale dell'Arma dei carabinieri, per un numero massimo di 1.000 unita', per l'esecuzione di speciali servizi di vigilanza e scorta di valori della Banca d'Italia. Il predetto contingente e' cosi' determinato:

- a) generali di ((divisione o)) brigata: 1;
- a-bis) colonnelli: 1;
- b) tenenti colonnelli e maggiori: 5;
- c) ufficiali inferiori: 2;
- d) ispettori: 132;
- e) sovrintendenti: 40;
- f) appuntati e carabinieri: 819.

2. Il predetto contingente e' posto in soprannumero all'organico dell'Arma dei carabinieri stabilito dalla sezione precedente. L'impiego del contingente e' disciplinato mediante apposito accordo tecnico stipulato tra il Comando generale dell'Arma dei carabinieri e la Banca d'Italia.

3. Gli assegni, le competenze accessorie e le indennita' comunque spettanti al personale effettivamente impiegato nei limiti massimi fissati dal comma 1, nonche' ogni altro elemento di onere connesso al servizio di vigilanza e scorta valori, sono a carico della Banca d'Italia.

## CAPO VII - TRANSITO TRA RUOLI DEGLI UFFICIALI IN SERVIZIO PERMANENTE

### SEZIONE I - UFFICIALI DELL'ESERCITO ITALIANO, DELLA MARINA MILITARE E DELL'AERONAUTICA MILITARE

#### Art. 831. - Concorsi per i ruoli normali e i ruoli speciali

1. L'Amministrazione della difesa ha facolta' di bandire concorsi per titoli ed esami per il transito dei tenenti e dei capitani dei ruoli speciali nei corrispondenti ruoli normali, se dopo le immissioni in ruolo e le promozioni annuali al grado superiore esistono vacanze nell'organico degli ufficiali inferiori del ruolo normale.

2. Ai concorsi di cui al comma 1 possono partecipare i tenenti e i capitani che alla data di scadenza del bando hanno:

- a) un'eta' non superiore a 41 anni;
- b) conseguito la laurea magistrale;
- c) riportato negli ultimi tre anni una qualifica non inferiore a <<eccellente>>.

3. I tenenti e i capitani trasferiti per concorso nei ruoli normali conservano l'anzianita' posseduta e sono iscritti in ruolo dopo l'ultimo pari grado avente la medesima anzianita' di grado.

4. I capitani ((e i maggiori)) dei ruoli speciali dell'Esercito italiano che non hanno partecipato o superato i concorsi di cui al comma 1 possono essere ammessi, previo concorso per titoli ((, nel numero di posti stabilito dal relativo bando di concorso)), al corso di stato maggiore. Gli ufficiali transitati nei ruoli speciali, perche' non hanno superato il corso di applicazione o perche' non hanno conseguito il diploma di laurea entro l'anno di inserimento nell'aliquota di valutazione al grado di maggiore, non sono ammessi al corso di stato maggiore, ancorche' in possesso del diploma di laurea.

5. ((Al concorso di cui al comma 4 possono partecipare i capitani e i maggiori che alla data di scadenza del bando hanno: a) un'eta' non superiore a 50 anni;))

- b) conseguito il diploma di laurea specialistica;
- c) ((LETTERA SOPPRESSA DAL D.LGS. 27 DICEMBRE 2019, N. 173));
- d) riportato negli ultimi ((cinque)) anni una qualifica non inferiore a <<eccellente>>.

6. I capitani ((e i maggiori)) di cui al comma 4 che superano il corso di stato maggiore sono iscritti nel ruolo normale corrispondente a quello di provenienza con l'anzianita' di grado posseduta dopo l'ultimo pari grado avente la medesima anzianita' di grado. Coloro che non superano il corso permangono nel ruolo speciale.

6-bis. In presenza di vacanze organiche nei relativi gradi dei ruoli normali ovvero speciali del Corpo sanitario, su richiesta della Forza armata interessata e' consentito, mediante concorso per titoli ed esami, il transito nel rispettivo ruolo normale ovvero speciale del Corpo sanitario degli ufficiali di grado non superiore a tenente colonnello appartenenti ad altri ruoli della stessa Forza armata, in possesso, per il transito nel ruolo normale, di una delle lauree e della relativa abilitazione all'esercizio della professione previste per il citato ruolo ovvero, per il transito nel ruolo speciale, della laurea in psicologia o odontoiatria e protesi dentaria e delle relative abilitazioni all'esercizio della professione. PERIODO SOPPRESSO DAL D.LGS. 28 GENNAIO 2014, N. 8. ((6-bis.1. In presenza di vacanze organiche nei relativi gradi del ruolo normale del corpo degli ingegneri dell'Esercito italiano, su richiesta della Forza armata, e' consentito il transito in tale ruolo, mediante concorso per titoli ed esami, degli ufficiali di grado non superiore a tenente colonnello appartenenti ad altri ruoli dell'Esercito italiano, in possesso della laurea magistrale o specialistica in ingegneria o architettura.))

6-ter. Nei concorsi di cui ((ai commi 6-bis e 6-bis.1)), nel trasferimento da ruolo a ruolo si conserva l'anzianita' di grado posseduta prima del trasferimento. L'ordine di precedenza e' determinato:

- a) a parita' di anzianita' di grado, dall'eta';
- b) a parita' di eta', si raffrontano le anzianita' nei gradi inferiori, fino a quello in cui non si riscontra parita';
- c) a parita' anche delle anzianita' nei gradi inferiori, e' considerato piu' anziano chi ha maggiore servizio effettivo.

6-quater. I militari che transitano in un ruolo nel quale erano stati gia' inquadrati in passato non possono assumere un'anzianita' che comporti un ordine di precedenza nel nuovo ruolo piu' favorevole rispetto a quello che avrebbero maturato se fossero rimasti continuativamente in detto ruolo; il rispetto di tale ordine di precedenza e' assicurato anche attraverso una corrispondente detrazione dell'anzianita' di grado.

#### Art. 832. - Transito per perdita di requisiti specifici

1. Gli ufficiali del ruolo normale o speciale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni, del ruolo normale o speciale dell'((Arma dei trasporti e dei materiali)) dell'Esercito italiano e del ruolo normale o speciale del Corpo di stato maggiore della Marina militare, fino al grado di capitano o corrispondente, che hanno perso gli specifici requisiti richiesti per tali ruoli, sono trasferiti ad altro ruolo, o all'interno del ruolo di appartenenza ad altra arma, compatibilmente con la professionalita' e le idoneita' accertate, con il grado e le anzianita' possedute.

2. Il personale di cui al comma 1 e' iscritto nei nuovi ruoli o nella nuova arma dopo l'ultimo dei pari grado avente la medesima anzianita' di grado. I requisiti fisici minimi per gli ufficiali del ruolo normale e speciale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni, nonche' per gli ufficiali del ruolo normale e speciale dell'((Arma dei trasporti e dei materiali)) sono stabiliti dagli ordinamenti di Forza armata. Con distinti decreti del Ministro della difesa sono indicati i limiti e le modalita' dei trasferimenti degli ufficiali di cui al comma 1. Per la Marina militare il decreto e' adottato d'intesa con il Ministero delle infrastrutture e dei trasporti.

3. Gli ufficiali dei ruoli naviganti normale o speciale dell'Aeronautica militare fino al grado di colonnello, divenuti permanentemente non idonei al volo, se conservano l'idoneita' al servizio militare incondizionato, sono trasferiti rispettivamente nei ruoli normale o speciale delle armi dell'Aeronautica militare con il grado e l'anzianita' posseduti e mantenendo gli obblighi di ferma contratti. Essi sono iscritti nei nuovi ruoli dopo l'ultimo dei pari grado avente la medesima anzianita' di grado.

#### Art. 833. - Transito dal ruolo normale al ruolo speciale dei capitani, maggiori e tenenti colonnelli delle varie Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni, nonche' degli ufficiali fino al grado di tenente colonnello dell'Arma dei trasporti e dei materiali e del Corpo di commissariato

1. Gli ufficiali del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni dell'Esercito italiano possono transitare, a domanda, nel ruolo speciale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni, limitatamente ai gradi di capitano, maggiore e tenente colonnello, nel numero e con le modalita' stabilite con decreto ministeriale.

1-bis. Gli ufficiali fino al grado di tenente colonnello appartenenti ai ruoli normali dell'Arma dei trasporti e dei materiali e del Corpo di commissariato dell'Esercito possono transitare, a domanda, nei rispettivi ruoli speciali dell'Arma dei trasporti e dei materiali e del Corpo di commissariato, nel numero e con le modalita' stabilite con decreto ministeriale. Si applicano i commi 2, 3, 4, 5 e 6.

((

1-ter. Gli ufficiali, limitatamente ai gradi di capitano di corvetta e capitano di fregata, appartenenti al ruolo normale del Corpo di stato maggiore della Marina militare possono transitare, a domanda, nel corrispondente ruolo speciale nel numero e con le modalita' stabiliti con decreto ministeriale. Gli ufficiali che hanno ottenuto il trasferimento nel ruolo speciale non possono chiedere di ritransitare nel ruolo normale. Si applicano i commi 2, 3, 4 e 6.

))

2. Gli ufficiali trasferiti conservano la posizione di stato e l'anzianita' di grado posseduta e assumono, se piu' favorevole, un'anzianita' di un giorno precedente a quella del pari grado del ruolo speciale o a esaurimento che ha uguale o minore anzianita' di nomina a ufficiale.

3. L'ordine di iscrizione in ruolo dei predetti ufficiali e' stabilito in base all'articolo 797, commi 2 e 3.

4. Non e' ammesso il transito nel ruolo speciale degli ufficiali che hanno conseguito il titolo di Istituto superiore di stato maggiore interforze, di cui all'articolo 751.

5. Gli ufficiali che hanno ottenuto il trasferimento nel ruolo speciale non possono chiedere di ritransitare nel ruolo normale ne' di partecipare al Corso di stato maggiore.

6. Se il numero di domande supera gli organici dei singoli gradi si procede alla formazione di graduatorie distinte per gradi, sulla base dei requisiti previsti dall'articolo 1058. A parita' di merito la precedenza spetta all'ufficiale con maggiore anzianita' di grado e, a parita' di grado, al piu' anziano in ruolo.

#### Art. 833-bis. - Trasferimento ovvero transito nel ruolo normale del Corpo del genio navale della Marina militare

1. A decorrere dal 1º gennaio 2013, gli ufficiali del ruolo normale del Corpo delle armi navali della Marina militare laureati in ingegneria edile, civile, civile idraulica, dell'ambiente e del territorio o in architettura, reclutati ai sensi dell'articolo 652, comma 1, e operanti nel settore delle infrastrutture sono trasferiti nel ruolo normale del Corpo del genio navale della Marina militare.

2. Gli ufficiali di grado non superiore a capitano di fregata dei ruoli normali della Marina militare laureati in ingegneria o in architettura, che operano o hanno operato per almeno tre anni nel settore infrastrutture nell'ambito ((della Direzione generale dei lavori, dell'Ufficio centrale competente)) e delle direzioni del genio militare per la Marina ed enti subordinati, possono transitare, a domanda, nel ruolo normale del Corpo del genio navale della Marina militare.

3. Gli ufficiali trasferiti o transitati ai sensi dei commi 1 e 2 mantengono il grado, la posizione di stato, l'anzianita' di grado e sono iscritti in ruolo secondo le modalita' di cui all'articolo 797, commi 2 e 3.

#### Art. 833-ter. - (( (Transito dal ruolo normale al ruolo speciale degli ufficiali con grado fino a tenente colonnello delle Armi dell'Aeronautica militare). ))

((

1. In relazione a particolari esigenze funzionali, gli ufficiali fino al grado di tenente colonnello possono transitare, a domanda, dal ruolo normale al ruolo speciale delle Armi dell'Aeronautica militare, nel numero e con le modalita' stabilite con decreto ministeriale. Gli ufficiali transitati ai sensi del presente articolo mantengono il grado, la posizione di stato, l'anzianita' di grado e sono iscritti in ruolo secondo le modalita' di cui all'articolo 797, commi 2 e 3.

))

#### Art. 833-quater. - (( (Trasferimento ovvero transito nel ruolo normale o speciale del Corpo del genio della Marina, specialita' infrastrutture). ))

((

1. A decorrere dal 1º gennaio 2017, gli ufficiali fino al grado di capitano di vascello dei ruoli normali e speciali degli altri corpi della Marina militare, laureati in ingegneria edile, civile, civile idraulica, dell'ambiente e del territorio o in architettura, che hanno operato nel settore infrastrutture possono transitare a domanda nel corrispondente ruolo del Corpo del genio della Marina, specialita' infrastrutture.

2. Gli ufficiali transitati ai sensi del comma 1 mantengono il grado, la posizione di stato, l'anzianita' di grado e sono iscritti in ruolo nel Corpo del genio della Marina, specialita' infrastrutture, secondo le modalita' di cui all'articolo 797, commi 2 e 3.))

((37))

---------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica si applica a decorrere dal 1° gennaio 2017.

#### Art. 834. - Disposizioni comuni

1. Salvo diversa disposizione e fermo restando quanto previsto dall'articolo 660, comma 1, se nei ruoli di transito non vi sono posti disponibili, l'ufficiale e' trasferito in soprannumero e l'eccedenza e' riassorbita al verificarsi della prima vacanza. Gli ufficiali trasferiti non possono conseguire nei nuovi ruoli promozioni con decorrenza anteriore alla data del trasferimento.

2. Nei casi di transito tra ruoli sono considerati validi ai fini dell'avanzamento i periodi di comando, di attribuzioni specifiche e di servizio prestati nel ruolo di provenienza.

### SEZIONE II - UFFICIALI DELL'ARMA DEI CARABINIERI

#### Art. 835.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

#### Art. 836.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

## CAPO VIII - COMPITI DEL PERSONALE MILITARE

### SEZIONE I - PERSONALE DELL'ESERCITO ITALIANO, DELLA MARINA MILITARE E DELL'AERONAUTICA MILITARE

#### Art. 837.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94))

#### Art. 838. - Ufficiali

((...))

1. ((Fermo restando quanto stabilito dall'articolo 627, commi 2 e 3, nonche' le attribuzioni e le competenze stabilite dall'ordinamento militare, gli ufficiali delle Forze armate,)) in relazione alle specifiche qualificazioni cui sono correlate autonoma responsabilita' decisionale e rilevante professionalita':

- a) esercitano compiti di comando, di direzione, di indirizzo, di coordinamento e di controllo delle unita' poste alle loro dipendenze;
- b) provvedono alla gestione e all'impiego delle risorse loro assegnate secondo criteri di efficacia, efficienza ed economicita' al fine di assicurarne la funzionalita' per il conseguimento degli obiettivi prefissati;
- c) assumono piena responsabilita' per le direttive impartite e per i risultati conseguiti e, nell'ambito degli stati maggiori, dei comandi, degli uffici o delle articolazioni ordinative, hanno anche la responsabilita' di settori funzionali, svolgono compiti di studio e partecipano all'attivita' dei superiori, che sostituiscono in caso di assenza o di impedimento;
- d) adottano i provvedimenti loro delegati e le iniziative connesse con l'espletamento del servizio nell'ambito dei comandi o dei settori cui sono preposti;
- e) formulano proposte ed esprimono pareri al rispettivo superiore gerarchico.

#### Art. 839. - Appartenenti al ruolo dei marescialli

1. Al personale appartenente al ruolo dei marescialli sono attribuite funzioni che richiedono una adeguata preparazione professionale. In tale ambito essi:

- a) sono di norma preposti a unita' operative, tecniche, logistiche, addestrative e a uffici;
- b) svolgono, in relazione alla professionalita' posseduta, interventi di natura tecnico-operativa nonche' compiti di formazione e di indirizzo del personale subordinato;
- c) espletano incarichi la cui esecuzione richiede continuita' d'impiego per elevata specializzazione e capacita' di utilizzazione di mezzi e strumentazioni tecnologicamente avanzate.

((

2. Al personale che riveste il grado di primo maresciallo e di luogotenente, sulla base della formazione accademica e professionale acquisita, sono attribuite funzioni che implicano un maggior livello di responsabilita', in relazione alle esigenze tecnico-operative stabilite in sede di definizione delle strutture organiche degli enti e delle unita'. In tale contesto i luogotenenti, ed in particolare coloro che rivestono la qualifica di primo luogotenente:

- a) sono i diretti collaboratori di superiori gerarchici, che possono sostituire in caso di impedimento o di assenza;
- b) assolvono, in via prioritaria, funzioni di indirizzo o di coordinamento con piena responsabilita' per l'attivita' svolta;
- c) possono assolvere in autonomia incarichi di comando commisurati al grado e al loro livello di responsabilita';
- d) possono svolgere attivita' di studio ricerca e sviluppo tecnico nei settori di specifico interesse e funzioni in materia giuridica, economica e finanziaria;
- e) possono essere nominati membri di commissioni di Forza armata relative all'avanzamento, al reclutamento di personale militare, nonche' alla gestione amministrativa dell'ente di appartenenza;
- f) possono assolvere funzioni di rappresentanza istituzionale in consessi interni ed esterni alla Difesa, nei settori tecnici, amministrativi e operativi;
- g) possono svolgere attivita' di insegnamento teorico-pratico presso istituti, scuole, enti di formazione e addestramento, secondo le disposizioni vigenti.

))

3. Il personale appartenente al ruolo dei marescialli della categoria <<nocchieri di porto>> del Corpo delle capitanerie di porto della Marina militare, svolge, oltre agli specifici incarichi caratteristici del proprio ruolo, anche funzioni di ufficiale di polizia giudiziaria, ai sensi del codice della navigazione e delle altre leggi che lo prevedono.

4. Ai primi ((...)) luogotenenti sono attribuiti, nell'ambito delle funzioni di cui ai commi 1, 2 e 3, gli incarichi di piu' rilevante responsabilita' individuati dall'ordinamento di ciascuna Forza armata.

#### Art. 840. - Appartenenti al ruolo dei sergenti

1. Al personale appartenente al ruolo dei sergenti sono attribuite, con responsabilita' personali, mansioni esecutive, anche qualificate e complesse, richiedenti adeguata preparazione professionale, che si traducono nello svolgimento di compiti operativi, addestrativi, logistico-amministrativi, tecnico-manuali, nonche' il comando di piu' militari e mezzi.

2. Il personale appartenente al ruolo dei sergenti della categoria <<nocchieri di porto>> del Corpo delle capitanerie di porto della Marina militare, svolge, oltre agli specifici incarichi caratteristici del proprio ruolo, anche funzioni di ufficiale di polizia giudiziaria, ai sensi del codice della navigazione e delle altre leggi che lo prevedono.

2-bis. ((I sergenti maggiori aiutanti, e corrispondenti)), compatibilmente con gli ordinamenti e le disposizioni di impiego di ciascuna Forza armata, la professionalita' posseduta e le competenze acquisite:

- a) ricoprono incarichi di maggiore e preminente responsabilita' e piu' intenso impegno operativo fra quelli di cui ai commi 1 e 2;
- b) sono i diretti collaboratori di superiori gerarchici, che possono sostituire in caso di impedimento o di assenza;
- c) assolvono, in via prioritaria, funzioni di indirizzo o di coordinamento con piena responsabilita' per l'attivita' svolta;
- d) possono assolvere in autonomia incarichi di comando commisurati ((alla qualifica)) e al loro livello di responsabilita';
- e) possono svolgere attivita' di insegnamento teorico-pratico presso istituti, scuole, enti di formazione e addestramento, secondo le disposizioni vigenti.

#### Art. 841. - Appartenenti al ruolo dei volontari in servizio permanente

1. Al personale appartenente al ruolo dei volontari in servizio permanente sono, di norma, attribuite mansioni esecutive sulla base del grado ((e della qualifica posseduti)), della categoria, della specializzazione di appartenenza, dell'incarico, nonche' incarichi di comando nei confronti di uno o piu' militari.

2. I volontari in servizio permanente sono prioritariamente impiegati nelle unita' operative o addestrative dell'Esercito italiano, della Marina militare e dell'Aeronautica militare.

2-bis. ((I graduati aiutanti, e corrispondenti)), compatibilmente con gli ordinamenti e le disposizioni di impiego di ciascuna Forza armata, la professionalita' posseduta e le competenze acquisite:

- a) ricoprono incarichi di maggiore responsabilita', fra quelli di cui al comma 1, individuati dall'ordinamento di ciascuna Forza armata;
- b) sono i diretti collaboratori di superiori gerarchici, che possono sostituire in caso di impedimento o di assenza;
- c) assolvono, in via prioritaria, funzioni di indirizzo o di coordinamento con piena responsabilita' per l'attivita' svolta.

3. Il personale appartenente al ruolo dei volontari in servizio permanente del Corpo delle capitanerie di porto svolge, oltre alle specifiche mansioni caratteristiche del proprio ruolo, anche funzioni di agente di polizia giudiziaria, ai sensi del codice della navigazione e delle altre leggi che lo prevedono.

#### Art. 842. - Appartenenti al ruolo dei volontari in ferma o in rafferma

1. I volontari in ferma prefissata sono impiegati in attivita' operative e addestrative nell'ambito delle unita' dell'Esercito italiano, della Marina militare, compreso il Corpo delle capitanerie di porto, e dell'Aeronautica militare, nonche' negli enti interforze, sia sul territorio nazionale sia all'estero, in ragione dell'anzianita' di servizio e della professionalita' acquisita.

2. Non e' precluso l'impiego dei volontari in ferma prefissata presso stabilimenti militari di pena con sede nel luogo di nascita o di residenza precedente all'arruolamento.

3. I volontari in ferma prefissata ((triennale)) sono prioritariamente impiegati in attivita' operative che possono comportare responsabilita' di comando di piccoli nuclei di personale.

3-bis. I volontari in ferma prefissata sono impiegati secondo le esigenze operative, addestrative e di servizio dei reparti, prevedendo turni di riposo per l'attivita' effettuata oltre il normale orario di servizio, disciplinati da apposita normativa di Forza armata.

3-ter. I volontari in ferma prefissata ((triennale)) sono impiegati per periodi di tempo complessivamente pari a quelli dei volontari in servizio permanente, salve le esigenze operative, addestrative e di servizio dei reparti.

#### Art. 843. - Particolari compiti del personale sottufficiali, graduati e militari di truppa

1. Relativamente ai sottufficiali, ai graduati e ai militari di truppa, ai fini dell'impiego e in relazione alle esigenze di servizio, le categorie, le specialita' ((o qualificazioni)), le qualifiche, le specializzazioni, le abilitazioni e gli incarichi, compresi quelli principali, sono individuati e disciplinati con determinazione del Capo di stato maggiore della rispettiva Forza armata.

### SEZIONE II - PERSONALE DELL'ARMA DEI CARABINIERI

#### Art. 844. - Generali di corpo d'armata

1. Gli ufficiali con grado di generale di corpo d'armata:

- a) esercitano le competenze loro attribuite dalla normativa vigente, nonche' quelle demandate dal Comandante generale. In tale ambito adottano gli atti e i provvedimenti amministrativi di pertinenza e sono responsabili dell'attivita' amministrativa della gestione e dei relativi risultati anche in relazione ai poteri di spesa delegati dal Comandante generale nel quadro delle programmazioni a bilancio;
- b) svolgono funzioni di comando, di alta direzione, di coordinamento e di controllo dei reparti alle loro dipendenze con particolare riguardo a quelli retti da ufficiali con il grado di generale e colonnello, verificando che le attivita' istituzionali siano costantemente orientate a efficacia, efficienza ed economicita';
- c) vigilano mediante attivita' ispettiva sull'attuazione delle direttive generali impartite dal Comandante generale. Nel quadro di dette direttive stabiliscono i criteri e gli indirizzi per l'esercizio delle funzioni nell'ambito degli uffici posti alle loro dipendenze e attribuiscono ai comandanti dipendenti con il grado fino a colonnello la responsabilita' di specifici progetti e gestioni.

2. Nel settore della disciplina di stato i generali di corpo d'armata:

- a) possono disporre l'inchiesta formale nei confronti del personale dipendente appartenente ai ruoli ispettori e sovrintendenti;
- b) designano i componenti della commissione di disciplina per il personale dei ruoli ispettori e sovrintendenti nei cui confronti hanno disposto l'inchiesta di cui alla lettera a).

#### Art. 845. - Generali di divisione, di brigata e colonnelli

1. Gli Ufficiali con i gradi di generale di divisione, generale di brigata e colonnello, esercitano le competenze loro attribuite dalla normativa vigente, nonche' quelle stabilite dal Comandante generale.

2. Gli stessi, in particolare:

- a) svolgono funzioni di comando, di direzione, di coordinamento e di controllo dei reparti alle loro dipendenze, con particolare riguardo a quelli retti da ufficiali;
- b) adottano gli atti e i provvedimenti amministrativi di pertinenza e sono responsabili dell'attivita' amministrativa, della gestione e dei relativi risultati, anche in relazione ai poteri di spesa delegati dal Comandante generale nel quadro delle programmazioni a bilancio;
- c) nell'esercizio delle loro funzioni applicano i criteri e gli indirizzi stabiliti dai superiori gerarchici con il grado di generale di corpo d'armata e sono responsabili dei progetti e delle gestioni loro attribuite.

#### Art. 846. - Ufficiali sino al grado di tenente colonnello

1. I tenenti colonnelli, i maggiori e gli ufficiali inferiori hanno le attribuzioni e gli incarichi determinati dal Comandante generale, secondo le norme vigenti.

2. Nel quadro delle competenze stabilite per il proprio livello gerarchico e la propria posizione d'impiego e in relazione alle specifiche qualificazioni cui si correlano autonoma responsabilita' decisionale e rilevante professionalita':

- a) esercitano compiti di comando, di direzione, di indirizzo, di coordinamento e di controllo delle unita' ordinamentali poste alle loro dipendenze;
- b) provvedono alla gestione e all'impiego delle risorse loro assegnate secondo criteri di efficacia, efficienza ed economicita', al fine di assicurare la funzionalita' del servizio per il conseguimento degli obiettivi istituzionali;
- c) assumono piena responsabilita' per le direttive impartite e per i risultati conseguiti e, nell'ambito del Comando generale, dei comandi, degli uffici o delle articolazioni ordinative rette da generale o colonnello, hanno anche la responsabilita' di settori funzionali, svolgono compiti di studio, e partecipano all'attivita' dei citati superiori, che sostituiscono in caso di assenza o impedimento;
- d) adottano i provvedimenti loro delegati e le iniziative connesse con l'espletamento dei servizi d'istituto nell'ambito dei comandi o dei settori cui sono preposti;
- e) formulano proposte ed esprimono pareri al rispettivo superiore gerarchico.

#### Art. 847. - Ufficiali del ruolo tecnico

((...))

1. Nell'esercizio delle funzioni proprie della specialita' di appartenenza, gli ufficiali del ruolo tecnico((...)) hanno le medesime attribuzioni, facolta' e competenze riconosciute agli ufficiali dei ruoli normali delle Forze armate costituiti per l'assolvimento di analoghe mansioni.

#### Art. 848. - Appartenenti al ruolo degli ispettori

1. Nell'espletamento delle proprie attribuzioni gli ispettori, oltre ai compiti di carattere militare previsti dalle disposizioni in vigore, svolgono funzioni di sicurezza pubblica e di polizia giudiziaria. Possono sostituire i diretti superiori gerarchici in caso di assenza o di impedimento ed essere preposti al comando di stazione carabinieri, unita' operative o addestrative, con le connesse responsabilita' per le direttive e istruzioni impartite e per i risultati conseguiti, nonche' assumere la direzione di uffici o funzioni di coordinamento di piu' unita' operative, nell'ambito delle direttive superiori, con piena responsabilita' per l'attivita' svolta. La carriera del ruolo ispettori ha sviluppo direttivo.

2. Al suddetto personale possono essere attribuiti incarichi, anche investigativi e addestrativi e di insegnamento, richiedenti particolari conoscenze e attitudini.

3. I luogotenenti e i marescialli maggiori sono diretti collaboratori degli ufficiali dell'Arma dei carabinieri e svolgono, in relazione alla preparazione accademica e professionale acquisita, funzioni di indirizzo e di coordinamento con piena responsabilita' sul personale dipendente, anche appartenente al ruolo degli ispettori.

((

3-bis. Il Comando di stazione nell'ambito delle varie organizzazioni funzionali e' prerogativa del personale del ruolo ispettori.

))

4. In relazione al qualificato profilo professionale raggiunto, ai luogotenenti carica speciale possono essere affidati, anche permanendo nello stesso incarico, compiti di maggiore responsabilita' fra quelli di cui ai commi precedenti, secondo la graduazione e i criteri fissati con determinazione del Comandante generale dell'Arma dei carabinieri.

#### Art. 849. - Appartenenti al ruolo dei sovrintendenti

1. Il personale appartenente al ruolo sovrintendenti, oltre ai compiti di carattere militare previsti dalle disposizioni in vigore, svolge mansioni esecutive, ((anche qualificate e complesse,)) richiedenti un'adeguata preparazione professionale e con il margine di iniziativa e di discrezionalita' inerente alle qualifiche di agente di pubblica sicurezza e di ufficiale di polizia giudiziaria.

2. Al suddetto personale possono essere affidati il comando di uno o piu' militari cui impartisce ordini dei quali controlla l'esecuzione e di cui risponde, compiti di carattere operativo, addestrativo e logistico-amministrativo, nonche' attribuito il comando di piccole unita'.

3. Ai brigadieri capo, oltre a quanto gia' specificato, possono essere attribuiti incarichi specialistici, richiedenti particolari conoscenze e attitudini, nonche' incarichi operativi di piu' elevato impegno.

3-bis. In relazione al qualificato profilo professionale raggiunto, ai brigadieri capo qualifica speciale possono essere affidati, anche permanendo nello stesso incarico, compiti di maggiore responsabilita' fra quelli di cui al comma precedente.

#### Art. 850. - Appartenenti al ruolo degli appuntati e carabinieri

1. Il personale appartenente al ruolo appuntati e carabinieri, oltre ai compiti di carattere militare previsti dalle disposizioni in vigore, svolge mansioni esecutive con il margine di iniziativa e di discrezionalita' inerente alle qualifiche possedute e puo' altresi' esercitare incarichi di comando di uno o piu' militari, nonche' di addestramento in relazione a una eventuale specifica preparazione professionale posseduta.

((

1-bis. In relazione al qualificato profilo professionale raggiunto, agli appuntati scelti qualifica speciale possono essere affidati, anche permanendo nello stesso incarico, i compiti di maggiore responsabilita' fra quelli di cui al comma precedente.

))

## TITOLO V STATO GIURIDICO E IMPIEGO CAPO I IL GRADO

### SEZIONE I - ATTRIBUZIONE E REVOCA DEL GRADO

#### Art. 851. - Grado dei militari

1. Il grado e' indipendente dall'impiego.

2. Il grado si acquista e si perde in base alle disposizioni contenute nel presente codice.

3. Non sono concessi gradi onorari per gli ufficiali.

#### Art. 852. - Conferimento del grado

1. Il grado e' conferito con atto di nomina o con atto di promozione.

((

2. Il grado iniziale e' conferito:

- a) per gli appartenenti ai ruoli degli ufficiali con decreto del Ministro della difesa, per gli appartenenti ai ruoli dei sottufficiali e dei volontari in servizio permanente, con determinazione dirigenziale;
- b) per gli appartenenti al ruolo degli appuntati e carabinieri, con determinazione del Comandante generale;
- c) per i militari di truppa, con determinazione del rispettivo comandante di corpo.

))

#### Art. 853. - Revoca del grado

1. Il grado e' soggetto a revoca se il militare al quale e' stato conferito non presta giuramento di fedelta', prima di assumere servizio.

2. La revoca ha effetto dalla data di decorrenza della nomina nel grado.

### SEZIONE II - ANZIANITA' DI GRADO

#### Art. 854. - Anzianita'

1. L'anzianita' di grado, salvo diverse disposizioni, determina la precedenza di un militare rispetto ai pari grado. La precedenza si intende riferita agli atti del servizio o della disciplina militare, secondo quanto stabilito dal presente codice e dal regolamento.

2. L'anzianita' di grado e' assoluta e relativa ed e' determinata secondo le disposizioni del presente codice.

#### Art. 855. - Precedenza tra militari di differenti ruoli o diverse categorie

1. Gli ufficiali dei ruoli normali e speciali ((dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)) hanno la precedenza sugli ufficiali dei ruoli a esaurimento di grado eguale solo per l'assolvimento degli obblighi di comando e di attribuzioni specifiche prescritte per l'avanzamento dalla normativa in vigore. In tutti gli altri casi la precedenza al comando compete all'ufficiale avente maggiore anzianita' di grado indipendentemente dal ruolo di appartenenza.

2. ((COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95)).

#### Art. 855-bis. - (( (Precedenza tra militari di differenti ruoli o diverse categorie per l'Arma dei carabinieri).))

((

1. Gli ufficiali del ruolo normale dell'Arma dei carabinieri hanno la precedenza sugli ufficiali dei ruoli a esaurimento di grado eguale solo per l'assolvimento degli obblighi di comando prescritti per l'avanzamento dalla normativa in vigore.

2. Gli ufficiali del ruolo normale dell'Arma dei carabinieri hanno la precedenza al comando sugli ufficiali di tutti gli altri ruoli dell'Arma dei carabinieri di grado eguale, allorquando ricoprono incarichi validi ai fini dell'avanzamento al grado superiore, anche oltre i periodi minimi di comando richiesti ai fini dell'avanzamento.

3. Gli ufficiali del ruolo forestale dell'Arma dei carabinieri hanno la precedenza al comando sugli ufficiali dei ruoli tecnico e a esaurimento dell'Arma dei carabinieri di grado uguale, allorquando ricoprono incarichi validi ai fini dell'avanzamento al grado superiore, anche oltre i periodi minimi di comando richiesti ai fini dell'avanzamento.

4. Gli ufficiali del ruolo tecnico dell'Arma dei carabinieri hanno la precedenza al comando sugli ufficiali dei ruoli forestale e a esaurimento dell'Arma dei carabinieri di grado uguale, allorquando ricoprono incarichi validi ai fini dell'avanzamento al grado superiore, anche oltre i periodi minimi di attribuzioni specifiche richiesti ai fini dell'avanzamento.

5. In tutti gli altri casi la precedenza al comando compete all'ufficiale avente maggiore anzianita' di grado indipendentemente dal ruolo di appartenenza, fatte salve le disposizioni ordinative che attribuiscono l'incarico di comando o di direzione a un determinato ruolo e grado.

))

#### Art. 856. - Anzianita' assoluta

1. Per anzianita' assoluta si intende il tempo trascorso dal militare nel proprio grado, salvo gli eventuali aumenti o detrazioni apportati in base alle disposizioni del presente codice.

2. L'anzianita' assoluta e' determinata dalla data del provvedimento di nomina o di promozione, se non e' altrimenti disposto.

#### Art. 857. - Anzianita' relativa

1. L'anzianita' relativa e' l'ordine di precedenza del militare fra i pari grado dello stesso ruolo.

2. L'anzianita' relativa e' determinata dalle graduatorie di merito, compilate al termine del concorso di ammissione in ruolo, o al termine del corso di formazione iniziale, o negli avanzamenti a scelta, quando espressamente stabilito.

#### Art. 858. - Detrazioni di anzianita'

1. Il militare in servizio permanente subisce una detrazione di anzianita', in base alle seguenti cause:

- a) detenzione per condanna a pena restrittiva della liberta' personale di durata non inferiore a un mese;
- b) detenzione in stato di custodia cautelare per reato che ha comportato condanna a pena restrittiva della liberta' personale di durata non inferiore a un mese;
- c) sospensione disciplinare dall'impiego;
- d) aspettativa per motivi privati.

2. Il militare delle categorie in congedo subisce una detrazione di anzianita', in base alle seguenti cause:

- a) detenzione per condanna a pena restrittiva della liberta' personale di durata non inferiore a un mese;
- b) detenzione in stato di custodia cautelare per reato che ha comportato condanna a pena restrittiva della liberta' personale di durata non inferiore a un mese;
- c) sospensione disciplinare dalle funzioni del grado.

3. La detrazione d'anzianita' e' pari al tempo trascorso in una delle anzidette situazioni((...)).

3-bis. La detrazione di anzianita', operata a qualsiasi titolo sul grado, ha effetto anche sulla decorrenza della qualifica posseduta.

3-ter. I periodi di congedo straordinario di cui all'articolo 42, comma 5, del decreto legislativo 26 marzo 2001, n. 151, sono computati nell'anzianita' richiesta ai fini della progressione di carriera.

#### Art. 859.

((ARTICOLO ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173))

#### Art. 860. - Rettifiche di anzianita'

1. Nessuna rettifica di anzianita' per errata assegnazione di posto nel ruolo puo' disporsi d'ufficio oltre il termine di sei mesi dalla data di pubblicazione del provvedimento, tranne il caso di accoglimento in via amministrativa di ricorso giurisdizionale o di ricorso straordinario al Presidente della Repubblica.

### SEZIONE III - PERDITA DEL GRADO

#### Art. 861. - Cause di perdita del grado

1. Il grado si perde per una delle seguenti cause:

- a) dimissioni volontarie;
- b) dimissioni d'autorita';
- c) cancellazione dai ruoli;
- d) rimozione all'esito di procedimento disciplinare;
- e) condanna penale.

2. ((COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173)).

3. La perdita del grado, se non consegue all'iscrizione in altro ruolo, comporta che il militare e' iscritto d'ufficio nei ruoli dei militari di truppa, senza alcun grado.

4. Per gli appartenenti ai ruoli dell'Arma dei carabinieri, la perdita del grado, se non consegue all'iscrizione in altro ruolo, comporta l'iscrizione d'ufficio nel ruolo dei militari di truppa dell'Esercito italiano, senza alcun grado.

#### Art. 862. - Dimissioni volontarie

1. ((Il militare)) ha facolta' di chiedere le dimissioni volontarie dal grado.

2. Le dimissioni dal grado sono consentite quando ((il militare)) raggiunge l'eta' per la quale cessa ogni obbligo di servizio per i militari di truppa e si e' collocati in congedo assoluto in detto ruolo.

3. ((Il militare)) in trattamento di quiescenza non puo' dimettersi dal grado finche' non e' collocato nel congedo assoluto.

4. ((Il militare)) sottoposto a procedimento disciplinare di stato, da cui possa derivare la perdita del grado per rimozione, ha facolta' di presentare istanza di dimissioni volontarie dal grado ((, purche' non sia sospeso precauzionalmente dall'impiego)).

5. L'accettazione delle dimissioni dal grado e' irrevocabile.

6. La facolta' di dimettersi dal grado e' sospesa dal giorno in cui e' indetta la mobilitazione, totale o parziale, ovvero e' dichiarato lo stato di grave crisi internazionale.

#### Art. 863. - Dimissioni d'autorita'

1. Le dimissioni d'autorita' sono determinate dalle seguenti cause:

- a) interdizione giudiziale;
- b) inabilitazione civile;
- c) amministrazione di sostegno;
- d) irreperibilita' accertata;
- e) sottoposizione a misura di prevenzione o di sicurezza personale definitiva.

2. Le dimissioni d'autorita' sono adottate per decisione del Ministro, sentito il parere della Corte militare d'appello:

- a) a seguito di sottoposizione a misure di prevenzione;
- b) a seguito di sottoposizione a misure di sicurezza personali, previste dall'articolo 215 del codice penale, se il militare e' prosciolto dal giudice penale, ovvero se il militare, condannato, e' ricoverato, a causa di infermita' psichica, in una casa di cura o di custodia. Se il militare, prosciolto, e' ricoverato in un ospedale psichiatrico giudiziario, ai sensi dell'articolo 222 c.p., e se il militare, condannato, e' ricoverato per infermita' psichica in una casa di cura o di custodia, ai sensi dell'articolo 219 c.p., la decisione e' presa quando il militare ne e' dimesso.

#### Art. 864. - Cancellazione dai ruoli

1. La cancellazione dai ruoli e' determinata dalle seguenti cause:

- a) perdita della cittadinanza;
- b) assunzione di servizio con qualsiasi grado o qualifica in una Forza armata o Corpo armato diversi o in una Forza di polizia a ordinamento civile;
- c) assunzione di servizio con grado inferiore nella Forza armata o Corpo armato di appartenenza;
- d) assunzione di servizio, non autorizzata, nelle Forze armate di Stati esteri.

2. Ai sensi del comma 1, lettere b) e c), l'assunzione di servizio si perfeziona con l'incorporazione a seguito di immissione nel nuovo ruolo.

#### Art. 865. - Rimozione per motivi disciplinari

1. La perdita del grado per rimozione e' sanzione disciplinare di stato, adottata a seguito di apposito giudizio disciplinare.

#### Art. 866. - Condanna penale

1. La perdita del grado, senza giudizio disciplinare, consegue a condanna definitiva, non condizionalmente sospesa, per reato militare o delitto non colposo che comporti la pena accessoria della rimozione o della interdizione temporanea dai pubblici uffici, oppure una delle pene accessorie di cui all'articolo 19, comma 1, numeri 2) e 6) del codice penale.((41))

2. I casi in base ai quali la condanna penale comporti l'applicazione della rimozione o della interdizione temporanea dai pubblici uffici sono contemplati, rispettivamente, dalla legge penale militare e dalla legge penale comune.

-------------- AGGIORNAMENTO (41) La Corte Costituzionale con sentenza 19 ottobre - 15 dicembre 2016, n. 268 (in G.U. 1ª s.s. 21/12/2016, n. 51) ha dichiarato l'illegittimita' costituzionale del comma 1 del presente articolo nella parte in cui non prevede l'instaurarsi del procedimento disciplinare per la cessazione dal servizio per perdita del grado conseguente alla pena accessoria della interdizione temporanea dai pubblici uffici.

#### Art. 867. - Provvedimenti di perdita del grado

1. Il provvedimento e' disposto con decreto ministeriale. Per gli appartenenti al ruolo appuntati e carabinieri la perdita del grado e' disposta con determinazione ministeriale per i militari in servizio e con determinazione del Comandante generale per i militari in congedo.

2. Per i militari dichiarati interdetti, inabilitati o sottoposti all'amministrazione di sostegno la perdita del grado decorre dalla data di pubblicazione della sentenza, ai sensi dell'articolo 421 del codice civile.

3. Se la perdita del grado consegue a condanna penale, la stessa decorre dal passaggio in giudicato della sentenza.((41))

4. Nei casi di assunzione di servizio di cui all'articolo 864, la perdita del grado decorre dalla data di assunzione del servizio stesso.

5. La perdita del grado decorre dalla data di cessazione dal servizio, ovvero, ai soli fini giuridici, dalla data di applicazione della sospensione precauzionale, se sotto tale data, risulta pendente un procedimento penale o disciplinare che si conclude successivamente con la perdita del grado, salvo che il militare sia stato riammesso in servizio:

- a) per il decorso della durata massima della sospensione precauzionale, ai sensi dell'articolo 919, comma 1;
- b) a seguito di revoca della sospensione precauzionale disposta dall'amministrazione, ai sensi dell'articolo 918, comma 2.

6. Per tutti gli altri casi la perdita del grado decorre dalla data del decreto.

-------------- AGGIORNAMENTO (41) La Corte Costituzionale con sentenza 19 ottobre - 15 dicembre 2016, n. 268 (in G.U. 1ª s.s. 21/12/2016, n. 51) ha dichiarato l'illegittimita' costituzionale del comma 3 del presente articolo nella parte in cui non prevede l'instaurarsi del procedimento disciplinare per la cessazione dal servizio per perdita del grado conseguente alla pena accessoria della interdizione temporanea dai pubblici uffici.

### SEZIONE IV - REINTEGRAZIONE NEL GRADO

#### Art. 868. - Disposizioni generali sulla reintegrazione nel grado

1. Il militare che ha subito un provvedimento di perdita del grado, puo' essere reintegrato nello stesso nei casi previsti dal presente codice e con le modalita' stabilite dal regolamento.

2. La reintegrazione nel grado e' disposta con decreto ministeriale e decorre dalla data del provvedimento.

3. La reintegrazione nel grado non comporta la riassunzione in servizio, salvo quanto previsto dagli articoli 961 e 962. Il militare reintegrato e' iscritto nei corrispondenti ruoli del congedo.

#### Art. 869. - Reintegrazione d'ufficio

1. La reintegrazione nel grado e' disposta d'ufficio se vengono meno le cause che hanno determinato la cancellazione dai ruoli per assunzione di servizio con grado inferiore nella Forza armata o Corpo armato di appartenenza.

2. La reintegrazione nel grado decorre dalla data in cui cessa l'assunzione di servizio nel grado inferiore.

#### Art. 870. - Reintegrazione a domanda

1. La reintegrazione nel grado e' disposta a domanda se vengono meno le cause che hanno determinato:

- a) l'interdizione giudiziale, l'inabilitazione civile o l'amministrazione di sostegno;
- b) l'irreperibilita' accertata;
- c) la perdita della cittadinanza;
- d) l'assunzione di servizio con qualsiasi grado o qualifica in una Forza armata o Corpo armato diversi o in una Forza di polizia a ordinamento civile.

#### Art. 871. - Reintegrazione a seguito di perdita del grado per rimozione

1. La reintegrazione nel grado per il militare che ne e' stato rimosso per motivi disciplinari e' disposta a domanda dell'interessato, previo parere favorevole della Corte militare d'appello.

2. La reintegrazione e' disposta se il militare conserva ottima condotta morale e civile per almeno cinque anni dalla data della rimozione. Tale periodo e' ridotto alla meta' per il militare che, per atti di valore personale compiuti dopo la rimozione dal grado, ha conseguito una promozione per merito di guerra o altra ricompensa al valor militare. Il militare che ha conseguito piu' di una di dette promozioni o ricompense puo' ottenere la reintegrazione nel grado in qualsiasi tempo.

3. Se la perdita del grado e' stata disposta in via disciplinare in conseguenza di una condanna penale che non comporta di diritto la perdita del grado, la reintegrazione non puo' aver luogo se non e' prima intervenuta sentenza di riabilitazione.

#### Art. 872. - Reintegrazione a seguito di perdita del grado per condanna

1. La reintegrazione nel grado per il militare che lo ha perso per condanna penale e' disposta a domanda dell'interessato, previo parere favorevole della Corte militare d'appello.

2. La reintegrazione e' disposta se il militare ottiene la riabilitazione a norma delle legge penale comune e, nel caso di applicazione della pena militare accessoria della rimozione, anche a norma della legge penale militare.

3. Se la reintegrazione richiesta a seguito di perdita del grado per condanna e' respinta nel merito, l'esame di una nuova domanda e' ammesso dopo cinque anni dalla data di decisione di rigetto o, in ogni tempo, se sono sopravvenuti o si scoprono nuovi elementi di giudizio particolarmente rilevanti ovvero se il militare consegue una ricompensa al valor militare.

#### Art. 873. - Reintegrazione a seguito di perdita del grado in conseguenza dell'applicazione di misure di sicurezza o di prevenzione

1. La reintegrazione nel grado per il militare che lo ha perso in applicazione di una misura di sicurezza o di una misura di prevenzione e' disposta a domanda dell'interessato, previo parere favorevole della Corte militare d'appello.

2. La reintegrazione e' disposta se la misura di sicurezza o la misura di prevenzione e' revocata o cessa di essere eseguita e il militare conserva ottima condotta morale e civile per almeno cinque anni dalla data di revoca o di cessazione. Tale periodo e' ridotto alla meta' per il militare che, per atti di valore personale compiuti dopo la rimozione dal grado, consegue una promozione per merito di guerra o altra ricompensa al valor militare. Il militare che consegue piu' di una di dette promozioni o ricompense puo' ottenere la reintegrazione nel grado in qualsiasi tempo.

3. Il militare sottoposto a misura di prevenzione deve, inoltre, ottenere la riabilitazione ai sensi dell'articolo 15 della legge 3 agosto 1988, n. 327.

## CAPO II - POSIZIONI DI STATO GIURIDICO

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 874. - Categorie di stato giuridico

1. In base alla posizione di stato giuridico i militari si distinguono in:

- a) militari in servizio permanente;
- b) militari in servizio temporaneo;
- c) militari in congedo.

2. Tutti i militari sono collocati all'interno di una delle predette categorie in distinti ruoli.

#### Art. 875. - Posizione di stato in servizio permanente

1. I militari in servizio permanente si trovano in una delle seguenti posizioni:

- a) servizio permanente effettivo;
- b) servizio permanente a disposizione, limitatamente agli ufficiali;
- c) sospesi dall'impiego;
- d) in aspettativa((;
- d-bis) in distacco sindacale.

#### Art. 876. - Categorie di personale in servizio permanente

1. Possono appartenere al servizio permanente solo i militari delle categorie degli ufficiali, dei sottufficiali e dei graduati di cui all'articolo 627.

#### Art. 877. - Posizione di stato in servizio temporaneo

1. I militari in servizio temporaneo si trovano in una delle seguenti posizioni:

- a) in servizio attivo alle armi;
- b) sospesi dal servizio.

#### Art. 878. - Categorie di personale in servizio temporaneo

((

1. I militari in servizio temporaneo appartengono a una delle seguenti categorie:

- a) volontari in ferma prefissata, in prolungamento di ferma e in rafferma;
- b) carabinieri effettivi in ferma;
- c) allievi delle scuole militari;
- d) allievi marescialli;
- e) allievi e aspiranti ufficiali;
- f) marescialli in ferma;
- g) ufficiali di complemento in ferma e in rafferma;
- h) allievi ufficiali e ufficiali in ferma prefissata;
- i) ufficiali e sottufficiali piloti e navigatori di complemento;
- l) allievi carabinieri.

))

2. I militari in servizio temporaneo non sono forniti di rapporto di impiego e prestano servizio attivo in relazione alla durata della rispettiva ferma.

3. Il rapporto di servizio temporaneo puo' essere sospeso, interrotto o cessare solo in base alle espresse previsioni di questo codice.

#### Art. 879. - Posizione di stato nel congedo

1. Il militare in congedo puo' trovarsi:

- a) temporaneamente richiamato o trattenuto in servizio;
- b) sospeso dalle funzioni del grado.

2. L'ufficiale, per giustificati motivi dell'amministrazione, puo' essere trattenuto in servizio oltre la data di decorrenza del provvedimento di cessazione dal servizio permanente. Se il trattenimento in servizio dura piu' di quindici giorni e' necessaria la preventiva autorizzazione del ((Ministero)) della difesa; in ogni caso il trattenimento in servizio non puo' eccedere la durata di giorni sessanta.

#### Art. 880. - Categorie di personale in congedo

1. I militari in congedo appartengono a una delle seguenti categorie:

- a) ausiliaria;
- b) complemento;
- c) congedo illimitato;
- d) riserva;
- e) riserva di complemento;
- f) congedo assoluto.

2. L'ausiliaria riguarda il personale collocato nel congedo dal servizio permanente.

3. Il complemento riguarda gli ufficiali e i sottufficiali.

4. Il congedo illimitato riguarda i militari di truppa e i graduati dell'Arma dei carabinieri in ferma che cessano dal servizio temporaneo.

5. La riserva di complemento riguarda esclusivamente gli ufficiali.

6. I militari in congedo assoluto non sono piu' vincolati a obblighi di servizio attivo in tempo di pace, in tempo di guerra o di grave crisi internazionale; il militare in congedo assoluto conserva il grado e l'onore dell'uniforme, che puo' essere indossata in base alle disposizioni di ciascuna Forza armata o del Corpo della Guardia di finanza, ed e' soggetto alle disposizioni di legge riflettenti il grado e la disciplina.

((

6-bis. L'inosservanza delle disposizioni concernenti l'uso delle uniformi da parte del personale cessato dal servizio costituisce grave violazione dei doveri attinenti al grado.

))

#### Art. 881. - Disposizioni per il personale militare deceduto o che ha contratto infermita' nel corso di missioni internazionali

1. Il personale militare in ferma volontaria che ha prestato servizio in missioni internazionali e contrae infermita' idonee a divenire, anche in un momento successivo, causa di inabilita' puo', a domanda, essere trattenuto alle armi con ulteriori rafferme annuali, da trascorrere interamente in licenza straordinaria di convalescenza o in ricovero in luogo di cura, anche per periodi superiori a quelli massimi previsti, fino alla definizione ((, con provvedimenti definitivi, sia della posizione medico-legale riguardante l'idoneita' al servizio sia del)) riconoscimento della dipendenza da causa di servizio. Ai fini del proscioglimento dalla ferma o rafferma contratta, al predetto personale che ha ottenuto il riconoscimento della causa di servizio non sono computati, a domanda, i periodi trascorsi in licenza straordinaria di convalescenza o in ricovero in luogo di cura connessi con il recupero dell'idoneita' al servizio militare a seguito della infermita' contratta.

2. Il personale di cui al comma 1 trattenuto alle armi e' computato nelle consistenze annuali previste dagli articoli 803 e ((2207)).

3. Al personale militare in servizio permanente, che presta o ha prestato servizio in missioni internazionali e che ha contratto le infermita' nei termini e nei modi di cui al comma 1, non e' computato nel periodo massimo di aspettativa il periodo di ricovero in luogo di cura o di assenza dal servizio fino a completa guarigione delle stesse infermita', che non devono comportare inidoneita' permanente al servizio.

4. Fino alla definizione dei procedimenti medico-legali riguardanti il riconoscimento della dipendenza da causa di servizio, al personale di cui ai commi 1 e 3 e' corrisposto il trattamento economico continuativo nella misura intera.

5. In relazione al personale di cui ai commi 1 e 3, deceduto o divenuto permanentemente inabile al servizio militare incondizionato ovvero giudicato assolutamente inidoneo ai servizi di istituto per lesioni traumatiche o per le infermita' di cui al comma 1, riconosciute dipendenti da causa di servizio, sono estesi al coniuge e ai figli superstiti, ovvero ai fratelli germani conviventi e a carico, se unici superstiti, i benefici di cui all'articolo 1, comma 2, della legge 23 novembre 1998, n. 407, e successive modificazioni.

### SEZIONE II - SERVIZIO PERMANENTE

#### Art. 882. - Servizio permanente effettivo

((

1. Il servizio permanente effettivo e' la posizione del militare che, essendo idoneo al servizio incondizionato, e' provvisto di rapporto d'impiego in base alle disposizioni del presente codice.

))

2. E' idoneo al servizio incondizionato il militare le cui condizioni psico-fisiche gli consentono di prestare servizio dovunque, presso reparti, comandi, uffici e a bordo per i militari della Marina militare.

3. Per i militari dei ruoli naviganti la temporanea inidoneita' al solo servizio di volo non costituisce impedimento alla permanenza nella posizione di servizio effettivo.

4. L'idoneita' al servizio incondizionato e' accertata periodicamente dagli organi e con le modalita' stabiliti dal regolamento.

#### Art. 883. - Servizio permanente a disposizione

1. La posizione di "a disposizione" e' quella del tenente colonnello e del colonnello e gradi corrispondenti idoneo al servizio incondizionato che continua a essere provvisto di rapporto di impiego.

2. L'ufficiale in servizio permanente a disposizione puo' essere impiegato negli incarichi previsti per gli ufficiali in servizio permanente effettivo, se occorre sopperire a deficienze organiche di ufficiali pari grado di tale posizione di stato.

#### Art. 884. - Aspettativa

1. L'aspettativa e' la posizione di stato del militare temporaneamente esonerato dal servizio per una delle cause previste dal presente codice.

2. L'aspettativa puo' conseguire a:

- a) stato di prigionia o di disperso, ai sensi dell'articolo 621; (7)
- b) infermita' temporanee;
- c) motivi privati;
- d) riduzione dei quadri;
- e) elezione in cariche politiche e amministrative;
- f) prestazione di servizio all'estero del coniuge, dipendente - civile o militare - dello Stato;
- g) ammissione a un dottorato di ricerca;
- h) applicazione delle disposizioni di cui alla sezione III del capo IV del titolo III del presente libro;
- i) applicazione dell'articolo 19, comma 3, del decreto del Presidente della Repubblica 29 ottobre 2001, n. 461, nonche' del decreto interministeriale di cui all'articolo 930.
- i-bis) applicazione dell'articolo 26 della legge 4 novembre 2010, n. 183;
- i-ter) ((aspettativa sindacale non retribuita)).

3. L'aspettativa per riduzione dei quadri riguarda esclusivamente gli ufficiali.

------------- AGGIORNAMENTO (7) Il D.L. 29 dicembre 2010, n. 228, convertito con modificazioni dalla L. 22 febbraio 2011, n. 9, ha disposto (con l'art. 5, comma 1-bis) che "L'aspettativa di cui all'articolo 884, comma 2, lettera a), del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, e' riconosciuta anche per eventi antecedenti alla data di entrata in vigore dello stesso decreto legislativo n. 66 del 2010, verificatisi a decorrere dal 1° gennaio 1982".

#### Art. 885. - Sospensione dall'impiego

1. Il militare puo' essere sospeso dall'impiego per motivi penali, disciplinari o precauzionali.

2. La sospensione dall'impiego come pena militare accessoria e' disciplinata dagli articoli 30 e 31 del codice penale militare di pace.

3. La sospensione disciplinare e quella precauzionale sono disciplinate dal presente codice.

### SEZIONE III - CONGEDO

#### Art. 886. - Ausiliaria

1. La categoria dell'ausiliaria comprende il personale militare che, essendovi transitato nei casi previsti, ha manifestato all'atto del collocamento nella predetta posizione la propria disponibilita' a prestare servizio nell'ambito del comune o della provincia di residenza presso l'amministrazione di appartenenza o altra amministrazione.

2. Il transito nella posizione di ausiliaria e i relativi obblighi sono stabiliti nel capo VII, sezione III del presente titolo.

#### Art. 887. - Riserva

1. La categoria della riserva e' composta dai militari che cessano dal servizio permanente o che vi transitano dalla categoria dell'ausiliaria.

2. I militari della riserva hanno obblighi di servizio soltanto in tempo di guerra o di grave crisi internazionale. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 888. - Complemento

1. La categoria del complemento comprende:

- a) gli ufficiali e i sottufficiali nominati direttamente in tale categoria, ai sensi delle sezioni II e III del capo III del titolo II e della sezione II del capo III del titolo III del presente libro;
- b) gli ufficiali e i sottufficiali provenienti dal servizio permanente nei casi previsti dal presente codice;
- c) gli ufficiali che assolvono l'obbligo di leva.

2. Gli ufficiali e i sottufficiali di complemento sono destinati a completare i quadri della rispettiva Forza armata o Corpo armato. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 889. - Congedo illimitato

1. Il personale in congedo illimitato puo' essere richiamato in servizio:

- a) in tempo di pace, per particolari esigenze di carattere operativo ovvero addestrativo delle Forze armate;
- b) in tempo di guerra o di grave crisi internazionale, ai sensi dell'articolo 1929, comma 2.

#### Art. 890. - Riserva di complemento

1. La categoria della riserva di complemento comprende gli ufficiali di complemento o gli ufficiali in servizio permanente che hanno cessato di appartenere alle rispettive categorie.

2. Il presente codice disciplina i casi e le modalita' che determinano il transito nella categoria della riserva di complemento.

3. L'ufficiale nella riserva di complemento ha obblighi di servizio solo in tempo di guerra o di gravi crisi internazionali.

### SEZIONE IV - COLLOCAMENTO FUORI RUOLO

#### Art. 891. - Impiego presso enti od organismi internazionali o presso Stati esteri

1. Il personale militare puo' con decreto ministeriale, previa autorizzazione della Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica, sentiti il Ministro della difesa e il Ministro per gli affari esteri, d'intesa con il Ministero dell'economia e delle finanze, essere collocato fuori ruolo per assumere un impiego o un incarico temporaneo di durata non inferiore a sei mesi presso enti od organismi internazionali, nonche' esercitare funzioni, anche di carattere continuativo, presso Stati esteri. Con la stessa procedura, l'incarico puo' essere rinnovato alla scadenza del termine o revocato prima di detta scadenza.

2. Per quanto non diversamente disposto dal presente codice, al personale militare impiegato presso enti od organismi internazionali o presso Stati esteri si applicano le disposizioni della legge 27 luglio 1962, n. 1114.

## CAPO III - RAPPORTO DI IMPIEGO

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 892. - Accesso al servizio permanente

1. Si accede al servizio permanente a seguito di:

- a) superamento di apposito concorso e successiva nomina diretta;
- b) superamento di apposito corso di formazione iniziale e successiva nomina nel grado;
- c) ammissione, al termine di un prestabilito periodo di ferma volontaria.

#### Art. 893. - Dell'impiego

1. Il militare in servizio permanente e' fornito di rapporto di impiego che consiste nell'esercizio della professione di militare.

2. Il rapporto di impiego puo' essere interrotto, sospeso o cessare solo in base alle disposizioni del presente codice.

#### Art. 894. - Incompatibilita' professionali

1. La professione di militare e' incompatibile con l'esercizio di ogni altra professione, salvo i casi previsti da disposizioni speciali.

2. E' altresi' incompatibile l'esercizio di un mestiere, di un'industria o di un commercio, la carica di amministratore, consigliere, sindaco o altra consimile, retribuita o non, in societa' costituite a fine di lucro.

((

2-bis. A decorrere dall'anno 2020 l'Amministrazione della difesa provvede al rimborso delle spese sostenute dal personale militare appartenente alle Armi del genio e delle trasmissioni dell'Esercito italiano, ai Corpi degli ingegneri dell'Esercito italiano, del genio della Marina militare e del genio aeronautico dell'Aeronautica militare per l'iscrizione al relativo albo professionale, quando tale iscrizione risulta obbligatoria per lo svolgimento della specifica attivita' di servizio a beneficio esclusivo della Forza armata d'appartenenza.

))

#### Art. 895. - Attivita' extraprofessionali sempre consentite

((

1. Sono sempre consentite le attivita', che diano o meno luogo a compensi, connesse con:

- a) la collaborazione a giornali, riviste, enciclopedie e simili;
- b) l'utilizzazione economica da parte dell'autore o inventore di opere dell'ingegno e di invenzioni industriali;
- c) la partecipazione a convegni e seminari;
- d) le prestazioni nell'ambito delle societa' e associazioni sportive dilettantistiche, ai sensi dell'articolo 90, comma 23, della legge 27 dicembre 2002, n. 289;
- e) incarichi per i quali e' corrisposto solo il rimborso delle spese documentate;
- f) la formazione diretta ai dipendenti della pubblica amministrazione.

))

2. Le predette attivita' devono comunque essere svolte al di fuori dell'orario di servizio e non condizionare l'adempimento dei doveri connessi con lo stato di militare.

#### Art. 896. - Attivita' extraprofessionali da svolgere previa autorizzazione o conferimento

1. I militari non possono svolgere incarichi retribuiti che non sono stati conferiti o previamente autorizzati dall'amministrazione di appartenenza.

2. Gli incarichi autorizzati possono essere svolti solamente al di fuori degli orari di servizio e non devono essere incompatibili con l'adempimento dei doveri connessi con lo stato di militare.

3. Disposizioni interne indicano quali sono gli incarichi retribuiti che possono essere autorizzati o conferiti e con quali modalita', secondo criteri oggettivi e predeterminati che tengono conto delle specifiche professionalita', tali da escludere casi di incompatibilita', sia di diritto sia di fatto, nell'interesse del buon andamento della pubblica amministrazione.

4. E' fatta salva l'applicazione, in quanto compatibile, dell'articolo 53, commi da 8 a 16-bis, del decreto legislativo 30 marzo 2001, n. 165.

#### Art. 897. - Docenza universitaria

1. E' consentito il cumulo dell'ufficio di professore di ruolo con quello di ufficiale superiore o generale delle Forze armate, nei casi e nei limiti previsti dalle norme in vigore.

#### Art. 898. - Decadenza dal rapporto di impiego per incompatibilita' professionale

1. Il militare che non osserva le norme sulle incompatibilita' professionali e' diffidato su determinazione ministeriale a cessare immediatamente dalla situazione di incompatibilita'.

2. Decorsi quindici giorni dalla diffida, senza che l'incompatibilita' cessi, il militare decade dall'impiego.

3. La circostanza che il militare ha obbedito alla diffida non preclude l'eventuale azione disciplinare.

4. Il militare che decade dall'impiego, ai sensi del comma 2, e che conti almeno venti anni di servizio effettivo e' collocato nella riserva. Se il servizio e' inferiore a detto limite:

- a) l'ufficiale e' collocato nel complemento o nella riserva di complemento, a seconda dell'eta';
- b) il sottufficiale e' collocato nel complemento;
- c) il graduato e' collocato sempre nella riserva.

5. Gli ufficiali delle Forze armate, nei casi di decadenza dall'impiego, ai sensi del comma 2, sono trattenuti in servizio ((...)) fino all'assolvimento delle ferme ordinarie e speciali o dei particolari vincoli di permanenza in servizio disposti dal presente codice.

#### Art. 899. - Personale assegnato alla Presidenza del Consiglio dei Ministri

1. Al personale militare continua ad applicarsi l'articolo 9, comma 5-bis, del decreto legislativo 30 luglio 1999, n. 303.

2. I posti resisi vacanti nell'Arma dei carabinieri a seguito della destinazione alla Presidenza del Consiglio dei Ministri, prevista dall'articolo 825, sono considerati disponibili per nuove nomine; la restituzione all'Arma dei carabinieri avviene, se necessario, anche in soprannumero, salvo successivo riassorbimento; resta ferma l'applicazione dell'articolo 2, comma 91, della legge 24 dicembre 2007, n. 244.

### SEZIONE II - SERVIZIO PERMANENTE A DISPOSIZIONE

#### Art. 900. - Collocamento nel servizio permanente a disposizione

1.((Fino all'anno 2029, i tenenti colonnelli)) in servizio permanente effettivo che sono stati valutati almeno tre volte ai fini dell'avanzamento, giudicati idonei ma non iscritti in quadro, sono collocati nella posizione di "a disposizione" dal 1° gennaio del terzo anno precedente a quello del raggiungimento del limite d'eta' per il collocamento in congedo. 2. L'ufficiale collocato "a disposizione" permane in detta posizione di stato fino al raggiungimento del limite d'eta' stabilito per il pari grado del rispettivo ruolo in servizio permanente.

### SEZIONE III - ASPETTATIVA

#### Art. 901. - Motivi privati

1. L'aspettativa per motivi privati e' disposta a domanda motivata dell'interessato.

2. L'aspettativa non puo' avere durata inferiore a quattro mesi e non puo' eccedere il periodo continuativo di un anno.

3. La sua concessione e' subordinata alle esigenze di servizio.

4. Trascorsi i primi quattro mesi il militare puo' fare domanda di ((rientro)) anticipato in servizio. Il militare ((rientra)) in servizio a domanda, se deve essere valutato per l'avanzamento o deve frequentare corsi o sostenere esami prescritti ai fini dell'avanzamento o per l'accesso ai ruoli superiori.

5. Il militare che e' gia' stato in aspettativa per motivi privati, per qualsiasi durata, non puo' esservi ricollocato se non sono trascorsi almeno due anni dal suo ((rientro)) in servizio.

6. Al militare in aspettativa per motivi privati non compete lo stipendio o altro assegno. Il periodo trascorso in aspettativa per motivi privati non e' computato ai fini del trattamento di quiescenza, della indennita' di fine servizio e dell'avanzamento.

7. Le disposizioni del presente articolo si applicano in quanto non diversamente disposto dai provvedimenti di concertazione per il personale delle Forze armate e delle Forze di polizia a ordinamento militare.

#### Art. 902. - Stato di prigionia o di disperso

1. L'aspettativa di cui all'articolo 884, comma 2, lettera a) e' disposta di diritto.

2. L'aspettativa in questione decorre dal momento della cattura o della dispersione e cessa normalmente con il venir meno della causa che l'ha determinata.

3. Al militare in aspettativa ai sensi del comma 1:

- a) compete l'intero trattamento economico goduto dal pari grado in attivita' di servizio;
- b) e' computato per intero agli effetti della pensione il tempo trascorso in aspettativa.

#### Art. 903. - Elezioni in cariche politiche

1. I militari eletti al Parlamento nazionale, al Parlamento europeo e nei Consigli regionali sono collocati d'ufficio in aspettativa senza assegni per la durata del mandato.

2. Essi possono optare per la conservazione, in luogo dell'indennita' parlamentare e dell'analoga indennita' corrisposta ai consiglieri regionali, del trattamento economico in godimento presso l'amministrazione di appartenenza, che resta a carico della medesima.

3. Il periodo di aspettativa in questione e' utile ai fini dell'anzianita' di servizio e del trattamento di quiescenza e di previdenza.

4. Il collocamento in aspettativa ha luogo all'atto della proclamazione degli eletti. Della stessa le Camere e i Consigli regionali danno comunicazione alle amministrazioni di appartenenza per i conseguenti provvedimenti.

#### Art. 904. - Elezioni in cariche amministrative

1. Salvo quanto disposto dall'articolo 903, l'aspettativa per le cariche elettive amministrative e' disposta, a domanda, ai sensi ((dell'articolo 81 del decreto legislativo 18 agosto 2000, n. 267, e dell'articolo 5 del decreto legislativo 17 settembre 2010, n. 156)).

#### Art. 904-bis. - (( (Aspettativa sindacale non retribuita). ))

((

1. L'aspettativa sindacale e' disposta, a domanda dell'associazione professionale a carattere sindacale tra militari riconosciuta rappresentativa ai sensi dell'articolo 1478, secondo la procedura di cui all'articolo 1480, comma 6.

2. Il periodo in cui il militare e' collocato in aspettativa sindacale:

- a) e' valido ai fini dell'anzianita' di servizio, salva la necessita' dell'effettivo compimento nonche' del completamento degli obblighi di comando, di attribuzioni specifiche, di servizio presso enti o reparti e di imbarco, ai fini della valutazione per l'avanzamento al grado superiore;
- b) non da' diritto ad alcuna retribuzione ne' maturazione della licenza;
- c) da' diritto alla contribuzione figurativa da accreditare secondo le disposizioni di cui all'articolo 8 della legge 23 aprile 1981, n. 155.

))

#### Art. 905. - Infermita' temporanea

1. L'aspettativa per infermita' temporanea e' disposta a domanda o d'autorita'.

2. Prima del collocamento in aspettativa per infermita' ai militari sono concessi i periodi di licenza non ancora fruiti.

3. Nei casi di aspettativa per infermita' si provvede tempestivamente agli accertamenti sanitari.

4. Se il militare e' giudicato ancora temporaneamente non idoneo al servizio incondizionato, l'aspettativa e' prorogata fino a raggiungere il periodo massimo previsto dall'articolo 912.

5. Se allo scadere di detto periodo massimo il militare e' ancora giudicato non idoneo al servizio incondizionato, lo stesso cessa dal servizio permanente, ai sensi dell'articolo 929.

6. Il militare in aspettativa per infermita', che ha maturato le condizioni per essere compreso nelle aliquote di valutazione per l'avanzamento o che deve frequentare corsi, compiere esperimenti o sostenere esami prescritti ai fini dell'avanzamento, se ne fa domanda, e' sottoposto ad accertamenti sanitari; se riconosciuto idoneo e' richiamato in servizio.

7. La cessazione dal servizio permanente si applica se il militare e' giudicato permanentemente inabile al servizio incondizionato anche prima dello scadere del periodo massimo di aspettativa, ovvero quando, nel quinquennio, e' giudicato non idoneo al servizio incondizionato, dopo che ha fruito del periodo massimo di aspettativa e gli sono state concesse le licenze eventualmente spettantigli.

8. Agli effetti della pensione, il tempo trascorso dal militare in aspettativa per infermita' proveniente o non proveniente da causa di servizio e' computato per intero.

9. Le disposizioni del presente articolo si applicano in quanto non diversamente disposto dai provvedimenti di concertazione per il personale delle Forze armate e delle Forze di polizia a ordinamento militare.

#### Art. 906. - Riduzione dei quadri per eccedenze in piu' ruoli

1. Se il conferimento delle promozioni annuali determina, nel grado di colonnello o di generale di un determinato ruolo, eccedenze rispetto agli organici previsti dal presente codice, ((. . .)) salvo quanto disposto dall'articolo 908, il collocamento in aspettativa per riduzione di quadri e' effettuato se la predetta eccedenza non puo' essere assorbita nelle dotazioni complessive di tale grado fissate per ogni Forza armata dal presente codice. Se si determinano eccedenze in piu' ruoli di una Forza armata non totalmente riassorbibili, e' collocato in aspettativa per riduzione di quadri l'ufficiale dei predetti ruoli anagraficamente piu' anziano e, a parita' di eta', l'ufficiale meno anziano nel grado.

2. Il collocamento in aspettativa per riduzione dei quadri di cui al comma 1 e' disposto al 31 dicembre dell'anno di riferimento.

#### Art. 907.

((ARTICOLO ABROGATO DAL D.LGS. 19 AGOSTO 2016, N. 177))

#### Art. 908. - Ipotesi speciale di riduzione dei quadri

1. Per gli ufficiali in servizio permanente effettivo, nei gradi in cui le promozioni a scelta al grado superiore non si effettuano tutti gli anni, ((l' articolo 906 si applica)) solo negli anni in cui si forma il quadro di avanzamento. Gli ufficiali che sono stati iscritti nel predetto quadro non sono computati nel numero massimo del grado di appartenenza fino alla promozione.

#### Art. 909. - Norme comuni alla riduzione dei quadri

1. Il collocamento in aspettativa per riduzione dei quadri avviene secondo il seguente ordine:

- a) ufficiali in possesso di un'anzianita' contributiva pari o superiore a quaranta anni che ne fanno richiesta;
- b) ufficiali che si trovano a non piu' di cinque anni dai limiti d'eta' del grado rivestito che ne fanno richiesta;
- c) ufficiali promossi nella posizione di «a disposizione»;
- d) ufficiali in servizio permanente effettivo.

2. Sono esclusi dal provvedimento di collocamento in aspettativa:

- a) il Capo di stato maggiore della difesa;
- b) i Capi di stato maggiore di Forza armata;
- b-bis) il Comandante del Comando operativo di vertice interforze;
- c) il Segretario generale del Ministero della difesa ((e il Direttore nazionale degli armamenti));
- d) il Comandante generale dell'Arma dei carabinieri;
- e) il Comandante generale del Corpo della Guardia di finanza;
- f) gli ufficiali di grado pari a quello degli ufficiali di cui al presente comma, che ricoprono incarichi di livello non inferiore a Capo di stato maggiore di Forza armata in comandi o enti internazionali.

3. Gli ufficiali collocati in aspettativa per riduzione di quadri permangono in tale posizione fino al raggiungimento del limite di eta'.

4. Gli ufficiali collocati in aspettativa per riduzione dei quadri possono chiedere di cessare dal servizio permanente a domanda.

5. Gli ufficiali nella posizione di aspettativa per riduzione di quadri sono a disposizione del Governo per essere all'occorrenza impiegati per esigenze del Ministero della difesa o di altri Ministeri. A essi si applicano le norme di cui agli articoli 993 e 995.

6. Fermo restando quanto previsto dal comma 5, il Ministro della difesa, in relazione a motivate esigenze di servizio delle Forze armate, ha facolta' di richiamare a domanda gli ufficiali in servizio permanente collocati in aspettativa per riduzione di quadri.

7. Il comma 6 non si applica nei confronti degli ufficiali che, all'atto del collocamento in aspettativa per riduzione dei quadri, rivestono il grado apicale dei ruoli normali.

8. Gli ufficiali transitati nella posizione di aspettativa per riduzione di quadri direttamente dal servizio permanente effettivo, in caso di richiamo in servizio, non sono piu' valutati per l'avanzamento. PERIODO SOPPRESSO DAL D.LGS. 26 APRILE 2016, N. 91.

9. Il personale collocato in aspettativa per riduzione dei quadri puo' chiedere il trasferimento anticipato dall'ultima sede di servizio al domicilio eletto. Il trasferimento e' ammesso una sola volta, indipendentemente dai richiami in servizio, e non puo' piu' essere richiesto all'atto del definitivo collocamento in congedo. Si applica l'articolo 23 della legge 18 dicembre 1973, n. 836, e il termine di cui al comma 1, secondo periodo, del medesimo articolo decorre dalla data del definitivo collocamento in congedo. Nessun beneficio e' riconosciuto al personale per il raggiungimento della sede di servizio a seguito di successivi richiami.

#### Art. 910. - Servizio all'estero del coniuge

1. Il militare, il cui coniuge - dipendente civile o militare della pubblica amministrazione - presti servizio all'estero, puo' chiedere di essere collocato in aspettativa se l'amministrazione non ritiene di poterlo destinare a prestare servizio nella stessa localita' in cui si trova il coniuge, o se non sussistono i presupposti per un suo trasferimento nella localita' in questione.

2. L'aspettativa, concessa sulla base del comma 1, puo' avere una durata corrispondente al periodo di tempo in cui permane la situazione che l'ha originata. Essa puo' essere revocata in qualunque momento per ragioni di servizio o in difetto di effettiva permanenza all'estero del dipendente in aspettativa. Il militare in aspettativa non ha diritto ad alcun assegno.

3. Il tempo trascorso in aspettativa concessa ai sensi del comma 1 non e' computato ai fini della progressione di carriera, dell'attribuzione degli aumenti periodici di stipendio e del trattamento di quiescenza e previdenza.

4. Il militare che cessa da tale posizione prende nel ruolo il posto di anzianita' che gli spetta, dedotto il tempo passato in aspettativa.

5. Se l'aspettativa si protrae oltre un anno, l'amministrazione ha facolta' di utilizzare il posto corrispondente ai fini delle assunzioni. In tal caso, il militare che cessa dall'aspettativa occupa - se non vi sono vacanze disponibili - un posto in soprannumero da riassorbirsi al verificarsi della prima vacanza.

#### Art. 911. - Dottorato di ricerca

1. Il militare ammesso ai corsi di dottorato di ricerca senza borsa di studio, o con rinuncia a questa, e' collocato a domanda in aspettativa ((, compatibilmente con le esigenze della Forza armata di appartenenza,)) e conserva il trattamento economico, previdenziale e di quiescenza in godimento da parte dell'amministrazione. Si applica l'articolo 2 della legge 13 agosto 1984, n. 476, e successive modificazioni.

#### Art. 911-bis. - (( (Aspettativa per assenze indebitamente fruite).))

((

1. Il militare che ha fruito di giorni non spettanti di congedo, permesso, licenza straordinaria o altro istituto e che non possa o non voglia chiederne la conversione in licenza ordinaria gia' maturata, e' collocato in aspettativa senza assegni per il corrispondente periodo. Il periodo di aspettativa e' utile ai fini dell'anzianita' di servizio, esclusi i casi nei quali la fruizione di giorni non spettanti e' imputabile a colpa del militare.

))

#### Art. 912. - (( (Durata dell'aspettativa). ))

((

1. I periodi di aspettativa per infermita' e per motivi privati non possono superare cumulativamente la durata di due anni in un quinquennio, anche in caso di trasferimento dall'una all'altra aspettativa.

))

#### Art. 913. - Norme comuni in materia di aspettativa

1. L'aspettativa e' disposta con decreto ministeriale.

2. Per il personale appartenente al ruolo appuntati e carabinieri, l'aspettativa e' disposta con determinazione del Comandante generale dell'Arma, con facolta' di delega, e decorre dalle date fissate nella determinazione stessa.

3. L'aspettativa decorre dalla data fissata nel decreto con il quale e' disposta, salvo l'aspettativa per prigionia di guerra o ipotesi corrispondenti che decorre dalla data della cattura. 4.L'aspettativa per motivi privati e le eventuali proroghe non possono essere concesse che a mesi interi. 5. Allo scadere dell'aspettativa il militare e' richiamato in servizio permanente effettivo o a disposizione. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### ((SEZIONE IIIBIS)) ((DISTACCO SINDACALE))

#### Art. 913-bis. - (Distacco sindacale)

1. Il distacco sindacale e' disposto, a domanda dell'associazione professionale a carattere sindacale tra militari riconosciuta rappresentativa ai sensi dell'articolo 1478, secondo la procedura di cui all'articolo 1480, comma 6.

2. Il periodo in cui il militare e' collocato in distacco sindacale:

- a) e' valido ai fini dell'anzianita' di servizio, salva la necessita' dell'effettivo compimento nonche' del completamento degli obblighi di comando, di attribuzioni specifiche, di servizio presso enti o reparti e di imbarco, ai fini della valutazione per l'avanzamento al grado superiore;
- b) da' diritto all'intera retribuzione spettante nel momento del collocamento in distacco sindacale, con esclusione dei compensi e delle indennita' per il lavoro straordinario e di quelli collegati all'effettivo svolgimento delle prestazioni;
- c) non e' valido ai fini della maturazione della licenza.

2-bis. ((Salvo che sia diversamente disposto, la posizione di stato giuridico del distacco sindacale e' equiparata, quanto agli effetti, a quella dell'aspettativa)).

### SEZIONE IV - SOSPENSIONE DALL'IMPIEGO

#### Art. 914. - Sospensione a seguito di condanna penale

1. La sospensione dall'impiego e' applicata ai militari durante l'espiazione di pene detentive, anche se sostituite in base alle disposizioni dell'ordinamento penitenziario.

#### Art. 915. - Sospensione precauzionale obbligatoria

1. La sospensione precauzionale dall'impiego e' sempre applicata nei confronti del militare se sono adottati a suo carico:

- a) il fermo o l'arresto;
- b) le misure cautelari coercitive limitative della liberta' personale;
- c) le misure cautelari interdittive o coercitive, tali da impedire la prestazione del servizio;
- d) le misure di prevenzione provvisorie, la cui applicazione renda impossibile la prestazione del servizio.

2. La sospensione obbligatoria viene meno con la revoca dei provvedimenti previsti dal comma 1, salva la potesta' dell'amministrazione di applicare la sospensione facoltativa ((...)), se la revoca stessa non e' stata disposta per carenza di gravi indizi di colpevolezza.

#### Art. 916. - Sospensione precauzionale facoltativa connessa a procedimento penale

1. La sospensione precauzionale puo' essere applicata nei confronti di un militare se lo stesso e' imputato per un reato da cui puo' derivare la perdita del grado.

#### Art. 917. - Sospensione precauzionale facoltativa connessa a procedimento disciplinare

1. La sospensione precauzionale puo' essere disposta durante lo svolgimento del procedimento disciplinare di stato instaurato per fatti di notevole gravita' da cui possa derivare la perdita del grado.

2. La sospensione precauzionale di cui al comma 1 puo' essere disposta in vista dell'esercizio dell'azione disciplinare, ma la stessa e' revocata a tutti gli effetti se la contestazione degli addebiti non ha luogo entro sessanta giorni dalla data in cui e' stato comunicato il provvedimento di sospensione.

#### Art. 918. - Revoca della sospensione

1. La sospensione e' revocata retroattivamente a tutti gli effetti:

- a) se il procedimento penale ha termine con sentenza definitiva che dichiara che il fatto non sussiste o che l'imputato non l'ha commesso;
- b) in ogni altro caso di proscioglimento, se il militare non e' sottoposto a procedimento disciplinare di stato;
- c) se, per i medesimi fatti contestati in sede penale, il procedimento disciplinare si esaurisce senza dar luogo a sanzione di stato, ovvero si conclude con l'irrogazione della sospensione disciplinare per un periodo che non assorbe quello sofferto a titolo di sospensione precauzionale;
- d) se il militare e' stato assolto all'esito di giudizio penale di revisione.

2. Rimane ferma la potesta' di revoca del provvedimento di sospensione precauzionale per sopravvenuti motivi di interesse pubblico, per mutamento della situazione di fatto o per una nuova valutazione dell'interesse pubblico originario.

#### Art. 919. - Durata massima della sospensione precauzionale facoltativa

1. La sospensione precauzionale non puo' avere una durata superiore ad anni cinque. Decorso tale termine la sospensione precauzionale e' revocata di diritto.

2. Il termine di durata massima e' riferito al singolo procedimento penale o disciplinare per il quale e' stata adottata la sospensione precauzionale.

3. Scaduto il quinquennio di cui al comma 1, se e' ancora pendente procedimento penale per fatti di eccezionale gravita', l'amministrazione, valutato specificamente ogni aspetto oggettivo e soggettivo della condotta del militare, previa contestazione degli addebiti:

- a) sospende l'imputato ((...)) o dall'impiego ai sensi dell'articolo 917;
- b) sospende il procedimento disciplinare ai sensi dell'articolo 1393.

#### Art. 920. - Norme comuni in materia di sospensione dall'impiego

1. Al militare durante la sospensione dall'impiego compete la meta' degli assegni a carattere fisso e continuativo. Agli effetti della pensione, il tempo trascorso in sospensione dal servizio e' computato per meta'.

2. La sospensione dall'impiego e' disposta con decreto ministeriale e puo' essere applicata anche nei confronti del militare in aspettativa, trasferendolo dalla posizione in cui si trova in quella di sospensione dall'impiego.

3. Per gli appartenenti al ruolo appuntati e carabinieri la sospensione e' disposta con determinazione del Comandante generale.

4. L'ufficiale nei cui confronti la sospensione precauzionale si prolunghi oltre un biennio e' considerato in soprannumero agli organici ovvero non computato nella consistenza massima del grado di appartenenza per tutto il tempo dell'ulteriore durata della sospensione.

5. La cessazione dal servizio, a qualunque titolo prestato, non impedisce lo svolgimento del procedimento disciplinare nei confronti del militare sospeso. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 921. - Ricostruzione di carriera e rimborso spese

1. In caso di revoca della sospensione, ai sensi dell'articolo 918, comma 1, il militare ha diritto a tutti gli assegni non percepiti, escluse le indennita' per servizi e funzioni di carattere speciale o per prestazioni di lavoro straordinario.

2. Dall'importo determinato ai sensi del comma 1 si deduce:

- a) l'assegno alimentare corrisposto;
- b) ogni altro emolumento a qualsiasi titolo percepito in dipendenza di prestazioni e attivita' svolte grazie alla sospensione dal servizio;
- c) il periodo di tempo corrispondente alla pena detentiva inflitta, nonche' all'interdizione temporanea dai pubblici uffici e alle altre pene accessorie che comunque incidono sul rapporto di servizio, ancorche' tali pene non sono state in concreto scontate, ovvero sono state dichiarate estinte;
- d) il periodo di tempo corrispondente alla pena inflitta a seguito di applicazione della pena su richiesta;
- e) il periodo di tempo corrispondente alla sanzione della sospensione disciplinare;
- f) nella sola ipotesi prevista dall'articolo 918, comma 1, lettera b), il periodo di tempo corrispondente alla detenzione sofferta a titolo di arresto, fermo, custodia cautelare in carcere, arresti domiciliari, e ogni altra misura cautelare interdittiva, coercitiva o misura di prevenzione che ha reso impossibile la prestazione del servizio.

3. Il militare prosciolto in sede disciplinare ha diritto al rimborso delle spese di viaggio e soggiorno documentate, sostenute a causa del procedimento medesimo; la domanda di rimborso deve essere proposta nel termine perentorio di 30 giorni dalla comunicazione del proscioglimento.

#### Art. 922. - Norma di rinvio

1. Al personale militare continuano ad applicarsi le ipotesi di sospensione dall'impiego previste dalle seguenti norme:

- a) articolo 4 della legge 25 gennaio 1982, n. 17;
- b) articolo 4 della legge 27 marzo 2001, n. 97.

### SEZIONE V - CESSAZIONE DAL SERVIZIO PERMANENTE

#### Art. 923. - Cause che determinano la cessazione del rapporto di impiego

1. Il rapporto di impiego del militare cessa per una delle seguenti cause:

- a) eta';
- b) infermita';
- c) non idoneita' alle funzioni del grado;
- d) scarso rendimento;
- e) domanda;
- f) d'autorita';
- g) applicazione delle norme sulla formazione;
- h) transito nell'impiego civile;
- i) perdita del grado;(41)
- l) per decadenza, ai sensi dell'articolo 898;
- m) a seguito della perdita dello stato di militare, ai sensi dell'articolo 622.
- m-bis) per infermita', a seguito di rinuncia al transito a domanda nell'impiego civile, secondo le modalita' previste dal decreto di cui all'articolo 930.

2. La cessazione dal servizio permanente d'autorita' e quella in applicazione delle norme sulla formazione si applicano soltanto agli ufficiali.

3. Il provvedimento di cessazione dal servizio e' adottato con decreto ministeriale, salvo quanto previsto dagli articoli seguenti. Se il provvedimento e' disposto a domanda, ne e' fatta menzione nel decreto.

4. Per gli appartenenti al ruolo appuntati e carabinieri il provvedimento di cessazione dal servizio e' adottato con determinazione del Comandante generale, salvo i casi di cui al comma 1, lettere c), d), l) ed m), per i quali il relativo provvedimento e' adottato con determinazione ministeriale.

5. Il militare cessa dal servizio, nel momento in cui nei suoi riguardi si verifica una delle predette cause, anche se si trova sottoposto a procedimento penale o disciplinare. Se detto procedimento si conclude successivamente con ((la perdita dello stato di militare ovvero con un provvedimento di perdita del grado, anche a seguito di dimissioni volontarie del militare, la cessazione dal servizio si considera avvenuta per tali cause)).((La disposizione di cui al precedente periodo si applica anche nel caso in cui la perdita del grado derivi da un procedimento disciplinare di stato instaurato dopo la definizione del procedimento penale che era pendente all'atto della cessazione dal servizio.))

-------------- AGGIORNAMENTO (41) La Corte Costituzionale con sentenza 19 ottobre - 15 dicembre 2016, n. 268 (in G.U. 1ª s.s. 21/12/2016, n. 51) ha dichiarato l'illegittimita' costituzionale della lettera i), comma 1 del presente articolo nella parte in cui non prevede l'instaurarsi del procedimento disciplinare per la cessazione dal servizio per perdita del grado conseguente alla pena accessoria della interdizione temporanea dai pubblici uffici.

#### Art. 924. - Raggiungimento dei limiti d'eta'

1. I militari cessano dal servizio permanente al raggiungimento del 60° anno di eta', salvo quanto disposto dagli articoli seguenti.

2. Il militare che ha raggiunto i limiti d'eta' indicati dal presente codice, in relazione al ruolo di appartenenza e al grado rivestito, cessa dal servizio permanente ed e' collocato in congedo.

3. Il militare puo' essere collocato in congedo nella riserva o, nei casi previsti, in ausiliaria, oppure, se non conserva l'idoneita' al servizio militare incondizionato, in congedo assoluto.

#### Art. 925. - Speciali limiti di eta' per gli ufficiali dell'Esercito italiano

1. I limiti di eta' per la cessazione dal servizio permanente, oltre il 60° anno di eta', per gli ufficiali dell'Esercito italiano, in relazione al grado rivestito e al ruolo di appartenenza, sono i seguenti:

- a) 65 anni: tenente generale del ruolo normale del Corpo degli ingegneri; tenente generale e maggiore generale dell'((Arma dei trasporti e dei materiali)); tenente generale e maggiore generale del ruolo normale del Corpo sanitario e del Corpo di commissariato;
- b) 63 anni: generale di corpo d'armata del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni; maggiore generale del ruolo normale del Corpo degli ingegneri; brigadiere generale del ruolo normale dell'((Arma dei trasporti e dei materiali)); brigadiere generale del ruolo normale del Corpo sanitario e del Corpo di commissariato;
- c) 61 anni: generale di divisione del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni; brigadiere generale del ruolo normale del Corpo degli ingegneri; colonnello del ruolo normale dell'((Arma dei trasporti e dei materiali)); colonnello del ruolo normale del Corpo sanitario e del Corpo di commissariato; colonnello dei ruoli speciali.

#### Art. 926. - Speciali limiti di eta' per gli ufficiali della Marina militare

1. I limiti di eta' per la cessazione dal servizio permanente, oltre il 60° anno di eta', per gli ufficiali della Marina militare, in relazione al grado rivestito e al ruolo di appartenenza, sono i seguenti:

- a) 65 anni: ammiraglio ispettore capo del ruolo normale del Corpo del genio ((della Marina)); ammiraglio ispettore capo e ammiraglio ispettore del ruolo normale del Corpo sanitario, del Corpo di commissariato e del Corpo delle capitanerie di porto; ((37))
- b) 63 anni: ammiraglio di squadra del ruolo normale del Corpo di stato maggiore; ammiraglio ispettore del ruolo normale del Corpo del genio ((della Marina)); contrammiraglio del ruolo normale del Corpo sanitario, del Corpo di commissariato e del Corpo delle capitanerie di porto;((37))
- c) 61 anni: ammiraglio di divisione del ruolo normale del Corpo di stato maggiore; contrammiraglio del ruolo normale del Corpo del genio ((della Marina)); capitano di vascello del ruolo normale del Corpo sanitario, del Corpo di commissariato e del Corpo delle capitanerie di porto; capitano di vascello dei ruoli speciali.((37))

----------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che le presenti modifiche si applicano a decorrere dal 1° gennaio 2017.

#### Art. 927. - Speciali limiti di eta' per gli ufficiali dell'Aeronautica militare

1. I limiti di eta' per la cessazione dal servizio permanente, oltre il 60° anno di eta', per gli ufficiali dell'Aeronautica militare, in relazione al grado rivestito e al ruolo di appartenenza, sono i seguenti:

- a) 65 anni: generale di squadra e generale di divisione del ruolo normale delle armi; generale ispettore capo del ruolo normale del Corpo del genio aeronautico; generale ispettore capo e generale ispettore del ruolo normale del Corpo sanitario e del Corpo di commissariato;
- b) 63 anni: generale di squadra aerea del ruolo naviganti normale; generale di brigata del ruolo normale delle armi; generale ispettore del ruolo normale del Corpo del genio aeronautico; brigadiere generale del ruolo normale del Corpo sanitario e del Corpo di commissariato;
- c) 61 anni: generale di divisione aerea del ruolo naviganti normale; colonnello del ruolo normale delle armi; brigadiere generale del ruolo normale del Corpo del genio aeronautico; colonnello del ruolo normale del Corpo sanitario e del Corpo di commissariato; colonnello dei ruoli speciali.

#### Art. 928. - Speciali limiti di' eta' per gli ufficiali dell'Arma dei carabinieri

1. I limiti di eta' per la cessazione dal servizio permanente, oltre il 60° anno di eta', per gli ufficiali dell'Arma dei carabinieri, in relazione al grado rivestito e al ruolo di appartenenza, sono i seguenti:

- a) generale di corpo d'armata: 65 anni;
- b) generale di divisione: 65 anni;
- c) generale di brigata: 63 anni;
- d) colonnello del ruolo ((forestale)) e del ruolo ((tecnico)): 61 anni.

#### Art. 929. - Infermita'

1. Il militare, che deve assicurare in costanza di servizio i requisiti di idoneita' specifici previsti dal capo II del titolo II del libro IV del regolamento, e accertati secondo le apposite metodologie ivi previste, cessa dal servizio permanente ed e' collocato, a seconda dell'idoneita', in congedo, nella riserva o in congedo assoluto, quando:

- a) e' divenuto permanentemente inidoneo al servizio incondizionato;
- b) non ha riacquistato l'idoneita' allo scadere del periodo massimo di aspettativa per infermita' temporanea;
- c) e' giudicato non idoneo al servizio incondizionato dopo che, nel quinquennio, ha fruito del periodo massimo di aspettativa e gli sono state concesse le licenze spettantegli.

2. Il provvedimento adottato in applicazione del comma 1 decorre, a seconda dei casi, dalla data di scadenza del periodo massimo di aspettativa o dalla data dell'accertamento sanitario definitivo ((o dalla data di rinuncia al transito nell'impiego civile, di cui all'articolo 923, comma 1, lettera m-bis))).

#### Art. 930. - Transito nell'impiego civile

1. Il personale delle Forze armate giudicato non idoneo al servizio militare incondizionato per lesioni dipendenti o meno da causa di servizio, transita nelle qualifiche funzionali del personale civile del Ministero della difesa, secondo modalita' e procedure definite con decreto del Ministro della difesa, di concerto con i Ministri dell'economia e delle finanze e della pubblica amministrazione e innovazione.

1-bis. La disposizione di cui al comma 1 si applica, a decorrere dall'entrata in vigore del codice, anche ai volontari in ferma prefissata quadriennale in posizione di rafferma, risultati idonei ma non vincitori al termine delle procedure di immissione nei ruoli dei volontari in servizio permanente di cui all'articolo 704, nel caso di sopravvenuta inidoneita' al servizio militare incondizionato. Il predetto personale transita secondo la corrispondenza prevista per il grado iniziale dei volontari in servizio permanente. 1-bis.1. La disposizione di cui al comma 1 si applica anche al personale militare di seguito specificato, il quale transita secondo la corrispondenza prevista per il grado iniziale dei volontari in servizio permanente:

- a) volontari in ferma prefissata quadriennale risultati vincitori nella graduatoria di merito per l'immissione in servizio permanente e successivamente esclusi dall'immissione a causa di un giudizio di permanente non idoneita' al servizio militare incondizionato;
- b) volontari in ferma prefissata annuale o raffermati nonche' volontari in ferma prefissata quadriennale o raffermati che hanno subito ferite o lesioni che abbiano causato una infermita' ascrivibile alla IV e alla V categoria della tabella A allegata al decreto del Presidente della Repubblica 30 dicembre 1981, n. 834, e riconosciute dipendenti da causa di servizio.

1-ter. La procedura di transito di cui al comma 1 e' sospesa qualora il militare sia sottoposto a procedimento disciplinare da cui potrebbe derivare una sanzione di stato ovvero qualora nei confronti del medesimo sia stata adottata a qualsiasi titolo la sospensione dall'impiego.

1-quater. Il transito e' precluso nei seguenti casi:

- a) perdita del grado ai sensi dell'articolo 865 all'esito del procedimento disciplinare di cui al comma 1-ter ovvero ai sensi dell'articolo 862, comma 4;
- b) perdita del grado ai sensi dell'articolo 866;
- c) perdita dello stato di militare ai sensi dell'articolo 622.

1-quinquies. Il personale delle Forze armate che transita nei ruoli del personale civile della Difesa, per effetto del comma 1, o di amministrazioni pubbliche nei casi previsti dalla legislazione vigente e' inquadrato in base alla Tabella H di cui all'articolo 45, comma 17 del decreto legislativo 29 maggio 2017, n. 95, e successive modificazioni, secondo le corrispondenze dei gradi militari con le qualifiche degli appartenenti alle Forze di polizia a ordinamento civile di cui all'articolo 632.

1-sexies. Il personale militare di cui al comma 1, che riveste il grado di maggiore o tenente colonnello, e gradi corrispondenti, puo' presentare domanda di transito ai sensi del medesimo comma 1 manifestando espressamente il proprio consenso all'inquadramento nella posizione apicale di livello non dirigenziale prevista dalla tabella di cui al comma 1-quinquies. Si applicano le modalita' e le procedure definite dal decreto di cui al comma 1.

#### Art. 931. - Non idoneita' alle funzioni del grado

1. Il militare non idoneo alle funzioni del grado per insufficienza di qualita' morali, di carattere, intellettuali, militari, o professionali, cessa dal servizio permanente ed e' collocato nella riserva o in congedo assoluto.

2. Il provvedimento che venga adottato in applicazione del comma 1 e' subordinato:

- a) alla deliberazione del Consiglio dei Ministri su proposta del Ministro della difesa, se si tratta di generale di corpo d'armata o ufficiale di grado corrispondente. La proposta e' formulata previo parere di una commissione militare, nominata di volta in volta dal Ministro e dal Capo di stato maggiore della difesa e il relativo provvedimento finale e' adottato con decreto del Presidente della Repubblica;
- b) alla determinazione del Ministro su proposta delle autorita' gerarchiche da cui dipende il militare. La determinazione e' adottata previo parere delle commissioni o autorita' competenti a esprimere giudizi sull'avanzamento.

3. Il procedimento della dispensa dal servizio di cui ai commi 1 e 2 deve prevedere l'assegnazione al militare di un termine per presentare le proprie eventuali osservazioni e la possibilita' di essere sentito personalmente dinanzi alle competenti commissioni di avanzamento.

4. Nei confronti del militare proposto per la cessazione dal servizio ai sensi del comma 1, la procedura relativa ha, in ogni caso, la precedenza su quella eventuale di avanzamento. Tale ultima procedura non ha piu' luogo se e' adottato il provvedimento di cessazione dal servizio.

5. Il militare non idoneo alle funzioni del grado e' tolto dai ruoli del servizio permanente e collocato nella posizione che gli compete entro un mese dalla data della partecipazione ministeriale della deliberazione o della determinazione che lo riguarda.

#### Art. 932. - Scarso rendimento

1. Il militare che dia scarso rendimento e' dispensato dal servizio permanente ed e' collocato nella riserva.

2. Il provvedimento che venga adottato in applicazione del comma 1 e' subordinato alla determinazione ministeriale su proposta delle autorita' gerarchiche da cui dipende l'interessato. La determinazione e' adottata a seguito di:

- a) ammonizione all'interessato;
- b) parere delle commissioni o autorita' competenti a esprimere giudizi sull'avanzamento.

3. Il procedimento della dispensa dal servizio di cui ai commi 1 e 2 deve prevedere l'assegnazione all'interessato di un termine per presentare le proprie eventuali osservazioni e la possibilita' di essere sentito personalmente dinanzi alle competenti commissioni di avanzamento.

#### Art. 933. - Cessazione a domanda

1. Il militare non puo' di norma chiedere di cessare dal servizio permanente e di essere collocato in congedo se deve rispettare obblighi di permanenza in servizio, contratti all'atto dell'incorporazione o al termine dei corsi di formazione.

2. L'amministrazione militare, solo in casi eccezionali che deve adeguatamente motivare a tutela dell'interesse pubblico, puo' concedere il proscioglimento dagli obblighi di servizio ai quali e' vincolato il militare, in relazione alla durata minima del servizio stesso.

3. Gli speciali obblighi di servizio sono individuati dalle particolari disposizioni contenute nei titoli II, III e V del presente libro.

4. L'ufficiale che cessa dal servizio permanente a domanda, se ha prestato almeno venticinque anni di servizio effettivo ovvero riveste il grado di colonnello o corrispondente, e' collocato nella riserva o in congedo assoluto a seconda dell'idoneita'.

5. Il sottufficiale e l'appartenente ai ruoli iniziali che ha compiuto venti anni di servizio effettivo e che cessa dal servizio permanente a domanda, e' collocato nella riserva.

6. Il militare che non si trova nelle condizioni di cui ai commi 4 e 5 ha egualmente diritto alla cessazione dal servizio permanente, dopo aver adempiuto agli obblighi delle ferme ordinarie o speciali eventualmente contratte. In tal caso e' collocato nella categoria del complemento, della riserva o della riserva di complemento a seconda dell'eta' e della categoria di appartenenza.

7. Nei casi previsti dai commi 4, 5 e 6, l'amministrazione ha facolta' di non accogliere la domanda di cessazione per motivi penali o disciplinari, o di ritardarne l'accoglimento per gravi motivi di servizio. Tale facolta' per gli ufficiali deve essere intesa nel senso che nei gravi motivi di servizio sono incluse anche le rilevanti deficienze degli effettivi rispetto all'organico nel grado e nel ruolo di appartenenza e che il ritardo puo' essere disposto per congruo periodo di tempo. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 934. - Cessazione d'autorita'

1. L'ufficiale puo' essere collocato, d'autorita', in ausiliaria o nella riserva.

2. L'adozione del provvedimento di cui al comma 1 e' subordinata:

- a) alla deliberazione del Consiglio dei Ministri su proposta del Ministro della difesa, se si tratta di generale di corpo d'armata o ufficiale di grado corrispondente. La proposta e' formulata previo parere di una commissione militare, nominata di volta in volta dal Ministro e dal Capo di stato maggiore della difesa e il relativo provvedimento finale e' adottato con decreto del Presidente della Repubblica;
- b) alla determinazione del Ministro previo parere delle commissioni o autorita' competenti a esprimere giudizi sull'avanzamento, se si tratta di ufficiale di altro grado.

#### Art. 935. - Applicazione delle norme sulla formazione

1. L'ufficiale cessa dal servizio permanente in applicazione delle disposizioni contenute nel titolo III, capo II del presente libro, in caso di:

- a) mancato superamento del corso applicativo per ufficiali dei ruoli normali a nomina diretta;
- b) mancato transito nei ruoli speciali degli ufficiali dei ruoli normali che non superino i corsi di formazione iniziale;
- c) mancato superamento del corso applicativo per ufficiali dei ruoli speciali;
- c-bis) mancato superamento da parte degli ufficiali dei ruoli normali frequentatori delle Accademie del corso di applicazione e collocamento in congedo nella categoria del complemento senza obblighi di ferma, a seguito di accertata non idoneita' in attitudine militare per l'Esercito e l'Arma dei carabinieri, attitudine professionale per la Marina e attitudine militare e professionale per l'Aeronautica, previo parere favorevole della commissione ordinaria di avanzamento.

### ((SEZIONE VBIS RIAMMISSIONE IN SERVIZIO))

#### Art. 935-bis. - (( (Norma di rinvio). ))

((

1. Al personale militare si applicano l'articolo 3, commi 57 e 57-bis, della legge 24 dicembre 2003, n. 350, l'articolo 2, commi 1, 4 e 6, del decreto-legge 16 marzo 2004, n. 66, convertito, con modificazioni, dalla legge 11 maggio 2004, n. 126, e successive modificazioni, l'articolo 2, comma 32, del decreto-legge 29 dicembre 2010, n. 225, convertito, con modificazioni, dalla legge 26 febbraio 2011, n. 10.

))

## CAPO IV - SERVIZIO TEMPORANEO

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 936. - Obblighi di servizio

1. I militari in servizio temporaneo sono vincolati a prestare servizio per un periodo determinato. Tale periodo di tempo e' definito da ferma disposta all'inizio del servizio o da rafferma disposta in prosecuzione di una precedente ferma.

2. Le ferme e le rafferme sono previste dal presente codice.

3. Se non e' diversamente disposto, al personale militare in servizio temporaneo, si applicano, in quanto compatibili, le norme sul personale militare in servizio permanente in materia di stato giuridico.

### SEZIONE II - UFFICIALI

#### Art. 937. - Ufficiali ausiliari

1. Sono ufficiali ausiliari di ciascuna Forza armata e del Corpo della Guardia di finanza, i cittadini di ambo i sessi reclutati in qualita' di:

- a) ufficiali di complemento in ferma o in servizio di 1^ nomina;
- b) ufficiali piloti e navigatori di complemento;
- c) ufficiali in ferma prefissata o in rafferma;
- d) ufficiali delle forze di completamento.

2. Il reclutamento degli ufficiali ausiliari di cui alle lettere c) e d) puo' avvenire solo al fine di soddisfare specifiche e mirate esigenze delle singole Forze armate connesse alla carenza di professionalita' tecniche nei rispettivi ruoli ovvero alla necessita' di fronteggiare particolari esigenze operative.

3. Gli ufficiali delle forze di completamento sono disciplinati al capo VII, sezione II del presente titolo.

#### Art. 938. - Cause di cessazione dalla ferma degli ufficiali ausiliari

1. Gli ufficiali ausiliari sono collocati in congedo, oltre che per le cause previste per gli ufficiali in servizio permanente:

- a) alla scadenza della ferma;
- b) prima della scadenza: 1) a domanda; 2) d'autorita', per motivi disciplinari; 3) per superamento del limite massimo di licenza straordinaria di convalescenza.

2. Le ipotesi di cessazione anticipata dalla ferma o dalla rafferma, a domanda o d'autorita', sono disciplinate agli articoli seguenti.

#### Art. 939. - Ufficiali in ferma prefissata

1. Ciascuna Forza armata e il Corpo della Guardia di finanza possono arruolare ufficiali in ferma prefissata con durata della ferma di due anni e sei mesi, incluso il periodo di formazione, da reclutare tra coloro che hanno superato con esito favorevole gli appositi corsi formativi.

((1-bis. L'Esercito italiano, la Marina militare e l'Aeronautica militare, al fine di sopperire alla carenza di professionalita' da impiegare per la difesa delle infrastrutture spaziali e dello spazio cibernetico, possono altresi' arruolare ufficiali in ferma prefissata con durata della ferma di quattro anni, incluso il periodo di formazione, da reclutare tra coloro che sono in possesso delle lauree magistrali indicate nel bando di concorso e che hanno superato con esito favorevole gli appositi corsi formativi, nell'ambito del numero massimo degli ufficiali ausiliari da mantenere in servizio come forza media stabilito annualmente dalla legge di bilancio.))

((110))

2. Agli ufficiali in ferma prefissata si applicano le norme di stato giuridico, in quanto compatibili, previste per gli ufficiali di complemento.

--------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 940. - Rafferma e trattenimento in servizio degli ufficiali in ferma prefissata

1. Gli ufficiali in ferma prefissata possono essere:

- a) ammessi, a domanda, a una ulteriore ferma annuale secondo criteri e modalita' stabiliti con decreto del Ministro della difesa ((o del Ministro dell'economia e delle finanze, secondo le rispettive competenze));
- b) trattenuti in servizio sino a un massimo di sei mesi, su proposta dei rispettivi Stati maggiori o Comandi generali e previo consenso degli interessati, per consentirne l'impiego ovvero la proroga dell'impiego nell'ambito di operazioni condotte fuori dal territorio nazionale ovvero in concorso con le Forze di polizia per il controllo del territorio nazionale o a bordo di unita' navali impegnate fuori dalla normale sede di servizio.

#### Art. 941. - Cessazione a domanda per ufficiali in ferma prefissata

1. In deroga a quanto disposto dall'articolo 933, l'amministrazione puo' rinviare il collocamento in congedo, sino a un massimo di 6 mesi, degli ufficiali in ferma prefissata che hanno presentato apposita domanda a decorrere dal diciottesimo mese di servizio, esclusivamente per una delle seguenti cause:

- a) per speciali esigenze di impiego;
- b) per la partecipazione a operazioni condotte fuori dal territorio nazionale;
- c) per concorso con le Forze di polizia al controllo del territorio nazionale;
- d) per impiego a bordo di unita' navali impegnate fuori dalla normale sede di servizio.

#### Art. 942. - Cessazione d'autorita' per ufficiali in ferma prefissata

1. Gli ufficiali in ferma prefissata, posti in congedo d'autorita' per motivi disciplinari, sono collocati nella riserva di complemento.

#### Art. 943. - Ufficiali piloti e navigatori di complemento

1. Gli ufficiali piloti e navigatori di complemento sono vincolati a una ferma di dodici anni che decorre dalla data di inizio del prescritto corso di formazione.

2. Gli ufficiali piloti e navigatori di complemento dell'Aeronautica militare, ruolo naviganti, che per qualsiasi motivo sono stati esonerati dal pilotaggio o dalla navigazione aerea, sono trasferiti, con il grado e l'anzianita' posseduti, nel ruolo delle armi dell'Aeronautica militare, mantenendo la ferma precedentemente contratta.

3. Gli ufficiali piloti e navigatori di complemento, vincolati alla ferma di anni dodici, possono acquisire, durante la ferma, i titoli e la preparazione necessari per il conseguimento dei brevetti e delle abilitazioni richiesti per l'impiego quale pilota professionista presso la compagnia di bandiera ovvero altre compagnie italiane, concessionarie di linee di trasporto aereo. I brevetti e le abilitazioni possono essere conseguiti anche durante il periodo di servizio militare.

#### Art. 944. - Cessazione a domanda per ufficiali piloti e navigatori di complemento

1. Gli ufficiali piloti e navigatori di complemento dell'Esercito italiano ((e della Marina militare)) che hanno conseguito il brevetto di pilota di aeroplano o attitudine a espletare mansioni di navigatore o di pilota di elicottero e che, successivamente, sono esonerati dal pilotaggio o dichiarati non idonei al volo per motivi psico-fisici, possono chiedere di essere prosciolti dalla ferma di anni dodici.

#### Art. 945. - Cessazione d'autorita' per ufficiali piloti e navigatori di complemento

1. Nel caso di cessazione d'autorita' per motivi disciplinari, all'ufficiale pilota o navigatore di complemento non e' corrisposto il premio di fine ferma di cui all'articolo 1797, salvo che, su proposta della competente commissione ordinaria di avanzamento, il Ministro della difesa, apprezzati le eventuali circostanze attenuanti o gli eventuali motivi giustificativi, non disponga, con proprio provvedimento, la corresponsione del premio di congedamento con una riduzione del 30 per cento per l'intero periodo di servizio prestato.

### SEZIONE III - SOTTUFFICIALI

#### Art. 946. - Cause di cessazione dalla ferma

1. Il sottufficiale cessa dalla ferma anche prima del termine stabilito, oltre che per le cause previste per i sottufficiali in servizio permanente, per motivi disciplinari e per superamento del limite massimo di licenza straordinaria di convalescenza. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/9/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 947. - Collocamento in congedo

1. Il sottufficiale che cessa dal servizio al termine della ferma, o prima di tale termine per una delle cause previste dall'articolo 946, eccettuata la perdita del grado, e' collocato nella categoria dei sottufficiali di complemento.

2. Nel caso di cessazione dal servizio per infermita', se si tratta di non idoneita' permanente al servizio incondizionato, il sottufficiale e' collocato in congedo assoluto.

### SEZIONE IV - PERSONALE IN FERMA DELL'ARMA DEI CARABINIERI

#### Art. 948. - Ammissione in servizio permanente

1. Al termine della ferma volontaria, i carabinieri che conservano l'idoneita' psico-fisica al servizio incondizionato e sono meritevoli per qualita' morali e culturali, buona condotta, attitudini e rendimento, di continuare a prestare servizio nell'Arma dei carabinieri, sono ammessi, salvo esplicita rinuncia, in servizio permanente con determinazione del Comandante generale che puo' delegare tale facolta' ai comandanti di corpo.

2. Possono ottenere altresi' l'ammissione al servizio permanente, con le modalita' di cui al comma 1, i marescialli che hanno un'anzianita' di servizio di almeno quattro anni.

3. La domanda di rinuncia al passaggio in servizio permanente va presentata, almeno sessanta giorni prima della scadenza della ferma volontaria, al comando cui e' in forza il militare.

#### Art. 949. - Non ammissione nel servizio permanente

1. L'ufficiale diretto da cui dipende il militare, se ritiene che il medesimo non e' meritevole di essere ammesso in servizio permanente, inoltra, per via gerarchica, motivata proposta di proscioglimento al Comandante generale, che decide, sentito il parere della ((commissione di valutazione e avanzamento, integrata da tre appuntati scelti individuati dal presidente della citata commissione tra i membri supplenti del ruolo appuntati e carabinieri con maggiore anzianita' assoluta e relativa)), se l'interessato e' carabiniere in ferma.

((

1-bis. Se non provvede l'ufficiale diretto, la proposta di cui al comma 1 puo' essere avanzata anche dagli altri ufficiali della linea gerarchica, fino al comandante di corpo.

))

2. I militari che non sono ammessi in servizio permanente cessano dalla ferma volontaria e sono collocati in congedo. Il periodo di tempo eventualmente trascorso in servizio oltre la scadenza della ferma volontaria e' considerato come servizio prestato in ferma volontaria.

#### Art. 950. - Prolungamento della ferma

1. Il militare che alla scadenza della ferma volontaria non possa essere ammesso in servizio permanente per temporanea inidoneita' ((psico-fisica)) al servizio incondizionato ((congedo obbligatorio per maternita')) o perche' imputato in un procedimento penale per delitto non colposo o sottoposto a procedimento disciplinare ((di stato)), anche se sospeso dal servizio, puo' ottenere, a domanda, di continuare a permanere in ferma volontaria. ((Qualora venga accolta la domanda di prolungamento della ferma del militare imputato in procedimento penale per delitto non colposo, la concessione di tale beneficio non condiziona le valutazioni concernenti la successiva istanza di ammissione in servizio permanente e non preclude la possibilita' di disporre il proscioglimento dalla ferma.))

2. La durata complessiva del prolungamento della ferma:

- a) per il militare temporaneamente non idoneo al servizio incondizionato, non puo' essere superiore al periodo massimo previsto per l'aspettativa;
- a-bis) per il militare in congedo obbligatorio per maternita', non puo' superare il periodo concesso ai sensi dell'articolo 16 del decreto legislativo 26 marzo 2001, n. 151;
- b) per il militare ((imputato in procedimento penale ovvero sottoposto a procedimento disciplinare di stato)), non puo' protrarsi oltre la data in cui e' definito il procedimento stesso.

3. Il militare che ha riacquistato l'idoneita' ((psico-fisica)) incondizionata e quello nei cui confronti il procedimento penale o disciplinare ((di stato)) si e' concluso favorevolmente possono ottenere, a domanda, l'ammissione in servizio permanente con decorrenza dal giorno successivo alla scadenza della ferma volontaria precedentemente contratta. ((In caso di conclusione del procedimento penale con sentenza o decreto penale irrevocabili ovvero con provvedimento di archiviazione, la domanda puo' essere presentata soltanto successivamente alla definizione del procedimento disciplinare, qualora avviato.))

((

3-bis. La concessione del beneficio del prolungamento della ferma nei confronti del militare imputato per delitto non colposo o sottoposto a procedimento disciplinare di stato di cui al comma 1, qualora delegata ai comandanti di corpo, dovra' essere preventivamente autorizzata dal Comandante generale dell'Arma dei carabinieri o altra autorita' delegata.

))

4. La domanda di cui al comma 3 deve essere presentata entro sessanta giorni dalla data di comunicazione del giudizio di idoneita' fisica o della notificazione dell'esito del procedimento penale o disciplinare.

5. Il militare che, allo scadere del periodo massimo di cui al comma 2, lettera a), non ha riacquistato l'idoneita' fisica incondizionata o che e' riconosciuto temporaneamente non idoneo, e' collocato in congedo con decorrenza dal giorno successivo a quello della data di comunicazione del relativo giudizio.

#### Art. 951. - Cause di cessazione dalla ferma

1. L'appartenente al ruolo appuntati e carabinieri cessa dalla ferma volontaria o dal prolungamento della stessa, anche prima del termine stabilito, oltre che per le cause previste per il personale in servizio permanente, per motivi disciplinari e per superamento del limite massimo di licenza straordinaria di convalescenza.

2. Per il personale del ruolo ispettori in ferma valgono le norme sulla cessazione dalla ferma previste per i sottufficiali, di cui alla precedente sezione III. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 952. - Collocamento in congedo

1. L'appartenente al ruolo degli appuntati e carabinieri che cessa dal servizio al termine della ferma volontaria o dal prolungamento della stessa, o prima di tale termine per una delle cause previste dall'articolo 951, eccettuata la perdita del grado, e' collocato in congedo illimitato.

2. Nel caso di cessazione dal servizio per infermita', se si tratta di non idoneita' permanente al servizio incondizionato, il militare e' collocato in congedo assoluto.

3. I provvedimenti di cessazione dal servizio, relativi al personale appartenente ai ruoli degli ispettori e degli appuntati e carabinieri, sono adottati con determinazione del Comandante generale dell'Arma dei carabinieri.

((3-bis. Il personale in ferma volontaria appartenente ai ruoli degli ispettori e degli appuntati e carabinieri dell'Arma dei carabinieri giudicato non idoneo al servizio militare incondizionato per lesioni dipendenti o meno da causa di servizio, che ha conseguito la nomina a carabiniere di cui agli articoli 768 e 783, transita nelle qualifiche funzionali del personale civile del Ministero della difesa, secondo modalita' e procedure di cui all'articolo 930. Nei riguardi del personale transitato trova applicazione il regime pensionistico e previdenziale dell'amministrazione di destinazione))

### SEZIONE V - VOLONTARI IN FERMA PREFISSATA

#### Art. 953. - Ammissione alla ferma volontaria

1. L'ammissione alla ferma ha decorrenza giuridica dalla data indicata nel relativo provvedimento adottato dalla Direzione generale per il personale militare e decorrenza economica dalla data di effettiva presentazione al reparto.

#### Art. 954. - (( (Rafferme dei volontari). ))

((

1. I volontari in ferma prefissata iniziale possono essere ammessi, a domanda, a un successivo periodo di rafferma della durata di un anno.

2. La rafferma di cui al comma 1 puo' essere prolungata, con il consenso degli interessati, per il tempo strettamente necessario al completamento dell'iter concorsuale di coloro che hanno presentato domanda per il reclutamento come volontari in ferma prefissata triennale.

3. I criteri e le modalita' di ammissione alla rafferma sono disciplinati con decreto del Ministro della difesa))

#### Art. 955. - Impiego dei volontari che hanno subito ferite o lesioni in servizio

1. I volontari in ferma prefissata che perdono l'idoneita' fisio-psico-attitudinale richiesta per il reclutamento, in seguito a ferite o lesioni per le quali e' avviato il procedimento per l'accertamento dell'eventuale dipendenza da causa di servizio, se giudicati idonei al servizio militare incondizionato ((ovvero per i quali tali ferite o lesioni sono ascrivibili alle categorie dalla 4ª alla 8ª della tabella A allegata al decreto del Presidente della Repubblica 30 dicembre 1981, n. 834, e successive modificazioni)), possono, a domanda, permanere in servizio fino al termine della ferma, in mansioni compatibili con il nuovo profilo sanitario, nonche' essere ammessi alle successive rafferme in attesa del giudizio sulla eventuale dipendenza da causa di servizio.

2. Se le ferite o lesioni sono riconosciute dipendenti da causa di servizio, i volontari in ferma prefissata possono essere ammessi, secondo le modalita' previste dalla normativa vigente, alle ulteriori ferme e rafferme, nonche' all'immissione nel ruolo dei volontari in servizio permanente e sono impiegati in incarichi, categorie, specialita' e specializzazioni adeguate al nuovo profilo sanitario posseduto. ((I volontari in ferma prefissata cui e' attribuita una inidoneita' complessiva ascrivibile alla 4ª e alla 5ª categoria della tabella A allegata al decreto del Presidente della Repubblica 30 dicembre 1981, n. 834, e successive modificazioni, fermo restando quanto previsto dall'articolo 882, comma 2, transitano nel servizio permanente come militari permanentemente non idonei in modo parziale.))

#### Art. 956. - Cause di cessazione dalla ferma o dalla rafferma

1. I volontari in ferma prefissata sono collocati in congedo illimitato:

- a) alla scadenza del termine della ferma;
- b) a seguito di proscioglimento dalla ferma, escluso il proscioglimento per permanente inidoneita' al servizio militare incondizionato.

#### Art. 957. - Casi di proscioglimento dalla ferma o dalla rafferma

1. Il proscioglimento dalla ferma e' disposto, oltre che per le cause previste per il personale in servizio permanente di cui all'articolo 923, comma 1, lettere i), l) ed m), nei seguenti casi:

- a) domanda presentata dall'interessato;
- b) assunzione in servizio nel Corpo nazionale dei vigili del fuoco;
- c) esito positivo degli accertamenti diagnostici per l'abuso di alcool, per l'uso, anche saltuario od occasionale, di sostanze stupefacenti, nonche' per l'utilizzo di sostanze psicotrope a scopo non terapeutico;
- d) superamento del limite massimo di licenza straordinaria di convalescenza;
- e) motivi disciplinari, ai sensi dell'articolo 1357, comma 1, lettera c);
- f) perdita dell'idoneita' fisio-psico-attitudinale, richiesta per il reclutamento quale volontario in ferma prefissata, salvo quanto previsto dall'articolo 955, accertata con riferimento alle direttive tecniche sanitarie approvate con decreto del Ministro della difesa;
- g) scarso rendimento di cui all'articolo 960.

2. Il proscioglimento per esito positivo degli accertamenti diagnostici per l'abuso di alcool, per l'uso, anche saltuario od occasionale, di sostanze stupefacenti, nonche' per l'utilizzo di sostanze psicotrope a scopo non terapeutico, e' disposto sulla base della documentazione attestante gli accertamenti diagnostici effettuati.

3. Il provvedimento di proscioglimento dalla ferma e' adottato dalla Direzione generale per il personale militare e determina la cessazione del rapporto di servizio.

#### Art. 958. - Proscioglimento a domanda

1. Oltre a quanto previsto dall'articolo 933, la domanda di proscioglimento puo' essere presentata nei seguenti casi, comprovati da adeguata documentazione:

- a) assunzione presso amministrazioni pubbliche, nonche' presso imprese od organizzazioni private;
- b) gravi motivi familiari; in ogni caso, costituiscono gravi motivi familiari: 1) la condizione di orfano di entrambi i genitori, con funzioni di capo famiglia, con fratelli minorenni a carico o portatori di handicap o affetti da grave patologia, non autosufficienti; 2) la condizione di figlio unico di genitore portatore di handicap, non autosufficiente, o invalido civile affetto da mutilazione o invalidita' analoghe a quelle per le quali e' previsto l'accompagnatore ai sensi del decreto del Presidente della Repubblica 30 dicembre 1981, n. 834; 3) la condizione di fratello di altro militare deceduto durante la prestazione del servizio.

((1-bis. Entro il dodicesimo mese di servizio i volontari in ferma prefissata iniziale possono presentare domanda di proscioglimento anche per i casi non previsti dal comma 1))

2. La domanda di proscioglimento presentata dall'interessato e' inoltrata dal comandante di corpo alla Direzione generale per il personale militare per il tramite dell'alto comando sovraordinato, corredata del parere dello stesso comandante, il quale puo' esprimersi anche sull'opportunita' di procrastinare l'adozione del provvedimento di proscioglimento per motivate imprescindibili esigenze di impiego.

3. I giovani ammessi alla ferma prefissata ((iniziale)) possono rassegnare le dimissioni entro il termine di quindici giorni dalla data di incorporazione.

((3-bis. Coloro che hanno rassegnato le dimissioni ai sensi del comma 3 non possono presentare domanda di partecipazione a concorsi per il reclutamento di volontari in ferma prefissata iniziale banditi nello stesso anno dalla stessa Forza armata))

#### Art. 959. - Proscioglimento a seguito di ferite o lesioni

1. I volontari in ferma prefissata che perdono l'idoneita' fisio-psico-attitudinale, richiesta per il reclutamento, in seguito a ferite o lesioni, sono prosciolti dalla ferma se le predette ferite o lesioni non sono riconosciute dipendenti da causa di servizio.

2. Sono, altresi', collocati in congedo illimitato, i volontari che perdono l'idoneita' fisio-psico-attitudinale, richiesta per il reclutamento, in seguito a ferite o lesioni, per le quali e' avviato il procedimento per l'accertamento dell'eventuale dipendenza da causa di servizio, i quali, se giudicati idonei al servizio militare incondizionato:

- a) non presentano domanda per permanere in servizio fino al termine della ferma, in attesa del giudizio sulla eventuale dipendenza da causa di servizio, in mansioni compatibili con il nuovo profilo sanitario;
- b) non presentano domanda di permanere in servizio, se le ferite o lesioni sono riconosciute dipendenti da causa di servizio.

#### Art. 960. - Proscioglimento per scarso rendimento

((1. La proposta di proscioglimento per scarso rendimento puo' essere avanzata dal comandante di corpo nei casi in cui il volontario in ferma prefissata ha conseguito la qualifica di "insufficiente" ovvero giudizi negativi in sede di redazione della documentazione caratteristica per un periodo di almeno nove mesi))

2. La proposta deve essere comunque avanzata nei predetti casi, quando essi hanno comportato un giudizio di non idoneita' all'avanzamento per due volte consecutive, ovvero nel caso di mancato superamento dei corsi di formazione previsti per la ferma prefissata ((...)).

### SEZIONE VI - RIAMMISSIONE IN SERVIZIO

#### Art. 961. - Riammissione in servizio nell'Arma dei carabinieri

1. Possono aspirare alla riammissione in servizio nell'Arma dei carabinieri, nei limiti degli organici fissati dal codice, i marescialli dei carabinieri e i carabinieri effettivi in congedo che non hanno superato il trentacinquesimo anno di eta', che ne sono ritenuti meritevoli e sono in possesso dei prescritti requisiti generali e speciali per il reclutamento nei rispettivi ruoli.

2. Ai fini del transito in servizio permanente e della progressione di carriera non e' computato il servizio svolto anteriormente alla riammissione nell'Arma dei carabinieri.

3. I riammessi devono vincolarsi a ferma quadriennale e sono incorporati col proprio grado.

4. Le disposizioni del presente articolo non si applicano al personale comunque cessato dal servizio permanente.

#### Art. 962. - Riammissione dei volontari alla ferma prefissata

1. I volontari prosciolti dalla ferma prefissata in quanto vincitori di concorsi per il reclutamento in qualita' di allievo nei ruoli degli ufficiali o dei sottufficiali delle Forze armate, se perdono la qualita' di allievo, possono essere restituiti, previo loro espresso assenso, ai reparti o enti di provenienza, nei limiti delle consistenze organiche e se non sono scaduti i limiti temporali della ferma prefissata originariamente contratta.

2. I volontari sono reintegrati nel grado precedentemente rivestito e i periodi trascorsi in qualita' di allievo sono computati nella ferma

## CAPO V - SPECIALI OBBLIGHI DI SERVIZIO

### SEZIONE I - UFFICIALI MEDICI IN SERVIZIO PERMANENTE

#### Art. 963. - Disposizioni generali

1. Agli ufficiali dei Corpi sanitari dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e agli ufficiali del comparto sanitario ((e psicologico, specialita' sanita' (medicina/farmacia) e specialita' veterinaria)) dell'Arma dei carabinieri, ammessi ai corsi di specializzazione presso facolta' universitarie per i quali opera la riserva di posti per esigenze dell'Amministrazione della difesa, si applicano gli articoli seguenti.

#### Art. 964. - Ammissione ai corsi di specializzazione

1. Gli ufficiali dei Corpi sanitari dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e gli ufficiali del comparto sanitario ((e psicologico, specialita' sanita' (medicina/farmacia) e specialita' veterinaria)) dell'Arma dei carabinieri in servizio permanente che sono ammessi, previa domanda, su designazione e per le esigenze dell'amministrazione, ai corsi di specializzazione delle facolta' mediche universitarie, all'atto dell'iscrizione alla scuola di specializzazione, sono vincolati a rimanere in servizio per un periodo di anni pari a due volte e mezzo il numero di anni prescritto per il conseguimento della specializzazione. Il vincolo della ferma decorre dalla data di ammissione ai corsi e la durata dello stesso e' aumentata dell'eventuale residuo periodo di precedente ferma contratta, ancora da espletare.

#### Art. 965. - Proroga della durata dei corsi

1. L'ufficiale dei Corpi sanitari dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e l'ufficiale del comparto sanitario ((e psicologico, specialita' sanita' (medicina/farmacia) e specialita' veterinaria)) dell'Arma dei carabinieri al quale e' stata concessa la proroga prevista dall'articolo 758, e' vincolato a rimanere in servizio per un periodo di anni pari al vincolo residuo di cui all'articolo 964, aumentato dell'anno di proroga ottenuto.

#### Art. 965-bis. - (( (Ammissione a dottorato di ricerca).))

((

1. Gli ufficiali in servizio permanente effettivo che, per le esigenze dell'amministrazione, previa domanda, sono ammessi a corsi di dottorato di ricerca, sono vincolati a rimanere in servizio per una durata pari a due volte e mezzo il numero di anni prescritto per il conseguimento del dottorato. Il vincolo della ferma decorre dalla data di ammissione ai corsi e la durata dello stesso e' aumentata dell'eventuale residuo periodo di precedente ferma contratta, ancora da espletare.

))

### SEZIONE II - PILOTI

#### Art. 966. - Ufficiali piloti

1. Gli ufficiali in servizio permanente delle Forze armate in possesso del brevetto di pilota militare, che hanno ultimato la ferma obbligatoria e maturato almeno sedici anni di servizio, sono ammessi a una ferma volontaria di durata biennale, rinnovabile per non piu' di quattro volte entro il quarantacinquesimo anno di eta'.

2. Gli ufficiali dell'Esercito italiano e dell'Arma dei carabinieri, che acquisiscono la specializzazione di pilota di aereo o di pilota di elicottero, assumono l'obbligo di rimanere in servizio per un periodo di dieci anni, a decorrere dalla data di ammissione ai relativi corsi.

#### Art. 967. - Sottufficiali piloti

1. I sottufficiali, per partecipare ai corsi di specializzazione di pilota di aeroplano o navigatore militare o di pilota di elicottero, sono vincolati, all'atto dell'ammissione, a una ferma volontaria di anni dodici decorrente dalla data di inizio dei corsi stessi.

2. I sottufficiali che non portano a termine o non superano i corsi di specializzazione per il conseguimento del brevetto di pilota di aeroplano o l'attitudine a espletare mansioni di navigatore o di pilota di elicottero, sono prosciolti dalla ferma di anni dodici. Per essi restano validi gli obblighi di ferma precedentemente contratti.

3. I sottufficiali che hanno conseguito il brevetto di pilota di aeroplano o l'attitudine a espletare mansioni di navigatore o di pilota di elicottero e che, successivamente, sono esonerati dal pilotaggio o dichiarati non idonei al volo per motivi psico-fisici, possono chiedere di essere prosciolti dalla ferma di anni dodici.

### SEZIONE III - PERSONALE ADDETTO AL CONTROLLO DEL TRAFFICO AEREO

#### Art. 968. - Abilitazione

1. Gli ufficiali ((, i sottufficiali e i graduati,)) addetti ai servizi della circolazione aerea e della difesa aerea del territorio, per poter essere adibiti alle operazioni di controllo dello spazio aereo devono essere in possesso di apposita abilitazione conseguita con il superamento dei corsi formativi all'uopo istituiti dal Ministero della difesa.

2. L'abilitazione e' di I, di II e di III grado, in relazione alle operazioni da compiere. Le operazioni connesse a ciascun grado di abilitazione sono stabilite con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

((

2-bis. I graduati possono conseguire solo il I grado di abilitazione ed essere adibiti alle operazioni di controllo dello spazio aereo con le medesime modalita' previste per i sottufficiali.

))

#### Art. 969. - Ufficiali

1. Gli ufficiali in servizio permanente ammessi a frequentare il corso di qualificazione per il controllo del traffico aereo sono vincolati a una ferma di anni cinque che decorre dalla data di inizio dei corsi stessi. Detto periodo e' aggiuntivo rispetto al periodo di ferma eventualmente in atto e non opera nel caso di mancato superamento o di dimissioni dal corso.

#### Art. 970. - Ulteriori ferme per il personale militare

1. Gli ufficiali e i sottufficiali delle Forze armate, in possesso dell'abilitazione di controllore del traffico aereo in corso di validita', vincolati, in connessione alla frequenza di corsi di formazione e specializzazione legati al proprio profilo di impiego nel settore del traffico aereo, a ferme obbligatorie per la complessiva durata di dieci anni, ai sensi dell'articolo 969 e degli articoli 971 e 972, al termine del periodo di ferma obbligatoria e successivamente al conseguimento del massimo grado di abilitazione previsto, sono ammessi a una ferma volontaria di durata biennale, rinnovabile per non piu' di quattro volte ((entro il quarantacinquesimo anno di eta')).

### SEZIONE IV - CORSI DI PARTICOLARE LIVELLO TECNICO

#### Art. 971. - Ufficiali

1. Gli ufficiali in servizio permanente ammessi a frequentare corsi di elevato livello tecnico-professionale sono vincolati a una ferma di anni cinque che decorre dalla data di inizio dei corsi stessi. Detto periodo e' aggiuntivo rispetto al periodo di ferma eventualmente in atto e non opera nel caso di mancato superamento o di dimissioni dal corso.

2. Il Ministro della difesa definisce, con proprio decreto da pubblicare nella Gazzetta Ufficiale, i corsi di elevato livello tecnico-professionale di cui al comma 1.

#### Art. 972. - Marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. La partecipazione ((...)) dei marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare ((a corsi di particolare livello tecnico, individuati con decreto del Ministro della difesa da pubblicare nella Gazzetta Ufficiale,)) e' subordinata al vincolo di una ulteriore ferma di anni cinque, che permane anche dopo il passaggio nel servizio permanente e decorre dalla scadenza della precedente ferma. La ferma precedentemente contratta non rimane operante in caso di mancato superamento del corso o di dimissioni.

1-bis. La ferma di cui al comma 1 si applica anche al personale che frequenta corsi di qualificazione di controllore del traffico aereo oppure corsi di controllo del traffico aereo connessi con il conseguimento del massimo grado di abilitazione, nonche' altri corsi di durata non inferiore a otto mesi o, se effettuati all'estero, non inferiore a sei mesi.

#### Art. 973. - Personale dell'Arma dei carabinieri

1. La partecipazione a corsi di particolare livello tecnico del personale dei ruoli ispettori, sovrintendenti e appuntati e carabinieri dell'Arma dei carabinieri e' subordinata al vincolo di una ulteriore ferma proporzionale alla durata del corso, fino a un massimo di cinque anni, dalla quale possono essere prosciolti, a domanda, per gravi e comprovati motivi. Il programma e la durata dei corsi e del vincolo di ferma obbligatoria che essi comportano sono determinati con decreto del Ministro della difesa.

2. Il vincolo della ferma obbligatoria di cui al comma 1 vale anche per i militari in servizio permanente.

((

2-bis. Il personale arruolato ai sensi degli articoli 683, comma 4-bis, 692, comma 4-bis, e 708, comma 1-bis, e' impiegato nella relativa specializzazione, salvo che non richieda di essere trasferito ad altra organizzazione dell'Arma dei carabinieri, non prima di dieci anni di servizio prestato nella specialita', ovvero d'autorita' per inidoneita' funzionale o per esonero dalla specializzazione.

))

#### Art. 974. - Sergenti e volontari in servizio permanente

1. All'atto dell'ammissione a corsi di specializzazione di particolare livello tecnico, individuati con determinazione del Capo di stato maggiore della difesa, i sergenti e i volontari in servizio permanente sono vincolati a una ferma della durata di cinque anni, decorrente dalla conseguita specializzazione.

### SEZIONE V - INCARICHI IN CAMPO INTERNAZIONALE

#### Art. 975. - Ufficiali

1. Gli ufficiali in servizio permanente che sono destinati a ricoprire incarichi particolarmente qualificanti in campo internazionale ((o, in campo nazionale, presso agenzie ed enti esterni al Ministero della difesa)) sono vincolati a una ferma pari a due volte la durata dell'incarico, con decorrenza dalla data di assunzione dell'incarico, aggiuntiva rispetto al periodo di ferma eventualmente in atto.

2. Il Ministro della difesa definisce, con proprio decreto da pubblicare nella Gazzetta Ufficiale, gli incarichi di cui al comma 1.

## CAPO VI - PRIMA ASSEGNAZIONE E TRASFERIMENTI

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 976. - Nozione

((

1. Al termine della fase di formazione, la prima assegnazione di sede di servizio del militare e' stabilita sulla base delle direttive d'impiego di ciascuna Forza armata, tenuto conto dell'ordine della graduatoria di merito.

))

2. Le successive assegnazioni di sede di servizio avvengono d'autorita' o a domanda.

3. Il cambiamento di incarico nella stessa sede di servizio non comporta necessariamente l'adozione di un provvedimento di trasferimento.

#### Art. 977. - Divieto di prima assegnazione e trasferimento discriminatori

1. Nei confronti dei militari, in sede di prima assegnazione o di trasferimento a comandi, a enti, a reparti, ad armi o a specializzazioni, si applica l'articolo 1468.

### SEZIONE II - PRIMA ASSEGNAZIONE

#### Art. 978. - Incentivi per il reclutamento alpino

1. Gli aspiranti volontari in ferma prefissata ((iniziale)) residenti nelle zone dell'arco alpino e nelle altre regioni tipiche di reclutamento alpino sono destinati, a domanda, ai reparti alpini, fino al completamento dell'organico.

#### Art. 978-bis. - (( (Impiego dei sergenti). ))

((

1. In relazione alle esigenze di ciascuna Forza armata, il personale vincitore del concorso di cui all'articolo 690, comma 1, all'esito del corso di formazione, puo' essere impiegato anche nella sede di servizio di provenienza, tenuto conto delle esigenze dell'Amministrazione di cui alle direttive di impiego di ciascuna Forza armata e, ove possibile, delle preferenze espresse dal personale stesso.

))

#### Art. 979.

Impiego dei marescialli ((e dei vice brigadieri)) dei carabinieri

1. I marescialli dell'Arma dei carabinieri promossi a conclusione dei corsi di formazione ((e i vice brigadieri promossi a conclusione del corso di cui all'articolo 776)) sono assegnati, secondo il vigente profilo d'impiego, di preferenza alle stazioni per compiervi almeno 2 anni di servizio.

### SEZIONE III - TRASFERIMENTI PARTICOLARI

#### Art. 980.

((ARTICOLO ABROGATO DAL D.LGS. 24 NOVEMBRE 2023, N. 192))

#### Art. 981. - Normativa applicabile

1. Al personale militare, compatibilmente con il proprio stato, continuano ad applicarsi le seguenti norme:

- a) articolo 13, comma 8, del decreto-legge 15 gennaio 1991, n. 8, convertito, con modificazioni, dalla legge 15 marzo 1991, n. 82;
- b) articolo 33, comma 5, della legge 5 febbraio 1992, n. 104, e successive modificazioni((, nel limite, per il personale di Esercito italiano, Marina militare, Aeronautica militare e Arma dei Carabinieri, delle posizioni organiche previste per il ruolo e il grado, vacanti nella sede di richiesta destinazione. In costanza di riconoscimento del diritto previsto da tale norma, il personale dell'Esercito italiano, della Marina militare, dell'Aeronautica militare e dell'Arma dei carabinieri interessato non e' impiegabile in operazioni in ambito internazionale o in attivita' addestrative propedeutiche alle stesse));
- c) articolo 78, comma 6, del decreto legislativo 18 agosto 2000, n. 267;
- d) articolo 108 del decreto legislativo 6 settembre 2011, n. 159;
- e) articolo 3, comma 1, della legge 27 marzo 2001, n. 97.

2. Al personale dell'Arma dei carabinieri continuano ad applicarsi le seguenti norme:

- a) articolo 81 della legge 1° aprile 1981, n. 121;
- b) articolo 33 del decreto del Presidente della Repubblica 15 luglio 1988, n. 574;
- c) articoli 8 e 11 del decreto legislativo 28 luglio 1989, n. 271;
- d) articolo 3 del decreto-legge 29 ottobre 1991, n. 345, convertito, con modificazioni, dalla legge 30 dicembre 1991, n. 410;
- e) articolo 1, commi 553, 554, 555 e 556, della legge 30 dicembre 2004, n. 311.

## CAPO VII - PERSONALE IN CONGEDO

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 982. - Obblighi

1. Il militare in congedo ((...)), richiamato o trattenuto, e' soggetto alle leggi e alle disposizioni vigenti per il personale in servizio permanente, in quanto applicabili.

2. Il militare in congedo e' in ogni caso soggetto alle disposizioni di stato riflettenti il grado, la disciplina e il controllo della forza in congedo.

#### Art. 983. - Militare permanentemente inabile al servizio

1. Il militare in congedo che, prima dei limiti di eta' stabiliti o della scadenza fissata dall'articolo 992, comma 2, lettera b), e' riconosciuto permanentemente inabile a qualsiasi servizio militare, e' collocato in congedo assoluto.

#### Art. 984. - Trasferimento di armi e servizi per gli ufficiali

1. L'ufficiale in congedo dell'Esercito italiano puo' essere trasferito da un'arma a un'altra arma o a un corpo, da un corpo a un'arma ovvero ad altro corpo, quando e' in possesso del titolo di studio richiesto dalle norme sul reclutamento degli ufficiali e inoltre, per i trasferimenti da un'arma a un corpo, quando ha superato il quarantunesimo anno di eta'. Salvo il disposto del comma 2, i trasferimenti sono effettuati a domanda o d'autorita' e, nel caso di trasferimento da un'arma a un corpo, soltanto a domanda.

2. Il trasferimento al Corpo sanitario e' obbligatorio, prescindendo dal suddetto limite di eta', per gli ufficiali inferiori delle armi e dei corpi forniti del prescritto titolo di studio. Il Ministro ha tuttavia facolta' di non effettuare il trasferimento dell'ufficiale, che, appartenendo al ruolo delle armi, faccia domanda di rimanervi.

3. L'ufficiale e' trasferito con il proprio grado e la propria anzianita'; nei trasferimenti da un'arma a un corpo e nei trasferimenti obbligatori al Corpo sanitario, l'ufficiale che riveste grado superiore a tenente e' trasferito col grado di tenente e con l'anzianita' che aveva in tale grado.

4. Per l'ufficiale in congedo della Marina militare non e' ammesso trasferimento da corpo a corpo.

((

5. Per l'ufficiale in congedo dell'Aeronautica militare non e' ammesso il trasferimento al ruolo naviganti.

))

((

5-bis. Fatto salvo il disposto di cui al comma 5, negli altri casi l'ufficiale in congedo dell'Aeronautica militare puo' essere trasferito a domanda, con il grado, l'anzianita' posseduti e la propria posizione di stato, in ruolo o corpo degli ufficiali dell'Aeronautica militare diverso da quello di appartenenza, previa determinazione ministeriale su indicazione della competente commissione di avanzamento, tenuti presenti la capacita', l'attitudine, gli studi compiuti, l'attivita' svolta nella vita civile e la dichiarazione di disponibilita' al richiamo in servizio da parte del richiedente.

))

#### Art. 984-bis. - ((Attivita' di consulenza gratuita))

((

1. Oltre quanto previsto dalla vigente normativa, in considerazione della peculiare funzione svolta e della specificita' professionale acquisita, gli ufficiali in congedo transitati a seguito di concorso pubblico nei ruoli del personale di cui all'articolo 9 della legge 2 aprile 1979, n. 97, che abbiano prestato almeno dieci anni di servizio militare senza demerito, possono svolgere a titolo gratuito, senza collocamento in fuori ruolo, funzioni di alta consulenza presso il Ministero della difesa ovvero presso gli Stati maggiori delle Forze armate o dei Comandi generali delle Forze di polizia ad ordinamento militare. Acquisito l'assenso dell'interessato, il Ministro della difesa ovvero il Ministro dell'economia e delle finanze richiedono agli organi di autogoverno l'autorizzazione allo svolgimento dei relativi incarichi di consulenza.

))

#### Art. 985. - Trasferimento di armi e servizi per i sottufficiali e i volontari

1. Il sottufficiale e il volontario in congedo dell'Esercito italiano puo' essere trasferito, conservando il proprio grado e la propria anzianita', da un'arma ad altra arma o a un servizio e da un servizio a un'arma o ad altro servizio, se e' riconosciuto piu' utilmente impiegabile nella diversa arma o servizio e se e' in possesso dei requisiti per l'appartenenza a detta arma o servizio.

2. Analogamente puo' essere trasferito da categoria a categoria e da specialita' a specialita' il sottufficiale e il volontario in congedo della Marina militare, da ruolo a ruolo e da categoria a categoria il sottufficiale e il volontario in congedo dell'Aeronautica militare.

### SEZIONE II - RICHIAMI IN SERVIZIO

#### Art. 986. - Tipologia dei richiami in servizio

1. Il militare in congedo puo' essere richiamato in servizio:

- a) d'autorita', secondo le norme e nei casi previsti dal presente codice;
- b) a domanda, con o senza assegni, in qualsiasi circostanza e per qualunque durata;
- c) previo consenso, in caso di richiamo nelle forze di completamento.

2. Il richiamo d'autorita' e' disposto con decreto del Ministro della difesa.

3. Il richiamo a domanda:

- a) senza assegni, e' disposto con decreto ministeriale;
- b) con assegni, ha luogo con decreto ministeriale, previa adesione del Ministro dell'economia e delle finanze.

4. Il militare in congedo, richiamato in servizio ((...)), e' impiegato in relazione all'eta' e alle condizioni fisiche.

#### Art. 987. - Ufficiali delle forze di completamento

1. In relazione alla necessita' di disporre di adeguate forze di completamento, con specifico riferimento alle esigenze correlate con le missioni all'estero ovvero con le attivita' addestrative, operative e logistiche sia sul territorio nazionale sia all'estero, gli ufficiali di complemento o in ferma prefissata, su proposta dei rispettivi Stati maggiori o Comandi generali e previo consenso degli interessati, possono essere richiamati in servizio con il grado e l'anzianita' posseduta e ammessi a una ferma non superiore a un anno, rinnovabile a domanda dell'interessato per non piu' di una volta, al termine della quale sono collocati in congedo.

2. Con decreto del Ministro della difesa sono definite in relazione alle specifiche esigenze di ciascuna Forza armata:

- a) le modalita' per l'individuazione delle ferme e della loro eventuale estensione nell'ambito del limite massimo di cui al comma 1;
- b) i requisiti fisici e attitudinali richiesti ai fini dell'esercizio delle mansioni previste per gli ufficiali chiamati o richiamati in servizio. Gli ordinamenti di ciascuna Forza armata individuano gli eventuali specifici requisiti richiesti, anche relativamente alle rispettive articolazioni interne.

#### Art. 988. - Richiami in servizio nelle forze di completamento

1. In relazione alla necessita' di disporre permanentemente, per le esigenze di cui all'articolo 1929, comma 2, di personale in congedo adeguatamente addestrato, allo scopo di garantire la funzionalita' e l'operativita' dei comandi, degli enti e delle unita', nonche' la loro alimentazione, possono essere richiamati in servizio, su base volontaria e a tempo determinato non superiore a un anno, i militari in congedo delle categorie dei sottufficiali, dei militari di truppa in servizio di leva, dei volontari in ferma annuale e dei volontari in ferma breve, in ferma prefissata e in servizio permanente. Tale personale, inserito nelle forze di completamento, e' impiegato in attivita' addestrative, operative e logistiche sia sul territorio nazionale sia all'estero.

2. Ai militari richiamati delle categorie dei sottufficiali e dei volontari in servizio permanente e' attribuito lo stato giuridico ((...)) dei pari grado in servizio.

3. ((Ai militari richiamati delle categorie dei militari di truppa in servizio di leva, dei volontari in ferma annuale e dei volontari in ferma prefissata di un anno e iniziale e' attribuito lo stato giuridico dei pari grado appartenenti ai volontari in ferma prefissata iniziale. Ai militari richiamati delle categorie dei volontari in ferma breve e in ferma prefissata triennale e quadriennale e' attribuito lo stato giuridico dei pari grado appartenenti ai volontari in ferma prefissata triennale)). In ogni caso, i richiamati non possono essere inquadrati con grado superiore rispetto a quello apicale previsto per la stessa categoria d'inquadramento. Lo stato giuridico attribuito durante il periodo di richiamo non ha effetti per l'avanzamento al grado superiore, ne' ai fini della partecipazione ai concorsi per volontario in ferma prefissata ((triennale)), per il reclutamento nelle carriere iniziali delle Forze di polizia a ordinamento civile e militare e a quelli per l'accesso al servizio permanente.

4. Con uno o piu' decreti del Ministro della difesa sono definiti, in relazione alle specifiche esigenze delle Forze armate, i requisiti richiesti ai fini del richiamo in servizio, la durata massima delle ferme e l'eventuale relativo prolungamento, nonche' le modalita' di cessazione anticipata dal vincolo temporaneo di servizio.

#### Art. 988-bis. - (Richiami in servizio dalla riserva di complemento).

1. L'Ufficiale nella riserva di complemento, previo consenso dell'interessato, puo' essere richiamato in servizio per le esigenze connesse con le missioni all'estero ovvero con le attivita' addestrative, operative e logistiche sia sul territorio nazionale sia all'estero, secondo le modalita' di cui all'articolo 987, purche' non abbia superato il ((60° anno di eta')).

#### Art. 989. - Personale assistente di volo

1. Gli assistenti di volo, militarizzati ai sensi dell'articolo 21, sono considerati in congedo richiamati in servizio.

#### Art. 990. - Conservazione del posto di lavoro

1. Il richiamo alle armi per qualunque esigenza delle Forze armate dei dipendenti di pubbliche amministrazioni, sospende il rapporto di lavoro per tutto il periodo del richiamo stesso e il predetto personale ha diritto alla conservazione del posto. Il tempo trascorso in servizio militare da richiamato e fino alla presentazione per riprendere il posto di lavoro e' computato agli effetti dell'anzianita' di servizio.

2. Per i rapporti di lavoro dei prestatori d'opera i quali, all'atto del richiamo alle armi per qualunque esigenza delle Forze armate, sono alle dipendenze di un privato datore di lavoro si applica la disposizione del comma 2 dell'art. 2111 del codice civile, in relazione ai commi 1 e 3 dell'art. 2110 dello stesso codice.

3. Alla fine del richiamo, il lavoratore deve porsi a disposizione del datore di lavoro per riprendere la sua occupazione, entro il termine di cinque giorni, se il richiamo ha avuto durata non superiore a un mese, di otto giorni se ha avuto durata superiore a un mese ma non a sei mesi, di quindici giorni se ha avuto durata superiore a sei mesi.

4. Il lavoratore, salvo il caso di cui al comma 1 dell'art. 2119 del codice civile, non puo' essere licenziato prima di tre mesi dalla ripresa della occupazione.

5. Nel caso che, senza giustificato impedimento, il lavoratore non si ponga a disposizione del datore di lavoro nei termini sopra indicati, e' considerato dimissionario.

6. Rimangono salve le condizioni piu' favorevoli ai lavoratori contenute nei contratti di lavoro.

7. Le norme previste dal presente articolo sono applicate anche ai trattenuti alle armi.

8. Le violazioni delle disposizioni del presente articolo sono punite con la sanzione amministrativa da euro 103,29 a euro 516,46. Se la violazione si riferisce a piu' di cinque lavoratori si applica la sanzione amministrativa da euro 154,94 a euro 1.032,91. Non e' ammesso il pagamento in misura ridotta.

9. La vigilanza per l'applicazione delle norme del presente articolo e' esercitata dagli ispettori del lavoro.

#### Art. 991. - Mantenimento dell'assistenza sanitaria

1. Ai familiari dei lavoratori richiamati alle armi e' dovuta l'assistenza sanitaria a cura del servizio sanitario nazionale al momento della chiamata o del richiamo alle armi, secondo le disposizioni vigenti.

2. Tale assistenza deve essere erogata ai familiari a carico per tutto il periodo dell'adempimento degli obblighi militari.

### SEZIONE III - AUSILIARIA

#### Art. 992. - Collocamento in ausiliaria

1. Il collocamento in ausiliaria del personale militare avviene esclusivamente a seguito di cessazione dal servizio per raggiungimento del limite di eta' previsto per il grado rivestito o a domanda, ai sensi dell'articolo 909, comma 4.

((

2. Il personale militare permane in ausiliaria per un periodo di 5 anni.

))

3. All'atto della cessazione dal servizio, il personale e' iscritto in appositi ruoli dell'ausiliaria, da pubblicare annualmente nella Gazzetta Ufficiale della Repubblica italiana con indicazione della categoria, del ruolo di appartenenza, nonche' del grado rivestito. Le pubbliche amministrazioni statali e territoriali, limitatamente alla copertura delle forze in organico, possono avanzare formale richiesta al competente Ministero per l'utilizzo del suddetto personale, nell'ambito della provincia di residenza e in incarichi adeguati al ruolo e al grado rivestito.

4. Ai fini della corresponsione dell'indennita' di ausiliaria, il personale, all'atto della cessazione dal servizio, manifesta, con apposita dichiarazione scritta, la propria disponibilita' all'impiego presso l'amministrazione di appartenenza e le altre pubbliche amministrazioni.

#### Art. 993. - Richiami in servizio

1. Il richiamo in servizio presso l'Amministrazione della difesa e' disposto con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze.

2. Il Ministero della difesa, sulla base delle richieste di impiego pervenute dalle amministrazioni pubbliche ai sensi dell'articolo 992, predispone appositi elenchi di posti organici disponibili, per gradi o qualifiche funzionali, suddivisi per province e relativi comuni.

3. Sulla base degli elenchi di cui al comma 2, l'amministrazione interessa, in ordine decrescente di eta', i militari in posizione di ausiliaria, che possiedono i requisiti richiesti, per l'assunzione dell'impiego nell'ambito del comune o della provincia di residenza.

4. Il richiamo in servizio dei militari che accettano l'impiego e' disposto con decreto del Ministro competente di concerto con il Ministro dell'economia e delle finanze e con il Ministro della pubblica amministrazione e l'innovazione ((, ferma restando la non riacquisizione delle qualifiche di ufficiale e agente di polizia giudiziaria e di pubblica sicurezza)).

5. Gli eventuali richiami in servizio non interrompono il decorso dell'ausiliaria.

#### Art. 994. - Obblighi del militare in ausiliaria

1. Il militare in ausiliaria non puo' assumere impieghi, ne' rivestire cariche, retribuite e non, presso imprese che hanno rapporti contrattuali con l'amministrazione militare. L'inosservanza di tale divieto comporta l'immediato passaggio nella categoria della riserva, con la perdita del trattamento economico previsto per la categoria dell'ausiliaria.

#### Art. 995. - Cessazione dell'ausiliaria

1. Il personale collocato in ausiliaria transita anticipatamente nella riserva se non accetta l'impiego, ovvero revoca l'accettazione degli impieghi assegnati, per due volte.

2. L'amministrazione che impiega il personale puo' variare la sede o la tipologia di impiego solo previo assenso dell'interessato. In caso di mancato assenso, il personale e' nuovamente collocato in ausiliaria e a esso si applica il disposto di cui al comma 1.

3. Al termine del periodo indicato il militare e' collocato nella riserva o in congedo assoluto, a seconda dell'eta' e della idoneita'.

4. Il militare in ausiliaria puo' essere collocato nella riserva, anche prima dello scadere del periodo anzidetto, per motivi di salute, previ accertamenti sanitari.

5. L'ufficiale in ausiliaria puo' altresi' essere collocato nella riserva o in congedo assoluto, prima dello scadere del periodo prescritto, per motivi professionali, previo parere della commissione o dell'autorita' competente a esprimere il giudizio sull'avanzamento.

#### Art. 996. - Transito in ausiliaria dalla riserva

1. Il militare che, all'atto della cessazione dal servizio permanente per raggiunto limite di eta', e' stato collocato nella riserva perche' non idoneo ai servizi dell'ausiliaria, se entro il periodo di tempo indicato dall'articolo 992 riacquista l'idoneita' ai servizi dell'ausiliaria, puo', a domanda, essere iscritto in tale categoria.

2. Il periodo trascorso dall'ufficiale nella riserva e' computato ai fini della durata massima di permanenza nell'ausiliaria.

### SEZIONE IV - COMPLEMENTO

#### Art. 997. - Obblighi

1. L'ufficiale e il sottufficiale di complemento ha, in tempo di pace, i seguenti obblighi di servizio:

- a) rispondere alle chiamate della rispettiva classe di nascita e alle chiamate per speciali esigenze o per soddisfare a particolari condizioni, in altre circostanze;
- b) frequentare i corsi di addestramento e di allenamento prescritti per le singole Forze armate;
- c) rispondere alle chiamate di controllo.

#### Art. 998. - Limiti di eta' fino ai quali i sottufficiali di complemento hanno obblighi in tempo di pace

1. I limiti di eta' fino ai quali i sottufficiali di complemento hanno obblighi in tempo di pace sono i seguenti:

- a) Esercito italiano: 1) primo maresciallo: 50 anni; 2) maresciallo, maresciallo ordinario e maresciallo capo: 48 anni; 3) appartenenti al ruolo sergenti: 45 anni;
- b) Marina militare: 1) appartenenti al ruolo marescialli: 52 anni; 2) appartenenti al ruolo sergenti: 48 anni;
- c) Aeronautica militare: 1) appartenenti al ruolo naviganti: 35 o 45 anni, in base a quanto stabilito dall'articolo 1003; 2) appartenenti al ruolo marescialli non naviganti: 52 anni; 3) appartenenti ruolo sergenti non naviganti: 50 anni;
- d) Arma dei carabinieri: 1) maresciallo aiutante sostituto ufficiale di pubblica sicurezza: 55 anni; 2) maresciallo, maresciallo ordinario e maresciallo capo: 52 anni; 3) appartenenti al ruolo sovrintendenti: 50 anni.

#### Art. 999. - Chiamate collettive in servizio

1. Le chiamate collettive in servizio ((...)) disposte a norma di legge e i successivi ricollocamenti in congedo hanno luogo con determinazione ministeriale.

#### Art. 1000. - Cessazione dell'appartenenza al complemento

1. L'ufficiale cessa di appartenere alla categoria di complemento ed e' collocato nella riserva di complemento quando raggiunge i seguenti limiti di eta': ((a) Esercito italiano: 55 anni;)) ((b) Marina militare: 55 anni;)) ((c) Aeronautica militare: 1) ruolo naviganti: 1.1) ufficiali inferiori: 45 anni; 1.2) ufficiali superiori: 52 anni; 2) tutti gli altri ruoli: 55 anni;)) d) Arma dei carabinieri: sottotenenti e tenenti: 45 anni; capitani: 48 anni; ufficiali superiori: 54 anni.

2. Per gli ufficiali inferiori e superiori dell'Aeronautica militare del ruolo naviganti i predetti limiti di eta' si applicano soltanto se gli stessi si trovano nelle condizioni previste dall'articolo 1001, comma 2.

3. L'ufficiale che, prima di raggiungere i detti limiti di eta', e' riconosciuto non idoneo ai servizi della categoria di complemento e' collocato nella riserva di complemento.

4. Il sottufficiale cessa di appartenere alla categoria di complemento ed e' collocato in congedo assoluto al raggiungimento del sessantesimo anno di eta'.

5. L'ufficiale o il sottufficiale e' collocato in congedo assoluto anche prima dell'eta' indicata nei commi precedenti, se e' riconosciuto permanentemente inabile al servizio militare.

#### Art. 1001. - Ufficiali di complemento del ruolo naviganti dell'Aeronautica militare

1. L'ufficiale di complemento del ruolo naviganti dell'Arma aeronautica, al compimento degli anni trentacinque, e' trasferito, con il grado e l'anzianita' posseduti, e con la propria posizione di stato, nel ruolo servizi o eccezionalmente, se e' possibile per il grado rivestito, in uno degli altri ruoli o categorie degli ufficiali dell'Aeronautica militare, su indicazione della competente commissione di avanzamento, tenuti all'uopo presenti la capacita', l'attitudine, gli studi compiuti e l'attivita' svolta nella vita civile.

2. L'ufficiale che all'eta' anzidetta ne faccia domanda e si impegni a effettuare annualmente i prescritti allenamenti e addestramenti nonche' l'ufficiale che svolga nella vita civile attivita' di volo a carattere continuativo possono, per determinazione del Ministro, rimanere a far parte del ruolo naviganti fino al raggiungimento del limite di eta' previsto dall'articolo 1000; raggiunto tale limite essi sono collocati nella riserva di complemento di detto ruolo.

3. All'ufficiale che non faccia domanda di rimanere a far parte del ruolo naviganti o che non ottenga di rimanervi, nonche' all'ufficiale che non adempia l'obbligo degli allenamenti o addestramenti si applicano le precedenti disposizioni circa il trasferimento nel ruolo delle armi o, eccezionalmente, in altro ruolo o categoria.

#### Art. 1002. - Reiscrizione nella categoria del complemento

1. L'ufficiale collocato nella riserva di complemento, perche' riconosciuto non idoneo ai servizi della categoria di complemento, puo', a domanda o d'autorita', essere reiscritto nella categoria di complemento, se riacquista l'idoneita' prevista per detta categoria e non ha raggiunto il limite di eta' stabiliti dall'articolo 1000.

#### Art. 1003. - Sottufficiali di complemento dell'Aeronautica militare

1. Il sottufficiale di complemento del ruolo naviganti dell'Arma aeronautica, al compimento degli anni trentacinque, e' trasferito, con il grado e l'anzianita' posseduti, in altro ruolo dei sottufficiali di complemento dell'Aeronautica militare, su indicazione della competente commissione di avanzamento, tenute all'uopo presenti la capacita' l'attitudine e l'attivita' svolta nella vita civile.

2. Il sottufficiale, pero', che all'eta' predetta ne faccia domanda e si impegni a effettuare annualmente i prescritti allenamenti e addestramenti fino all'eta' di quarantacinque anni, nonche' il sottufficiale che svolga nella vita civile attivita' di volo a carattere continuativo possono, per determinazione ministeriale, rimanere nel ruolo naviganti fino al compimento del cinquantaduesimo anno; raggiunta tale eta', il sottufficiale e' trasferito in altro ruolo con le modalita' innanzi indicate e con le stesse modalita' sono trasferiti in altro ruolo il sottufficiale che non faccia domanda di rimanere nel ruolo naviganti o non ottenga di rimanervi, nonche' il sottufficiale che non adempia l'obbligo degli allenamenti e addestramenti.

#### Art. 1004. - Nomine nel complemento del personale dell'Arma dei carabinieri

1. I ((luogotenenti)) dell'Arma dei carabinieri all'atto della loro cessazione dal servizio possono conseguire, a domanda, la nomina a ufficiale di complemento dell'Arma dei carabinieri, se hanno acquisito in via normale diritto al collocamento a riposo per avere compiuto il periodo minimo di servizio prescritto.

2. I sottotenenti di complemento nominati ai sensi del comma 1 non frequentano corsi formativi e non prestano servizio di prima nomina. Per essi il limite massimo di eta' per conseguire la nomina anzidetta e' di 65 anni. Le nomine hanno luogo, secondo l'eta', nelle categorie del complemento o della riserva di complemento.

3. La nomina a vice brigadiere di complemento e a maresciallo di complemento e' conferita, a domanda, all'atto della cessazione dal servizio rispettivamente agli appuntati scelti e ai brigadieri capo, se hanno acquisito in via normale diritto al collocamento a riposo per avere compiuto il periodo minimo di servizio prescritto.

#### Art. 1005. - Ufficiali in ferma biennale

1. L'ammissione degli ufficiali di complemento di prima nomina alla ferma biennale puo' avvenire esclusivamente nelle ipotesi di ripristino del servizio obbligatorio di leva di cui all'articolo 1929, comma 2.

2. Gli ufficiali e gli aspiranti ufficiali di complemento delle Forze armate possono chiedere, dopo almeno tre mesi di servizio dalla nomina a ufficiale o ad aspirante, di vincolarsi a una ferma volontaria di due anni decorrente dal giorno successivo a quello del compimento del servizio di prima nomina.

3. L'ammissione alla ferma e' effettuata per concorso, sulla base dei servizi prestati dopo la nomina a ufficiale o ad aspirante, e degli altri titoli e requisiti stabiliti con decreto del Ministro della difesa.

4. La valutazione dei concorrenti e' effettuata da apposita commissione che procede alla formazione della relativa graduatoria di merito degli idonei sulla base dei complessi di elementi di cui all'articolo 1058.

5. La commissione e' istituita, per ciascuna Forza armata, con decreto del Ministro della difesa ed e' composta da un presidente, ufficiale generale o colonnello e gradi corrispondenti, e da quattro membri ufficiali superiori in servizio permanente, di cui il meno anziano svolge anche le funzioni di segretario.

6. Gli ufficiali ammessi alle ferme di cui al presente articolo possono chiedere di esserne prosciolti dopo almeno un anno di servizio in ferma. Il Ministro ha facolta' di ritardare l'accoglimento della domanda per motivi di servizio.

7. L'ufficiale che e' divenuto permanentemente inabile al servizio incondizionato o che non ha riacquistato la idoneita' allo scadere del periodo massimo di licenza eventualmente spettantegli e' prosciolto dalla ferma e collocato nella riserva di complemento o in congedo assoluto a seconda dell'idoneita'.

8. Gli ufficiali ammessi alla ferma biennale, di cui al presente articolo, sono valutati per l'avanzamento a tenente dopo due anni complessivi di permanenza nei gradi di aspirante e sottotenente o corrispondente e, se idonei, promossi con decorrenza dal ventottesimo mese di servizio prestato da aspirante e ufficiale, compreso quello di prima nomina.

9. Il numero massimo degli ufficiali di complemento da ammettere annualmente alla ferma di cui al comma 1 e' fissato per ciascuna Forza armata con la legge di bilancio.

10. Agli ufficiali vincolati alle ferme biennali, puo' essere riservato fino all'80 per cento dei posti messi a concorso per i ruoli speciali di ciascuna Forza armata, e, nei concorsi a nomina diretta a ufficiale, per i ruoli di ciascuna Forza armata per i quali l'immissione e' subordinata al possesso di un diploma di laurea. I posti riservati non coperti sono portati in aumento di quelli previsti per i partecipanti al concorso a diverso titolo.

11. Agli ufficiali che terminano senza demerito la ferma biennale sono conferite riserve di posti nei concorsi per la nomina in prova nella qualifica iniziale dei ruoli delle carriere direttive e di concetto del personale civile, nelle misure del 5 per cento per l'Amministrazione della difesa e del 2 per cento per le altre amministrazioni dello Stato, comprese quelle a ordinamento autonomo.

### SEZIONE V - CONGEDO ILLIMITATO

#### Art. 1006. - Militari di truppa

1. I militari di truppa in congedo illimitato sono soggetti alle disposizioni del presente codice e del regolamento riflettenti il grado, la disciplina e il controllo della forza in congedo.

2. I militari di truppa in congedo illimitato sono soggetti ai richiami in servizio ai sensi dell'articolo 889.

3. I richiami sono disposti d'autorita' dal Ministro della difesa nei limiti e con le modalita' previsti dalle disposizioni vigenti all'atto del richiamo.

4. I militari di truppa richiamati in servizio ((...)) sono soggetti alle disposizioni vigenti all'atto del richiamo.

#### Art. 1007. - Cessazione dal congedo illimitato

1. I militari di truppa cessano dal congedo illimitato e sono collocati in congedo assoluto:

- a) al raggiungimento del quarantacinquesimo anno di eta';
- b) prima del raggiungimento del quarantacinquesimo anno di eta', se riconosciuti permanentemente non idonei al servizio militare incondizionato.

### SEZIONE VI - RISERVA

#### Art. 1008. - Collocamento nella riserva

1. Il personale militare puo', a domanda, rinunciare al passaggio nella categoria dell'ausiliaria:

- a) ((al)) compimento del limite massimo di eta' previsto per ciascun ruolo, in relazione al grado;
- b) se chiede di cessare a domanda ai sensi 909, comma 4. (14)

2. Nei casi di cui al comma 1 il militare e' collocato direttamente nella categoria della riserva.

------------- AGGIORNAMENTO (14) Il D.Lgs. 24 febbraio 2012, n. 20, ha disposto (con l'art. 4, comma 1, lettera oo)) che "all'articolo 1008, comma 1, lettera b), le parole: «dell'art.» sono sostituite dalle seguenti: «dell'articolo»".

#### Art. 1009. - Permanenza nella riserva

1. L'ufficiale cessa di appartenere alla riserva ed e' collocato in congedo assoluto quando raggiunge i seguenti limiti di eta':

- a) 73 anni se generale o ammiraglio di qualsiasi grado;
- b) 70 anni se ufficiale superiore o inferiore.

2. ((Il restante personale militare)) delle Forze armate cessa di appartenere alla categoria della riserva ed e' collocato in congedo assoluto al raggiungimento del sessantacinquesimo anno di eta'.

3. Il militare e' collocato in congedo assoluto anche prima dell'eta' indicata nei commi precedenti, se e' riconosciuto permanentemente inabile al servizio militare.

### SEZIONE VII - RISERVA DI COMPLEMENTO

#### Art. 1010. - Cessazione dell'appartenenza alla riserva di complemento

1. L'ufficiale cessa di appartenere alla riserva di complemento ed e' collocato in congedo assoluto quando raggiunge i seguenti limiti di eta':

- a) 65 anni se ufficiale superiore;
- b) 62 anni se ufficiale inferiore.

### SEZIONE VIII - CHIAMATE DI CONTROLLO

#### Art. 1011. - Obbligo di risposta alle chiamate di controllo

1. Gli ufficiali in aspettativa per riduzione di quadri senza richiamo e gli ufficiali, sottufficiali, graduati e militari di truppa in congedo, a esclusione di quelli in congedo assoluto, devono rispondere alle chiamate disposte per ragioni di controllo dalle autorita' militari da cui dipendono; all'atto in cui cessano da un periodo di servizio effettivo hanno l'obbligo di indicare all'autorita' militare la propria residenza e notificarne poi qualsiasi cambiamento.

2. I predetti militari rispondono alle chiamate ordinate con manifesto o con precetto personale, dalle autorita' militari per il controllo della forza in congedo.

3. Le chiamate di controllo hanno luogo generalmente in giorno festivo.

4. I militari in congedo devono presentarsi all'amministrazione del comune di residenza, ovvero alle autorita' militari nel comune stesso, secondo le indicazioni del manifesto o del precetto personale di chiamata.

5. Gli stessi non hanno diritto ad alcun assegno o indennita' e sono esonerati da qualsiasi obbligo di servizio, nello stesso giorno di presentazione.

#### Art. 1012. - Mancata presentazione alla chiamata di controllo

1. I militari in congedo e gli ufficiali in aspettativa per riduzione dei quadri senza richiamo, i quali manchino, senza giustificato motivo, alle chiamate di controllo oppure omettano di notificare i cambiamenti della propria residenza e abitazione, sono puniti, a richiesta dell'autorita' militare dalla quale dipendono, con la sanzione amministrativa da euro 2,58 a euro 193,67.

2. Non si fa luogo alla richiesta, se il contravventore paga, entro un mese dalla data di notificazione del processo verbale di accertamento della contravvenzione, una somma equivalente al quinto del massimo della sanzione.

3. La richiesta, in ogni caso, non puo' essere piu' proposta, decorsi tre mesi dal giorno in cui l'autorita' militare ha avuto notizia del fatto che costituisce infrazione amministrativa.

4. In tempo di guerra, di grave crisi internazionale o di mobilitazione, totale o parziale, la misura della sanzione amministrativa stabilita nel comma 1 puo' essere aumentata fino a euro 619,74 e non puo' essere inferiore a euro 6,19.

5. Per quanto disposto dal presente articolo, si applica la legge 24 novembre 1981, n. 689.

### SEZIONE IX - REINSERIMENTO DEL PERSONALE IN CONGEDO NEL MONDO DEL LAVORO

#### Art. 1013. - Formazione professionale, inserimento nel mondo del lavoro e crediti formativi

1. ((Il Ministero della difesa stipula convenzioni con associazioni di imprese private e con le agenzie per il lavoro di cui al decreto legislativo 10 settembre 2003, n. 276, e successive modificazioni,)) al fine di favorire il collocamento preferenziale sul mercato del lavoro del personale eccedente le esigenze delle Forze armate, prevedendo, in particolare, il ricorso agli istituti previsti dalla legislazione vigente diretti a incentivare le assunzioni da parte delle imprese.

((

1-bis. Il Ministero della difesa puo' stipulare convezioni con le aziende iscritte nel Registro nazionale delle imprese di cui alla legge 9 luglio 1990, n. 185, e successive modificazioni, affinche' tali aziende, in caso di nuove assunzioni di personale non dirigente, sottopongano a selezione prioritariamente i volontari in ferma prefissata e in ferma breve congedati senza demerito, iscritti nell'apposita banca dati tenuta dallo stesso Ministero, in possesso dei requisiti e delle qualificazioni richieste.

))

2. Le norme di incentivazione dell'occupazione e dell'imprenditorialita' che individuano i beneficiari anche sulla base dell'eta', della condizione occupazionale precedente, o della residenza, sono applicate ai volontari in ferma breve e in ferma prefissata congedati senza demerito che hanno completato la ferma prescindendo dai limiti di eta' e dai requisiti relativi alla precedente condizione occupazionale, e considerando la residenza precedente l'arruolamento.

((

3. Il Governo, su proposta del Ministero della difesa di concerto con il Ministero del lavoro e delle politiche sociali, d'intesa con la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e successive modificazioni, definisce un programma di iniziative in materia di formazione professionale e di collocamento nel mercato del lavoro dei volontari delle Forze armate congedati senza demerito, da attuarsi tramite apposite convenzioni tra le amministrazioni regionali e il Ministero della difesa, che possa:

- a) garantire la tendenziale uniformita' del riconoscimento da parte delle Regioni nella formazione professionale di crediti formativi connessi con il servizio prestato nelle Forze armate;
- b) riconoscere l'eventuale equipollenza dei titoli conseguiti al termine di corsi di formazione e di perfezionamento frequentati nelle Forze armate con i titoli rilasciati dagli istituti di formazione accreditati presso le Regioni;
- c) favorire l'inserimento nei piani operativi regionali di misure specifiche per la formazione professionale e di una riserva a vantaggio dei medesimi soggetti per l'ammissione ai corsi erogati "a catalogo" dagli enti territoriali preposti alla formazione nella misura stabilita dalla medesima intesa con la Conferenza unificata;
- d) estendere, in caso di ricollocazione professionale in regione diversa da quella di precedente residenza, le misure piu' favorevoli previste in materia alloggiativa.

))

4. Il Ministero della difesa favorisce la costituzione di cooperative di servizi tra i militari di truppa in ferma breve e in ferma prefissata congedati per l'affidamento di attivita' di supporto logistico di interesse delle Forze armate.

5. Le Universita' degli studi possono riconoscere crediti formativi, ai fini del conseguimento di titoli di studio da esse rilasciati, per attivita' formative prestate nel corso del servizio militare in qualita' di volontario in ferma breve ovvero in ferma prefissata rilevanti per il curriculum degli studi.

((

5-bis. Senza nuovi o maggiori oneri per la finanza pubblica e, a partire dall'anno 2017, anche ricorrendo ai risparmi il Ministero della difesa derivanti dalla revisione dello strumento militare, accertati secondo quanto previsto dall'articolo 4, comma 1, lettera d), della legge 31 dicembre 2012, n. 244, il Ministero della difesa puo' ammettere i volontari in servizio e quelli congedati senza demerito alla partecipazione a corsi di formazione tenuti presso propri enti, anche assumendo a proprio carico, nell'ambito delle risorse disponibili, gli oneri connessi con vitto, alloggio e viaggio dei volontari congedati. Con decreto del Ministro della difesa, su proposta del Capo di stato maggiore della difesa, sono stabiliti i criteri generali per la frequenza dei corsi da parte dei volontari congedati. L'attivita' di formazione di cui al presente comma puo' essere accentrata presso un polo di formazione unico istituito e disciplinato secondo le modalita' previste dal regolamento.

5-ter. Le convenzioni di cui al comma 1 possono prevedere, senza nuovi o maggiori oneri per la finanza pubblica, l'attivita' di docenza da parte di personale delle associazioni di categoria dei datori di lavoro per i corsi di formazione di cui al comma 5-bis.

5-quater. Il Ministero della difesa, a seguito di attivita' formative conformi ai criteri previsti dal decreto adottato in attuazione dell'articolo 3, comma 9, della legge 15 luglio 2009, n. 94, puo' rilasciare al personale che ha prestato almeno un anno di servizio senza demerito nelle Forze armate attestati che assolvono ai requisiti di formazione richiesti per l'iscrizione nell'elenco del personale addetto ai servizi di controllo di cui al comma 8 del medesimo articolo 3.

))

#### Art. 1013-bis. - (( (Corsi di formazione professionale). ))

((

1. Il Ministero della difesa eroga corsi di formazione e di perfezionamento professionale, diretti unicamente ai militari in servizio, nelle materie afferenti alle proprie esigenze organizzative interne.

2. I corsi di cui al comma 1, qualora conferiscano abilitazioni di cui all'articolo 73, comma 5, del decreto legislativo 9 aprile 2008, n. 81, ovvero competenze riferite a qualificazioni delle professioni non organizzate in ordini o collegi, ai sensi del decreto legislativo 16 gennaio 2013, n. 13, sono inseriti nel repertorio nazionale di cui all'articolo 8 del medesimo decreto legislativo n. 13 del 2013.

3. Entro il 30 giugno 2024, con decreto del Ministro della difesa, di concerto con i Ministri dell'istruzione e del merito, dell'economia e delle finanze e del lavoro e delle politiche sociali, previo accordo in sede di Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, ai sensi dell'articolo 4, comma 1, del decreto legislativo 28 agosto 1997, n. 281, sono adottate linee guida vincolanti, con le quali sono definite le modalita' tecniche e operative per l'attuazione delle disposizioni del presente articolo))

#### Art. 1014. - (( (Riserve di posti nel pubblico impiego) ))

((

1. A favore dei volontari in ferma breve e ferma prefissata delle Forze armate congedati senza demerito ovvero durante il periodo di rafferma nonche' dei volontari in servizio permanente, fermi restando i diritti dei soggetti aventi titolo all'assunzione ai sensi della legge 12 marzo 1999, n. 68, e tenuto conto dei limiti previsti dall'articolo 5, primo comma, del decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, e successive modificazioni, e dall'articolo 52, commi 1-bis e 1-ter, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, e' riservato:

- a) il 30 per cento dei posti nei concorsi per l'assunzione di personale non dirigente nelle pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni nonche' nelle aziende speciali e nelle istituzioni di cui al decreto legislativo 18 agosto 2000, n. 267;
- b) il 20 per cento dei posti nei concorsi per l'accesso alle carriere iniziali dei corpi di polizia municipale e provinciale;
- c) il 50 per cento dei posti nei concorsi per le assunzioni di personale civile, non dirigenziale, del Ministero della difesa.

2. La riserva di cui al comma 1, lettera a), non opera per le assunzioni nelle Forze di polizia a ordinamento militare e civile e nel Corpo nazionale dei vigili del fuoco.

3. Le amministrazioni, le aziende speciali e le istituzioni di cui al comma 1, lettere a) e b), trasmettono al Ministero della difesa copia dei bandi di concorso o comunque dei provvedimenti che prevedono assunzioni di personale nonche', entro il mese di gennaio, il prospetto delle assunzioni operate ai sensi del presente articolo nel corso dell'anno precedente.

4. Se le riserve di cui al comma 1 non possono operare integralmente o parzialmente, perche' danno luogo a frazioni di posto, tali frazioni si cumulano con le riserve relative ai successivi concorsi per l'assunzione di personale non dirigente banditi dalla medesima amministrazione, azienda o istituzione ovvero sono utilizzate nei casi in cui si procede a ulteriori assunzioni attingendo alla graduatoria degli idonei.

))

#### Art. 1015. - Abilitazione all'esercizio della professione d'ingegnere

1. Gli ufficiali generali e gli ufficiali superiori dell'artiglieria, del genio militare, del Corpo degli ingegneri dell'Esercito italiano, del genio ((della Marina)), del genio aeronautico e delle armi dell'Aeronautica militare i quali cessano definitivamente dal servizio permanente effettivo, possono essere abilitati all'esercizio della professione di ingegnere, senza obbligo di sostenere l'esame di Stato, se dimostrano di possedere tutti i requisiti indicati nel regolamento. ((37))

2. Possono del pari ottenere l'abilitazione all'esercizio della professione di ingegnere, senza obbligo di sostenere l'esame di Stato, gli ufficiali ammiragli e gli ufficiali superiori del Corpo di stato maggiore della Marina militare, i quali cessano definitivamente dal servizio permanente effettivo, se dimostrano o di possedere la laurea in ingegneria o di aver conseguito uno dei brevetti di specializzazione superiore tecnica della Marina e posseggono, nell'un caso e nell'altro, i requisiti indicati nel regolamento.

3. L'abilitazione all'esercizio della professione di ingegnere ai detti ufficiali i quali ne facciano domanda e sono nelle condizioni indicate nei precedenti commi, e' concessa con speciale decreto rilasciato dal Ministro dell'istruzione, dell'universita' e della ricerca, sentito il parere del competente organo consultivo.

4. Gli ufficiali ai quali e' rilasciato il decreto ministeriale suddetto, devono pagare la tassa di diploma stabilita per coloro che conseguono il diploma di abilitazione alla professione di ingegnere.

------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica si applica a decorrere dal 1° gennaio 2017.

#### Art. 1016. - Agevolazioni per il conseguimento di titoli professionali marittimi

1. Coloro che provengono dal Corpo delle capitanerie di porto, dal Corpo equipaggi militari marittimi - ruolo servizi portuali e categoria nocchieri di porto -, dall'Arma dei carabinieri e dal Corpo della Guardia di finanza possono, entro cinque anni dalla cessazione dal servizio e previa immatricolazione tra la gente di mare, a prescindere dal limite di eta' previsto dall'articolo 119 del codice della navigazione, conseguire i titoli professionali marittimi indicati nel regolamento e previsti dagli articoli 253, 253-bis, 254, 254-bis, 256, 257, 259, 270, 270-bis, 271 e 273 del regolamento per l'esecuzione del codice della navigazione, se sono in possesso dei requisiti indicati per ciascuno di essi, maturati durante la prestazione del servizio militare.

2. Coloro che provengono dagli equipaggi delle unita' navali in dotazione dell'Aeronautica militare iscritte nel ruolo speciale del naviglio militare dello Stato, possono, entro cinque anni dalla cessazione dal servizio e previa immatricolazione tra la gente di mare, a prescindere dal limite di eta' previsto dall'articolo 119 del codice della navigazione, conseguire i titoli professionali marittimi indicati dal regolamento e previsti dagli articoli 270-bis e 271 del regolamento per la esecuzione del codice della navigazione, se sono in possesso dei requisiti indicati per ciascuno di essi, maturati durante la prestazione del servizio.

## CAPO VIII - DISPOSIZIONI PER IL TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

### Art. 1017. - Richiami in servizio

1. In tempo di guerra o di grave crisi internazionale il militare in congedo, a qualunque categoria appartenga, e' costantemente a disposizione per essere, all'occorrenza, richiamato in servizio, fermo restando per gli appartenenti alle Forze di polizia a ordinamento civile e al Corpo nazionale dei Vigili del fuoco quanto previsto dai rispettivi ordinamenti.

### Art. 1018. - Trasferimento degli ufficiali di complemento tra Forze armate

1. In tempo di guerra o di grave crisi internazionale il Ministro della difesa ha facolta', sentito il parere dei Capi di stato maggiore interessati, di trasferire da una ad altra Forza armata gli ufficiali di complemento che, a suo giudizio, possano essere piu' utilmente impiegati nei ruoli di complemento dell'altra Forza armata.

2. Gli ufficiali trasferiti conservano il grado e l'anzianita' posseduti.

### Art. 1019. - Cessazione dal servizio

1. In tempo di guerra o di grave crisi internazionale e' sospesa l'applicazione dell'articolo 933, concernente la possibilita' di cessare dal servizio a domanda.

### Art. 1020. - Passaggio in servizio permanente per merito di guerra

1. In tempo di guerra o di grave crisi internazionale i militari possono, previo unanime parere favorevole della competente commissione di avanzamento, e con l'approvazione del Ministro della difesa, essere ammessi o riammessi in servizio permanente per merito di guerra, se non hanno superato i limiti di eta' stabiliti con decreto del Ministro della difesa.

2. Le ammissioni o le riammissioni in servizio di cui al comma 1 si effettuano col grado rivestito dal militare e nei limiti delle vacanze organiche.

3. Gli ammessi in carriera seguono in ruolo, nelle rispettive categorie, il pari grado ultimo iscritto nel ruolo medesimo che si trova in servizio alla data del fatto d'arme, o dell'ultimo fatto d'arme, che ha dato titolo al trasferimento, assumendone la stessa anzianita' assoluta.

## TITOLO VI DOCUMENTAZIONE PERSONALE CAPO I DISPOSIZIONI GENERALI

### Art. 1021. - Documentazione personale

1. La documentazione personale e' impiantata, aggiornata e custodita al fine di adempiere gli obblighi previsti dal presente codice in materia di reclutamento, formazione, avanzamento, rapporto di impiego e di servizio, gestione del personale militare anche in congedo.

2. La documentazione personale dei militari si compone dei documenti matricolari e dei documenti caratteristici.

### Art. 1022. - Rapporti con altre fonti normative

1. I dati personali contenuti nella documentazione personale dei militari sono trattati nel rispetto delle previsioni contenute nel decreto legislativo 30 giugno 2003, n. 196.

2. In materia di documentazione personale, gli obblighi di partecipazione procedimentale e di motivazione sono assolti secondo le modalita' previste nel presente titolo.

## CAPO II - DOCUMENTAZIONE MATRICOLARE

### Art. 1023. - Documentazione matricolare

1. La documentazione matricolare registra per ogni militare:

- a) gli eventi di servizio relativi allo stato giuridico, all'avanzamento e all'impiego;
- b) gli imbarchi per il personale della Marina militare;
- c) le campagne di guerra e le missioni militari;
- d) gli eventi di natura penale e disciplinare;
- e) la progressione economica;
- f) le variazioni di stato civile;
- g) i provvedimenti e gli accertamenti medico-legali;
- h) le benemerenze, le onorificenze e le ricompense acquisite;
- i) le specializzazione e i brevetti;
- l) i titoli di studio e culturali;
- m) ogni altro elemento utile ai fini dell'avanzamento e della determinazione degli obblighi e dei diritti degli interessati.

2. La tenuta, la conservazione, l'iscrizione, la trascrizione, le variazioni, le rettifiche e le cancellazioni inerenti alla documentazione matricolare sono disciplinate nel regolamento.

3. Per l'attestazione dei titoli acquisiti durante il servizio, relativamente agli ufficiali in ferma prefissata e ai volontari in ferma prefissata, e' predisposto un estratto della documentazione di servizio, redatto secondo il modello stabilito con decreto del Ministro della difesa.

### Art. 1024. - Indicazione di malattia o cause inabilitanti nel congedo militare

1. Il foglio di congedo, le copie di fogli matricolari e dello stato di servizio e ogni altro documento rilasciato dall'amministrazione militare sono redatti in modo da non fare alcun riferimento alla causa della inidoneita' al servizio militare.

2. Le comunicazioni degli specifici motivi della inidoneita' al servizio militare, per cause fisiche o psichiche, sono fatte esclusivamente ai diretti interessati, dietro loro richiesta, e alle strutture sanitarie pubbliche.

## CAPO III - DOCUMENTAZIONE CARATTERISTICA

### Art. 1025. - Documenti caratteristici

1. Gli ufficiali, i sottufficiali, i graduati e i militari di truppa delle Forze armate sono sottoposti a valutazione mediante la compilazione di documenti caratteristici.

2. La valutazione si effettua per periodi non superiori all'anno e negli altri casi indicati dal regolamento.

3. I documenti caratteristici sono costituiti dalla scheda valutativa, dal rapporto informativo e dal foglio di comunicazione.

4. I documenti caratteristici dei volontari in ferma prefissata sono compilati, oltre al verificarsi dei casi di cui all'articolo 691 del regolamento, anche per la partecipazione alle procedure per la rafferma.

((

4-bis. La redazione della documentazione caratteristica e' condotta attraverso l'informatizzazione dei dati e l'uso della firma digitale.

))

### Art. 1026. - Qualifiche

1. I giudizi espressi nella scheda valutativa si concludono con l'attribuzione di una delle seguenti qualifiche: eccellente, superiore alla media, nella media, inferiore alla media, insufficiente.

### Art. 1027. - Comunicazione agli interessati

1. Il giudizio e la qualifica finali espressi nella scheda valutativa e il giudizio finale espresso nel rapporto informativo sono comunicati al militare nei modi stabiliti dal regolamento.

### Art. 1028. - Disposizioni di attuazione in materia di modelli di documenti caratteristici

1. Il modello dei documenti caratteristici, gli elementi in base ai quali compilarli, i periodi di tempo e gli altri casi in cui vanno compilati, le autorita' competenti alla compilazione e alla revisione degli stessi nonche' quant'altro occorra per la esecuzione del presente capo, sono stabiliti nel regolamento.

### Art. 1029. - Norme applicabili all'Arma dei carabinieri

1. Al personale dell'Arma dei carabinieri continua ad applicarsi l'articolo 10, comma 2, del decreto legislativo 28 luglio 1989, n. 271.

## TITOLO VII AVANZAMENTO CAPO I DISPOSIZIONI GENERALI

### Art. 1030. - Nozione e rapporti con altre fonti normative

1. L'avanzamento e' il complesso delle procedure autoritative e delle operazioni tecnico-amministrative, disciplinate dal presente titolo, necessarie per la progressione di carriera del personale militare.

2. In materia di avanzamento, gli obblighi di partecipazione procedimentale e di motivazione sono assolti secondo le modalita' previste nel presente titolo.

### Art. 1031. - Modalita' di avanzamento

1. L'avanzamento dei militari ((, ferme restando le modalita' e condizioni previste dal presente codice,)) ha luogo:

- a) ad anzianita';
- b) a scelta;
- c) a scelta per esami;
- d) per meriti eccezionali;
- e) per benemerenze d'istituto.

2. L'avanzamento a scelta riguarda gli ufficiali e i sottufficiali. 3 L'avanzamento a scelta per esami riguarda gli appartenenti al ruolo ispettori dell'Arma dei carabinieri e gli appartenenti ai ruoli marescialli delle Forze armate; per questi ultimi la procedura di avanzamento a scelta per esami avviene mediante concorso interno per titoli ed esami, le cui modalita' e i criteri di valutazione sono disciplinati con apposito decreto ministeriale. 4. L'avanzamento per benemerenze d'istituto riguarda esclusivamente gli appartenenti ai ruoli ispettori, sovrintendenti, appuntati e carabinieri.

### Art. 1032. - Elementi di giudizio

1. Le autorita' competenti esprimono i giudizi sull'avanzamento sulla base degli elementi risultanti dalla documentazione personale del valutando, tenendo conto, per gli ufficiali, della presenza dei particolari requisiti previsti dall'articolo 1093 e dell'eventuale frequenza del corso superiore di stato maggiore interforze.

2. Nelle valutazioni degli ufficiali del Corpo delle capitanerie di porto aventi grado non inferiore a capitano di vascello le autorita' competenti esprimono i giudizi sull'avanzamento, basandosi anche sugli elementi risultanti da uno speciale rapporto informativo del Ministero delle infrastrutture e dei trasporti per quanto attiene ai servizi d'istituto di competenza di tale amministrazione.

3. Le autorita' competenti hanno facolta' di interpellare qualunque superiore di grado, in servizio, che ha o che ha avuto alle dipendenze il valutando.

4. In ogni giudizio di avanzamento si tiene conto di tutti i precedenti di carriera del militare da giudicare.

### Art. 1033. - Personale militare femminile

1. L'avanzamento del personale militare femminile e' disciplinato dalle disposizioni vigenti per il personale militare maschile.

2. Al personale militare femminile in avanzamento si applica l'articolo 1495.

## CAPO II - AUTORITA' COMPETENTI A ESPRIMERE GIUDIZI SULL'AVANZAMENTO

### SEZIONE I - COMMISSIONI DI AVANZAMENTO PER GLI UFFICIALI

#### Art. 1034. - Denominazioni e composizione

1. Esprimono giudizi sull'avanzamento ad anzianita' e a scelta degli ufficiali:

- a) le Commissioni di vertice nei riguardi degli ufficiali aventi grado di generale di divisione e corrispondenti;
- b) le Commissioni superiori di avanzamento nei riguardi degli ufficiali aventi grado da tenente colonnello a generale di brigata e corrispondenti;
- c) le Commissioni ordinarie di avanzamento nei riguardi degli ufficiali in servizio permanente aventi grado da sottotenente a maggiore e corrispondenti;
- d) i superiori gerarchici per gli ufficiali di complemento.

2. I componenti delle commissioni di avanzamento devono appartenere ai ruoli del servizio permanente effettivo, salvo che ricoprano cariche ((di cui all'articolo 1094, comma 3)).

3. Non possono far parte delle commissioni di avanzamento gli ufficiali che ricoprono una delle seguenti cariche:

- a) Ministro o Sottosegretario di Stato presso qualsiasi amministrazione;
- b) Capo di Gabinetto del Ministero della Difesa o presso qualsiasi altra amministrazione;
- c) Comandante generale della Guardia di finanza;
- d) Consigliere militare del Presidente della Repubblica;
- e) Consigliere militare del Presidente del Consiglio dei Ministri.

4. Non possono, inoltre, far parte delle predette commissioni gli ufficiali:

- a) impiegati presso il dipartimento e le agenzie per le informazioni e la sicurezza di cui alla legge 3 agosto 2007, n. 124;
- b) impiegati presso gli enti, comandi o unita' internazionali che hanno sede di servizio fuori dal territorio nazionale;
- c) impiegati presso il Dipartimento della Protezione Civile presso la Presidenza del Consiglio dei Ministri;
- d) temporaneamente a disposizione di altra amministrazione per incarichi non previsti dalle norme di ordinamento.

#### Art. 1035. - Norme procedurali

1. Le Commissioni di vertice e le Commissioni superiori di avanzamento, costituite presso ciascuna Forza armata, sono convocate dal Ministro della difesa su proposta del Capo di stato maggiore della difesa.

2. I componenti delle commissioni ordinarie di avanzamento sono annualmente designati e convocati dal Ministro della difesa su proposta del Capo di stato maggiore di Forza armata e del Comandante generale dell'Arma dei carabinieri.

3. I componenti delle commissioni si pronunciano con votazione palese in ordine inverso di grado e di anzianita'. Il presidente si pronuncia per ultimo.

4. Per la validita' delle deliberazioni delle Commissioni e' necessaria la presenza di almeno due terzi dei componenti con diritto al voto.

#### Art. 1036. - Commissione di vertice

1. Per la valutazione dei generali di divisione e gradi corrispondenti e' costituita presso ciascuna Forza armata una commissione di vertice di cui fanno parte i medesimi membri della commissione superiore d'avanzamento.

2. Il Capo di stato maggiore della difesa assume la presidenza di ciascuna commissione di vertice e il Capo di stato maggiore di Forza armata o il Comandante generale dell'Arma dei carabinieri ne assume la funzione di vice presidente.

#### Art. 1037. - Commissione superiore di avanzamento dell'Esercito italiano

1. La commissione superiore di avanzamento dell'Esercito italiano e' composta:

- a) dal Capo di stato maggiore dell'Esercito;
- a-bis) dal Sottocapo di Stato maggiore dell'Esercito;
- b) dai generali di corpo d'armata che sono preposti ai comandi collocati alle dipendenze dirette del Capo di stato maggiore dell'Esercito, con l'esclusione dei comandi internazionali e multinazionali all'estero e in Italia;
- c) dai due generali di corpo d'armata del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni piu' anziani in ruolo che hanno espletato o stanno espletando le funzioni del grado, che non ricoprono le cariche di cui ((alle lettere a-bis) e b) ove non compresi nei generali di corpo d'armata di cui alle lettere a-bis) e b);));
- d) dall'ufficiale generale piu' elevato in grado e piu' anziano dei singoli Corpi se si tratta di valutare ufficiali appartenenti ai rispettivi Corpi;
- e) dall'ufficiale piu' elevato in grado e piu' anziano dell'Arma dei trasporti e dei materiali, se non ricopre l'incarico di Comandante logistico, quando si tratta di valutare ufficiali appartenenti a tale Arma.

2. Assume la presidenza della commissione superiore di avanzamento il Capo di stato maggiore dell'Esercito o, in caso di assenza o di impedimento, il generale di corpo d'armata o grado corrispondente piu' anziano di grado e, a parita' di anzianita' di grado, piu' anziano di eta' tra i presenti.

#### Art. 1038. - Commissione superiore di avanzamento della Marina militare

1. La commissione superiore di avanzamento della Marina militare e' composta:

- a) dal Capo di stato maggiore della Marina;
- b) dagli ammiragli di squadra che sono o sono stati preposti al comando in capo di forze navali al comando scuole della Marina militare o al comando logistico della Marina militare;
- c) dall'ammiraglio di squadra piu' anziano in ruolo, non compreso tra gli ammiragli di cui alle lettere a) e b);
- d) dal Sottocapo di stato maggiore della Marina, qualora ammiraglio di squadra non compreso tra gli ammiragli di cui alle lettere b) e c);
- e) dall'ufficiale ammiraglio non appartenente al corpo di stato maggiore piu' elevato in grado, o piu' anziano degli altri corpi della Marina, se la valutazione riguarda ufficiali del rispettivo corpo.

2. Assume la presidenza della commissione superiore di avanzamento il Capo di stato maggiore della Marina o, in caso di assenza o di impedimento, l'ammiraglio di squadra o grado corrispondente piu' anziano di grado e, a parita' di anzianita' di grado, piu' anziano di eta' tra i presenti.

#### Art. 1039. - Commissione superiore di avanzamento dell'Aeronautica militare

1. La commissione superiore di avanzamento dell'Aeronautica militare e' composta:

- a) dal Capo di stato maggiore dell'Aeronautica;
- b) dai quattro generali di squadra aerea piu' anziani in ruolo che non ricoprono la carica di cui alla lettera a) e che hanno svolto le funzioni di Sottocapo di stato maggiore dell'Aeronautica o che sono o sono stati preposti a comandi di grande unita' ((aerea)) ovvero ad alto comando di vertice nei settori operativo, tecnico logistico o addestrativo, nonche' dal Sottocapo di stato maggiore dell'Aeronautica ove non compreso nei predetti generali e in possesso del grado di generale squadra aerea;
- c) dall'ufficiale generale piu' elevato in grado, o piu' anziano, dell'Arma aeronautica ruolo delle armi o del Corpo del genio aeronautico, o del Corpo di commissariato aeronautico, o del Corpo sanitario aeronautico, se la valutazione riguarda gli ufficiali della rispettiva Arma o Corpo.

2. Assume la presidenza della commissione superiore di avanzamento il Capo di stato maggiore dell'Aeronautica o, in caso di assenza o di impedimento, il generale di squadra aerea o grado corrispondente piu' anziano di grado e, a parita' di anzianita' di grado, piu' anziano di eta' tra i presenti.

#### Art. 1040. - Commissione superiore d'avanzamento dell'Arma dei carabinieri

1. La commissione superiore di avanzamento dell'Arma dei carabinieri e' composta:

- a) dal Comandante generale dell'Arma dei carabinieri;
- b) dai generali di corpo d'armata dell'Arma dei carabinieri;
- c) dall'ufficiale generale piu' elevato in grado o piu' anziano del ruolo tecnico((...)) se la valutazione riguarda gli ufficiali di detto ruolo. c-bis). dall'ufficiale generale piu' elevato in grado o piu' anziano del ruolo forestale dell'Arma dei carabinieri se la valutazione riguarda gli ufficiali di detto ruolo.

2. Assume la presidenza della commissione superiore di avanzamento il Comandante generale dell'Arma dei carabinieri o, in caso di assenza o di impedimento, il generale di corpo d'armata piu' anziano di grado e, a parita' di anzianita' di grado, piu' anziano di eta' tra i presenti.

#### Art. 1041. - Altri membri delle Commissioni di vertice e superiori di avanzamento

1. Il Segretario generale del Ministero della difesa, ovvero il Vice Segretario generale militare se il Segretario generale riveste qualifica dirigenziale civile, ((e il Direttore nazionale degli armamenti, ovvero il Vice direttore nazionale degli armamenti militare se il Direttore nazionale degli armamenti riveste qualifica dirigenziale civile, partecipano, quali componenti,)) alla commissione di vertice della Forza armata di appartenenza, se non gia' previsto dall'articolo 1036. E' obbligatoriamente consultato dalle Commissioni di vertice allorche' la valutazione riguardi ufficiali di Forza armata diversa da quella di appartenenza in servizio presso uffici od organi dipendenti.

2. ((Il Vice Segretario generale e il Vice Direttore nazionale degli armamenti del Ministero della difesa, se militari,)) nonche' il Sottocapo di stato maggiore della difesa partecipano, quali componenti, alle Commissioni superiori di avanzamento della Forza armata di appartenenza, se non gia' previsto dagli articoli precedenti. Sono obbligatoriamente consultati dalle Commissioni superiori di avanzamento:

- a) ((il Vice Segretario generale e il Vice Direttore nazionale degli armamenti del Ministero della difesa, se militari,)) quando le Commissioni valutano gli ufficiali di Forza armata diversa da quella di appartenenza, in servizio presso gli organi dell'area centrale tecnico amministrativa;
- b) il Sottocapo di stato maggiore della difesa quando le Commissioni valutano gli ufficiali di Forza armata diversa da quella di appartenenza, in servizio presso gli organi interforze dell'area tecnico operativa.

#### Art. 1042. - Commissione ordinaria di avanzamento dell'Esercito italiano

1. La commissione ordinaria di avanzamento dell'Esercito italiano e' composta:

- a) da un generale di corpo d'armata, che la presiede;
- b) da un generale di divisione;
- c) da cinque ((generali di brigata o)) colonnelli del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni;
- d) da un ((brigadier generale o)) colonnello dell'Arma dei trasporti e dei materiali o dei Corpi, se la valutazione riguarda ufficiali della predetta Arma o dei Corpi;
- e) da un colonnello dei ruoli speciali delle Armi o dei Corpi, se la valutazione riguarda ufficiali dei predetti ruoli.

2. In caso di assenza o di impedimento del presidente assume la presidenza l'ufficiale piu' elevato in grado e, a parita' di grado, il piu' anziano.

#### Art. 1043. - Commissione ordinaria di avanzamento della Marina militare

1. La commissione ordinaria di avanzamento della Marina militare e' composta:

- a) da un ammiraglio di squadra, che la presiede;
- b) da quattro ufficiali ammiragli o capitani di vascello del Corpo di stato maggiore;
- c) da un ufficiale di grado non inferiore a capitano di vascello ((di ciascuno degli altri corpi o specialita' della Marina, se la valutazione riguarda ufficiali del rispettivo Corpo o specialita')). ((37))

2. In caso di assenza o di impedimento del presidente assume la presidenza l'ufficiale piu' elevato in grado e, a parita' di grado, il piu' anziano.

------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica si applica a decorrere dal 1° gennaio 2017.

#### Art. 1044. - Commissione ordinaria di avanzamento dell'Aeronautica militare

1. La commissione ordinaria di avanzamento dell'Aeronautica militare e' composta:

- a) da un generale di squadra aerea, che la presiede;
- b) da quattro ufficiali generali o colonnelli del ruolo naviganti normale dell'Arma aeronautica;
- c) da un Ufficiale di grado non inferiore a colonnello del ruolo normale delle armi dell'Arma aeronautica, del Corpo del genio aeronautico, o di commissariato aeronautico o sanitario aeronautico, se la valutazione riguarda ufficiali della rispettiva Arma o Corpo.

2. In caso di assenza o di impedimento del presidente assume la presidenza l'ufficiale piu' elevato in grado e, a parita' di grado, il piu' anziano.

#### Art. 1045. - Commissione ordinaria di avanzamento dell'Arma dei carabinieri

1. La commissione ordinaria di avanzamento dell'Arma dei carabinieri e' composta:

- a) dal Vice comandante generale dell'Arma dei carabinieri, presidente;
- b) da un generale di ((corpo d'armata o di)) divisione ((del ruolo normale)) dell'Arma dei carabinieri;
- c) da cinque ((generali di brigata o)) colonnelli del ruolo normale dell'Arma dei carabinieri;
- d) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95));
- e) da un ((generale di brigata o)) colonnello del comparto di appartenenza dell'ufficiale da valutare, se la valutazione riguarda gli ufficiali del ruolo ((tecnico));
- e-bis) da un ((generale di brigata o)) colonnello del ruolo forestale dell'Arma dei carabinieri, se la valutazione riguarda ufficiali di detto ruolo.

2. In caso di assenza o di impedimento del presidente assume la presidenza l'ufficiale piu' elevato in grado e, a parita' di grado, il piu' anziano.

#### Art. 1046. - Altri membri delle Commissioni ordinarie di avanzamento

1. Alle Commissioni ordinarie partecipa il Direttore generale della Direzione generale per il personale militare, esprimendo parere sull'idoneita' all'avanzamento.

2. In caso di assenza o di impedimento puo' essere rappresentato da un ufficiale di grado non inferiore a colonnello, destinato alla Direzione generale, possibilmente appartenente alla medesima Forza armata dell'ufficiale da valutare.

### SEZIONE II - COMMISSIONI DI AVANZAMENTO PER I SOTTUFFICIALI, I GRADUATI E I MILITARI DI TRUPPA

#### Art. 1047. - Commissioni permanenti

1. Per la valutazione ai fini dell'avanzamento ad anzianita' e a scelta, per la compilazione dei relativi quadri nonche' per l'attribuzione delle qualifiche del personale appartenente a ciascuno dei ruoli marescialli, sergenti e volontari in servizio permanente, sono istituite presso l'Esercito italiano, la Marina militare e l'Aeronautica militare commissioni permanenti.

2. Ciascuna delle commissioni di cui al comma 1 e' cosi' composta:

- a) presidente: ufficiale generale;
- b) membri ordinari: 1) ufficiali superiori in numero non superiore a tredici, dei quali il piu' anziano assume il ruolo di vicepresidente e il meno anziano quello di segretario; 2) il piu' anziano del ruolo a cui appartiene il personale da valutare alla data del 1° gennaio dell'anno considerato e che possa far parte della commissione almeno per l'intero anno solare;
- c) membri supplenti.

3. Per eventuali esigenze connesse alla tempistica delle operazioni di valutazione e ai carichi di lavoro, possono essere istituite una o piu' sottocommissioni, le cui attivita' sono subordinate e funzionali a quella della commissione di cui al comma 1, dalla quale dipendono. Le sottocommissioni, ove istituite, sono cosi' composte:

- a) presidente: ufficiale di grado inferiore a quello del presidente della commissione di cui al comma 1 e non inferiore a tenente colonnello;
- b) membri ordinari: 1) ufficiali superiori in numero non superiore a sette, dei quali il piu' anziano assume il ruolo di vicepresidente e il meno anziano quello di segretario; 2) un militare di grado apicale del ruolo cui appartiene il personale da valutare alla data del 1° gennaio dell'anno considerato e che possa far parte della commissione almeno per l'intero anno solare;
- c) membri supplenti.

4. Per la valutazione ai fini dell'avanzamento ad anzianita' e a scelta e per la compilazione dei quadri del personale appartenente ai ruoli ispettori, sovrintendenti e appuntati e carabinieri e gradi corrispondenti e' istituita una commissione permanente per l'Arma dei carabinieri, costituita come segue: ((a) presidente: non inferiore a generale di divisione)); b) membri ordinari: sette ufficiali superiori, dei quali il piu' anziano assume il ruolo di vice presidente e il meno anziano quello di segretario; tre luogotenenti o un brigadiere capo ovvero un appuntato scelto, rispettivamente se si tratta di valutazione di personale del ruolo ispettori, sovrintendenti ovvero appuntati e carabinieri, che possano far parte della commissione almeno per l'intero anno solare, a cui si riferiscono le valutazioni da effettuare. b-bis) membri supplenti.

5. Il giudizio di idoneita' per l'avanzamento dei militari di truppa, che comporta la valutazione delle qualita', capacita' e attitudini in rapporto ai compiti da svolgere nel grado superiore, e in relazione alle esigenze di quegli incarichi nel reparto, e' espresso da una apposita commissione costituita presso ciascun corpo o reparto d'impiego, composta da almeno tre membri nominati dal comandante di corpo. Per la partecipazione alla commissione non e' prevista la corresponsione di alcuna indennita' o compenso ne' rimborso spese.

#### Art. 1048. - Attribuzioni speciali delle commissioni permanenti

1. Le commissioni permanenti di avanzamento, se necessario, sono chiamate a pronunciarsi anche sulle ammissioni o esclusioni o ripetizioni dei corsi, degli esami e degli esperimenti e negli altri casi previsti dal presente codice.

2. Il parere delle commissioni permanenti di avanzamento puo' essere sentito, altresi', se e' ritenuto necessario dal Ministro della difesa.

3. La commissione permanente di avanzamento per l'Arma dei carabinieri e' competente a pronunciarsi anche sulla idoneita' alla nomina nel complemento, ai sensi dell'articolo 1004.

#### Art. 1049.

((ARTICOLO ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173))

## CAPO III - VALUTAZIONI PER L'AVANZAMENTO

### SEZIONE I - ALIQUOTE DI AVANZAMENTO

#### Art. 1050. - Disposizioni generali

1. L'ufficiale, per essere valutato per l'avanzamento ad anzianita' o a scelta, deve trovarsi compreso in apposite aliquote di ruolo, la cui formazione e' disciplinata dall'articolo 1053.

2. Il grado e l'ordine di anzianita' degli ufficiali, ai fini dell'avanzamento, risultano dai ruoli formati ai sensi delle norme sullo stato giuridico.

3. Il personale appartenente ai ruoli dei marescialli, degli ispettori, dei sergenti, dei sovrintendenti e dei volontari in servizio permanente, da valutare per l'avanzamento, deve essere incluso in apposite aliquote definite con decreto ministeriale al 31 dicembre di ogni anno.

4. Nelle aliquote di valutazione di cui al comma 3 e' incluso tutto il personale che alla data del 31 dicembre ha compiuto i previsti periodi minimi di comando, di attribuzioni specifiche, di servizio, di imbarco e ha superato gli eventuali corsi ed esami prescritti; l'ammissione all'avanzamento per il personale appartenente al ruolo appuntati e carabinieri e' disciplinata dall'articolo 1311.

#### Art. 1051. - Impedimenti, sospensione ed esclusione

1. Non puo' essere valutato per l'avanzamento il militare che ricopra la carica di Ministro o di Sottosegretario di Stato.

2. Non puo' essere inserito nell'aliquota di avanzamento o valutato per l'avanzamento il personale militare: ((a) nei cui confronti sia stata emessa, per delitto non colposo, sentenza di condanna in primo grado ovvero sentenza di applicazione della pena su richiesta o decreto penale di condanna esecutivo, anche qualora la pena sia condizionalmente sospesa)); b) sottoposto a procedimento disciplinare da cui puo' derivare una sanzione di stato; c) sospeso dall'impiego o dalle funzioni del grado; d) in aspettativa per qualsiasi motivo per una durata non inferiore a 60 giorni.

2-bis. Il personale dell'Arma dei carabinieri imputato in un procedimento penale per delitto non colposo e ammesso al prolungamento della ferma volontaria ai sensi dell'articolo 950, non e' inserito nell'aliquota di avanzamento o valutato per l'avanzamento, fino all'ammissione in servizio permanente.

3. Se eccezionalmente le autorita' competenti ritengono di non poter addivenire alla pronuncia del giudizio sull'avanzamento, sospendono la valutazione, indicandone i motivi.

4. Se, durante i lavori della competente commissione d'avanzamento e prima della pubblicazione del quadro di avanzamento o della conclusione dei lavori di valutazione per gli Appuntati e Carabinieri, il personale militare si trova nelle situazioni previste dal comma 2, e' sospesa la valutazione o, se il quadro e' stato formato, il direttore generale del personale militare ne dispone la cancellazione.

5. Al militare e' data comunicazione della sospensione della valutazione e dei motivi che l'hanno determinata.

6. Nei riguardi del personale escluso dalle aliquote o dalla valutazione, per non aver maturato, per motivi di servizio o di salute, le condizioni di cui all'articolo 1050, ovvero escluso ai sensi del comma 2 o sospeso ai sensi dei commi 3 e 4, e' apposta riserva fino al cessare delle cause impeditive.

7. Al venir meno delle predette cause, salvo che le stesse non comportino la cessazione dal servizio permanente, gli interessati sono inclusi nella prima aliquota utile per la valutazione o sono sottoposti a valutazione.

8. Il personale militare inserito nei ruoli del servizio permanente che e' stato condannato con sentenza definitiva a una pena non inferiore a due anni per delitto non colposo compiuto mediante comportamenti contrari ai doveri di fedelta' alle istituzioni ovvero lesivi del prestigio dell'amministrazione e dell'onore militare e' escluso da ogni procedura di avanzamento e dalla possibilita' di transito da un ruolo a un altro.

#### Art. 1051-bis. - (( (Promozioni in particolari situazioni).))

((

1. A decorrere dal 1° luglio 2017, il militare, che e' deceduto ovvero e' stato collocato in congedo per limite di eta' o per invalidita' permanente dopo aver maturato la permanenza minima nel grado per l'inserimento nell'aliquota di avanzamento ad anzianita' o per l'attribuzione delle qualifiche di primo luogotenente, di carica speciale o di qualifica speciale ovvero, se appartenente al ruolo appuntati e carabinieri o corrispondenti ruoli forestali dell'Arma dei carabinieri, dopo aver conseguito il requisito temporale per l'avanzamento al grado superiore o per l'attribuzione della qualifica speciale, e' comunque valutato e, previo giudizio di idoneita', e' promosso al grado superiore ovvero, previa verifica del possesso dei relativi requisiti, consegue la prevista qualifica.

))

#### Art. 1052. - Militare in aspettativa

1. Al militare in aspettativa per infermita', ai fini dell'avanzamento, si applica 905, comma 6.

#### Art. 1053. - Formazione delle aliquote di valutazione degli ufficiali

1. Il ((15 settembre)) di ogni anno, il Direttore generale della Direzione generale per il personale militare, con apposite determinazioni, indica per ciascuna Forza armata, per ciascun grado e ruolo, gli ufficiali da valutare per la formazione dei quadri di avanzamento per l'anno successivo. In tali determinazioni sono inclusi:

- a) gli ufficiali non ancora valutati che, alla data suddetta, hanno raggiunto tutte le condizioni prescritte dall'articolo 1093;
- b) gli ufficiali gia' giudicati idonei e non iscritti in quadro;
- c) gli ufficiali da valutare o rivalutare perche' sono venute a cessare le cause che ne avevano determinato la sospensione della valutazione o della promozione.

1-bis. A decorrere dal 31 ottobre 2017, i contrammiragli del corpo del genio della Marina sono inclusi in un'aliquota unica di valutazione indipendentemente dalla specialita' di provenienza, con l'ordine di iscrizione derivante dall'anzianita' relativa definita a tal fine sulla base dell'applicazione dei seguenti criteri in ordine successivo:

- a) a parita' di anzianita' assoluta, l'ordine di precedenza e' determinato dalla maggiore eta' anagrafica;
- b) a parita' di eta' si raffrontano in successione le anzianita' assolute nei gradi inferiori fino a quello in cui non si riscontra parita' di anzianita';
- c) se si riscontra parita' anche nell'anzianita' assoluta di nomina, e' considerato piu' anziano colui che ha maggior servizio effettivo.

2. COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8.

3. COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8.

4. Il Direttore generale della Direzione generale per il personale militare con proprie determinazioni indica, altresi', gli ufficiali che non possono essere valutati per l'avanzamento per non aver raggiunto le condizioni prescritte dagli articoli 1093 e 1096. Essi sono poi inclusi nella prima determinazione annuale dell'aliquota successiva alla data del raggiungimento delle predette condizioni.

#### Art. 1054. - Anzianita' minime di grado richieste per gli ufficiali

1. Ai fini della determinazione delle anzianita' minime di grado richieste per l'inclusione nelle aliquote di valutazione, si fa riferimento all'anno solare di conferimento del grado rivestito.

### SEZIONE II - AVANZAMENTO AD ANZIANITA'

#### Art. 1055. - Avanzamento ad anzianita' degli ufficiali

1. L'avanzamento ad anzianita' si effettua promuovendo gli ufficiali nell'ordine di iscrizione nel rispettivo ruolo, con le modalita' previste dall'articolo 1071, commi 3 e 4.

2. Le competenti commissioni esprimono i giudizi sull'avanzamento ad anzianita' dichiarando se l'ufficiale sottoposto a valutazione e' idoneo o non idoneo all'avanzamento.

3. E' giudicato dalla commissione idoneo all'avanzamento l'ufficiale che riporta un numero di voti favorevoli superiore alla meta' dei votanti.

4. Gli ufficiali che hanno riportato giudizio di idoneita' e gli ufficiali che hanno riportato giudizio di non idoneita' sono iscritti dalla commissione in due distinti elenchi, in ordine di ruolo.

#### Art. 1056. - Avanzamento ad anzianita' dei sottufficiali e dei volontari in servizio permanente

1. Il personale appartenente ai ruoli dei marescialli, degli ispettori, dei sergenti, dei sovrintendenti e dei volontari in servizio permanente, iscritto nel quadro di avanzamento ad anzianita', e' promosso a ruolo aperto, secondo le modalita' previste dai commi successivi, con decorrenza dal giorno successivo a quello di compimento del periodo di permanenza nel grado previsto dal presente codice.

2. Le competenti commissioni esprimono i giudizi sull'avanzamento ad anzianita' dichiarando se il sottufficiale o il volontario in servizio permanente sottoposto a valutazione e' idoneo o non idoneo all'avanzamento. E' giudicato idoneo il sottufficiale che riporta un numero di voti favorevoli superiore alla meta' dei votanti.

3. Coloro che sono giudicati idonei sono iscritti nel quadro di avanzamento in ordine di ruolo.

4. A coloro che sono giudicati non idonei e' data comunicazione delle motivazioni del giudizio di non idoneita'.

5. Il personale appartenente ai ruoli dei marescialli, degli ispettori, dei sergenti, dei sovrintendenti e dei volontari in servizio permanente giudicato non idoneo e' valutato nuovamente e a tale fine e' incluso nell'aliquota di valutazione dell'anno successivo. Lo stesso, se giudicato per la seconda volta non idoneo, puo' essere ulteriormente valutato nel quarto anno successivo a ogni giudizio negativo. A tal fine e' incluso in aliquota di valutazione e, se giudicato idoneo, promosso con le stesse modalita' e con le stesse decorrenze attribuite ai pari grado con i quali e' stato portato in avanzamento.

((

5-bis. La promozione non e' attribuita nei casi in cui sia stato espresso parere non favorevole da parte della competente autorita' giudiziaria, ai sensi dell'articolo 15 delle Norme di attuazione, di coordinamento e transitorie del codice di procedura penale, approvate dal decreto legislativo 28 luglio 1989, n. 271. Il provvedimento di sospensione della promozione e' adottato con determinazione del Direttore generale della Direzione generale per il personale militare o del Comandante generale per il ruolo appuntati e carabinieri. In tal caso, il militare, e' sottoposto a nuova valutazione secondo quanto indicato nel comma 5.

))

6. Il personale appartenente ai predetti ruoli, escluso dalle aliquote per l'avanzamento ad anzianita', per i motivi di cui all'articolo 1051, e' promosso, se idoneo, con la stessa decorrenza attribuita ai pari grado con i quali sarebbe stato valutato in assenza delle cause impeditive, riacquistando l'anzianita' relativa precedentemente posseduta.

6-bis. I quadri d'avanzamento ad anzianita' sono pubblicati sui portali istituzionali della rispettiva Forza armata.

### SEZIONE III - AVANZAMENTO A SCELTA

#### Art. 1057. - Sistema di avanzamento a scelta degli ufficiali

1. Il giudizio di avanzamento a scelta degli ufficiali delle Forze armate discende da un'attivita' valutativa svolta dalle competenti commissioni di avanzamento, osservando le modalita' e i criteri stabiliti dalla presente sezione.

2. L'avanzamento a scelta si effettua promuovendo gli ufficiali nell'ordine risultante dalla graduatoria di merito o nell'ordine di iscrizione in ruolo.

3. Il giudizio di avanzamento a scelta si articola in due fasi, entrambe a carattere collegiale. La prima fase e' diretta ad accertare, ai sensi dell'articolo 1058, commi 1 e 2, l'idoneita' di ciascun ufficiale all'adempimento delle funzioni del grado superiore. La seconda fase, caratterizzata dall'applicazione dei criteri di cui all'articolo 1058, commi 4, 5, 6 e 7, e' volta a determinare, attraverso l'attribuzione di un punteggio di merito, la misura in cui si ritiene che le qualita', le capacita' e le attitudini sono possedute da ciascun ufficiale giudicato idoneo; sulla base di detto punteggio, e' conseguentemente formata la graduatoria di merito degli ufficiali giudicati idonei.

4. L'attribuzione dei punteggi rappresenta la sintesi del giudizio di merito assoluto espresso dalle commissioni di avanzamento nei confronti degli ufficiali idonei.

#### Art. 1058. - Giudizio di idoneita' e attribuzione del punteggio di merito

1. Le competenti commissioni esprimono i giudizi sull'avanzamento a scelta dichiarando anzitutto se l'ufficiale sottoposto a valutazione e' idoneo o non idoneo all'avanzamento.

2. E' giudicato dalla commissione idoneo all'avanzamento l'ufficiale che riporta un numero di voti favorevoli superiore ai due terzi dei votanti.

3. Gli ufficiali che hanno riportato giudizio di non idoneita' sono iscritti dalla commissione in un elenco in ordine di ruolo

4. A ciascun ufficiale giudicato idoneo la commissione attribuisce successivamente un punto di merito da uno a trenta e, in base al punto attribuito, compila una graduatoria di merito di detti ufficiali, dando, a parita' di punti, precedenza al piu' anziano in ruolo.

5. Il punto di merito e' attribuito dalla commissione con l'osservanza delle norme che seguono. Se il giudizio riguarda ufficiali aventi grado non superiore a colonnello o corrispondente, ogni componente della commissione assegna all'ufficiale un punto da uno a trenta per ciascun complesso di elementi di cui alle seguenti lettere:

- a) qualita' morali, di carattere e fisiche;
- b) benemerenze di guerra e comportamento in guerra e qualita' professionali dimostrate durante la carriera, specialmente nel grado rivestito, con particolare riguardo all'esercizio del comando o delle attribuzioni specifiche, se richiesti dal presente codice ai fini dell'avanzamento, al servizio prestato presso reparti o in imbarco;
- c) doti intellettuali e di cultura con particolare riguardo ai risultati di corsi, esami, esperimenti;
- d) attitudine ad assumere incarichi nel grado superiore, con specifico riferimento ai settori di impiego di particolare interesse per l'amministrazione.

6. Le somme dei punti assegnati per ciascun complesso di elementi di cui alle lettere a), b), c), d) sono divise per il numero dei votanti, e i relativi quozienti, calcolati al centesimo, sono sommati tra di loro. Il totale cosi' ottenuto e' quindi diviso per quattro, calcolando il quoziente, al centesimo. Detto quoziente costituisce il punto di merito attribuito all'ufficiale dalla commissione.

7. Se il giudizio riguarda ufficiali aventi grado di generale di divisione o di brigata o ufficiali di grado corrispondente, ogni componente della commissione assegna all'ufficiale un punto da uno a trenta in relazione agli elementi indicati nelle precedenti lettere a), b), c), d) considerati nel loro insieme; la somma dei punti cosi' assegnati e' divisa per il numero dei votanti, calcolando il quoziente al centesimo. Detto quoziente costituisce il punto di merito attribuito all'ufficiale dalla commissione.

8. Nel regolamento sono riportate le ulteriori modalita' e i criteri riguardanti la procedura e i punteggi per l'avanzamento a scelta degli ufficiali di cui al presente articolo.

#### Art. 1059. - Avanzamento a scelta dei sottufficiali

1. Le competenti commissioni esprimono i giudizi sull'avanzamento a scelta dichiarando innanzitutto se il sottufficiale e' idoneo o non idoneo all'avanzamento. E' giudicato idoneo il sottufficiale che riporta un numero di voti favorevoli superiore alla meta' dei votanti.

2. Successivamente le commissioni valutano i sottufficiali giudicati idonei, attribuendo a ciascuno di essi un punto di merito secondo i criteri di seguito indicati.

3. Ogni componente della commissione assegna distintamente per ciascun sottufficiale un punto da 1 a 30 per ognuno dei seguenti complessi di elementi:

- a) qualita' morali, di carattere e fisiche;
- b) benemerenze di guerra e comportamento in guerra, benemerenze di pace, qualita' professionali dimostrate durante la carriera, specialmente nel grado rivestito, con particolare riguardo al servizio prestato presso reparti o in imbarco, eventuale attivita' svolta al comando di minori unita', nonche' numero e importanza degli incarichi ricoperti e delle specializzazioni possedute;
- c) doti culturali e risultati di corsi, esami ed esperimenti.

4. Le somme dei punti assegnati per ciascun complesso di elementi di cui alle lettere a), b) e c), sono divise per il numero dei votanti e i relativi quozienti, calcolati al centesimo, sono sommati tra loro. Il totale cosi' ottenuto e' quindi diviso per tre, calcolando il quoziente al centesimo. Detto quoziente costituisce il punto di merito attribuito al sottufficiale dalla commissione. Sulla base della graduatoria di merito risultante da tali punteggi la commissione compila il relativo quadro d'avanzamento.

5. I quadri d'avanzamento a scelta sono pubblicati sui portali istituzionali della rispettiva Forza armata.

6. Agli interessati e' data comunicazione, se idonei, del punteggio conseguito e, se non idonei, delle motivazioni del giudizio di non idoneita'.

7. Il personale appartenente ai ruoli dei marescialli, degli ispettori, dei sergenti e dei sovrintendenti giudicato non idoneo e' valutato nuovamente e a tal fine e' incluso nell'aliquota di valutazione dell'anno successivo. Lo stesso, se giudicato per la seconda volta non idoneo, puo' essere ulteriormente valutato nel quarto anno successivo a ogni giudizio negativo. A tal fine e' incluso in aliquota di valutazione e, se giudicato idoneo, promosso a scelta con le stesse modalita' e con le stesse decorrenze attribuite ai pari grado con i quali e' stato portato in avanzamento.

7-bis. Al personale appartenente ai ruoli di cui al comma 7, escluso dalle aliquote per l'avanzamento a scelta per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del presente titolo VII, in materia di rinnovazione dei giudizi di avanzamento.

((

7-ter. La promozione non e' attribuita nei casi in cui sia stato espresso parere non favorevole da parte della competente autorita' giudiziaria, ai sensi dell'articolo 15 delle Norme di attuazione, di coordinamento e transitorie del codice di procedura penale, approvate dal decreto legislativo 28 luglio 1989, n. 271. Il provvedimento di sospensione della promozione e' adottato con determinazione del Direttore generale della Direzione generale per il personale militare. In tal caso, il militare, e' sottoposto a nuova valutazione secondo quanto indicato nel comma 7.

))

#### Art. 1060. - Autonomia dei giudizi di avanzamento a scelta

1. I vari giudizi di avanzamento sono autonomi tra loro anche se la commissione d'avanzamento e' composta dagli stessi membri e il militare e' sempre preposto al medesimo incarico. L'eventuale diversita' di valutazioni, sia in senso positivo che negativo, concernente lo stesso militare, deve trovare giustificazione in elementi di giudizio intervenuti nel tempo e risultanti dalla documentazione di cui all'articolo 1032.

### SEZIONE IV - AVANZAMENTI STRAORDINARI

#### Art. 1061. - Avanzamento per meriti eccezionali degli ufficiali

1. L'avanzamento per meriti eccezionali puo' aver luogo nei riguardi dell'ufficiale che nell'esercizio delle sue attribuzioni ha reso eccezionali servizi alle Forze armate e che ha dimostrato di possedere qualita' intellettuali, di cultura e professionali, tali da dare sicuro affidamento di adempiere in modo eminente le funzioni del grado superiore.

2. Per essere proposto per l'avanzamento per meriti eccezionali l'ufficiale deve essere compreso nella prima meta' del ruolo del proprio grado, aver compiuto il prescritto periodo di comando o di attribuzioni specifiche e non aver gia' conseguito nel corso della carriera una promozione per meriti eccezionali.

3. L'avanzamento per meriti eccezionali si effettua promuovendo l'ufficiale con precedenza sui pari grado idonei all'avanzamento ad anzianita' o a scelta.

4. La proposta di avanzamento per meriti eccezionali e' formulata dal generale o ammiraglio in carica, dal quale l'ufficiale gerarchicamente dipende ed e' corredata dei pareri delle ulteriori autorita' gerarchiche.

5. Sulla proposta decide il Ministro, previo parere favorevole della competente commissione superiore di avanzamento, espresso a unanimita' di voti.

6. L'ufficiale riconosciuto dal Ministro meritevole dell'avanzamento per meriti eccezionali e' iscritto al primo posto nel quadro di avanzamento che e' formato dopo la data della decisione del Ministro. Se piu' ufficiali sono stati riconosciuti meritevoli dell'avanzamento per meriti eccezionali, essi sono iscritti in quadro, con precedenza sugli altri pari grado, in ordine di anzianita'.

7. Il decreto di promozione per meriti eccezionali ne reca la motivazione.

#### Art. 1062. - Avanzamento per meriti eccezionali dei sottufficiali e dei graduati

1. L'avanzamento straordinario per meriti eccezionali puo' aver luogo nei riguardi del personale, appartenente ai ruoli dei marescialli, degli ispettori, dei sergenti, dei sovrintendenti, dei volontari in servizio permanente e degli appuntati e carabinieri, che nell'esercizio delle proprie attribuzioni ha reso servizi di eccezionale importanza alle Forze armate e che ha dimostrato di possedere qualita' intellettuali, di cultura, professionali, cosi' preclare da dare sicuro affidamento di adempiere in modo eminente le funzioni del grado superiore.

2. La proposta di avanzamento per meriti eccezionali e' formulata dall'ufficiale generale o grado equiparato dal quale il suddetto personale gerarchicamente dipende ed e' corredata dei pareri delle autorita' gerarchiche superiori.

3. Sulla proposta decide, previo parere favorevole della competente commissione di avanzamento, espresso a unanimita' di voti:

- a) il Direttore generale del personale militare;
- b) il Comandante generale dell'Arma dei carabinieri, per il personale appartenente al ruolo appuntati e carabinieri.

4. Il personale, riconosciuto meritevole dell'avanzamento per meriti eccezionali, e' promosso con decorrenza dalla data della proposta. Nel caso di piu' sottufficiali con proposte di pari data, gli stessi sono promossi nell'ordine di iscrizione in ruolo.

5. Il decreto di promozione per meriti eccezionali ne reca la motivazione.

6. Il personale, promosso per meriti eccezionali, prende posto nel ruolo in base all'anzianita' di grado attribuitagli seguendo i pari grado aventi la stessa anzianita'.

6-bis. I ((luogotenenti)) e gradi corrispondenti conseguono la promozione per meriti eccezionali nel grado di sottotenente del ruolo speciale secondo gli ordinamenti di Forza armata ((o del ruolo normale per l'Arma dei carabinieri.)).

#### Art. 1063. - Avanzamento per benemerenze d'istituto del personale dell'Arma dei carabinieri

1. L'avanzamento straordinario per benemerenze di istituto puo' aver luogo nei riguardi del personale ispettori, sovrintendenti, appuntati e carabinieri che, effettivamente e personalmente, ha partecipato a operazioni di polizia di rilevante entita', dimostrando, nel portare a compimento le operazioni stesse, chiaro senso di responsabilita' e spiccate qualita' professionali e militari.

2. La proposta di avanzamento straordinario per benemerenze di istituto e' formulata dal comandante di corpo dal quale il personale gerarchicamente dipende ed e' corredata dei pareri delle altre autorita' gerarchiche.

3. Il personale riconosciuto meritevole dell'avanzamento straordinario per benemerenze di istituto e' promosso con decorrenza dalla data del fatto che ha determinato la proposta, o dalla data della proposta, se essa si riferisce a piu' fatti avvenuti in tempi diversi.

4. Le promozioni sono disposte con decreto ministeriale, previo parere favorevole della competente commissione di avanzamento, espresso a unanimita' di voti. Sulle proposte di promozione, inoltrate tramite gerarchico e corredate dalla necessaria documentazione, riguardanti gli appuntati e i carabinieri, pronuncia il giudizio decisivo il Comandante generale.

5. Per la formulazione della proposta d'avanzamento straordinario per benemerenze di istituto e per la conseguente promozione si prescinde dai requisiti relativi all'anzianita' di grado, da esami, periodi di comando o di impiego in incarichi di specializzazione, dalla esistenza o meno di vacanze nell'organico nel ruolo del grado superiore.

6. Le conseguenti eccedenze che si verificano nel ruolo del grado superiore, sono assorbite al formarsi della prima corrispondente vacanza.

7. L'avanzamento per benemerenze d'istituto e per meriti eccezionali si effettua anche se determinano il passaggio nel ruolo superiore.

### SEZIONE V - DISPOSIZIONI FINALI

#### Art. 1064. - Approvazione degli elenchi delle graduatorie degli ufficiali

1. Gli elenchi degli ufficiali idonei e dei non idonei e le graduatorie di merito sono sottoposti al Ministro, il quale li approva dopo aver eventualmente apportato, negli elenchi degli idonei e nelle graduatorie di merito, le esclusioni che giudica giuste e necessarie nell'interesse dell'amministrazione.

2. Gli ufficiali compresi negli elenchi degli idonei e nelle graduatorie di merito, approvati dal Ministro, sono idonei all'avanzamento.

3. Gli ufficiali compresi negli elenchi dei non idonei, approvati dal Ministro, sono non idonei all'avanzamento.

((

3-bis. Il Ministro puo' richiedere la documentazione afferente ai giudizi espressi dai membri delle competenti commissioni di avanzamento.

))

#### Art. 1065. - Ufficiali giudicati non idonei

1. Gli ufficiali, giudicati non idonei all'avanzamento, sono nuovamente valutati a distanza di un anno dal giudizio di non idoneita' e, se idonei e iscritti in quadro, sono promossi con anzianita' riferita all'anno per il quale sono stati valutati l'ultima volta.

2. Gli ufficiali, giudicati per la seconda volta non idonei all'avanzamento, sono ulteriormente valutati nel quarto anno successivo a ogni giudizio negativo e, se giudicati idonei e iscritti in quadro, promossi con anzianita' riferita all'anno per il quale sono stati valutati l'ultima volta.

#### Art. 1066. - Profili di carriera degli ufficiali

1. I profili di carriera e le modalita' di avanzamento degli ufficiali in servizio permanente nei vari gradi di ciascun ruolo di ogni Forza armata sono indicati nei capi VII, VIII, IX e X del presente titolo.

## CAPO IV - QUADRI DI AVANZAMENTO E PROMOZIONI

### SEZIONE I - FORMAZIONE DEI QUADRI DI AVANZAMENTO

#### Art. 1067. - Formazione dei quadri di avanzamento degli ufficiali

1. Il Direttore generale della Direzione generale per il personale militare, sulla scorta degli elenchi degli idonei e delle graduatorie di merito approvate dal Ministro della difesa, forma altrettanti quadri di avanzamento, iscrivendovi:

- a) per l'avanzamento ad anzianita', tutti gli ufficiali idonei, in ordine di ruolo;
- b) per l'avanzamento a scelta, gli ufficiali idonei, nell'ordine della graduatoria di merito, compresi nel numero di posti corrispondente a quello delle promozioni da effettuare, fatto salvo quanto previsto dall'articolo 1072-bis.
- c) LETTERA SOPPRESSA DAL D.LGS. 28 GENNAIO 2014, N. 8.

2. COMMA ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8.

3. I quadri di avanzamento hanno validita' per l'anno cui si riferiscono.

4. ((COMMA ABROGATO DAL D.LGS. 26 APRILE 2016, N. 91)).

5. Agli ufficiali valutati per l'avanzamento e' data comunicazione dell'esito dell'avanzamento.

#### Art. 1068. - Formazione dei quadri di avanzamento a seguito di eventuali esclusioni

1. Se un ufficiale e' tolto dal quadro di avanzamento a scelta per una delle cause stabilite dal presente codice, subentra nel quadro l'ufficiale che segue nella graduatoria di merito l'ultimo dei pari grado iscritti nel quadro stesso.

#### Art. 1069. - Cancellazione dai quadri per gli ufficiali

1. L'autorita', che ritiene che un dipendente ufficiale iscritto nel quadro di avanzamento abbia perduto uno dei requisiti previsti dal presente codice per l'avanzamento, inoltra, nei riguardi dell'ufficiale stesso, proposta di cancellazione dal quadro.

2. Sulla proposta, corredata dei pareri delle autorita' gerarchiche, decide il Ministro sentita la commissione superiore di avanzamento, se si tratta di ufficiale di grado non inferiore a tenente colonnello o corrispondente, ovvero la commissione ordinaria di avanzamento, se si tratta di ufficiale di altro grado.

3. Fino a quando non interviene la decisione del Ministro, gli effetti dell'iscrizione in quadro dell'ufficiale sono sospesi.

4. L'ufficiale cancellato dal quadro e' non idoneo all'avanzamento.

5. All'ufficiale e' data comunicazione dell'avvenuta cancellazione e dei motivi che l'hanno determinata.

### SEZIONE II - PROMOZIONI

#### Art. 1070. - Promozioni degli ufficiali

1. La promozione e' disposta con decreto del Presidente della Repubblica per gli ufficiali di grado non inferiore a generale di brigata e gradi corrispondenti e, previa deliberazione del Consiglio dei Ministri, per i generali di corpo d'armata e gradi corrispondenti.

2. Per i rimanenti gradi si provvede con decreto ministeriale.

#### Art. 1071. - Promozioni annuali degli ufficiali

1. Nei gradi in cui l'avanzamento ha luogo a scelta, il numero delle promozioni fisse annuali e' stabilito per ciascun grado dal presente codice.

1-bis. Nell'avanzamento a scelta al grado di maggiore e gradi corrispondenti di tutti i ruoli normali e speciali delle Armi e dei Corpi dell'Esercito italiano, della Marina militare e dell'Aeronautica militare il numero annuale di promozioni e' fissato in tante unita' quanti sono i capitani e gradi corrispondenti inseriti nell'aliquota di valutazione e giudicati idonei all'avanzamento.

2. Gli ufficiali iscritti nei quadri di avanzamento a scelta sono promossi ((alla data del 1° gennaio)) dell'anno cui si riferiscono i quadri stessi.

3. Le promozioni ad anzianita' sono conferite con decorrenza dal giorno del compimento delle anzianita' di grado richieste, in base alle disposizioni del presente codice.

4. Le promozioni di cui al presente articolo sono conferite anche in soprannumero agli organici previsti dalle norme vigenti. Le eventuali eccedenze che si determinano in applicazione delle norme di cui al presente comma sono assorbite con le vacanze che si verificano per cause diverse da quelle determinate dalle promozioni, salvo l'applicazione dell'aspettativa per riduzione dei quadri di cui agli articoli 906 e 907.

#### Art. 1072. - Promozioni non annuali degli ufficiali

1. Per i gradi nei quali le promozioni a scelta non si effettuano tutti gli anni, il Ministro della difesa, per gli anni in cui non sono previste promozioni, approva egualmente la graduatoria, ma il Direttore generale della Direzione generale per il personale militare forma il quadro di avanzamento solo se nel corso dell'anno si verificano una o piu' vacanze nei gradi rispettivamente superiori. ((Le conseguenti promozioni decorrono dalla data della vacanza.)) In tale caso, il nuovo ciclo di promozioni decorre dall'anno di apertura del quadro. ((110))

2. Se non diversamente stabilito dal presente codice, per i gradi degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, nei quali le promozioni a scelta non si effettuano tutti gli anni, il quadro di avanzamento e' formato computando gli anni precedenti nei quali non sono state disposte promozioni.

--------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 1072-bis. - Promozione dei tenenti colonnelli dell'Esercito italiano, della Marina militare, dell'Aeronautica militare e dell'Arma dei carabinieri).

1. In relazione all'andamento dei ruoli, fermo restando il numero di promozioni di cui alle tabelle 1, 2, 3 e 4, allegate al presente codice, per l'avanzamento a scelta al grado di colonnello e gradi corrispondenti, il numero delle promozioni da attribuire ai tenenti colonnelli e gradi corrispondenti con almeno tredici anni di anzianita' nel grado e' determinato annualmente con decreto del Ministro della difesa, di concerto con il Ministro delle infrastrutture e dei trasporti per il Corpo delle capitanerie di Porto, su proposta dei Capi di stato maggiore di Forza armata ovvero dei Comandanti generali dell'Arma dei carabinieri e del Corpo delle capitanerie di porto, in misura non superiore a: ((a) cinque per i ruoli normali delle Armi varie dell'Esercito, del Corpo di stato maggiore della Marina e dei naviganti dell'Arma aeronautica;)) ((a-bis) sette per il ruolo normale dell'Arma dei carabinieri;)) b) tre per i ruoli normali del Corpo delle capitanerie di porto e delle armi dell'Aeronautica militare; c) due per i ruoli normali del Corpo sanitario dell'Esercito, del Corpo del genio della Marina e del Corpo del genio aeronautico; (37) d) uno per i restanti ruoli normali e speciali dell'Esercito, della Marina e dell'Aeronautica.

2. Se le promozioni previste nell'anno sono pari o inferiori all'unita', il decreto di cui al comma 1 puo' essere adottato solo in casi eccezionali, opportunamente motivati.

------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che la presente modifica si applica a decorrere dal 1° gennaio 2017.

#### Art. 1072-ter. - (( (Ricostruzione della carriera in determinate situazioni per il personale dell'Esercito italiano, della Marina militare, dell'Aeronautica militare e dell'Arma dei Carabinieri). ))

((

1. Al personale militare, che ha ricoperto o ricopre incarichi non a termine presso altre pubbliche amministrazioni, per i quali e' prevista dalla legge o da altra fonte normativa la ricostruzione della carriera all'atto del rientro nell'amministrazione di appartenenza, salvo sussistano motivi ostativi previsti dalla legislazione vigente, e' conferita la promozione:

- a) fino al grado di tenente colonnello e corrispondenti con la medesima decorrenza attribuita al primo dei militari promossi che lo avrebbe seguito nei ruoli di provenienza;
- b) al grado di colonnello o di generale di brigata e corrispondenti qualora, oltre al possesso dei requisiti previsti dalle specifiche disposizioni normative, il medesimo personale abbia rivestito nei predetti incarichi la qualifica di dirigente di seconda fascia, rispettivamente, di livello intermedio o iniziale ovvero di quello apicale o superiore o equiparate, con la medesima decorrenza attribuita al primo dei militari promossi che lo avrebbe seguito nei ruoli di provenienza.

2. Gli ufficiali di cui al comma 1 sono riposizionati in ruolo in posizione immediatamente antecedente a quella conseguita dal pari aliquota promosso che ha ottenuto il miglior posizionamento tra coloro che lo seguivano nel ruolo e nel grado di provenienza.

3. Al rientro nell'amministrazione di appartenenza, il periodo di servizio prestato con l'incarico di generale di divisione o gradi corrispondenti presso altre pubbliche amministrazioni costituisce elemento di valutazione ai fini della nomina a generale di corpo d'armata e gradi corrispondenti.

4. Le disposizioni del presente articolo non si applicano in relazione al servizio prestato nel contingente speciale del personale addetto al Dipartimento delle informazioni per la sicurezza e ai servizi di informazione per la sicurezza di cui all'articolo 21 della legge 3 agosto 2007, n. 124.

))

#### Art. 1073. - Sospensione obbligatoria della promozione dell'ufficiale

1. E' sospesa la promozione dell'ufficiale, iscritto nel quadro di avanzamento, nel caso previsto dall'articolo 1051, comma 2.

2. La sospensione della promozione annulla la valutazione gia' effettuata.

3. All'ufficiale e' data comunicazione della sospensione della promozione.

#### Art. 1074. - Sospensione facoltativa della promozione dell'ufficiale

1. Il Ministro ha facolta' di sospendere, con propria determinazione, la promozione dell'ufficiale iscritto nel quadro di avanzamento, nei cui riguardi sono intervenuti fatti di notevole gravita'.

2. La sospensione della promozione annulla la valutazione gia' effettuata.

3. All'ufficiale e' data comunicazione della sospensione della promozione e dei motivi che l'hanno determinata.

#### Art. 1075. - Morte o permanente inidoneita' fisica dell'ufficiale

1. La morte dell'ufficiale o la permanente inidoneita' fisica derivante da ferite, lesioni o malattie riportate in servizio o per causa di servizio, non impedisce la promozione, quando l'ufficiale avrebbe potuto conseguirla con anzianita' anteriore alla data del decesso o del sopravvenire della non idoneita'.

#### Art. 1076.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

#### Art. 1077.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

### SEZIONE III - VACANZE ORGANICHE

#### Art. 1078. - Determinazione delle vacanze organiche per i gradi di ufficiale

1. Determinano vacanze organiche:

- a) le promozioni;
- b) le cessazioni dal servizio permanente;
- c) i trasferimenti in altro ruolo;
- d) i collocamenti in soprannumero agli organici;
- e) i decessi.

2. Le vacanze decorrono dalla data in cui si verificano le cause che le hanno determinate nei casi di cui alle lettere a), b), c) e d) e per la lettera e) dal giorno successivo a quello del decesso.

#### Art. 1079. - Modalita' per colmare ulteriori vacanze organiche degli ufficiali

1. Se per gli ufficiali, effettuate in un grado le promozioni stabilite per l'anno dal presente codice, si constatano al 1° luglio ulteriori vacanze nel grado superiore, le stesse sono colmate con promozioni aggiuntive ((decorrenti in pari data)). Le stesse non possono eccedere un decimo del numero delle promozioni da effettuare nell'anno e comunque, non possono essere inferiori all'unita'. ((110))

2. Se il numero degli ufficiali dichiarati idonei all'avanzamento a scelta e' inferiore al numero delle promozioni stabilite per l'anno dalle speciali disposizioni del presente codice, le promozioni non effettuate sono portate in aumento al numero delle promozioni da effettuare nell'anno immediatamente successivo.

3. Nel caso di cui al comma 2, il Ministro della difesa ha facolta' di richiamare in servizio gli ufficiali dall'aspettativa per riduzione dei quadri ovvero dall'ausiliaria.

--------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

#### Art. 1080. - Vacanze derivanti da collocamenti in soprannumero degli ufficiali

1. Le vacanze derivanti dai collocamenti in soprannumero non sono colmate con promozioni se nei corrispondenti gradi esistono eccedenze o soprannumeri determinati da altre cause.

#### Art. 1081. - Contingente dell'Arma dei carabinieri per la Banca d'Italia

1. Ai fini dell'avanzamento, le vacanze determinate nei vari gradi dai collocamenti in soprannumero all'organico per la dotazione del contingente di ufficiali, ispettori, sovrintendenti e graduati dell'Arma dei carabinieri per l'esecuzione di speciali servizi di vigilanza e scorta valori della Banca d'Italia, sono ripianate sotto la data in cui i collocamenti stessi sono disposti. 2, Le eccedenze conseguenti a cessazione dal soprannumero all'organico sono assorbite al verificarsi della prima vacanza.

### SEZIONE IV - PROMOZIONI ALL'ATTO DEL COLLOCAMENTO IN CONGEDO

#### Art. 1082.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

#### Art. 1083.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

#### Art. 1084. - Personale militare che cessa dal servizio per infermita'

1. Ai militarideceduti o divenuti permanentemente inidonei al servizio per ferite, lesioni o malattie riportate in servizio e per causa di servizio durante l'impiego in attivita' operative o addestrative, e' attribuita la promozione al grado superiore il giorno precedente la cessazione dal servizio, previo parere favorevole della competente commissione d'avanzamento, che tiene conto delle circostanze nelle quali si e' verificato l'evento. La promozione e' attribuita anche oltre il grado massimo previsto per il ruolo. ((Ai luogotenenti, e gradi corrispondenti, puo' essere attribuita la promozione al grado di sottotenente e corrispondenti, dei ruoli speciali degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare per il personale delle Forze armate e nel ruolo normale per il personale dell'Arma dei carabinieri.)) Se la promozione comporta la corresponsione di un trattamento economico inferiore a quello in godimento, all'interessato e' attribuito un assegno personale pensionabile pari alla differenza tra il trattamento economico in godimento e quello spettante nel nuovo grado.

#### Art. 1084-bis. - (Promozione a titolo onorifico per il personale militare che cessa dal servizio)

1. A decorrere dal 1° gennaio 2015, ai militari in servizio permanente, che nell'ultimo quinquennio hanno prestato servizio senza demerito, e' attribuita la promozione ad anzianita' al grado superiore a decorrere dalla data di cessazione dal servizio nei casi di:

- a) raggiungimento del limite di eta';
- b) collocamento a domanda in ausiliaria o riserva nei casi previsti dalla legislazione vigente;
- c) infermita';
- d) rinuncia al transito nell'impiego civile di cui all'articolo 923, comma 1, lettera m-bis).

2. La promozione di cui al comma 1 e' attribuita anche ai militari in servizio permanente deceduti, a decorrere dal giorno antecedente al decesso.

2-bis. Per il personale dell'Arma dei carabinieri, la promozione di cui al comma 1 e' altresi' attribuita, su istanza dell'interessato, anche ai militari cessati a domanda e collocati in ausiliaria o nella riserva fino al 31 dicembre 2014, che non hanno potuto beneficiare di alcuna promozione, a vario titolo, all'atto della cessazione dal servizio.

3. La promozione di cui ai commi 1 e 2 e' esclusa per i militari destinatari della promozione di cui all'articolo 1084 nonche' per gli ufficiali che rivestono il grado di generale di corpo d'armata e gradi corrispondenti e per i marescialli, sergenti e graduati che rivestono il grado apicale del ruolo di appartenenza.

4. Ai militari che ai sensi del comma 3 non conseguono la promozione di cui ai commi 1 e 2, e' attribuita, ove prevista, la carica o qualifica ((relativa al corrispettivo grado apicale)).

5. L'attribuzione della promozione o della carica o qualifica ((relativa al corrispettivo grado apicale)) di cui al presente articolo non produce alcun effetto sui trattamenti economico, previdenziale e pensionistico.

6. Nei casi previsti dai commi 1 e 2, ai militari cessati dal servizio dal 1° gennaio 2015 e fino al giorno antecedente alla data di entrata in vigore del presente articolo, la promozione e' attribuita secondo le decorrenze previste dalle disposizioni vigenti anteriormente a tale ultima data.

## CAPO V - RINNOVAZIONE DEI GIUDIZI DI AVANZAMENTO

### Art. 1085. - Cessazione delle cause impeditive della valutazione o della promozione degli ufficiali

1. L'ufficiale non valutato o non promosso a norma dell'articolo 1051, comma 2 e dell'articolo 1073, perche' sottoposto a procedimento disciplinare o perche' sospeso dall'impiego o perche' in aspettativa per infermita', e' valutato o nuovamente valutato per l'avanzamento, cessata la causa impeditiva della valutazione o della promozione e, nel caso di detrazioni di anzianita' ai sensi del presente codice, se risulta piu' anziano di un pari grado gia' valutato. Se l'avanzamento ha luogo a scelta la valutazione e' effettuata in occasione della formazione della prima graduatoria successiva alla cessazione della causa impeditiva.

2. All'ufficiale nei cui riguardi il procedimento disciplinare si e' concluso in senso favorevole o per il quale e' stata revocata la sospensione dall'impiego di carattere precauzionale o che e' stato in aspettativa per infermita' dipendente da causa di servizio, quando e' valutato o nuovamente valutato, si applicano le disposizioni seguenti:

- a) l'ufficiale appartenente a grado nel quale l'avanzamento ha luogo ad anzianita', se giudicato idoneo e gia' raggiunto dal turno di promozione, e' promosso anche se non esiste vacanza nel grado superiore, con l'anzianita' che sarebbe spettata se la promozione avesse avuto luogo a suo tempo;
- b) l'ufficiale appartenente a grado nel quale l'avanzamento ha luogo a scelta, se giudicato idoneo e se riporta un punto di merito per cui sarebbe stato promosso, qualora lo stesso punto gli fosse stato attribuito in una precedente graduatoria, e' promosso anche se non esiste vacanza nel grado superiore, con anzianita' che gli sarebbe spettata se la promozione avesse avuto luogo a suo tempo. La promozione e' computata nel numero di quelle da effettuare per l'anno cui si riferisce la graduatoria in occasione della quale l'ufficiale e' stato valutato o nuovamente valutato;
- c) se il provvedimento di sospensione dall'impiego ha colpito un ufficiale con responsabilita' di comando, al medesimo e' attribuito lo stesso comando o un altro di livello equivalente alla prima assegnazione di comandi dopo la cessazione della causa impeditiva.

3. Agli ufficiali, imputati in procedimento penale, che sono stati assolti con sentenza definitiva, fatta salva la definizione dell'eventuale procedimento disciplinare, si applicano le disposizioni di cui all'articolo 1090, commi 1, 2 e 3. La valutazione o il rinnovo del giudizio va effettuato entro sei mesi dalla cessazione dell'impedimento.

### Art. 1086. - Ufficiale che ha cessato dalla carica di Ministro o Sottosegretario

1. L'ufficiale non valutato in base all'articolo 1051, comma 1, e' valutato per l'avanzamento dopo che cessa dalla carica di Ministro o di Sottosegretario di Stato. Se l'avanzamento ha luogo a scelta la valutazione e' effettuata in occasione della formazione della prima graduatoria successiva alla cessazione dalla carica. All'ufficiale si applicano le disposizioni dell'articolo 1085, comma 2, lettere a) e b).

### Art. 1087. - Ufficiale sospeso dalla promozione con determinazione del Ministro

1. L'ufficiale per il quale e' stata sospesa la promozione a norma dell'articolo 1074 e' nuovamente valutato per l'avanzamento entro sei mesi dalla data della sospensione della promozione, se si tratta di avanzamento ad anzianita', o in occasione della formazione della prima graduatoria successiva alla data predetta, se si tratta di avanzamento a scelta. All'ufficiale si applicano le disposizioni dell'articolo 1085, comma 2, lettere a) e b).

### Art. 1088. - Maturazione tardiva dei requisiti speciali per gli ufficiali

1. All'ufficiale non valutato a suo turno per mancanza delle condizioni prescritte dagli articoli 1093 e 1096, e per il quale il raggiungimento delle condizioni anzidette e' stato ritardato per motivi di servizio ((comprovati dagli organi preposti della Forza armata di appartenenza)) o per motivi di salute dipendenti da cause di servizio, si applicano, quando e' valutato per l'avanzamento, le disposizioni dell'articolo 1085, comma 2, lettere a) e b).

2. Se l'avanzamento ha luogo a scelta, l'ufficiale e' valutato in occasione della formazione della prima graduatoria successiva al raggiungimento delle predette condizioni.

### Art. 1089. - Cessazione dei motivi della sospensione discrezionale

1. L'ufficiale, nei cui riguardi e' stato sospeso il giudizio sull'avanzamento a norma dell'articolo 1051, comma 3, e' valutato per l'avanzamento quando le autorita' competenti riconoscono cessati i motivi della sospensione, e comunque non oltre un anno dalla data della sospensione stessa.

2. L'ufficiale appartenente a grado, nel quale l'avanzamento ha luogo ad anzianita', se giudicato idoneo, e' iscritto nel quadro di avanzamento in vigore e, se gia' raggiunto dal turno di promozione, e' promosso anche se non esiste vacanza nel grado superiore, con l'anzianita' che gli sarebbe spettata se la valutazione non fosse stata sospesa.

3. L'ufficiale appartenente a grado nel quale l'avanzamento ha luogo a scelta, se giudicato idoneo, e' iscritto, secondo il punto di merito attribuitogli, nella graduatoria in cui sarebbe stato compreso se la valutazione non fosse stata sospesa. Se, per effetto del posto conseguito nella graduatoria, l'ufficiale e' iscritto nel quadro di avanzamento ed e' gia' raggiunto dal turno di promozione, egli e' promosso anche se non esiste vacanza nel grado superiore, con l'anzianita' che gli sarebbe spettata. Nel caso che la promozione ha luogo dopo che e' stato raggiunto il numero delle promozioni stabilite per l'anno, la promozione e' computata in quelle da effettuare per l'anno successivo.

### Art. 1090. - Giudizi annullati in sede di tutela amministrativa o giurisdizionale

1. Se si deve rinnovare un giudizio di avanzamento annullato d'ufficio o in seguito ad accoglimento di ricorso giurisdizionale o di ricorso straordinario al Presidente della Repubblica si applicano le seguenti disposizioni:

- a) l'ufficiale appartenente al grado nel quale l'avanzamento ha luogo ad anzianita', se giudicato idoneo, e' promosso al grado superiore con l'anzianita' che gli sarebbe spettata se la promozione avesse avuto luogo a suo tempo;
- b) l'ufficiale appartenente al grado nel quale l'avanzamento ha luogo a scelta, se giudicato idoneo e riporta un punto di merito per cui sarebbe stato promosso se attribuito in una precedente graduatoria, e' promosso al grado superiore con l'anzianita' che gli sarebbe spettata se la promozione avesse avuto luogo a suo tempo.

2. La promozione di cui al comma 1 non e' ricompresa tra quelle attribuite nell'anno in cui e' rinnovato il giudizio. Se non sussiste vacanza nelle dotazioni organiche o nei numeri massimi del grado in cui deve essere effettuata la promozione, l'eventuale eccedenza, determinata dalla promozione stessa, e' riassorbita al verificarsi della prima vacanza successiva al 1° luglio dell'anno dell'avvenuta promozione dell'interessato e comunque entro il 30 giugno dell'anno successivo a quello in cui e' rinnovato il giudizio. Se entro tale data non si sono verificate vacanze, le eccedenze sono assorbite con le modalita' di cui agli articoli 906 e 907.

3. ((Fermo restando quanto previsto dagli articoli 1058 e 1093, all'ufficiale)) promosso a seguito di ricorso, che ha superato il limite di eta' del grado conseguito ovvero che raggiunge il limite di eta' prima del compimento del periodo di comando o di attribuzioni specifiche prescritto per l'avanzamento, non sono richiesti i requisiti di cui ((all'articolo)) 1096.

4. Il rinnovo del giudizio e' effettuato dagli organi competenti entro sei mesi dall'annullamento d'ufficio, dalla comunicazione del decreto del Capo dello Stato o dalla notifica all'amministrazione competente della pronuncia giurisdizionale che ha annullato la precedente valutazione. Se il titolo dell'annullamento contiene elementi tali da rendere automatica l'iscrizione in quadro del ricorrente, non e' necessario procedere a una nuova valutazione. In tal caso il Ministro competente provvede d'ufficio agli adempimenti per la promozione del ricorrente.

### Art. 1091. - Ricostruzione della carriera

1. Per il militare in servizio permanente e dei ruoli a esaurimento, che si trovi in aspettativa d'autorita' derivante da cariche elettive, la ricostruzione della carriera, al termine dell'aspettativa, avviene, fermo restando il solo requisito del limite di eta' previsto per la posizione finale e secondo quanto disposto dal comma 2, sulla base dei soli minimi di anzianita', ove richiesti, ovvero, se piu' favorevole, del periodo impiegato per l'inclusione nelle aliquote di valutazione del pari grado che lo avrebbe preceduto nel ruolo nell'ipotesi di una promozione o dei pari grado che lo avrebbero preceduto nell'ipotesi di pluralita' di promozioni.

2. Il militare di cui al comma 1 e' promosso, prescindendo dall'inserimento in aliquote e quadri di avanzamento, in eccedenza al numero delle promozioni stabilite per l'anno e non e' computato nei numeri massimi previsti per la dirigenza militare. I concorsi per titoli o esami, i corsi-concorsi, le valutazioni per l'avanzamento, la frequenza di corsi, i periodi di servizio, comandi o incarichi richiesti dagli ordinamenti del personale militare per l'accesso ai vari gradi, anche dirigenziali, si considerano utilmente superati o adempiuti.

3. La ricostruzione di carriera prevista dal comma 2 e' consentita fino al grado di colonnello e gradi equiparati.

### Art. 1092. - Estensione di norme

1. Le disposizioni del presente capo sono applicate, in quanto compatibili, a tutto il personale militare.

## CAPO VI - NORME PARTICOLARI PER GLI UFFICIALI IN SERVIZIO PERMANENTE

### Art. 1093. - Requisiti generali per l'avanzamento degli ufficiali

1. Per l'avanzamento al grado superiore l'ufficiale deve possedere i requisiti fisici, morali, di carattere, intellettuali, di cultura, professionali, necessari per bene adempiere le funzioni del nuovo grado. Aver disimpegnato bene le funzioni del proprio grado e' condizione indispensabile, ma non sufficiente, per l'avanzamento al grado superiore.

2. Per l'avanzamento ai vari gradi di generale o di ammiraglio i requisiti di cui al comma 1 devono essere posseduti in modo eminente, in relazione alle funzioni di alto comando o di alta direzione da esercitare nel nuovo grado.

### Art. 1094. - Attribuzione dei gradi di vertice

1. L'ufficiale generale o ammiraglio nominato Capo di stato maggiore della difesa e' promosso, con decorrenza dalla data della nomina, al grado di generale o ammiraglio.

2. La promozione al grado di generale o ammiraglio puo' essere conferita esclusivamente all'ufficiale generale o ammiraglio di cui al comma 1.

2-bis. Gli ufficiali generali o ammiragli nominati Capo di stato maggiore della difesa ((, Segretario generale o Direttore nazionale degli armamenti)) del Ministero della difesa sono collocati in soprannumero agli organici della Forza armata di appartenenza, a decorrere dal 30 dicembre 2019.

3. Gli ufficiali generali o ammiragli nominati Capi di stato maggiore della difesa o di Forza armata, il Comandante del Comando operativo di vertice interforze, il Comandante generale dell'Arma dei carabinieri ((, il Segretario generale ovvero il Direttore nazionale degli armamenti))) del Ministero della Difesa, durano in carica tre anni e, se non abbiano raggiunto il limite di eta' al termine del triennio, permangono nell'incarico fino al limite di eta' e comunque al massimo per un altro anno, senza possibilita' di proroga o rinnovo. Al termine del mandato, qualora il personale, di cui al primo periodo, non abbia raggiunto i limiti di eta' previsti per il grado, puo' esserne disposto, a domanda, il collocamento in congedo da equiparare a tutti gli effetti a quello per raggiungimento dei limiti di eta', con riconoscimento, in aggiunta a qualsiasi altro istituto spettante, del trattamento pensionistico e dell'indennita' di buonuscita che sarebbero spettati in caso di permanenza in servizio fino al limite di eta', compresi gli eventuali aumenti periodici e i passaggi di classe di stipendio. (49) (85)

4. Gli ufficiali generali o ammiragli di cui al comma 3, se raggiunti dai limiti di eta', sono richiamati d'autorita' fino al termine del triennio. (85)

----------- AGGIORNAMENTO (49) Il D.L. 16 ottobre 2017, n. 148, convertito con modificazioni dalla L. 4 dicembre 2017, n. 172, ha disposto (con l'art. 7, comma 10) che "In fase di prima attuazione, i mandati in corso alla data di entrata in vigore delle disposizioni di cui ai commi da 7 a 9, se di durata inferiore a tre anni comprese le proroghe, sono estesi fino alla durata di tre anni complessivi. Restano fermi i mandati in corso di durata pari o superiore a tre anni comprese le proroghe". ------------ AGGIORNAMENTO (85) Il D.L. 30 dicembre 2021, n. 228, convertito con modificazioni dalla L. 25 febbraio 2022, n. 15 ha disposto (con l'art. 1, comma 21) che "L'articolo 1094 del Codice dell'ordinamento militare di cui al decreto legislativo 15 marzo 2010, n. 66, come modificato dal comma 20 del presente articolo, si applica anche ai mandati in corso alla data di entrata in vigore del presente decreto".

### Art. 1094-bis. - (( (Attribuzione del grado di vertice per alcuni ruoli). ))

((

1. All'ufficiale piu' anziano appartenente ai ruoli normali dell'Arma dei trasporti e dei materiali, del Corpo di commissariato e del Corpo sanitario dell'Esercito italiano, del Corpo sanitario militare marittimo e del Corpo di commissariato militare marittimo della Marina militare, delle Armi dell'Aeronautica militare, del Corpo di commissariato aeronautico e del Corpo sanitario aeronautico dell'Aeronautica militare, che ha maturato un periodo di permanenza minima pari a un anno nel grado di maggior generale o grado corrispondente, previo giudizio di idoneita' all'avanzamento, espresso dalla commissione di vertice della Forza armata di appartenenza, ai sensi dell'articolo 1058, comma 2, e secondo le modalita' di cui all'articolo 710 del regolamento, e' conferito il grado di tenente generale o grado corrispondente.

2. Il conferimento e' effettuato in sovrannumero rispetto alle dotazioni organiche previste dal presente codice per il grado di generale di corpo d'armata o grado corrispondente e, in deroga all'articolo 1078, non da' luogo a vacanza organica nel grado di maggior generale o grado corrispondente))

### Art. 1095.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

### Art. 1096. - Requisiti speciali

1. L'ufficiale in servizio permanente effettivo, per essere valutato per l'avanzamento, deve, in relazione al ruolo di appartenenza:

- a) aver maturato gli anni di permanenza minima indicati per ciascun grado e aver compiuto i periodi minimi di comando, di attribuzioni specifiche, di servizio presso enti e reparti e d'imbarco previsti dal presente codice;
- b) essere in possesso dei titoli e aver superato gli esami e i corsi stabiliti con decreto del Ministro della difesa.

2. Ai fini della valutazione per l'avanzamento, i previsti periodi di comando, di attribuzioni specifiche, di servizio e di imbarco possono essere svolti, in tutto o in parte, nel grado immediatamente inferiore, se espressamente disposto dal presente codice.

3. I predetti periodi devono essere svolti presso comandi, unita', reparti ed enti organicamente previsti o costituiti per specifiche esigenze di carattere operativo o logistico, anche in ambito internazionale.

4. Il periodo di comando prescritto ai fini dell'avanzamento deve essere compiuto nell'esercizio di funzioni che comportino attribuzioni, oltre che disciplinari, di addestramento e di impiego.

5. Il periodo di attribuzioni specifiche prescritto ai fini dell'avanzamento deve essere compiuto nell'esercizio di funzioni proprie del ruolo di appartenenza.

6. I periodi di comando, di attribuzioni specifiche, di servizio e di imbarco possono essere compiuti anche in incarichi equipollenti a quelli indicati, determinati con decreto ((adottato dal Ministro della difesa su proposta del Capo di stato maggiore della difesa, sentito il Capo di stato maggiore di Forza armata, e, per l'Arma dei carabinieri, su proposta del Comandante generale, inoltrata tramite il Capo di stato maggiore della difesa)).

### Art. 1097. - Forme di avanzamento

1. L'avanzamento degli ufficiali ((dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)) avviene:

- a) ad anzianita', per i gradi di tenente, capitano ((...)) e tenente colonnello e gradi corrispondenti;
- b) a scelta, per i gradi di maggiore, ((...)) colonnello, generale di brigata, generale di divisione e generale di corpo d'armata e gradi corrispondenti.

((

1-bis. L'avanzamento degli ufficiali dell'Arma dei carabinieri avviene:

- a) ad anzianita', per i gradi di tenente e capitano;
- b) a scelta, per i gradi di maggiore, tenente colonnello, colonnello, generale di brigata, generale di divisione e generale di corpo d'armata.

))

### Art. 1098. - Mancato superamento di corsi ed esami prescritti ai fini dell'avanzamento

1. Gli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare che non superano i corsi e gli esami prescritti ai fini dell'avanzamento sono ammessi a ripeterli. Se non li superano nuovamente, possono richiedere, a domanda, di ripeterli per una sola volta dopo che sono trascorsi almeno tre anni dal mancato superamento.

2. Gli ufficiali fino al grado di maggiore compreso che non superano le ulteriori prove concesse ai sensi del comma 1 sono inclusi nelle aliquote di valutazione per l'avanzamento non appena sono in possesso dei seguenti requisiti minimi:

- a) per la promozione a maggiore e gradi corrispondenti, undici anni di permanenza nel grado di capitano e diciotto anni di anzianita' di servizio;
- b) per la promozione a tenente colonnello e gradi corrispondenti, cinque anni di permanenza nel grado e ventidue anni di anzianita' di servizio.

### Art. 1099. - Promozione dei tenenti colonnelli a disposizione

1. Se nel grado di colonnello, dopo che sono state effettuate le promozioni dei tenenti colonnelli in servizio permanente effettivo, previste per l'anno, non si raggiunge il numero massimo stabilito dal presente codice, i rimanenti posti sono colmati promuovendo altri tenenti colonnelli.

2. Per effettuare le promozioni previste dal comma 1 sono valutati i tenenti colonnelli collocati nella posizione di <<a disposizione>>.

3. L'avanzamento si effettua a scelta ((e la promozione e' attribuita al 1° luglio)).

4. L'ufficiale promosso non e' piu' valutato per l'avanzamento, rimane nella posizione di <<a disposizione>> anche nel nuovo grado.

5. COMMA ABROGATO DAL D.LGS. 26 APRILE 2016, N. 91.

## CAPO VII - AVANZAMENTO DEGLI UFFICIALI DELL'ESERCITO ITALIANO ((...))

### Art. 1099-bis. - (( (Dotazioni organiche e profili di carriera degli ufficiali dell'Esercito italiano). ))

((

1. Le dotazioni organiche e i profili di carriera degli ufficiali dei ruoli normali e speciali dell'Esercito italiano sono stabiliti dalla tabella 1 allegata al presente codice.

))

### Art. 1100.

((ARTICOLO ABROGATO DAL D.LGS. 23 NOVEMBRE 2023, N. 185)).

## ((...))

### Art. 1101.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1102.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1103.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1104.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1105.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1106.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1107.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1108.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1109.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1110.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1111.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1112.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1113.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1114.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1115.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1116.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 1117.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1118.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1119.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1120.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 1121.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1122.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1123.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1124.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1125.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1126.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1127.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1128.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1129.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1130.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1131.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1132.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1133.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1134.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1135.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1136.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## CAPO VIII - AVANZAMENTO DEGLI UFFICIALI DELLA MARINA MILITARE ((...))

### Art. 1136-bis. - (( (Dotazioni organiche e profili di carriera degli ufficiali della Marina militare). ))

((

1. Le dotazioni organiche e i profili di carriera degli ufficiali dei ruoli normali e speciali della Marina militare sono stabiliti dalla tabella 2 allegata al presente codice.

))

### Art. 1137. - Ulteriori requisiti per la valutazione degli ufficiali della Marina militare

1. Per gli ufficiali della Marina militare i periodi di servizio prestati su navi da guerra estere o in territorio estero sono considerati come compiuti su navi da guerra nazionali o in territorio nazionale.

2. Ai fini dell'avanzamento e' valido il periodo di imbarco compiuto, con funzioni inerenti al proprio grado o come comandato, su navi non iscritte nel naviglio dello Stato per l'espletamento di servizi previsti da speciali disposizioni. E' altresi' valido anche il periodo di imbarco compiuto su navi mercantili per istruzione professionale. In ogni caso la meta' del periodo di imbarco prescritto ai fini dell'avanzamento deve essere trascorsa su navi della Marina militare in armamento o in riserva.

### Art. 1137-bis. - (( (Mancato conseguimento del diploma di laurea). ))

((

1. Gli ufficiali del ruolo normale del Corpo di stato maggiore che non conseguono il titolo di studio previsto dagli ordinamenti di Forza armata entro l'anno di inserimento nell'aliquota di valutazione per l'avanzamento al grado di capitano di corvetta transitano d'autorita', anche in soprannumero per il solo anno del transito, nel corrispondente ruolo speciale, con decorrenza dal 1° gennaio dell'anno di formazione della predetta aliquota di valutazione, mantenendo l'anzianita' di grado posseduta, e sono iscritti in ruolo prima dei pari grado aventi la stessa anzianita' di grado.

))

## ((...))

### Art. 1138.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1139.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1140.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1141.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1142.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1143.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1144.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1145.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 1146.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1147.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1148.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1149.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1150.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1151.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1152.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1153.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1154.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1155.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1156.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1157.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1158.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1159.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1160.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1161.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

## ((...))

### Art. 1162.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1163.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1164.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1165.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1166.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1167.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1168.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1169.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1170.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1171.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1172.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1173.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1174.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1175.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1176.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1177.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1178.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1179.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1180.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1181.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1182.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1183.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1184.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1185.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

## CAPO IX - AVANZAMENTO DEGLI UFFICIALI DELL'AERONAUTICA MILITARE ((...))

### Art. 1185-bis. - (( (Dotazioni organiche e profili di carriera degli ufficiali dell'Aeronautica militare). ))

((

1. Le dotazioni organiche e i profili di carriera degli ufficiali dei ruoli normali e speciali dell'Aeronautica militare sono stabiliti dalla tabella 3 allegata al presente codice.

))

### Art. 1186.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1187.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1188.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1189.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1190.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1191.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1192.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1193.

((ARTICOLO ABROGATO DAL D.LGS. 24 FEBBRAIO 2012, N. 20))

### Art. 1194.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 1195.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1196.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1197.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1198.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1199.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1200.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1201.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1202.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1203.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1204.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1205.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1206.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1207.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1208.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1209.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1210.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1211.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1212.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1213.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1214.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## ((...))

### Art. 1215.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1216.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1217.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1218.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22))

---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 1219.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1220.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1221.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1222.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22)) ---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 1223.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1224.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1225.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1226.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22)) ---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

## CAPO X - AVANZAMENTO DEGLI UFFICIALI DELL'ARMA DEI CARABINIERI ((...))

### Art. 1226-bis. - Dotazioni organiche e profili di carriera degli ufficiali dell'Arma dei carabinieri).

1. Le dotazioni organiche e i profili di carriera degli ufficiali ((...)) dell'Arma dei carabinieri sono stabiliti dalla tabella 4 allegata al presente codice.

### Art. 1227. - Estensione di norme ai fini dell'avanzamento

((

1. Agli ufficiali dell'Arma dei carabinieri continuano ad applicarsi le seguenti norme:

- a) articolo 22, della legge 1° aprile 1981, n. 121;
- b) articolo 10, comma 4, del decreto del Presidente della Repubblica 9 ottobre 1990, n. 309;
- c) articolo 4, comma 4, del decreto-legge 29 ottobre 1991, n. 345, convertito, con modificazioni, dalla legge 30 dicembre 1991, n. 410;
- d) articolo 3, comma 3, della legge 23 marzo 1998, n. 93 ;
- e) l'articolo 2, comma 6-terdecies, del decreto-legge 29 dicembre 2010, n. 225, convertito, con modificazioni, dalla legge 26 febbraio 2011, n. 10.

))

2. Ai soli fini dell'avanzamento, ai capitani dell'Arma dei carabinieri in servizio alle dipendenze del Raggruppamento operativo speciale si applica il disposto dell'articolo 3, comma 3, della legge 15 novembre 1988, n. 486.

## ((...))

### Art. 1228.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1229.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1230.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1231. - Mancato conseguimento del diploma di laurea

1. Gli ufficiali del ruolo normale (( reclutati ai sensi dell'articolo 651-bis, comma 1, lettere a) e c) ))che non conseguano il diploma di laurea magistrale entro il 31 dicembre dell'anno di nomina al grado di capitano sono collocati nella categoria del complemento con obbligo di ultimare l'eventuale periodo residuo di ferma contratta.

- a) LETTERA SOPPRESSA DAL D.LSG. 29 MAGGIO 2017, N. 95;
- b) LETTERA SOPPRESSA DAL D.LSG. 29 MAGGIO 2017, N. 95.

### Art. 1232.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1233.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1234.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1235.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1236.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

## ((...))

### Art. 1237.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1238.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 1239.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

## CAPO XI - AVANZAMENTO DEGLI UFFICIALI AUSILIARI

### SEZIONE I - UFFICIALI IN FERMA PREFISSATA E DELLE FORZE DI COMPLETAMENTO

#### Art. 1240. - Avanzamento degli ufficiali in ferma prefissata

1. I sottotenenti e i guardiamarina in ferma prefissata sono valutati per l'avanzamento ad anzianita' al grado superiore dai superiori gerarchici al compimento del secondo anno di permanenza nel grado e, se idonei, promossi con tale decorrenza.

#### Art. 1241. - Avanzamento degli ufficiali delle forze di completamento

1. L'avanzamento degli ufficiali delle forze di completamento avviene con le modalita' previste per gli ufficiali in congedo.

### SEZIONE II - UFFICIALI PILOTI E NAVIGATORI DI COMPLEMENTO

#### Art. 1242. - Aliquote di valutazione

1. Gli ufficiali piloti e navigatori di complemento, per essere valutati per l'avanzamento, devono trovarsi compresi in apposite aliquote di ruolo stabilite dal Ministro della difesa. Per gli ufficiali compresi nelle predette aliquote, che vengano a trovarsi in una delle condizioni previste per l'impedimento alla valutazione o alla promozione, previste dall'articolo 1051 e dalla sezione II del capo IV del presente titolo operano, in quanto applicabili, le norme di cui al capo V del presente titolo.

2. Agli effetti di quanto disposto nel comma 1, il ((15 settembre)) di ogni anno il Ministro determina le aliquote di ruolo per la formazione dei quadri di avanzamento comprendendovi per ciascun grado, gli ufficiali che, entro il 31 dicembre dell'anno successivo, maturino la permanenza nel grado o l'anzianita' di servizio prevista all'articolo 1243.

3. I tenenti sono valutati e se idonei sono promossi con anzianita' decorrente dal giorno successivo al compimento delle permanenze previste dall'articolo 1243.

#### Art. 1243. - Periodi di permanenza minima nel grado e requisiti speciali

1. Gli ufficiali inferiori, per essere valutati ai fini dell'avanzamento, devono aver compiuto i periodi di comando, di servizio o d'imbarco previsti, per gli ufficiali di complemento.

2. I periodi di comando di cui al comma 1 sono sostituibili con un uguale periodo di servizio svolto presso reparti o scuole di volo.

3. Sono valutati e, se idonei, promossi al grado superiore gli ufficiali che maturino entro il 31 dicembre: ((a) se tenenti, cinque anni di anzianita' nel grado;)) b) se sottotenenti, due anni di anzianita' nel grado.

#### Art. 1244. - Estensione di norme

1. Agli ufficiali piloti e navigatori di complemento sono estese ((...)) in quanto applicabili le altre norme sull'avanzamento degli ufficiali.

#### Art. 1245. - Periodi di servizio effettivo presso societa' di navigazione aerea

1. Per gli ufficiali piloti e navigatori di complemento il periodo di effettivo servizio aeronavigante compiuto presso societa' di navigazione aerea e' computato per meta' ai fini del raggiungimento dei prescritti periodi di comando, di imbarco o di servizio, ma non oltre i 4/5 dei periodi suddetti.

## CAPO XII - AVANZAMENTO DEGLI UFFICIALI IN CONGEDO

### SEZIONE I - NORME COMUNI

#### Art. 1246. - Categorie di ufficiali in congedo

1. Nelle categorie degli ufficiali in congedo l'avanzamento si effettua per gli ufficiali in ausiliaria, per gli ufficiali di complemento e per gli ufficiali della riserva.

2. L'avanzamento ha luogo ad anzianita'.

#### Art. 1247. - Aliquote di ruolo per la valutazione

1. Il Ministro della difesa determina, in rapporto alle prevedibili esigenze di mobilitazione, le aliquote di ruolo degli ufficiali in ausiliaria, degli ufficiali di complemento e degli ufficiali della riserva da valutare per la formazione di quadri di avanzamento.

#### Art. 1248. - Idoneita' al servizio militare incondizionato

1. L'ufficiale compreso nelle aliquote di ruolo di cui all'articolo 1247 non puo' essere valutato per l'avanzamento se non e' stato riconosciuto incondizionatamente idoneo al servizio militare.

#### Art. 1249. - Cause di sospensione della valutazione o della promozione

1. Per l'ufficiale compreso nelle aliquote di ruolo di cui all'articolo 1247, che venga a trovarsi in alcuna delle condizioni che determinano la sospensione della valutazione o della promozione, previste dall'articolo 1051 e dalla sezione II del capo IV del presente titolo, valgono, in quanto applicabili, le norme di cui al capo V del presente titolo.

#### Art. 1250. - Promozioni

1. Gli ufficiali iscritti in quadro di avanzamento sono promossi nel numero che il Ministro stabilisce in rapporto alle esigenze di mobilitazione.

2. Se, dopo effettuate le promozioni nel numero suddetto, restino ancora ufficiali iscritti in quadro, la validita' del quadro stesso e' prorogata all'anno seguente.

3. Gli ufficiali che non conseguono la promozione entro il secondo anno di validita' del quadro di avanzamento sono nuovamente valutati in occasione della formazione di un successivo quadro di avanzamento.

### SEZIONE II - UFFICIALI IN AUSILIARIA

#### Art. 1251. - Grado massimo

1. L'avanzamento degli ufficiali in ausiliaria ha luogo fino al grado massimo previsto per il ruolo del servizio permanente effettivo da cui provengono.

#### Art. 1252. - Requisiti per l'avanzamento

1. L'ufficiale in ausiliaria per essere valutato per l'avanzamento deve aver compiuto i periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco, prescritti per l'avanzamento del pari grado in servizio permanente effettivo.

2. Se per l'avanzamento del pari grado in servizio permanente effettivo non e' prescritto il compimento dei periodi di cui al comma 1, l'ufficiale in ausiliaria, per essere valutato per l'avanzamento, deve avere prestato, nel grado, almeno un anno di servizio.

3. I requisiti di cui ai commi 1 e 2 non sono richiesti per la prima promozione nell'ausiliaria.

#### Art. 1253. - Promozioni

1. L'ufficiale in ausiliaria che e' giudicato idoneo all'avanzamento e' iscritto in quadro, ma e' promosso solo dopo la promozione degli ufficiali in servizio permanente di pari grado e anzianita' che lo precedevano nel ruolo di provenienza.

2. Non costituisce ostacolo alla promozione dell'ufficiale in ausiliaria l'esistenza nel servizio permanente di pari grado non idonei all'avanzamento o per i quali e' sospesa la valutazione o la promozione.

### SEZIONE III - UFFICIALI DI COMPLEMENTO

#### Art. 1254. - Grado massimo

1. L'avanzamento degli ufficiali di complemento ha luogo fino al grado di tenente colonnello o corrispondente.

#### Art. 1255. - Requisiti per l'avanzamento

1. L'ufficiale di complemento per essere valutato per l'avanzamento deve, a seconda della Forza armata di appartenenza e del grado rivestito, aver compiuto i corsi di istruzione, gli esperimenti pratici, essere in possesso dei titoli stabiliti dalla sezione IV del presente capo.

2. L'esperimento puo' essere svolto in uno o piu' periodi della durata minima di un mese.

3. E' dispensato dal compiere il corso e l'esperimento pratico l'ufficiale richiamato alle armi che ha compiuto il periodo di comando, di attribuzioni specifiche, di servizio, di imbarco, indicato nella sezione IV del presente capo.

#### Art. 1256. - Promozioni

1. L'ufficiale di complemento, che e' giudicato idoneo all'avanzamento e iscritto in quadro, e' promosso solo dopo la promozione degli ufficiali di pari grado, di maggiore o di eguale anzianita', appartenenti ai corrispondenti ruoli normali e speciali del servizio permanente effettivo.

2. Non costituisce ostacolo alla promozione degli ufficiali di complemento l'esistenza nel servizio permanente effettivo di parigrado non idonei all'avanzamento o per i quali e' sospesa la valutazione o la promozione.

#### Art. 1257. - Promozione degli ufficiali

((...))

1. I sottotenenti e i guardiamarina di complemento che, dopo il servizio di prima nomina hanno prestato almeno un anno di servizio continuativo, possono essere valutati per l'avanzamento prescindendo dalla determinazione delle aliquote di cui all'articolo 1247.

2. Analogamente possono essere valutati i tenenti e gli ufficiali di grado corrispondente di complemento che hanno prestato nel grado rivestito almeno due anni di servizio, di cui sei mesi al comando di reparto se ufficiali dell'Esercito italiano appartenenti alle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni e dell'Arma dei carabinieri.

3. Gli ufficiali di cui al comma 2, se giudicati idonei, sono promossi, sotto la data del relativo decreto, indipendentemente dal disposto dell'articolo 1250, comma 1, solo dopo la promozione degli ufficiali di pari grado e anzianita' appartenenti ai corrispondenti ruoli normali e speciali del servizio permanente effettivo.

4. Non costituisce ostacolo alla promozione l'esistenza nel servizio permanente effettivo di pari grado non idonei all'avanzamento o per i quali e' stata sospesa la valutazione o la promozione.

5. Gli ufficiali di complemento di cui al presente articolo, se giudicati non idonei, non sono piu' valutati per l'avanzamento in servizio, ferma restando la possibilita' di avanzamento nella posizione di congedo.

### SEZIONE IV - REQUISITI SPECIALI PER L'AVANZAMENTO DEGLI UFFICIALI DI COMPLEMENTO

#### Art. 1258. - Ufficiali delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni, in relazione al grado sono i seguenti:

- a) maggiore e capitano: corso di aggiornamento per comandante di battaglione o gruppo; 3 mesi di esperimento pratico presso un comando di battaglione o gruppo, dopo il corso in periodo di esercitazioni;
- b) tenente: corso di aggiornamento per ufficiali ((...)); 3 mesi di esperimento pratico presso un comando di compagnia, squadrone o batteria, dopo il corso, in periodo di esercitazioni;
- c) sottotenente: corso di aggiornamento per ufficiali ((...)) ovvero compimento del 4° anno dalla data di ammissione al corso allievi ufficiali di complemento.

2. I periodi di comando e di servizio validi ai fini dell'avanzamento degli ufficiali di complemento delle Armi di fanteria, cavalleria, artiglieria, genio e trasmissioni, in sostituzione delle condizioni di cui al comma 1 e in relazione al grado sono i seguenti:

- a) maggiore: 1 anno di servizio di cui 6 mesi di comando di battaglione o gruppo o comando equipollente;
- b) capitano: un anno di comando di compagnia, squadrone o comando equipollente;
- c) tenente e sottotenente: un anno di comando di plotone o di sezione o comando equipollente.

3. Per gli incarichi equipollenti, in cui possono essere validamente compiuti i periodi minimi di comando, valgono quelli determinati per gli ufficiali in servizio permanente.

#### Art. 1259. - Ufficiali dell'Arma dei trasporti e dei materiali

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento dell'Arma dei trasporti e dei materiali, in relazione al grado sono i seguenti:

- a) maggiore e capitano: corso di aggiornamento per ufficiali superiori dell'Arma; 3 mesi di esperimento pratico presso un reparto;
- b) tenente: corso di aggiornamento per ufficiali ((...)) dell'Arma; 3 mesi di esperimento pratico presso un reparto;
- c) sottotenente: corso di aggiornamento per ufficiali ((...)) dell'Arma ovvero compimento del 4° anno dalla data di ammissione al corso allievi ufficiali di complemento.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1260. - Ufficiali del Corpo degli ingegneri dell'Esercito italiano

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del corpo degli ingegneri, in relazione al grado sono i seguenti:

- a) maggiore, capitano e tenente: 3 mesi di esperimento pratico;
- b) sottotenente: corso di aggiornamento per ufficiali ((...)) ovvero compimento del 4° anno dalla data di ammissione al corso allievi ufficiali di complemento.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1261. - Ufficiali del Corpo sanitario dell'Esercito italiano

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del corpo sanitario, in relazione al grado sono i seguenti:

- a) maggiore: 3 mesi di esperimento pratico presso un ente sanitario;
- b) capitano: corso di aggiornamento; 15 anni di esercizio della professione nella vita civile;
- c) tenente: 10 anni di esercizio della professione nella vita civile;
- d) sottotenente: 3 anni di esercizio della professione nella vita civile.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1262. - Ufficiali del Corpo di commissariato dell'Esercito italiano

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del corpo di commissariato, in relazione al grado sono i seguenti:

- a) maggiore: 3 mesi di esperimento pratico presso una direzione, una sezione o uno stabilimento del corpo;
- b) capitano e tenente: corso di aggiornamento;
- c) sottotenente: corso di aggiornamento per ufficiali ((...)) ovvero compimento del 4° anno dalla data di ammissione al corso allievi ufficiali di complemento.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1263. - Periodi di imbarco per gli ufficiali della Marina militare

1. Per gli ufficiali di complemento della Marina militare, il periodo di imbarco su navi della Marina mercantile, con funzioni attinenti ai servizi del Corpo di appartenenza, e' computato per meta' ai fini del raggiungimento del periodo di imbarco previsto dalla seguente sezione V, ma non oltre i quattro quinti del periodo suddetto.

#### Art. 1264. - Ufficiali dei vari Corpi della Marina militare

1. Per l'avanzamento degli ufficiali di complemento della Marina militare dei vari Corpi, con il grado capitano di corvetta, tenente di vascello e sottotenente di vascello, e' prescritto un corso di istruzione e 3 mesi di esperimento pratico.

2. I periodi di imbarco e di servizio validi ai fini dell'avanzamento, in sostituzione delle condizioni di cui al comma 1 e in relazione al grado e al corpo di appartenenza sono i seguenti:

- a) capitano di corvetta, tenente di vascello e sottotenente di vascello del Corpo di stato maggiore: 1 anno di imbarco;
- b) capitano di corvetta, tenente di vascello e sottotenente di vascello del Corpo del genio della Marina: 1 anno di imbarco o di servizio tecnico;(37)
- c) capitano di corvetta, tenente di vascello e sottotenente di vascello del Corpo sanitario marittimo, del Corpo di commissariato marittimo e del Corpo delle capitanerie di porto: 1 anno di servizio;(37)
- d) ((LETTERA SOPPRESSA DAL D.LGS. 26 APRILE 2016, N. 91)).

---------------- AGGIORNAMENTO (37) Il D.Lgs. 26 aprile 2016, n. 91 ha disposto (con l'art. 2, comma 1, alinea) che le presenti modifiche si applicano a decorrere dal 1° gennaio 2017.

#### Art. 1265. - Ufficiali del ruolo naviganti dell'Aeronautica militare

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del ruolo naviganti, in relazione al grado sono i seguenti:

- a) maggiore: frequentare il corso di aggiornamento; avere frequentato i corsi di allenamento e di addestramento svolti negli ultimi due anni; 3 mesi di esperimento presso un comando di stormo;
- b) capitano: frequentare il corso di aggiornamento; avere frequentato i corsi di allenamento e di addestramento svolti negli ultimi due anni; 3 mesi di esperimento presso un comando di gruppo;
- c) tenente: frequentare il corso di aggiornamento; avere frequentato i corsi di allenamento e di addestramento svolti negli ultimi due anni.

2. I periodi di comando e di servizio validi ai fini dell'avanzamento degli ufficiali di complemento del ruolo naviganti, in sostituzione delle condizioni di cui al comma 1 e in relazione al grado sono i seguenti:

- a) maggiore: un anno di servizio in reparti di impiego;
- b) capitano: un anno di servizio in reparti di impiego dei quali 6 mesi presso un comando di gruppo;
- c) tenente: un anno di servizio in reparto di impiego.

#### Art. 1266. - Ufficiali del ruolo delle armi dell'Aeronautica militare

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del ruolo delle armi, in relazione al grado sono i seguenti:

- a) maggiore: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un reparto servizi dell'Aeronautica militare;
- b) capitano: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un reparto servizi di aeroporto;
- c) tenente: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un reparto di impiego o in servizi di aeroporto.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1267. - Ufficiali del Corpo di commissariato aeronautico

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del Corpo di commissariato aeronautico, in relazione al grado sono i seguenti:

- a) maggiore: frequentare il corso di aggiornamento; 3 mesi di esperimento presso una direzione di commissariato;
- b) capitano: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un ufficio amministrativo di aeroporto o una direzione di commissariato;
- c) tenente: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un ufficio amministrativo di aeroporto.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1268. - Ufficiali del Corpo sanitario aeronautico

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento del Corpo sanitario aeronautico, in relazione al grado sono i seguenti:

- a) maggiore: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un istituto ((di medicina aerospaziale dell'Aeronautica militare));
- b) capitano: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un ufficio sanitario dell'Aeronautica militare;
- c) tenente: frequentare il corso di aggiornamento; 3 mesi di esperimento presso un servizio sanitario di aeroporto.

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali dei vari gradi ai fini dell'avanzamento devono svolgere un anno di servizio.

#### Art. 1269. - Ufficiali dell'Arma dei carabinieri

1. I corsi di istruzione, gli esperimenti e i titoli richiesti ai fini dell'avanzamento degli ufficiali di complemento dell'Arma dei carabinieri, in relazione al grado sono i seguenti:

- a) maggiore: corso di aggiornamento per comandante di gruppo, reparto territoriale o battaglione; 3 mesi di esperimento pratico presso un comando di regione;
- b) capitano: corso di aggiornamento per comandante di gruppo, reparto territoriale o battaglione; 3 mesi di esperimento pratico presso un comando provinciale;
- c) tenente: corso di aggiornamento per ufficiali subalterni; 3 mesi di esperimento pratico presso un comando compagnia territoriale;
- d) sottotenente: corso di aggiornamento per ufficiali subalterni ovvero compimento del 4° anno dalla data di ammissione al corso allievi ufficiali di complemento.

((

2. In sostituzione delle condizioni di cui al comma 1, gli ufficiali di complemento dell'Arma dei carabinieri, ai fini dell'avanzamento, devono aver svolto almeno diciotto mesi continuativi di servizio.

))

### SEZIONE V - UFFICIALI DELLA RISERVA

#### Art. 1270. - Grado massimo

1. L'avanzamento degli ufficiali della riserva ha luogo soltanto al grado superiore a quello col quale l'ufficiale ha cessato dal servizio permanente.

#### Art. 1271. - Requisiti per l'avanzamento

1. L'ufficiale della riserva per essere valutato per l'avanzamento deve, nel grado rivestito, aver compiuto, in servizio permanente o in ausiliaria, i periodi di comando, di attribuzioni specifiche, di servizio presso reparti e d'imbarco prescritti dal presente codice.

2. Per i periodi di comando, di attribuzioni specifiche, di servizio presso reparti e d'imbarco compiuti in ausiliaria vale quanto prescritto dall'articolo 1252, commi 1 e 2.

#### Art. 1272. - Promozioni

1. L'ufficiale della riserva giudicato idoneo all'avanzamento e' iscritto in quadro, ma e' promosso solo dopo la promozione degli ufficiali in servizio permanente di pari grado e anzianita' che lo precedevano nel ruolo del servizio permanente effettivo.

2. Non costituisce ostacolo alla promozione l'esistenza nel servizio permanente di pari grado non idonei all'avanzamento o per i quali e' sospesa la valutazione o la promozione.

## CAPO XIII - AVANZAMENTO DEI SOTTUFFICIALI DELL'ESERCITO ITALIANO,DELLA MARINA MILITARE E DELL'AERONAUTICA MILITARE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1273. - Avanzamento a scelta

1. L'avanzamento a scelta ((del personale appartenente ai ruoli dei marescialli)) dell'Esercito italiano, della Marina militare e dell'Aeronautica militare avviene secondo le modalita' e le valutazioni di cui all'articolo 1059.

2. Fatta eccezione per quanto previsto all'articolo 1282, nell'avanzamento a scelta, le promozioni da conferire sono cosi' determinate: ((a) il primo terzo del personale iscritto nel quadro d'avanzamento a scelta, e' promosso al grado superiore in ordine di ruolo con decorrenza dal 1° luglio dell'anno di inserimento in aliquota;)) b) il restante personale e' sottoposto a seconda valutazione per l'avanzamento all'epoca della formazione delle corrispondenti aliquote di scrutinio dell'anno successivo. Di essi: 1) la prima meta' e' promossa in ordine di ruolo, previa nuova valutazione, con un anno di ritardo rispetto al personale di cui alla lettera a), prendendo posto nel ruolo dopo il primo terzo del personale da promuovere in prima valutazione nello stesso anno ai sensi della medesima lettera a); 2) la seconda meta' e' promossa in ordine di ruolo, previa nuova valutazione, con due anni di ritardo rispetto al personale di cui alla lettera a), prendendo posto nel ruolo dopo il personale da promuovere in seconda valutazione nello stesso anno.

((

2-bis. Per il personale appartenente al ruolo dei marescialli dell'Aeronautica militare, le procedure di avanzamento a scelta si effettuano distintamente nell'ambito di ciascuna categoria e specialita' con l'attribuzione delle relative promozioni secondo il criterio di proporzionalita', assicurando almeno una promozione per specialita'.

))

3. Ogni sottufficiale e' comunque promosso in data non anteriore a quella di promozione del pari grado che lo precede.

4. Il personale escluso dalle aliquote di valutazione per i motivi di cui all'articolo 1051, nell'avanzamento a scelta, prende posto, se idoneo, a seconda del punteggio globale attribuito, nella graduatoria di merito dei pari grado con i quali sarebbe stato valutato in assenza delle cause impeditive, ed e' promosso secondo le modalita' indicate nei precedenti commi.

5. COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94.

#### Art. 1274. - Condizioni particolari per l'avanzamento

1. Il personale appartenente ai ruoli dei marescialli e dei sergenti deve, a seconda della Forza armata o Corpo o categoria o specialita' di appartenenza, aver compiuto i periodi minimi di comando, di attribuzioni specifiche, di servizio presso reparti e di imbarco e aver superato i corsi e gli esami stabiliti.

((

1-bis. Per l'avanzamento a primo maresciallo e' richiesto il possesso della laurea.

))

2. Il Ministro della difesa ha facolta' di istituire con proprio decreto corsi per acquisire condizioni per l'avanzamento tenendo conto delle esigenze formative dei marescialli e delle particolari necessita' di servizio.

#### Art. 1275. - Ulteriori condizioni particolari per l'avanzamento dei sottufficiali della Marina militare

1. Per la Marina militare e' esentato dal compiere il periodo minimo di imbarco o in reparti operativi il personale appartenente alla categoria ovvero alla ((specialita')) dei musicanti, dei conduttori di automezzi e degli istruttori marinareschi educatori fisici.

2. Ai fini dell'avanzamento e' considerato come imbarcato su navi della Marina militare, in armamento o in riserva, esclusivamente il personale che ricopre incarichi attinenti alla specifica categoria o specialita' o specializzazione posseduta e previsti dall'ordinamento di Forza armata presso i reparti di volo o presso gli eliporti o gli aeroporti e quello che frequenta corsi di istruzione per il conseguimento dell'abilitazione di specialista d'elicottero o d'aereo.

3. I sottufficiali della Marina militare sbarcati da una nave della Marina militare all'estero per brevi missioni, per il computo del periodo di imbarco necessario per l'avanzamento, sono considerati imbarcati per tutto il tempo della missione; in caso di missione prolungata e' in facolta' del Ministero della difesa disporre diversamente.

4. Per determinate specialita' o gradi di esse il Ministro della difesa, sentito il parere delle competenti commissioni di avanzamento, puo' con suo decreto disporre l'esonero dall'obbligo del periodo minimo d'imbarco per l'avanzamento, ovvero la riduzione della sua durata, in relazione alle specifiche attribuzioni di dette specialita' oppure alla possibilita' di assegnare personale a bordo delle navi.

5. I sottufficiali abilitati <<montatori artificieri>> sono esentati dagli obblighi connessi con le particolari condizioni per l'avanzamento prescritte dal presente codice.

((

6. Per il personale nocchieri di porto le attribuzioni specifiche, oltre che in destinazioni di imbarco, possono essere soddisfatte, in tutto o in parte, con la permanenza presso uffici territoriali, reparti operativi o componenti specialistiche in incarichi di comando o incarichi attinenti alla categoria, specialita' e abilitazione di appartenenza.

))

6-bis. ((COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173)).

### SEZIONE II - PROFILO DI CARRIERA DEI MARESCIALLI

#### Art. 1276. - Articolazione della carriera

1. Lo sviluppo di carriera dei marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare prevede i seguenti gradi gerarchici:

- a) maresciallo: capo di 3^ classe per la Marina militare, maresciallo di 3^ classe per l'Aeronautica militare;
- b) maresciallo ordinario: capo di 2^ classe per la Marina militare, maresciallo di 2^ classe per l'Aeronautica militare;
- c) maresciallo capo: capo di 1^ classe per la Marina militare, maresciallo di 1^ classe per l'Aeronautica militare;
- d) primo maresciallo.
- d-bis) luogotenente.

2. Al ((luogotenente)) puo' essere conferita la qualifica di ((primo luogotenente)).

#### Art. 1277. - Forme di avanzamento

1. L'avanzamento avviene:

- a) ad anzianita', per il grado di maresciallo ordinario e maresciallo capo;
- b) a scelta, per il grado di primo maresciallo ((e luogotenente));
- c) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 94)).

#### Art. 1278. - Periodi minimi di permanenza nel grado

1. Il periodo di permanenza minima nel grado, richiesto per l'inserimento nell'aliquota di valutazione a scelta, e' stabilito in:

- a) ((7)) anni per l'avanzamento al grado di primo maresciallo;
- b) 8 anni per l'avanzamento al grado di luogotenente.

2. COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94.

3. Il periodo di permanenza minima nel grado, richiesto per la promozione ad anzianita' e' stabilito in:

- a) 2 anni per l'avanzamento a maresciallo ordinario e gradi corrispondenti;
- b) ((6)) anni per l'avanzamento a maresciallo capo e gradi corrispondenti.

#### Art. 1279. - Condizioni particolari per l'avanzamento dei marescialli dell'Esercito italiano

1. I periodi minimi di attribuzioni specifiche per l'avanzamento da maresciallo ordinario a maresciallo capo dell'Esercito italiano sono determinati in 3 anni di comando di plotone o reparti corrispondenti, oppure in 4 anni di impiego in incarichi tecnici o nelle specializzazioni, anche se compiuti in tutto o in parte da maresciallo.

2. Gli incarichi tecnici e le specializzazioni sono stabiliti con decreto del Ministro della difesa in base alle esigenze della Forza armata.

#### Art. 1280. - Condizioni particolari per l'avanzamento dei marescialli della Marina militare

1. Oltre a quanto disposto dall'articolo 1137, ai marescialli della Marina militare si applicano anche i seguenti commi.

2. I periodi minimi di imbarco per l'avanzamento da capo di 2^ classe a capo di 1^ classe della Marina militare, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 6 anni;
- b) tecnici del sistema di combattimento: 6 anni;
- c) supporto e servizio amministrativo/logistico, servizio sanitario: 3 anni;
- d) incursori, fucilieri di marina, palombari, specialisti di volo: 6 anni.

3. I periodi minimi di imbarco per l'avanzamento da capo di 1^ classe a primo maresciallo della Marina militare, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 8 anni;
- b) tecnici del sistema di combattimento: 7 anni;
- c) supporto e servizio amministrativo/logistico, servizio sanitario: 4 anni;
- d) nocchieri di porto: 3 anni;
- e) incursori, fucilieri di marina, palombari, specialisti di volo: 7 anni.

((

4. I periodi minimi di imbarco per l'avanzamento da primo maresciallo a luogotenente della Marina militare, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 9 anni;
- b) tecnici del sistema di combattimento: 8 anni;
- c) nocchieri di porto: 6 anni;
- d) incursori, fucilieri di marina, palombari, specialisti di volo: 8 anni.

))

4-bis. Per le categorie e specialita' di cui ai commi 2, lettera d), 3, lettera e), e 4, lettera d), i relativi periodi minimi indicati possono essere svolti anche in reparti operativi, definiti dall'ordinamento di Forza armata.

((

4-ter. Per i marescialli della categoria tecnici del sistema di combattimento specialita' operatore elaborazione automatica dati, i periodi minimi indicati ai commi 2, lettera b), 3, lettera b) e 4, lettera b), sono ridotti rispettivamente a 3 anni, 4 anni e 4 anni.

4-quater. L'eventuale modifica della suddivisione in categorie, specialita' e abilitazioni, che comporta il transito di una specialita' ad un'altra categoria con periodi minimi di imbarco diversi da quelli previsti per la categoria di provenienza, determina l'applicazione, ai fini dell'avanzamento, dei periodi minimi di imbarco piu' favorevoli.

))

((

5. I periodi indicati si intendono comprensivi degli anni di imbarco ovvero di reparti operativi effettuati nei gradi precedenti, anche in ruoli diversi e in ferma.

))

#### Art. 1281. - Condizioni particolari per l'avanzamento dei marescialli dell'Aeronautica militare

1. I periodi minimi di attribuzioni specifiche per l'avanzamento dei marescialli dell'Aeronautica militare, in relazione al grado rivestito, sono cosi' determinati:

- a) da maresciallo di 2^ classe a maresciallo di 1^ classe: 5 anni di impiego in incarichi della categoria di appartenenza anche se svolti in parte nel grado di maresciallo di 3^ classe;
- b) da maresciallo di 1^ classe a primo maresciallo: 4 anni di impiego in incarichi della categoria di appartenenza.

#### Art. 1282. - (( (Avanzamento a scelta al grado di luogotenente per il personale militare dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). ))

((

1. All'avanzamento a scelta al grado di luogotenente sono ammessi i primi marescialli:

- a) che hanno maturato il periodo minimo di permanenza nel grado previsto all'articolo 1278, comma 1, lettera b);
- b) iscritti nei quadri di avanzamento e non promossi.

2. I primi marescialli giudicati idonei e iscritti nel quadro d'avanzamento a scelta sono promossi al grado superiore, nell'ordine della graduatoria di merito, nel limite dei posti disponibili di cui al successivo comma 3.

3. Il numero delle promozioni da conferire annualmente e' stabilito in misura non superiore a 1/47 dell'organico dei rispettivi ruoli dei marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, di cui all'articolo 798-bis, comma 1, ovvero di quelli previsti nel decreto di cui all'articolo 2207.

4. La commissione di cui all'articolo 1047 valuta i primi marescialli di cui al comma 1, secondo i criteri stabiliti dall'articolo 1059.

5. Il conferimento del grado decorre dal giorno successivo a quello del compimento del periodo minimo di permanenza previsto all'articolo 1278, comma 1, lettera b).

))

### SEZIONE III - PROFILO DI CARRIERA DEI SERGENTI

#### Art. 1283. - Articolazione della carriera

1. Lo sviluppo di carriera dei sergenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare prevede i seguenti gradi gerarchici:

- a) sergente;
- b) sergente maggiore: secondo capo per la Marina militare;
- c) sergente maggiore capo: secondo capo scelto per la Marina militare.

1-bis. Ai sergenti maggiori capi e gradi corrispondenti puo' essere conferita la seguente qualifica: ((sergente maggiore aiutante per l'Esercito italiano e l'Aeronautica militare; secondo capo aiutante per la Marina militare)).

#### Art. 1284. - (( (Forme di avanzamento).))

((

1. L'avanzamento ai gradi di sergente maggiore e sergente maggiore capo e gradi corrispondenti avviene ad anzianita'.

))

#### Art. 1285. - Periodi di permanenza minima nel grado

1. Il periodo di permanenza minima nel grado ((...)) per l'avanzamento al grado di sergente maggiore capo e corrispondenti e' stabilito in ((5 anni)).

2. Il periodo di permanenza minima nel grado, richiesto per la promozione ad anzianita' al grado di sergente maggiore, e' stabilito in ((4 anni)).

#### Art. 1286. - Condizioni particolari per l'avanzamento dei sergenti dell'Esercito italiano

((

1. I periodi minimi di attribuzioni specifiche per l'avanzamento da sergente maggiore a sergente maggiore capo sono determinati in 4 anni di comando di squadra o reparti corrispondenti ovvero di impiego in incarichi tecnici o nelle specializzazioni, anche se compiuti tutti o in parte nel grado inferiore. Per gli incarichi tecnici delle operazioni speciali e di quelli dei tecnici aeromobili, il periodo indicato e' comprensivo del periodo di frequenza dei corsi per conseguire la qualifica ovvero il brevetto, ove questi siano terminati con esito favorevole.

))

2. Gli incarichi tecnici e le specializzazioni sono stabiliti con decreto del Ministro della difesa in base alle esigenze della Forza armata.

#### Art. 1287. - Condizioni particolari per l'avanzamento dei sergenti della Marina militare

1. Oltre a quanto disposto dall'articolo 1137, ai sergenti della Marina militare si applicano anche i seguenti commi.

((

2. I periodi minimi di imbarco per l'avanzamento da sergente a 2° capo della Marina militare, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 5 anni;
- b) tecnici del sistema di combattimento: 5 anni;
- c) supporto e servizio amministrativo/logistico, servizio sanitario: 4 anni;
- d) nocchieri di porto: 2 anni;
- e) incursori, fucilieri di marina, palombari, specialisti di volo: 5 anni.

3. I periodi minimi di imbarco per l'avanzamento da 2° capo a 2° capo scelto della Marina militare, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 8 anni;
- b) tecnici del sistema di combattimento: 7 anni;
- c) supporto e servizio amministrativo/logistico, servizio sanitario: 5 anni;
- d) nocchieri di porto: 4 anni;
- e) incursori, fucilieri di marina, palombari, specialisti di volo: 7 anni.

))

3-bis. Per le categorie e specialita' di cui ai commi 2, lettera e), e 3, lettera e), i relativi periodi minimi indicati possono essere svolti anche in reparti operativi , definiti dall'ordinamento di Forza armata.

4. I periodi indicati si intendono comprensivi degli anni di imbarco ovvero di reparti operativi effettuati nei gradi precedenti, anche in ruoli diversi e in ferma.

((

4-bis. L'eventuale modifica della suddivisione in categorie, specialita' e abilitazioni, che comporta il transito di una specialita' ad un'altra categoria con periodi minimi di imbarco diversi da quelli previsti per la categoria di provenienza, determina l'applicazione, ai fini dell'avanzamento, dei periodi minimi di imbarco piu' favorevoli.

))

#### Art. 1288. - Condizioni particolari per l'avanzamento dei sergenti dell'Aeronautica militare

1. I periodi minimi di attribuzioni specifiche, per l'avanzamento dei sergenti dell'Aeronautica militare, da sergente a sergente maggiore e da sergente maggiore a sergente maggiore capo sono determinati in ((3 anni)) di impiego in incarichi della categoria di appartenenza

## CAPO XIV - AVANZAMENTO DEGLI ISPETTORI E DEI SOVRINTENDENTI DELL'ARMA DEI CARABINIERI

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1289. - Avanzamento a scelta degli ispettori e dei sovrintendenti

1. L'avanzamento a scelta degli ispettori e dei sovrintendenti avviene secondo le modalita' e le valutazioni di cui all'articolo 1059.

#### Art. 1290. - Condizioni per l'avanzamento

1. Gli ispettori e i sovrintendenti per essere valutati devono aver compiuto i periodi minimi di comando, di attribuzioni specifiche e aver superato i corsi e gli esami stabiliti dagli articoli successivi.

2. Il Ministro della difesa ha facolta' di istituire con proprio decreto corsi per acquisire condizioni per l'avanzamento tenendo conto delle esigenze formative dei marescialli e delle particolari necessita' di servizio.

### SEZIONE II - PROFILO DI CARRIERA DEGLI ISPETTORI

#### Art. 1291. - Articolazione della carriera

1. Lo sviluppo di carriera degli ispettori dell'Arma dei carabinieri prevede i seguenti gradi gerarchici:

- a) maresciallo;
- b) maresciallo ordinario;
- c) maresciallo capo;
- d) maresciallo ((maggiore)).

((

2. Al luogotenente puo' essere attribuita la qualifica di carica speciale.

))

#### Art. 1292. - Forme di avanzamento

1. L'avanzamento avviene:

- a) ad anzianita', per il grado di maresciallo ordinario e maresciallo capo;
- b) a scelta, per i gradi di maresciallo maggiore e luogotenente.
- c) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95)).

#### Art. 1293. - Periodi minimi di permanenza nel grado

1. Il periodo minimo di permanenza nel grado, richiesto per l'inserimento nell'aliquota di valutazione a scelta e' stabilito in:

- a) ((7 anni)) per l'avanzamento a maresciallo maggiore;
- b) 8 anni per l'avanzamento a luogotenente.

2. COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95.

3. Il periodo minimo di permanenza nel grado, richiesto per la promozione ad anzianita' e' stabilito in:

- a) 2 anni per l'avanzamento al grado di maresciallo ordinario;
- b) ((6 anni)) per l'avanzamento al grado di maresciallo capo.

#### Art. 1294. - (Condizioni particolari per l'avanzamento dei marescialli capo)

1. I periodi minimi di attribuzioni specifiche per l'avanzamento da maresciallo capo a maresciallo maggiore sono determinati in un anno di comando di stazione ((territoriale)) o di altra unita' organizzativa individuata, ovvero di impiego in incarichi di specializzazione, anche se compiuto in tutto o in parte nel grado di maresciallo o maresciallo ordinario.

2. Gli incarichi utili al compimento del periodo di attribuzione specifica di cui al comma 1 sono stabiliti con determinazione del Comandante generale dell'Arma dei carabinieri.

#### Art. 1295.

(( (Avanzamento a scelta al grado di maresciallo maggiore).)) ((

1. Le promozioni da conferire al grado di maresciallo maggiore sono cosi' determinate:

- a) il primo terzo dei marescialli capo iscritti nel quadro di avanzamento a scelta e' promosso al grado superiore in ordine di ruolo con decorrenza dal giorno successivo a quello di compimento del periodo minimo di permanenza previsto dall'articolo 1293;
- b) i restanti marescialli capo sono sottoposti a seconda valutazione per l'avanzamento all'epoca della formazione delle corrispondenti aliquote di scrutinio dell'anno successivo. Di essi: 1) la prima meta' e' promossa, in ordine di ruolo, con un anno di ritardo rispetto al periodo minimo di permanenza previsto dall'articolo 1293, prendendo posto nel ruolo dopo i marescialli capo da promuovere in prima valutazione nello stesso anno secondo la norma della lettera a); 2) la seconda meta', previo giudizio di idoneita', in ordine di ruolo, e' promossa con due anni di ritardo rispetto al periodo minimo di permanenza previsto dall'articolo 1293, prendendo posto nel ruolo dopo i marescialli capo da promuovere in seconda valutazione nello stesso anno, secondo la norma del numero 1).

2. I marescialli capo esclusi dalle aliquote di valutazione ai sensi dell'articolo 1051, nell'avanzamento a scelta prendono posto, se idonei, a seconda del punteggio globale attribuito nella graduatoria di merito dei parigrado con i quali sarebbero stati valutati in assenza delle cause impeditive. In relazione alla posizione in graduatoria, sono promossi secondo le modalita' indicate nel comma 1.

#### Art. 1295-bis. - (( (Avanzamento a scelta al grado di luogotenente).))

((

1. I marescialli maggiori giudicati idonei e iscritti nel quadro d'avanzamento "a scelta" sono promossi, in ordine di ruolo, al grado superiore nel limite dei posti disponibili.

2. All'avanzamento "a scelta" al grado di luogotenente sono ammessi i marescialli maggiori:

- a) che hanno maturato il periodo minimo di permanenza nel grado;
- b) iscritti nei quadri di avanzamento e non rientranti nel numero delle promozioni annuali da conferire, con riferimento alle aliquote di valutazione determinate negli anni precedenti;

3. Il numero delle promozioni da conferire annualmente e' stabilito in misura non superiore a 1/47 dell'organico del ruolo ispettori e periti dell'Arma dei carabinieri di cui all'articolo 800, comma 2.

4. La commissione di cui all'articolo 1047 valuta i marescialli maggiori di cui al comma 1 secondo i criteri stabiliti dall'articolo 1059. Tra i titoli assume rilevanza preferenziale il comando della tenenza e della stazione territoriale.

5. Il conferimento del grado decorre dal giorno successivo a quello del compimento del periodo minimo di anzianita' di permanenza previsto all'articolo 1293, comma 1, lettera b). Per il personale di cui al comma 2, lettera b), la promozione ha decorrenza nell'anno in cui risulta utilmente iscritto nel quadro di avanzamento.

))

#### Art. 1296. - Avanzamento a sottotenente

1. I ((luogotenenti)) dell'Arma dei carabinieri possono conseguire la promozione per meriti eccezionali e per benemerenze d'istituto nel grado di sottotenente del ruolo ((normale)) degli ufficiali dell'Arma dei carabinieri.

2. La proposta di avanzamento e' formulata secondo le norme di cui agli articoli 1062 e 1063.

### SEZIONE III - PROFILO DI CARRIERA DEI SOVRINTENDENTI

#### Art. 1297. - Articolazione della carriera

1. Lo sviluppo di carriera dei sovrintendenti dell'Arma dei carabinieri prevede i seguenti gradi gerarchici:

- a) vice brigadiere;
- b) brigadiere;
- c) brigadiere capo.

((

1-bis. Al brigadiere capo puo' essere attribuita la qualifica di qualifica speciale.

))

#### Art. 1298. - Forme di avanzamento

1. L'avanzamento ((ai gradi di brigadiere e di brigadiere capo avviene ad anzianita'.))

- a) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95));
- b) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95)).

#### Art. 1299. - (Periodi minimi di permanenza nel grado)

1. Il periodo minimo di permanenza nel grado, richiesto per la promozione ad anzianita' ((e' stabilito in: a) 4 anni per l'avanzamento al grado di brigadiere; b) 5 anni per l'avanzamento al grado di brigadiere capo.))

#### Art. 1300.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

## CAPO XV - AVANZAMENTO DEI GRADUATI E MILITARI DI TRUPPA

### SEZIONE I - AVANZAMENTO DEI MILITARI DI TRUPPA

#### Art. 1301.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8)).

#### Art. 1302. - Avanzamento al grado di caporal maggiore e corrispondenti

1. Previo giudizio di idoneita', i caporali o gradi corrispondenti possono conseguire il grado di caporal maggiore o corrispondente, non prima del compimento del diciottesimo mese dall'ammissione alla ferma prefissata ((triennale)).

2. Decorso un anno dal giudizio di non idoneita', il volontario e' sottoposto a nuova valutazione.

#### Art. 1303. - (( (Avanzamento al grado di graduato e corrispondenti). ))

((1. I volontari in ferma prefissata triennale conseguono il grado di graduato o corrispondente, con decorrenza dalla data di immissione nei ruoli dei volontari in servizio permanente))

#### Art. 1304. - Conferimento del grado

1. Il grado e' conferito dal comandante di corpo, previa acquisizione del giudizio della commissione di cui all'articolo 1047, comma 5.

#### Art. 1305. - Estensione delle norme sull'avanzamento

1. Per quanto non diversamente disposto, ai volontari in ferma prefissata si applicano, in quanto compatibili, le disposizioni in materia di avanzamento relative ai volontari in servizio permanente

### SEZIONE II - PROFILO DI CARRIERA DEI VOLONTARI IN SERVIZIO PERMANENTE

#### Art. 1306. - Articolazione della carriera

1. Lo sviluppo di carriera dei volontari in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare prevede i seguenti gradi gerarchici:

- a) ((graduato)) o grado corrispondente;
- b) ((graduato scelto)) o grado corrispondente;
- c) ((graduato capo)) o grado corrispondente;
- d) ((primo graduato)) o grado corrispondente.

1-bis. Ai ((primi graduati)), e gradi corrispondenti, puo' essere conferita la seguente qualifica: ((graduato aiutante per l'Esercito italiano e l'Aeronautica militare; sottocapo aiutante per la Marina militare)).

#### Art. 1307. - Avanzamento dei volontari in servizio permanente

1. Al ((graduato)) o corrispondente, che ha un anno di anzianita' nel servizio permanente, e' conferito ad anzianita', previo giudizio di idoneita', espresso dalle commissioni d'avanzamento, il grado di ((graduato scelto)) o corrispondente.

2. Al ((graduato scelto)) o corrispondente, che ha cinque anni di anzianita' di grado, e' conferito ad anzianita', previo giudizio di idoneita', espresso dalle commissioni d'avanzamento, il grado di ((graduato capo)) o corrispondente.

3. Al ((graduato capo)) o corrispondente, che ha quattro anni di anzianita' di grado, e' conferito ad anzianita', previo giudizio di idoneita', espresso dalle commissioni d'avanzamento, il grado di ((primo graduato)) o corrispondente.

4. I gradi di cui ai commi precedenti sono conferiti, con decreto ministeriale, con decorrenza dal giorno successivo a quello del compimento del periodo minimo di servizio o di permanenza nel grado.

5. Nei periodi di servizio di cui al presente articolo non sono computati gli anni durante i quali gli interessati sono stati giudicati non idonei all'avanzamento, nonche' i periodi di detrazione di anzianita' subiti per effetto di condanne penali, di sospensioni dal servizio per motivi disciplinari o di aspettative per motivi privati.

#### Art. 1307-bis.

(Attribuzione della qualifica ((di graduato aiutante e di sottocapo aiutante)) ai ((primi graduati)) e gradi corrispondenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). 1.Per l'attribuzione della qualifica ((di graduato aiutante e di sottocapo aiutante)) sono inseriti in un'aliquota determinata con decreto dirigenziale al 31 dicembre di ogni anno i ((primi graduati e gradi corrispondenti)) in possesso dei seguenti requisiti: a) cinque anni di anzianita' di grado; b) assenza delle condizioni di cui all'articolo 1051; c) aver riportato nel triennio precedente alla data di formazione dell'aliquota, in sede di valutazione caratteristica, la qualifica di almeno «superiore alla media» o giudizio equivalente secondo i criteri definiti dalla Direzione generale per il personale militare; d) non aver riportato nel biennio precedente alla data di formazione dell'aliquota sanzioni disciplinari piu' gravi della consegna. 2. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado previsto dal comma 1, lettera a). 3. COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173. 4. Al personale escluso dalle aliquote di cui al comma 1 per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del titolo VII, in materia di rinnovazione dei giudizi di avanzamento. 4-bis. I ((primi graduati e gradi corrispondenti)) esclusi dalle aliquote per mancanza dei requisiti di cui al comma 1, lettere c) e d), sono inseriti nella prima aliquota successiva alla data di maturazione di tali requisiti e la qualifica ((di graduato aiutante e di sottocapo aiutante)) e' conferita a decorrere dal giorno successivo a tale data.

#### Art. 1308. - Condizioni particolari per l'avanzamento dei volontari della Marina militare

1. Il personale appartenente al ruolo dei volontari in servizio permanente della Marina militare per essere valutato deve, a seconda della categoria o specialita' o specializzazione di appartenenza, in aggiunta a quanto disposto dall'articolo 1137, aver compiuto i periodi minimi di imbarco.

2. I periodi minimi di imbarco per l'avanzamento da sottocapo di 2^ classe a sottocapo di 1^ classe, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 6 anni;
- b) tecnici del sistema di combattimento: 6 anni;
- c) supporto e servizio amministrativo/logistico, servizio sanitario: 3 anni;
- d) incursori, fucilieri di marina, palombari, specialisti di volo: 6 anni.

3. I periodi minimi di imbarco per l'avanzamento da sottocapo di 1^ classe a ((sottocapo scelto)) della Marina militare, in relazione alla categoria o specialita' o specializzazione di appartenenza, sono cosi' determinati:

- a) nocchieri, specialisti del sistema di combattimento, specialisti del sistema di piattaforma: 8 anni;
- b) tecnici del sistema di combattimento: 7 anni;
- c) supporto e servizio amministrativo/logistico, servizio sanitario: 4 anni;
- d) nocchieri di porto: 3 anni;
- e) incursori, fucilieri di marina, palombari, specialisti di volo: 7 anni.

3-bis. Per le categorie e specialita' di cui ai commi 2, lettera d), e 3, lettera e), i relativi periodi minimi indicati possono essere svolti anche in reparti operativi, definiti dall'ordinamento di Forza armata.

4. I periodi indicati si intendono comprensivi degli anni di imbarco ovvero di reparti operativi effettuati nei gradi precedenti, anche in ruoli diversi e in ferma.

4-bis. Per i nocchieri di porto di cui al comma 3, lettera d) i relativi periodi possono essere soddisfatti, in tutto o in parte, anche con la permanenza presso uffici territoriali, reparti operativi o componenti specialistiche in incarichi attinenti alla categoria, specialita' e abilitazione di appartenenza.

4-ter. L'eventuale modifica della suddivisione in categorie, specialita' e abilitazioni che comporta il transito di una specialita' ad un'altra categoria, con periodi minimi di imbarco diversi da quelli previsti per la categoria di provenienza, determina l'applicazione, ai fini dell'avanzamento, dei periodi minimi di imbarco piu' favorevoli.

#### Art. 1309. - Ulteriori condizioni particolari per l'avanzamento dei volontari della Marina militare

1. Per la Marina militare e' esentato dal compiere il periodo minimo di imbarco o di reparto operativo il personale appartenente alla categoria ovvero alla ((specialita')) dei musicanti, dei conduttori di automezzi e degli istruttori marinareschi educatori fisici.

2. Ai fini dell'avanzamento e' considerato come imbarcato su navi della Marina militare, in armamento o in riserva, solo il personale che ricopre incarichi attinenti alla specifica categoria o specialita' o specializzazione posseduta e previsti dall'ordinamento di Forza armata presso i reparti di volo o presso gli eliporti o gli aeroporti e quello che frequenta corsi di istruzione per il conseguimento dell'abilitazione di specialista d'elicottero o d'aereo.

3. I volontari in servizio permanente della Marina militare sbarcati da una nave della Marina militare all'estero per brevi missioni, per il computo del periodo di imbarco necessario per l'avanzamento, sono considerati imbarcati per tutto il tempo della missione; in caso di missione prolungata e' in facolta' del Ministero della difesa disporre diversamente.

4. Per determinate specialita' o gradi di esse il Ministro della difesa, sentito il parere delle competenti commissioni di avanzamento, puo' con suo decreto disporre l'esonero dall'obbligo del periodo minimo d'imbarco per l'avanzamento, ovvero la riduzione della sua durata, in relazione alle specifiche attribuzioni di dette specialita' oppure alla possibilita' di assegnare personale a bordo delle navi.

((

5. Per il personale nocchieri di porto le attribuzioni specifiche, oltre che in destinazioni di imbarco, possono essere soddisfatte in tutto o in parte con la permanenza presso uffici territoriali, reparti operativi o componenti specialistiche in incarichi attinenti alla categoria, specialita' e abilitazione di appartenenza.

))

### SEZIONE III - PROFILO DI CARRIERA DEGLI APPUNTATI E CARABINIERI

#### Art. 1310. - Articolazione della carriera

1. Lo sviluppo di carriera degli appuntati e carabinieri prevede i seguenti gradi gerarchici:

- a) carabiniere;
- b) carabiniere scelto;
- c) appuntato;
- d) appuntato scelto.

((1-bis. All'appuntato scelto puo' essere attribuita la qualifica di qualifica speciale))

#### Art. 1311. - Avanzamento degli appuntati e carabinieri

1. Ai carabinieri che hanno compiuto quattro anni e sei mesi di anzianita' nel grado, e' conferito il grado di carabiniere scelto.

2. Ai carabinieri scelti che hanno compiuto cinque anni di anzianita' nel grado, e' conferito il grado di appuntato.

3. Agli appuntati che hanno compiuto quattro anni di anzianita' nel grado, e' conferito il grado di appuntato scelto.

4. I gradi di cui ai commi 1, 2 e 3 sono conferiti, con decorrenza dal giorno successivo a quello del compimento del periodo minimo di anzianita' nel grado, data in cui ha inizio la procedura di valutazione, con determinazione del Comandante generale dell'Arma dei carabinieri, o dell'autorita' da questi delegata, previo giudizio di idoneita' espresso ai sensi dell'articolo 1056 dalla competente commissione permanente di avanzamento. ((PERIODO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)). Ai militari giudicati non idonei e' data comunicazione delle motivazioni.

4-bis. Gli appuntati e i carabinieri giudicati non idonei sono valutati nuovamente dopo un anno. Gli stessi, se giudicati per la seconda volta non idonei, possono essere ulteriormente valutati nel quarto anno successivo a ogni giudizio negativo. A tal fine, se giudicati idonei, sono promossi con le stesse modalita' e con le stesse decorrenze attribuite ai pari grado con i quali sono stati portati in avanzamento.

#### Art. 1312. - Impedimenti alla valutazione

1. Non puo' essere valutato per l'avanzamento il personale appartenente al ruolo appuntati e carabinieri che si trovi nelle condizioni indicate dall'articolo 1051.

2. Al venir meno delle singole cause impeditive elencate all'articolo 1051, purche' sussistano i requisiti di legge per l'iscrizione a ruolo, il medesimo personale e' sottoposto a valutazione con le modalita' di cui all'articolo 1311 e, se dichiarato idoneo, e' promosso con la stessa decorrenza che gli sarebbe spettata se la valutazione fosse stata effettuata in assenza della causa impeditiva.

#### Art. 1313.

((ARTICOLO ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248))

## CAPO XVI - AVANZAMENTO NEL RUOLO D'ONORE

### SEZIONE I - PERSONALE ISCRITTO NEL RUOLO D'ONORE

#### Art. 1314. - Promozioni nel ruolo d'onore

1. I militari iscritti nel ruolo d'onore possono conseguire avanzamento al grado superiore a quello di iscrizione, dopo aver compiuto cinque anni di anzianita' di grado e almeno un anno di permanenza in detto ruolo oppure, nel caso di richiamo, dopo almeno un anno di servizio.

2. Gli stessi militari possono conseguire una seconda promozione:

- a) dopo altri cinque anni di permanenza nel ruolo;
- b) o se hanno maturato una anzianita' complessiva minima di dieci anni cumulativamente nell'attuale grado e in quello precedente, con almeno sei anni di permanenza nel ruolo;
- c) o, nel caso di richiamo ai sensi dell'articolo 804, comma 2, dopo almeno un anno di servizio dalla data del precedente avanzamento.

3. I militari che hanno conseguito la promozione ai sensi del comma 2 possono ottenere una terza promozione se, successivamente alla data della seconda promozione, maturano le condizioni di cui alle lettere a) o c) del comma 2.

4. Possono conseguire una quarta promozione i militari che sono titolari di pensione di prima categoria di cui alla tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, oppure sono titolari di un identico trattamento pensionistico, corrisposto in base alle leggi precedentemente vigenti, e che fruiscono di assegno di superinvalidita', se si verificano per essi, dopo la terza promozione, le condizioni di cui alle lettere a) o c) del comma 2.

5. Le promozioni per merito di guerra, ovvero conseguite in tempo di guerra o di grave crisi internazionale, non sono comprese tra quelle previste nei precedenti commi.

6. I graduati possono conseguire la promozione al grado superiore a quello di iscrizione anche se di sottufficiale.

#### Art. 1315. - Nomina dei sottufficiali a ufficiale

1. I sottufficiali del ruolo d'onore titolari di pensione di prima, seconda o terza categoria, ovvero decorati al valor militare o promossi per merito di guerra, aventi grado di ((luogotenente)) o corrispondente, nonche' quelli nelle stesse condizioni che pervengono al grado predetto ai sensi dell'articolo 1314 e che non hanno gia' ottenuto il numero massimo di promozioni previste dallo stesso articolo, possono, a domanda e previo giudizio favorevole della commissione ordinaria di avanzamento, conseguire il grado di sottotenente nel ruolo d'onore della rispettiva Forza armata, dopo aver maturato l'anzianita' di grado e di ruolo o di servizio richiesta per le promozioni dall'articolo 1314.

2. Per la nomina a sottotenente, la commissione ordinaria di avanzamento:

- a) giudica tenendo presenti, in quanto applicabili, le disposizioni di questo codice sull'avanzamento degli ufficiali;
- b) determina l'arma, corpo, ruolo o servizio di assegnazione nei casi di incompatibilita' professionale o di mancanza, nel grado di ufficiale, dell'arma, corpo, ruolo o servizio da cui il sottufficiale proviene.

3. Gli ufficiali cosi' nominati non possono conseguire complessivamente, nei ruoli d'onore degli ufficiali e dei sottufficiali, un numero di promozioni, ivi compresa la nomina a sottotenente, superiore a quello previsto dall'articolo 1314, ne' possono, comunque, ottenere promozioni oltre il grado di capitano.

#### Art. 1316. - Forma di avanzamento

1. L'avanzamento di cui ai precedenti articoli ha luogo ad anzianita', senza che occorra determinare aliquota di ruolo e prescindendo dal requisito dell'idoneita' fisica. I militari sono valutati dagli organi competenti, per ciascuna Forza armata, a esprimere giudizi di avanzamento.

2. I militari giudicati idonei sono promossi senza iscrizione in quadro di avanzamento con anzianita' corrispondente alla data di compimento dell'anzianita' di grado o del periodo di permanenza nel ruolo o di servizi prescritti.

#### Art. 1317. - Limite alle promozioni per gli ufficiali

1. Gli ufficiali non possono conseguire avanzamento oltre il grado massimo previsto per il ruolo dal quale provengono. Peraltro, gli ufficiali provenienti dal ruolo di complemento possono conseguire avanzamento fino al grado di colonnello, se titolari di pensione di 1ª categoria, che fruiscono di assegno di superinvalidita'.

#### Art. 1318. - Nomina al grado vertice dei ruoli marescialli e ispettori

1. I graduati e i militari di truppa dell'Esercito italiano, della Marina militare, dell'Aeronautica militare e dell'Arma dei carabinieri, in godimento di pensione vitalizia o assegno rinnovabile di prima categoria con diritto agli assegni di superinvalidita' di cui alla lettera A e alla lettera A-bis, numeri 1 e 3, della tabella E), annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, possono, a domanda, conseguire la nomina ((a luogotenente)).

2. La stessa nomina puo' essere conferita, a domanda, ai sottufficiali che si trovano nelle condizioni di cui al comma 1 e che sono iscritti nel ruolo d'onore con gradi inferiore a quello di ((luogotenente)).

### SEZIONE II - PERSONALE DECORATO AL VALOR MILITARE O CIVILE IN SERVIZIO

#### Art. 1319. - Promozioni per i trattenuti o richiamati in servizio

1. Il personale militare iscritto nel ruolo d'onore, decorato al valor militare o civile, trattenuto o richiamato in servizio, puo' conseguire fino a tre promozioni oltre il grado rivestito all'atto del trattenimento o del richiamo in servizio, ciascuna delle quali dopo il compimento di cinque anni dal conseguimento della precedente.

2. Al personale titolare di pensione di prima categoria di cui alla tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e che fruisca di assegno di superinvalidita', puo' essere conferita una quarta promozione se sono trascorsi cinque anni dal conseguimento della terza ai sensi del comma 1.

3. Il numero delle promozioni complessivamente conseguibili ai sensi delle disposizioni del presente capo non puo' essere superiore a quattro; non e' consentito in ogni caso il superamento del grado massimo previsto per il ruolo di appartenenza.

#### Art. 1320. - Forma di avanzamento

1. L'avanzamento di cui all'articolo 1319 ha luogo ad anzianita', senza che occorra determinare aliquota di ruolo e prescindendo dal requisito dell'idoneita' fisica.

2. Il personale giudicato idoneo e' promosso senza iscrizione in quadro di avanzamento, con anzianita' corrispondente alla data di compimento di ognuno dei quinquenni di cui all'articolo 1319.

## CAPO XVII - ATTRIBUZIONE DI QUALIFICHE INDIPENDENTI DAL GRADO

### SEZIONE I - PRIMO CAPITANO

#### Art. 1321. - Qualifica

1. E' istituita la qualifica di primo capitano o primo tenente di vascello per i capitani e gradi corrispondenti.

2. La qualifica di primo capitano e corrispondente non influisce in alcun modo sull'anzianita' di grado nei rapporti gerarchici e disciplinari se non in quanto manifesta l'anzianita' di grado dell'ufficiale.

3. Ai primi capitani e qualifiche corrispondenti possono essere attribuiti incarichi del grado superiore.

#### Art. 1322. - Conferimento della qualifica di primo capitano

1. La qualifica di primo capitano e corrispondente e' conferita ai capitani e gradi corrispondenti di tutti i ruoli che hanno compiuto dodici anni di grado.

2. Ai capitani e gradi corrispondenti delle categorie in congedo di tutti i ruoli spetta la qualifica di primo capitano e qualifica corrispondente se l'hanno assunta gli ufficiali pari grado in servizio permanente effettivo di pari anzianita' del rispettivo ruolo.

3. La qualifica e' conferita, altresi', ai capitani e gradi corrispondenti delle Forze armate che hanno compiuto cinque anni di grado e venti di servizio permanente effettivo computati dal ventottesimo anno di eta' compiuto, in tutti i casi in cui il grado di capitano e' quello finale della carriera.

4. La qualifica di primo capitano e corrispondenti e' conferita con decreto ministeriale.

### SEZIONE II - ((PRIMO LUOGOTENENTE E QUALIFICA SPECIALE))

#### Art. 1323. - (Attribuzione della qualifica di primo luogotenente ai luogotenenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)

((1. Per l'attribuzione della qualifica di primo luogotenente sono inseriti in un'aliquota determinata con decreto dirigenziale al 31 dicembre di ogni anno i luogotenenti in possesso dei seguenti requisiti:)) ((alla data di formazione dell'aliquota)) ((secondo i criteri definiti dalla Direzione generale per il personale militare)) ((nel biennio precedente alla data di formazione dell'aliquota))

2. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado previsto dal comma 1, lettera a).

3. ((COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173)).

4. Al personale escluso dalle aliquote di cui ((al comma 1)) per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del titolo VII, in materia di rinnovazione dei giudizi di avanzamento.

((

4-bis. I luogotenenti esclusi dalle aliquote per mancanza dei requisiti di cui al comma 1, lettere c) e d), sono inseriti nella prima aliquota successiva alla data di maturazione di tali requisiti e la qualifica speciale e' conferita a decorrere dal giorno successivo a tale data.

))

#### Art. 1323-bis.

(Attribuzione della qualifica ((di sergente maggiore aiutante o di secondo capo aiutante)) ai ((sergenti maggiori capi e gradi corrispondenti)) dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). 1. Per l'attribuzione della qualifica ((di sergente maggiore aiutante o di secondo capo aiutante)) sono inseriti in un'aliquota determinata con decreto dirigenziale al 31 dicembre di ogni anno i sergenti maggiori capi ((e gradi corrispondenti)) in possesso dei seguenti requisiti: a) sei anni di anzianita' di grado; b) assenza delle condizioni di cui all'articolo 1051; c) aver riportato nel triennio precedente alla data di formazione dell'aliquota, in sede di valutazione caratteristica, la qualifica di almeno «superiore alla media» o giudizio equivalente secondo i criteri definiti dalla Direzione generale per il personale militare; d) non aver riportato nel biennio precedente alla data di formazione dell'aliquota sanzioni disciplinari piu' gravi della consegna. 2. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al comma 1, lettera a). 3. COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173. 4. Al personale escluso dalle aliquote di cui al comma 1 per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del titolo VII, in materia di rinnovazione dei giudizi di avanzamento. 4-bis. I sergenti maggiori capi ((e gradi corrispondenti)) esclusi dalle aliquote per mancanza dei requisiti di cui al comma 1, lettere c) e d), sono inseriti nella prima aliquota successiva alla data di maturazione di tali requisiti e la qualifica ((di sergente maggiore aiutante o di secondo capo aiutante)) e' conferita a decorrere dal giorno successivo a tale data.

#### Art. 1324.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

#### Art. 1325.

((ARTICOLO ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173))

#### Art. 1325-bis. - (Attribuzione della qualifica di carica speciale ai luogotenenti dell'Arma dei carabinieri)

1. La qualifica di carica speciale e' attribuita, previa verifica del possesso dei requisiti da parte dalla commissione di cui all'articolo 1047, ai luogotenenti che:

- a) hanno maturato 4 anni di anzianita' di grado;
- b) non si trovano nelle condizioni di cui all'articolo 1051;
- c) nel triennio precedente hanno ottenuto, in sede di valutazione caratteristica, la qualifica di almeno "eccellente" o giudizio equivalente;
- d) nell'ultimo biennio non abbiano riportato alcuna sanzione disciplinare piu' grave del "rimprovero";

2. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al precedente comma.

3. Per il personale:

- a) sospeso dalla procedura ai sensi del comma 1, lettera b), la qualifica e' conferita con la stessa decorrenza attribuita ai pari grado con i quali sarebbe stato valutato in assenza della causa impeditiva, riacquistando l'anzianita' relativa precedentemente posseduta;
- b) escluso dalla procedura ai sensi del comma 1, lettere c) e d), la qualifica e' conferita dal giorno successivo al maturamento dei requisiti richiesti.

#### Art. 1325-ter. - (Attribuzione della qualifica di qualifica speciale ai brigadieri capo dell'Arma dei carabinieri)

1. La qualifica di qualifica speciale e' attribuita, previa verifica del possesso dei requisiti da parte della commissione di cui all'articolo 1047, ai brigadieri capo che:

- a) hanno maturato ((6 anni)) di anzianita' di grado;
- b) non si trovano nelle condizioni di cui all'articolo 1051;
- c) nel triennio precedente hanno ottenuto, in sede di valutazione caratteristica, la qualifica di almeno "superiore alla media" o giudizio equivalente;
- d) nell'ultimo biennio non abbiano riportato alcuna sanzione disciplinare piu' grave del «rimprovero»;

2. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al precedente comma.

3. Per il personale:

- a) sospeso dalla procedura ai sensi del comma 1, lettera b) la qualifica e' conferita con la stessa decorrenza attribuita ai pari grado con i quali sarebbe stato valutato in assenza della causa impeditiva, riacquistando l'anzianita' relativa precedentemente posseduta;
- b) escluso dalla procedura ai sensi del comma 1, lettere c) e d), la qualifica e' conferita dal giorno successivo al maturamento dei requisiti richiesti.

#### Art. 1325-quater. - (Attribuzione della qualifica speciale agli appuntati scelti dell'Arma dei carabinieri)

1. La qualifica di qualifica speciale e' attribuita, previa verifica del possesso dei requisiti da parte dalla commissione di cui all'articolo 1047, agli appuntati scelti che:

- a) hanno maturato ((5 anni)) di anzianita' di grado;
- b) non si trovano nelle condizioni di cui all'articolo 1051;
- c) nel triennio precedente hanno ottenuto, in sede di valutazione caratteristica, la qualifica di almeno "superiore alla media" o giudizio equivalente;
- d) nell'ultimo biennio non abbiano riportato alcuna sanzione disciplinare piu' grave del "rimprovero";

2. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al comma 1.

3. Per il personale:

- a) sospeso dalla procedura ai sensi del comma 1, lettera b) la qualifica e' conferita con la stessa decorrenza attribuita ai pari grado con i quali sarebbe stato valutato in assenza della causa impeditiva, riacquistando l'anzianita' relativa precedentemente posseduta;
- b) escluso dalla procedura ai sensi del comma 1, lettere c) e d), la qualifica e' conferita dal giorno successivo al maturamento dei requisiti richiesti.

## CAPO XVIII - AVANZAMENTO IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1326. - Definizione

1. Le disposizioni contenute nel presente capo, si applicano nel periodo che ha inizio con la data di dichiarazione dello stato di guerra o di grave crisi internazionale e che termina col 31 dicembre dell'anno in cui e' dichiarata la cessazione dello stato di guerra o della grave crisi internazionale.

2. Continuano ad applicarsi le norme contenute nei capi precedenti del presente titolo, salvo quanto stabilito dalle disposizioni che seguono.

#### Art. 1327. - Generale e gradi corrispondenti

1. Al generale di corpo d'armata, all'ammiraglio di squadra e al generale di squadra aerea, in servizio permanente effettivo, puo' essere conferito, rispettivamente, il grado di generale o di ammiraglio, prescindendo dall'ordine di anzianita'.

2. Il conferimento del grado suddetto e' effettuato con decreto del Presidente della Repubblica, su proposta del Ministro della difesa, previa deliberazione del Consiglio dei Ministri.

#### Art. 1328. - Aiutante di battaglia

1. Ai sottufficiali, ai graduati e ai militari di truppa dell'Esercito italiano, della Marina militare, dell'Aeronautica militare e dell'Arma dei carabinieri, per azioni compiute in guerra o in grave crisi internazionale, puo' essere conferito il grado di aiutante di battaglia.

2. Il grado di aiutante di battaglia e' superiore al grado di ((luogotenente)) e corrispondenti.

3. Il grado di aiutante di battaglia si conserva anche se e' dichiarata la cessazione dello stato di guerra o di grave crisi internazionale.

4. Agli aiutanti di battaglia non provenienti dal servizio permanente puo' essere eccezionalmente concesso il passaggio in servizio permanente per merito di guerra.

#### Art. 1329. - Requisiti per l'avanzamento

1. I periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco, prescritti dal presente codice per l'avanzamento, sono ridotti alla meta'.

2. Non si fa luogo agli esami, corsi ed esperimenti, eventualmente prescritti dal presente codice.

#### Art. 1330. - Collocamento in aspettativa per prigionia di guerra e irreperibilita' accertata

1. I collocamenti in aspettativa per prigionia di guerra e ipotesi equiparate, disposti prima della cessazione delle ostilita', e la irreperibilita' accertata a norma della legge di guerra determinano vacanze organiche agli effetti dell'avanzamento con decorrenza, rispettivamente, dalla data del decreto ministeriale di collocamento in aspettativa e dalla data del verbale di irreperibilita'.

#### Art. 1331. - Avanzamento a scelta degli ufficiali

1. Per i gradi nei quali l'avanzamento si effettua a scelta, l'iscrizione in quadro degli ufficiali ha luogo sempre nell'ordine di ruolo.

2. Se entro il primo semestre dell'anno e' raggiunto in uno dei gradi suddetti il numero delle promozioni, stabilite per l'anno dalle disposizioni del presente codice, e si sono verificate altre vacanze nel grado superiore, il Ministro ha facolta' di colmare, in tutto o in parte, tali vacanze con ulteriori promozioni. A dette promozioni si fa luogo mediante formazione di un quadro di avanzamento suppletivo, previa nuova valutazione degli ufficiali gia' giudicati idonei in occasione della valutazione effettuata per l'anno. Le promozioni sono disposte con decorrenza dal 1° luglio e sono computate nel numero di quelle da effettuare per l'anno successivo.

3. Se in un grado non si raggiunge durante l'anno, per insufficienza di vacanze nel grado superiore, il numero delle promozioni stabilito dal presente codice, le restanti promozioni sono effettuate in soprannumero agli organici, e l'eccedenza e' assorbita al verificarsi della prima vacanza.

#### Art. 1332. - Colonnelli dell'Esercito italiano dei ruoli delle Armi

1. I colonnelli dell'Esercito italiano appartenenti alle Armi di fanteria, di cavalleria, di artiglieria, del genio e delle trasmissioni concorrono alle promozioni da effettuare ai sensi dell'articolo 1331, comma 2, proporzionalmente al numero delle promozioni fisse annuali per essi stabilito; nell'effettuare la ripartizione proporzionale, i quozienti sono calcolati al centesimo e sono arrotondati all'unita', fino a raggiungere il totale delle promozioni da effettuare, i quozienti che presentino la parte decimale piu' elevata.

#### Art. 1333. - Ufficiali di complemento

1. L'ufficiale di complemento per essere valutato per l'avanzamento deve aver compiuto i periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco, prescritti per l'avanzamento del pari grado in servizio permanente effettivo.

2. Se per l'avanzamento del pari grado in servizio permanente effettivo non e' prescritto il compimento dei periodi di cui al comma 1, l'ufficiale di complemento per essere valutato per l'avanzamento deve aver prestato, nel grado, almeno un anno di servizio.

#### Art. 1334. - Ufficiali della riserva

1. Gli ufficiali della riserva, richiamati in servizio, possono conseguire promozioni, prescindendo dalle limitazioni indicate nell'articolo 1270. L'avanzamento ha luogo ad anzianita', con le stesse norme che regolano l'avanzamento degli ufficiali in ausiliaria.

2. Gli ufficiali della riserva di complemento, richiamati in servizio, possono conseguire promozioni ad anzianita' con le stesse norme che regolano l'avanzamento degli ufficiali di complemento.

#### Art. 1335. - Avanzamento dei militari in particolari condizioni fisiche

1. Il militare compreso nell'aliquota di ruolo dei militari da valutare mentre e' temporaneamente non idoneo al servizio incondizionato per ferite riportate in combattimento o per lesioni dovute a esiti di congelamento in zona di operazioni a diretto contatto col nemico, o per altra invalidita' riportata per causa di servizio di guerra in zona di operazioni a diretto contatto col nemico, e' ugualmente valutato prescindendo dal requisito della idoneita' fisica, anche se, in conseguenza delle cause predette, non ha potuto compiere i periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco di cui all'articolo 1329 o eventualmente il periodo di servizio di cui all'articolo 1333, comma 2. Se idoneo all'avanzamento il militare puo' conseguire la promozione a suo turno.

2. Analogamente si provvede nei riguardi del militare che, riacquistata l'idoneita' fisica, non ha compiuto i periodi anzidetti per non idoneita' temporanea dovuta a una delle cause di cui al comma 1.

3. Se per il mancato compimento dei periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco, o eventualmente del periodo di servizio, le autorita' competenti ritengono di non potere addivenire alla pronuncia del giudizio sull'avanzamento, sospendono la valutazione fino a quando il militare, riacquistata l'idoneita' fisica, ha compiuto i periodi stessi. Al militare si applica il disposto dell'articolo 1088.

4. Le disposizioni del presente articolo si applicano anche oltre il tempo di guerra o di grave crisi internazionale, purche' il militare risulta compreso in aliquote di ruolo di militare da valutare durante il tempo di guerra o di grave crisi internazionale. Per l'ufficiale di complemento, pero', agli effetti dell'applicazione del comma 3, e' sufficiente il raggiungimento delle condizioni previste dall'articolo 1255, se piu' favorevoli.

### SEZIONE II - PROMOZIONI E AVANZAMENTI PER MERITO DI GUERRA

#### Art. 1336. - Generalita'

1. In tempo di guerra o di grave crisi internazionale non si fa luogo ad avanzamento per meriti eccezionali. Si possono effettuare promozioni e avanzamenti per merito di guerra.

2. I militari di truppa possono conseguire soltanto promozioni per merito di guerra.

#### Art. 1337. - Promozione per merito di guerra

1. La promozione per merito di guerra e' conferita al militare che in combattimento, in situazioni particolarmente complesse, ha esercitato l'azione di comando in modo eccezionale, dimostrando di possedere tutte le qualita' necessarie per bene adempiere le funzioni del grado superiore.

2. Ai fini della promozione per merito di guerra non e' richiesto il compimento di periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco.

3. La promozione per merito di guerra decorre, a tutti gli effetti, dalla data del fatto che la determino'.

4. La promozione si effettua anche se non esista vacanza nel grado superiore.

#### Art. 1338. - Ufficiali in particolari situazioni

1. La promozione per merito di guerra puo' essere conferita anche all'ufficiale non idoneo all'avanzamento ad anzianita' o a scelta.

2. L'ufficiale a disposizione promosso per merito di guerra permane in detta posizione sino al raggiungimento del limite di eta' del grado conseguito per merito di guerra.

#### Art. 1339. - Disposizioni generali sull'avanzamento per merito di guerra

1. L'avanzamento per merito di guerra e' conferito al militare che ha contribuito in modo eccezionalmente efficace alla preparazione o allo svolgimento di operazioni di guerra, dando prova di eminenti qualita' professionali.

2. L'ufficiale non piu' valutabile per l'avanzamento ad anzianita' o a scelta non puo' conseguire avanzamento per merito di guerra.

3. Il militare che e' riconosciuto meritevole dell'avanzamento per merito di guerra acquista titolo all'avanzamento stesso dalla data conclusiva dell'azione o delle azioni di guerra, alla cui preparazione o svolgimento ha contribuito.

4. L'avanzamento per merito di guerra si effettua spostando il militare nel ruolo del proprio grado, alla data predetta, di un numero di posti pari:

- a) per l'ufficiale in servizio permanente effettivo, alle aliquote dell'organico in vigore al 1° gennaio dell'anno in cui l'ufficiale stesso ha acquistato il titolo all'avanzamento, stabilite con decreto del Ministro della difesa, successivo al dichiarato stato di guerra o di grave crisi internazionale;
- b) per gli altri militari, a un quindicesimo dei posti dell'organico calcolato per ogni ruolo.

5. Per l'ufficiale a disposizione o delle categorie in congedo l'avanzamento per merito di guerra si effettua spostando l'ufficiale nel ruolo del proprio grado, alla data in cui ha acquisito il titolo, fino a precedere i pari grado che hanno anzianita' superiore di un anno a quella da lui posseduta.

6. Il militare non puo', comunque, per effetto dello spostamento in ruolo, prendere posto nel ruolo del grado superiore, ne' oltrepassare il pari grado gia' piu' anziano che ha in precedenza conseguito titolo all'avanzamento per merito di guerra.

#### Art. 1340. - Avanzamento per merito di guerra degli ufficiali

1. L'ufficiale al quale e' conferito l'avanzamento per merito di guerra e che, per effetto dello spostamento nel ruolo, e' compreso in aliquota di ruolo di pari grado gia' valutati per l'avanzamento, se ha compiuto i periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco, di cui all'articolo 1329, o eventualmente il periodo di servizio di cui all'articolo 1333, comma 2, e' valutato per l'avanzamento. Se l'avanzamento ha luogo a scelta la valutazione e' effettuata in occasione della formazione della prima graduatoria successiva al conferimento dell'avanzamento per merito di guerra.

2. L'ufficiale appartenente a grado nel quale l'avanzamento ha luogo ad anzianita', se giudicato idoneo e gia' raggiunto dal turno di promozione, e' promosso anche se non esiste vacanza nel grado superiore, con l'anzianita' che gli compete secondo il posto conseguito per effetto dello spostamento nel ruolo.

3. L'ufficiale appartenente a grado nel quale l'avanzamento ha luogo a scelta, se giudicato idoneo e se riporta un punto di merito per cui sarebbe stato promosso, qualora tale punto gli fosse stato attribuito in una precedente graduatoria, e' promosso anche se non esista vacanza nel grado superiore, con l'anzianita' che gli compete. La promozione e' computata nel numero di quelle da effettuare per l'anno cui si riferisce la graduatoria in occasione della quale l'ufficiale e' stato valutato.

4. L'ufficiale che non ha ancora compiuto i periodi indicati al comma 1, e' valutato dopo che li ha ultimati, ma e' considerato come se avesse compiuto i periodi stessi alla data in cui acquisi' il titolo all'avanzamento per merito di guerra.

5. All'ufficiale non puo' comunque essere attribuita, nella promozione, anzianita' anteriore alla data in cui ha acquisito il titolo.

#### Art. 1341. - Proposte

1. Le proposte di promozione e di avanzamento per merito di guerra sono formulate dal superiore alle cui dirette dipendenze il militare si e' distinto, e sono corredate dei pareri delle autorita' gerarchiche.

2. Dette proposte sono trasmesse al Ministero non oltre il termine di tre mesi, rispettivamente, dalla data del fatto d'arme o dalla data conclusiva dell'azione o delle azioni di guerra alla cui preparazione o svolgimento il militare dette contributo, o, eccezionalmente, nel caso di impedimento derivante da comprovata causa di forza maggiore, non oltre tre mesi dalla data di cessazione della causa stessa.

3. Sulle proposte decide il Ministro, previo parere favorevole, espresso a unanimita' di voti, della competente commissione di avanzamento. Il decreto con il quale e' conferita la promozione o l'avanzamento per merito di guerra ne reca la motivazione.

### SEZIONE III - AVANZAMENTO DEI MILITARI REDUCI DA PRIGIONIA

#### Art. 1342. - Militari in servizio permanente

1. Per ogni militare in servizio permanente reduce da prigionia o ipotesi equiparate, il Ministro, constatata la posizione sia penale sia disciplinare in rapporto al fatto della cattura, dichiara se nulla osta alla valutazione per l'avanzamento.

2. Il militare non valutato o non promosso a norma degli articoli ((...)) 1051 e 1073 perche' in aspettativa per prigionia di guerra o ipotesi equiparate, se ottiene il nulla osta, e' valutato o nuovamente valutato, compiuti i prescritti periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco e, se appartiene a grado per il quale non sono richiesti detti periodi, deve aver prestato nel grado almeno sei mesi di effettivo servizio. Se l'avanzamento ha luogo a scelta, il militare e' valutato in occasione della formazione della prima graduatoria successiva al rilascio del nulla osta o, eventualmente, al compimento dei periodi anzidetti. All'ufficiale si applicano le disposizioni dell'articolo 1085, comma 2, lettere a) e b).

3. Analogamente si provvede nei riguardi del militare in servizio permanente effettivo che, promosso ai sensi del comma 2, risulti nel nuovo grado gia' raggiunto dal turno di avanzamento, ma la nuova promozione non comporta corresponsione di assegni arretrati.

4. Per l'avanzamento del militare reduce da prigionia si continuano ad applicare le disposizioni degli articoli 1329 e 1331, comma 1, anche se e' cessato il tempo di guerra o di grave crisi internazionale, quando tali disposizioni hanno avuto applicazione per i pari grado con i quali il militare avrebbe dovuto essere valutato o promosso.

#### Art. 1343. - Ufficiale delle categorie in congedo e del ruolo d'onore

1. L'ufficiale delle categorie in congedo o del ruolo d'onore, prigioniero di guerra, non puo' durante la prigionia o ipotesi equiparate, essere valutato per l'avanzamento ne' conseguire promozione. La valutazione effettuata prima della cattura e' annullata a ogni effetto.

2. Per l'ufficiale delle categorie anzidette, reduce da prigionia, si osserva il disposto dell'articolo 1342, comma 1.

3. L'ufficiale non valutato o non promosso perche' prigioniero di guerra, se ottiene il nulla osta, e' valutato o nuovamente valutato soltanto se, prima della cattura o prima della cessazione del tempo di guerra o di grave crisi internazionale, ha raggiunto le condizioni prescritte per l'avanzamento, salvo per l'ufficiale in ausiliaria e per l'ufficiale di complemento il disposto dei successivi commi 4 e 5. Se giudicato idoneo e gia' raggiunto dal turno di promozione, l'ufficiale e' promosso con l'anzianita' che gli sarebbe spettata se la promozione avesse avuto luogo a suo tempo.

4. L'ufficiale in ausiliaria compreso in aliquote di ruolo per il tempo di guerra o di grave crisi internazionale, che prima della cessazione del tempo di guerra o di grave crisi internazionale non ha raggiunto le condizioni prescritte per l'avanzamento dal presente titolo, puo' essere promosso con l'anzianita' che gli sarebbe spettata se raggiunge tali condizioni anche fuori del tempo di guerra o di grave crisi internazionale, esclusa comunque ogni corresponsione di assegni arretrati.

5. L'ufficiale di complemento compreso in aliquote di ruolo per il tempo di guerra o di grave crisi internazionale, che prima della cessazione del tempo di guerra o di grave crisi internazionale non ha raggiunto le condizioni prescritte per l'avanzamento dal presente titolo, e l'ufficiale in ausiliaria o di complemento compreso in aliquote di ruolo fuori del tempo di guerra o di grave crisi internazionale, puo' essere promosso con l'anzianita' che gli sarebbe spettata solo se raggiunge le condizioni prescritte per l'avanzamento dal presente codice esclusa comunque ogni corresponsione di assegni arretrati.

6. Le disposizioni dei commi 3, 4 e 5 valgono anche se l'ufficiale, nel nuovo grado, risulta raggiunto da turno di avanzamento, ma la nuova promozione non comporta, comunque, corresponsione di assegni arretrati.

#### Art. 1344. - Militare ferito

1. Al militare caduto prigioniero dopo essere stato ferito in combattimento e al militare caduto prigioniero durante la degenza in luogo di cura per ferite o per lesioni dovute a operazioni a diretto contatto col nemico o per altra invalidita' riportata per causa di servizio di guerra in zona di operazioni a diretto contatto col nemico, al ritorno dalla prigionia se gia' compreso in aliquote di ruolo di militari da valutare e se ha ottenuto il nulla osta di cui all'articolo 1342, comma 1, sono applicabili le disposizioni dell'articolo 1335.

2. Al militare che, conseguita la promozione ai sensi del comma 1, risulti nel nuovo grado gia' raggiunto dal turno di avanzamento, si applicano, a seconda delle categorie di appartenenza, le disposizioni dei commi 3 e 4 dell'articolo 1342.

### SEZIONE IV - NORME FINALI

#### Art. 1345. - Funzioni del grado superiore

1. In tempo di guerra o di grave crisi internazionale, per sopperire a temporanee deficienze organiche o a deficienze derivanti da temporanei esoneri dal servizio effettivo o dalla indisponibilita' di ufficiali comunque sprovvisti di impiego possono essere conferite le funzioni del grado superiore all'ufficiale che nel proprio grado, ha compiuto i periodi di comando, di attribuzioni specifiche, di servizio presso reparti, di imbarco, prescritti ai fini dell'avanzamento, e che e' destinato a unita', enti, reparti impiegati in operazioni di guerra o approntati per tali operazioni.

2. Le funzioni del grado superiore sono conferite con decreto del Ministro. Esse sono revocate se viene meno la ragione del conferimento, e cessano di diritto con la cessazione delle ostilita'.

3. L'ufficiale al quale sono conferite le funzioni del grado superiore ha diritto a tutti gli assegni e le indennita' di tale grado ed e' considerato, agli effetti disciplinari, come rivestito del grado stesso. Il servizio prestato nell'esercizio delle funzioni del grado superiore e' valido ai fini dell'avanzamento al grado superiore a quello di cui l'ufficiale ha disimpegnato le funzioni, se e' stato prestato in incarichi utili agli effetti del compimento dei periodi indicati dal presente codice.

## TITOLO VIII DISCIPLINA MILITARE CAPO I FONDAMENTI DELLE ISTITUZIONI MILITARI

### Art. 1346. - Disciplina militare

1. La disciplina del militare e' l'osservanza consapevole delle norme attinenti allo stato di militare in relazione ai compiti istituzionali delle Forze armate e alle esigenze che ne derivano. Essa e' regola fondamentale per i cittadini alle armi in quanto costituisce il principale fattore di coesione e di efficienza.

2. Per il conseguimento e il mantenimento della disciplina sono determinate le posizioni reciproche del superiore e dell'inferiore, le loro funzioni, i loro compiti e le loro responsabilita'. Da cio' discendono il principio di gerarchia e quindi il rapporto di subordinazione e il dovere dell'obbedienza.

3. Il militare osserva con senso di responsabilita' e consapevole partecipazione tutte le norme attinenti alla disciplina e ai rapporti gerarchici. Nella disciplina tutti sono uguali di fronte al dovere e al pericolo.

### Art. 1347. - Obbedienza

1. L'obbedienza consiste nella esecuzione pronta, rispettosa e leale degli ordini attinenti al servizio e alla disciplina, in conformita' al giuramento prestato.

2. Il dovere dell'obbedienza e' assoluto, salvo i limiti posti dall'articolo 1349, comma 2 e dall'articolo 729 del regolamento.

## CAPO II - DOVERI

### Art. 1348. - Dovere di fedelta'

1. L'assoluta fedelta' alle istituzioni repubblicane e' il fondamento dei doveri del militare.

2. Il comportamento dei militari nei confronti delle istituzioni democratiche deve essere improntato a principi di scrupolosa fedelta' alla Costituzione repubblicana e alle ragioni di sicurezza dello Stato.

### Art. 1349. - Ordini militari

1. Gli ordini devono, conformemente alle norme in vigore, attenere alla disciplina, riguardare le modalita' di svolgimento del servizio e non eccedere i compiti di istituto.

2. Il militare al quale e' impartito un ordine manifestamente rivolto contro le istituzioni dello Stato o la cui esecuzione costituisce comunque manifestamente reato, ha il dovere di non eseguire l'ordine e di informare al piu' presto i superiori.

3. Agli ordini militari non si applicano i capi I, III e IV della legge 7 agosto 1990, n. 241.

### Art. 1350. - Condizioni per la applicazione delle disposizioni in materia di disciplina

1. I militari sono tenuti all'osservanza delle norme sulla disciplina militare e sui limiti all'esercizio dei diritti, dal momento della incorporazione a quello della cessazione dal servizio attivo, ferma restando la disciplina dettata per il personale in congedo.

2. Le disposizioni in materia di disciplina militare, si applicano nei confronti dei militari che si trovino in una delle seguenti condizioni:

- a) svolgono attivita' di servizio;
- b) sono in luoghi militari o comunque destinati al servizio;
- c) indossano l'uniforme;
- d) si qualificano, in relazione ai compiti di servizio, come militari o si rivolgono ad altri militari in divisa o che si qualificano come tali.

3. Quando non ricorrono le suddette condizioni, i militari sono comunque tenuti all'osservanza delle disposizioni del codice e del regolamento che concernono i doveri attinenti al giuramento prestato, al grado, alla tutela del segreto e al dovuto riserbo sulle questioni militari, in conformita' alle vigenti disposizioni.

4. Le attribuzioni conferite al Ministro della difesa in materia di disciplina militare, per quel che concerne i Corpi armati dello Stato, sono devolute, ai sensi dei rispettivi ordinamenti, ai Ministri alle cui dipendenze dirette i predetti Corpi sono posti.

### Art. 1351. - Uso dell'uniforme

1. Durante l'espletamento dei compiti di servizio e nei luoghi militari o comunque destinati al servizio e' obbligatorio l'uso dell'uniforme, salvo diverse disposizioni.

2. L'uso dell'abito civile e' consentito fuori dai luoghi militari, durante le licenze e i permessi.

3. Nelle ore di libera uscita e' consentito l'uso dell'abito civile, salvo limitazioni derivanti dalle esigenze:

- a) delle accademie militari, durante il primo anno di corso;
- b) delle scuole allievi sottufficiali, durante i primi quattro mesi di corso formativo;
- c) delle scuole militari;
- d) dei servizi di sicurezza di particolari impianti e installazioni;
- e) operative e di addestramento fuori sede.

## CAPO III - SANZIONI DISCIPLINARI

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1352. - Illecito disciplinare

1. Costituisce illecito disciplinare ogni violazione dei doveri del servizio e della disciplina militare sanciti dal presente codice, dal regolamento, o conseguenti all'emanazione di un ordine.

2. La violazione dei doveri indicati nel comma 1 comporta sanzioni disciplinari di stato o sanzioni disciplinari di corpo.

#### Art. 1353. - Tassativita' delle sanzioni

1. Non possono essere inflitte sanzioni disciplinari diverse da quelle previste nel presente capo.

#### Art. 1354. - Titolarita' del potere sanzionatorio

1. E' attribuito all'autorita' militare il potere sanzionatorio nel campo della disciplina.

#### Art. 1355. - Criteri per la irrogazione delle sanzioni disciplinari

1. Le sanzioni disciplinari sono commisurate al tipo di mancanza commessa e alla gravita' della stessa.

2. Nel determinare la specie ed eventualmente la durata della sanzione sono inoltre considerati i precedenti di servizio disciplinari, il grado, l'eta', e l'anzianita' di servizio del militare che ha mancato.

3. Vanno punite con maggior rigore le infrazioni:

- a) intenzionali;
- b) commesse in presenza di altri militari;
- c) commesse in concorso con altri militari;
- d) ricorrenti con carattere di recidivita'.

4. Nel caso di concorso di piu' militari nella stessa infrazione disciplinare e' inflitta una sanzione piu' severa al piu' elevato in grado o, a parita' di grado, al piu' anziano.

5. Se deve essere adottato un provvedimento disciplinare riguardante piu' trasgressioni commesse da un militare, anche in tempi diversi, e' inflitta un'unica punizione in relazione alla piu' grave delle trasgressioni e al comportamento contrario alla disciplina rivelato complessivamente dalla condotta del militare stesso.

#### Art. 1356. - Militari tossicodipendenti, alcooldipendenti e assuntori di sostanze dopanti

1. In deroga alle norme del decreto del Presidente della Repubblica 9 ottobre 1990, n. 309, della legge 30 marzo 2001, n. 125 e della legge 14 dicembre 2000, n. 376, ai militari tossicodipendenti, alcol-dipendenti o che assumono sostanze dopanti, si applicano le disposizioni di stato in materia di idoneita', di sospensione dal servizio e di disciplina.

### SEZIONE II - CLASSIFICAZIONE DELLE SANZIONI DISCIPLINARI

#### Art. 1357. - Sanzioni disciplinari di stato

1. Le sanzioni disciplinari di stato sono:

- a) la sospensione disciplinare dall'impiego per un periodo da uno a dodici mesi;
- b) la sospensione disciplinare dalle funzioni del grado per un periodo da uno a dodici mesi;
- c) la cessazione dalla ferma o dalla rafferma per grave mancanza disciplinare o grave inadempienza ai doveri del militare;
- d) la perdita del grado per rimozione.

#### Art. 1358. - Sanzioni disciplinari di corpo

1. Le sanzioni disciplinari di corpo consistono nel richiamo, nel rimprovero, nella consegna e nella consegna di rigore.

2. Il richiamo e' verbale.

3. Il rimprovero e' scritto.

4. La consegna consiste nella privazione della libera uscita fino al massimo di sette giorni consecutivi.

5. La consegna di rigore comporta il vincolo di rimanere, fino al massimo di quindici giorni, in apposito spazio dell'ambiente militare - in caserma o a bordo di navi - o nel proprio alloggio, secondo le modalita' stabilite dagli articoli successivi .

6. La sanzione della consegna di rigore non puo' essere inflitta se non per i comportamenti specificamente previsti dall'articolo 751 del regolamento.

#### Art. 1359. - Richiamo

1. Il richiamo e' un ammonimento con cui sono punite:

- a) lievi mancanze;
- b) omissioni causate da negligenza.

2. Il richiamo puo' essere inflitto da qualsiasi superiore. Se il superiore e' collocato nella linea gerarchica di dipendenza del militare non v'e' obbligo di rapporto.

3. Il richiamo non da' luogo a trascrizione nella documentazione personale dell'interessato ((...)).

4. Si tiene conto del richiamo, limitatamente al biennio successivo alla sua inflizione, esclusivamente ai fini della recidiva nelle mancanze per le quali puo' essere inflitta la sanzione del rimprovero.

#### Art. 1360. - Rimprovero

1. Il rimprovero e' una dichiarazione di biasimo con cui sono punite le lievi trasgressioni alle norme della disciplina e del servizio o la recidiva nelle mancanze per le quali puo' essere inflitto il richiamo.

2. Il rimprovero e' inflitto dalle autorita' di cui all'articolo 1396.

3. Il provvedimento con il quale e' inflitta la punizione e' comunicato per iscritto all'interessato ed e' trascritto nella documentazione personale.

#### Art. 1361. - Consegna

1. Con la consegna sono punite:

- a) la violazione dei doveri diversi da quelli previsti dall'articolo 751 del regolamento;
- b) la recidiva nelle mancanze gia' sanzionate con il rimprovero;
- c) piu' gravi trasgressioni alle norme della disciplina e del servizio.

2. Il provvedimento con il quale e' inflitta la punizione e' comunicato per iscritto all'interessato ed e' trascritto nella documentazione personale.

3. Il provvedimento e' esecutivo dal giorno della comunicazione verbale all'interessato.

4. I militari di truppa coniugati, ((i graduati,)) i sottufficiali e gli ufficiali che usufruiscono di alloggio privato sono autorizzati a scontare presso tale alloggio la punizione di consegna.

#### Art. 1362. - Consegna di rigore

1. La consegna di rigore si applica per le infrazioni specificamente indicate nell' articolo 751 del regolamento.

2. Il proprio alloggio di cui all'articolo 1358, comma 5 puo' essere sia quello privato sia quello di servizio.

3. Il comandante di corpo puo' far scontare, per particolari ragioni di disciplina, la consegna di rigore in apposito spazio nell'ambiente militare anche al personale provvisto di alloggio privato o di servizio.

4. Il superiore che ha inflitto la punizione puo' disporre che la consegna di rigore venga scontata con le stesse modalita' previste per la consegna, se lo richiedono particolari motivi di servizio.

5. I locali destinati ai puniti di consegna di rigore hanno caratteristiche analoghe a quelle degli altri locali della caserma adibiti ad alloggio.

6. Il controllo dell'esecuzione della sanzione e' affidato a superiori o pari grado del punito ed e' esercitato secondo le disposizioni di ciascuna Forza armata o Corpo armato.

7. Con la consegna di rigore possono, inoltre, essere puniti:

- a) fatti previsti come reato, per i quali il comandante di corpo non ritenga di richiedere il procedimento penale, ai sensi dell'articolo 260 c.p.m.p.;
- b) fatti che hanno determinato un giudizio penale a seguito del quale e' stato instaurato un procedimento disciplinare.

8. Il provvedimento relativo alla punizione e' subito comunicato verbalmente all'interessato e successivamente notificato mediante comunicazione scritta. Esso e' trascritto nella documentazione personale.

9. Il provvedimento e' esecutivo dal giorno della comunicazione verbale all'interessato.

### SEZIONE III - ISTANZE E RICORSI AVVERSO LE SANZIONI DISCIPLINARI DI CORPO

#### Art. 1363. - Organo sovraordinato

1. L'organo sovraordinato di cui all'articolo 1 del decreto del Presidente della Repubblica 24 novembre 1971, n. 1199, e' rappresentato dall'organo gerarchicamente superiore a quello che ha emesso il provvedimento.

2. Avverso le sanzioni disciplinari di corpo non e' ammesso ricorso giurisdizionale o ricorso straordinario al Presidente della Repubblica se prima non e' stato esperito ricorso gerarchico o sono trascorsi novanta giorni dalla data di presentazione del ricorso.

3. E' comunque in facolta' del militare presentare, secondo le modalita' stabilite dal presente codice, istanze tendenti a ottenere il riesame di sanzioni disciplinari di corpo.

#### Art. 1364. - Istanza di riesame e ricorso gerarchico

1. In relazione all'istanza di riesame e al ricorso gerarchico di cui all'articolo 1363 proposti dal militare che si ritenga ingiustamente punito, si osservano anche le norme di cui ai successivi articoli 1365 e 1366.

#### Art. 1365. - Istanza di riesame delle sanzioni disciplinari di corpo

1. Ogni militare puo' presentare, in qualunque tempo, istanza scritta tendente a ottenere il riesame della sanzione disciplinare inflittagli, se sopravvengono nuove prove tali da far ritenere applicabile una sanzione minore o dichiarare il proscioglimento dall'addebito.

2. L'istanza di riesame non sospende l'esecuzione della sanzione ne' i termini per la proposizione dei ricorsi avverso il provvedimento disciplinare previsti dall'articolo 1366.

3. L'istanza deve essere diretta, in via gerarchica, alla stessa autorita' che ha emesso il provvedimento.

4. Avverso la decisione sull'istanza di riesame emanata dall'autorita' adita ai sensi del comma 3, il militare puo' proporre ricorso gerarchico ai sensi dell'articolo 1366.

#### Art. 1366. - Ricorso gerarchico avverso le sanzioni disciplinari di corpo

1. Il superiore, per il cui tramite va proposto il ricorso gerarchico, deve inoltrarlo sollecitamente senza pareri o commenti all'autorita' gerarchica immediatamente superiore a quella che ha inflitto la sanzione di corpo.

### SEZIONE IV - DISPOSIZIONI PARTICOLARI

#### Art. 1367. - Presentazione dei militari puniti

1. Tutti i militari, ultimata la punizione, sono presentati al superiore che l'ha inflitta, se non ne sono espressamente dispensati.

2. Il giorno e l'ora di presentazione sono stabiliti dalla predetta autorita'.

#### Art. 1368. - Sospensione e condono delle sanzioni disciplinari di corpo

1. L'autorita' che ha inflitto la sanzione della consegna o della consegna di rigore puo' sospenderne l'esecuzione, per il tempo strettamente necessario, sia per concrete e motivate esigenze di carattere privato del militare punito, sia per motivi di servizio.

2. Il Ministro della difesa, in occasione di particolari ricorrenze, ha facolta' di condonare collettivamente le sanzioni della consegna e della consegna di rigore in corso di esecuzione. Analoga facolta' e' concessa al Capo di stato maggiore di Forza armata o Comandante generale per la festa d'Arma e al comandante del corpo in occasione della festa del corpo stesso.

3. Il condono non comporta la cancellazione della trascrizione dagli atti matricolari o personali.

#### Art. 1369. - Cessazione degli effetti delle sanzioni disciplinari di corpo

1. I militari possono chiedere la cessazione di ogni effetto delle sanzioni trascritte nella documentazione personale. L'istanza relativa puo' essere presentata, per via gerarchica, al Ministro della difesa dopo almeno due anni di servizio dalla data della comunicazione della punizione, se il militare non ha riportato, in tale periodo, sanzioni disciplinari ((diverse dal richiamo)).

2. Il Ministro, ovvero l'autorita' militare da lui delegata, decide entro sei mesi dalla presentazione dell'istanza tenendo conto del parere espresso dai superiori gerarchici e di tutti i precedenti di servizio del richiedente.

3. In caso di accoglimento dell'istanza le annotazioni relative alla sanzione inflitta sono eliminate dalla documentazione personale, esclusa peraltro ogni efficacia retroattiva.

## CAPO IV - PROCEDIMENTO DISCIPLINARE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1370. - Contestazione degli addebiti e diritto di difesa

1. Nessuna sanzione disciplinare puo' essere inflitta senza contestazione degli addebiti e senza che sono state acquisite e vagliate le giustificazioni addotte dal militare interessato.

2. Il militare inquisito e' assistito da un difensore da lui scelto fra militari in servizio, anche non appartenenti al medesimo ente o Forza armata nella quale egli presta servizio o, in mancanza, designato d'ufficio. Il difensore designato d'ufficio non puo' rifiutarsi salvo sussista un legittimo impedimento. Un militare non puo' esercitare l'ufficio di difensore piu' di sei volte in dodici mesi.

3. Il difensore:

- a) non puo' essere di grado superiore a quello del presidente della commissione;
- b) non deve trovarsi in alcuna delle condizioni di cui all'articolo 1380, comma 3;
- c) e' vincolato al segreto d'ufficio e non deve accettare alcun compenso per l'attivita' svolta;
- d) non e' dispensato dai suoi normali obblighi di servizio, salvo che per il tempo necessario all'espletamento del mandato;
- e) non puo' essere punito per fatti che rientrano nell'espletamento del mandato;
- f) e' ammesso a intervenire alle sedute della commissione di disciplina anche se l'incolpato non si presenta alla seduta, ne' fa constare di essere legittimamente impedito.

((

3-bis. Nei procedimenti disciplinari di stato il militare inquisito, in aggiunta al difensore di cui ai commi 2 e 3, puo' farsi assistere, a sue spese, anche da un avvocato del libero foro.

))

4. Successivamente alla nomina del difensore le comunicazioni d'ufficio possono essere effettuate indifferentemente all'inquisito o al suo difensore.

5. Il militare inquisito puo' chiedere il differimento dello svolgimento del procedimento disciplinare solo se sussiste un effettivo legittimo impedimento. Se la richiesta di differimento e' dovuta a ragioni di salute:

- a) l'impedimento addotto deve consistere, sulla scorta di specifica certificazione sanitaria, in una infermita' tale da rendere impossibile la partecipazione al procedimento disciplinare;
- b) l'autorita' disciplinare puo' recarsi presso l'inquisito per svolgere il procedimento disciplinare, se tale evenienza non e' espressamente esclusa dalla commissione medica ospedaliera incaricata di tale accertamento.

6. I commi 2, 3, 4 e 5 del presente articolo non si applicano ai procedimenti disciplinari di corpo instaurati per l'applicazione di una sanzione diversa dalla consegna di rigore.

#### Art. 1371. - Divieto di sostituzione delle sanzioni disciplinari

1. Fatto salvo quanto previsto dagli articoli 1365 e 1366, un medesimo fatto non puo' essere punito piu' di una volta con sanzioni di differente specie.

#### Art. 1372. - Annullamento d'ufficio del procedimento disciplinare

1. E' consentito l'esercizio del potere di annullamento d'ufficio degli atti del procedimento disciplinare riconosciuti illegittimi dall'amministrazione militare, nei limiti sanciti dall'articolo 21 nonies della legge 7 agosto 1990, n. 241.

#### Art. 1373. - Rinnovazione del procedimento disciplinare

1. Annullati uno o piu' atti del procedimento disciplinare a seguito di autotutela ((, anche contenziosa)), di giudicato amministrativo ovvero di decreto decisorio di ricorso straordinario, se non e' esclusa la facolta' dell'amministrazione di rinnovare in tutto o in parte il procedimento e non sono gia' decorsi, limitatamente alle sanzioni di stato, gli originari termini perentori, il nuovo procedimento riprende, a partire dal primo degli atti annullati, nel termine perentorio di sessanta giorni dalla data in cui l'amministrazione ha avuto piena conoscenza dell'annullamento o dalla data di adozione del provvedimento di autotutela.

#### Art. 1374. - Estinzione del procedimento disciplinare

1. Il decesso dell'incolpato estingue il procedimento disciplinare.

### SEZIONE II - PROCEDIMENTO DISCIPLINARE DI STATO ((E RAPPORTO TRA PROCEDIMENTO DISCIPLINARE DI STATO E DI CORPO E PROCEDIMENTO PENALE))

#### Art. 1375. - Potesta' sanzionatoria di stato

1. La potesta' sanzionatoria di stato compete al Ministro della difesa o autorita' militare da lui delegata; tutti i provvedimenti che concludono procedimenti disciplinari di stato devono essere motivati.

#### Art. 1376. - Inizio del procedimento disciplinare di stato

1. Il procedimento disciplinare di stato, costituito dall'insieme degli atti e delle procedure necessari per l'irrogazione di una sanzione disciplinare di stato, inizia con l'inchiesta formale, che comporta la contestazione degli addebiti.

#### Art. 1377. - Inchiesta formale

1. L'inchiesta formale e' il complesso degli atti diretti all'accertamento di una infrazione disciplinare per la quale il militare puo' essere passibile di una delle sanzioni indicate all'articolo 1357.

2. Le autorita' che hanno disposto l'inchiesta formale, in base alle risultanze della stessa:

- a) se ritengono che al militare deve o meno essere inflitta una delle sanzioni disciplinari indicate nell' articolo 1357, comma 1, lettere a) e b), ne fanno proposta al Ministro della difesa;
- b) se ritengono che al militare possono essere inflitte le sanzioni disciplinari indicate all'articolo 1357, comma 1, lettere c) e d) ne ordinano il deferimento a una commissione di disciplina.

3. Il Ministro della difesa puo', in ogni caso e nei confronti di qualsiasi militare, ordinare direttamente una inchiesta formale.

4. Il Ministro della difesa puo' sempre disporre, all'esito dell'inchiesta formale, il deferimento del militare a una commissione di disciplina.

((

5. L'accettazione delle dimissioni dal grado estingue l'azione disciplinare.

))

#### Art. 1378. - Autorita' competenti a ordinare l'inchiesta formale

1. La decisione di sottoporre un militare a inchiesta formale spetta alle seguenti autorita':

- a) al Ministro della difesa se si tratti di: 1) ufficiali generali o colonnelli o gradi corrispondenti; 2) ufficiali o sottufficiali assegnati a enti, comandi e reparti di altra Forza armata; 3) militari corresponsabili appartenenti alla stessa Forza armata, ma dipendenti da autorita' diverse; 4) militari corresponsabili appartenenti a Forze armate diverse, anche quando ricorre l'ipotesi di connessione tra i fatti a loro ascritti;
- b) al Capo di stato maggiore della difesa, nell'area di competenza, nei confronti del personale militare dipendente;
- c) al Segretario generale della difesa o al Direttore nazionale degli armamenti, se militari, ovvero, quando gli stessi rivestono la qualifica dirigenziale civile, al Vice Segretario generale o al Vice direttore nazionale degli armamenti, nei confronti del personale militare dipendente, dell'area tecnico-amministrativa e dell'area tecnico-industriale;
- d) ai Capi di stato maggiore, sul personale militare in servizio presso reparti e uffici dei rispettivi stati maggiori e organismi centrali di Forza armata;
- d-bis) al Comandante del Comando operativo di vertice interforze, nell'area di competenza, nei confronti del personale militare dipendente;
- e) al Comandante generale dell'Arma dei carabinieri: 1) per gli ufficiali dell'Arma dei carabinieri; 2) per gli altri militari dell'Arma, se non provvedono le autorita' di cui alle lettere h) e i);
- f) ai rispettivi comandanti di Forza armata, di livello gerarchico pari a generale di corpo d'armata o gradi corrispondenti, per gli ufficiali, i sottufficiali e i volontari in servizio dell'Esercito italiano e dell'Aeronautica militare, nonche' agli alti comandanti della Marina militare, per gli ufficiali, i sottufficiali e i volontari in servizio della Marina militare; ai comandanti territoriali di livello gerarchico pari a generale di corpo d'armata e gradi corrispondenti competenti in ragione del luogo di residenza dell'interessato se in congedo;
- g) al comandante militare competente a provvedere per il sottufficiale o per il militare di truppa piu' elevato in grado o piu' anziano, se vi e' corresponsabilita' tra sottufficiali o i militari di truppa della stessa Forza armata dipendenti da comandanti militari diversi o residenti in territori di competenza di diversi comandanti militari territoriali, tra quelli sopra considerati;
- h) ai rispettivi comandanti di vertice, di livello gerarchico pari a generale di corpo d'armata, per gli ispettori e i sovrintendenti dell'Arma dei carabinieri in servizio, o in caso diverso o in mancanza di tale dipendenza, ai comandanti territoriali di livello gerarchico pari a generale di corpo d'armata competenti in ragione del luogo di residenza dell'interessato;
- i) ai rispettivi comandanti di corpo per gli appuntati e carabinieri in servizio, o in caso diverso o in mancanza di tale dipendenza, al comandante territoriale di corpo competente in ragione del luogo di residenza dell'interessato. In caso di corresponsabilita' tra piu' appuntati e carabinieri provvede il comandante di corpo del piu' elevato in grado o del piu' anziano. In caso di corresponsabilita' con militari di altre Forze armate si provvede ai sensi della lettera g).

#### Art. 1379. - Applicazione della sospensione disciplinare

1. La sospensione disciplinare e' adottata a seguito di inchiesta formale, senza il necessario preventivo deferimento a una commissione di disciplina.

2. La sospensione precauzionale dall'impiego sofferta per gli stessi fatti oggetto di sanzione disciplinare e' computata nel periodo di tempo della sospensione disciplinare irrogata. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1380. - Composizione delle commissioni di disciplina

1. La commissione di disciplina e' formata di volta in volta, in relazione al grado rivestito dal giudicando, dall'autorita' che ha disposto l'inchiesta formale.

2. Quando l'inchiesta formale e' disposta dal Ministro della difesa, la commissione di disciplina e' formata da uno dei comandanti militari indicati dall'articolo 1378, designato dal Ministro stesso; se il giudicando e' ufficiale generale o colonnello alla composizione della commissione provvede il Ministro della difesa.

3. Non possono far parte della commissione di disciplina:

- a) gli ufficiali che sono Ministri o Sottosegretari di Stato in carica;
- b) il Capo di stato maggiore della difesa, i Capi e i Sottocapi di stato maggiore dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, gli ufficiali generali o ammiragli addetti allo Stato maggiore della difesa, agli Stati maggiori dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, il Comandante generale dell'Arma dei carabinieri;
- c) gli ufficiali addetti alla Presidenza della Repubblica;
- d) gli ufficiali che prestano servizio al Ministero della difesa in qualita' di Segretario generale, ((Direttore nazionale degli armamenti,)) Direttore generale, Capo di Gabinetto, e gli ufficiali addetti al Gabinetto del Ministro o alle segreterie del Ministro e dei Sottosegretari di Stato o alle dirette dipendenze dei Segretari generali;
- e) i militari frequentatori dei corsi presso gli istituti militari;
- f) i parenti e gli affini tra loro sino al terzo grado incluso;
- g) l'offeso o il danneggiato e i parenti o affini del giudicando, dell'offeso o danneggiato, sino al quarto grado incluso;
- h) i superiori gerarchici alle cui dipendenze il militare ha prestato servizio allorche' ha commesso i fatti che hanno determinato il procedimento disciplinare, o alle cui dipendenze il giudicando si trova alla data di convocazione della commissione di disciplina, se non si tratta di generale di corpo d'armata e gradi corrispondenti;
- i) l'ufficiale che ha presentato rapporti o eseguito indagini sui fatti che hanno determinato il procedimento disciplinare o che per ufficio ha dato parere in merito o che per ufficio tratta questioni inerenti allo stato, all'avanzamento e alla disciplina del personale;
- l) gli ufficiali che in qualsiasi modo hanno avuto parte in un precedente giudizio penale o ((commissione)) di disciplina per lo stesso fatto ovvero sono stati sentiti come testimoni nella questione disciplinare di cui trattasi;
- m) l'ufficiale sottoposto a procedimento penale o a procedimento disciplinare di stato.

#### Art. 1381. - Commissioni di disciplina per gli ufficiali generali, colonnelli e gradi corrispondenti

1. La commissione di disciplina per i generali o colonnelli, e gradi corrispondenti, si compone di cinque ufficiali generali o di grado corrispondente, della stessa Forza armata cui il giudicando appartiene, tutti in servizio permanente e di grado superiore a quello rivestito dal giudicando medesimo, o anche di sola anzianita' superiore se trattisi di generale di corpo d'armata o ufficiale di grado corrispondente.

2. In caso di indisponibilita' possono essere chiamati a far parte della commissione ufficiali generali o di grado corrispondente della stessa Forza armata del giudicando, appartenenti all'ausiliaria o alla riserva, e, in caso di indisponibilita' anche di costoro, ufficiali generali o di grado corrispondente, in servizio permanente, delle altre Forze armate.

((

3. Il presidente deve rivestire grado non inferiore a:

- a) generale di corpo d'armata o corrispondente, se il giudicando riveste almeno il grado di generale di brigata o corrispondente;
- b) generale di divisione o corrispondente, se il giudicando riveste il grado di colonnello o corrispondente.

))

4. L'ufficiale meno elevato in grado o meno anziano assume le funzioni di segretario.

#### Art. 1382. - Commissioni di disciplina per gli altri ufficiali

1. La commissione di disciplina per gli ufficiali da sottotenente a tenente colonnello, o gradi corrispondenti, si compone di cinque ufficiali della stessa Forza armata cui appartiene il giudicando, tutti in servizio permanente e di grado superiore a quello rivestito dal giudicando medesimo.

2. Il presidente non puo' essere di grado inferiore a colonnello o grado corrispondente e, se il giudicando e' tenente colonnello o grado corrispondente, il presidente non puo' essere di grado inferiore a generale di brigata o grado corrispondente.

3. Il presidente, deve appartenere:

- a) a una qualsiasi delle Armi per gli ufficiali dell'Esercito italiano;
- b) al Corpo di stato maggiore, per gli ufficiali della Marina militare;
- c) al ruolo naviganti, per gli ufficiali dell'Aeronautica militare;
- d) al ruolo normale, per gli ufficiali dell'Arma dei carabinieri.

4. I membri in relazione all'Arma, al Corpo o al ruolo del giudicando, sono scelti:

- a) per l'Esercito italiano: 1) promiscuamente tra gli ufficiali delle Armi, per gli appartenenti ai ruoli delle Armi; 2) in numero di due, promiscuamente, tra gli ufficiali delle Armi e in numero di due tra gli ufficiali del Corpo o del ruolo di appartenenza, per gli altri ufficiali;
- b) per la Marina militare: 1) tra gli ufficiali del Corpo di stato maggiore, per gli appartenenti al medesimo Corpo; 2) in numero di due dal Corpo di stato maggiore e in numero di due dal Corpo di appartenenza, per gli altri ufficiali;
- c) per l'Aeronautica militare: 1) tra gli ufficiali del ruolo naviganti, per gli appartenenti al medesimo ruolo; 2) in numero di due dal ruolo naviganti e in numero di due dal ruolo o dal Corpo di appartenenza, per gli altri ufficiali;
- d) per l'Arma dei carabinieri: 1) tra gli ufficiali del ruolo normale, per gli appartenenti al medesimo ruolo; 2) in numero di due dal ruolo normale e in numero di due dal ruolo di appartenenza, per gli altri ufficiali.

5. L'ufficiale meno elevato in grado o meno anziano assume le funzioni di segretario.

#### Art. 1383. - Commissioni di disciplina per i sottufficiali, i graduati e i militari di truppa

1. La commissione di disciplina per i giudizi a carico di uno o piu' sottufficiali o volontari di una stessa Forza armata si compone di tre ufficiali in servizio permanente, dei quali almeno due ufficiali superiori e l'altro di grado non inferiore a capitano o corrispondente, tutti della Forza armata cui il giudicando o i giudicandi appartengono.

2. Il presidente della commissione di disciplina non puo' avere grado inferiore a tenente colonnello o corrispondente.

3. Il membro meno elevato in grado o meno anziano assume le funzioni di segretario.

#### Art. 1384. - Commissioni di disciplina per gli appuntati e carabinieri

1. La commissione di disciplina per gli appuntati e carabinieri si compone di un ufficiale superiore dell'Arma dei carabinieri, presidente, e di due capitani dell'Arma stessa in servizio.

#### Art. 1385. - Commissioni di disciplina per militari appartenenti a diverse Forze armate

1. Per la formazione della commissione di disciplina a carico di piu' militari appartenenti a Forze armate diverse, il presidente e' tratto dalla Forza armata cui appartiene il piu' elevato in grado o piu' anziano.

2. Per la scelta degli altri quattro membri:

- a) se il numero dei giudicandi e' di due, tre membri sono tratti dalla Forza armata cui appartiene il meno elevato in grado o meno anziano e un membro e' tratto dalla Forza armata cui appartiene il presidente;
- b) se il numero dei giudicandi e' superiore a due, ed essi appartengano a due Forze armate, tre membri sono tratti dalla Forza armata cui appartiene il giudicando meno elevato in grado o meno anziano e uno e' tratto dalla Forza armata cui appartiene il presidente. Nel caso che il piu' elevato in grado o piu' anziano e il meno elevato in grado o meno anziano appartengano alla stessa Forza armata, per la scelta dei membri sara' considerato meno elevato in grado il giudicando di minor grado o di minore anzianita' appartenente alla Forza armata diversa da quella cui appartiene il presidente;
- c) se il numero dei giudicandi e' superiore a due ed essi appartengano a tre Forze armate, sono tratti due membri da ciascuna delle due Forze armate diverse da quella cui appartiene il presidente;
- d) se i giudicandi appartengono a piu' di tre Forze armate si prevedono due componenti per Forza armata e il membro della stessa Forza armata del presidente deve essere l'ufficiale meno elevato in grado o meno anziano.

#### Art. 1386. - Ricusazione

1. Il militare sottoposto al giudizio della commissione di disciplina ha diritto di ricusare per una sola volta uno o due dei componenti della commissione, se quest'ultima e' composta rispettivamente da tre o da cinque membri. La ricusazione non deve essere motivata e deve essere presentata entro due giorni dalla data della comunicazione della convocazione della commissione di disciplina.

2. I componenti ricusati sono sostituiti.

#### Art. 1387. - Convocazione della commissione di disciplina

1. La commissione di disciplina e' convocata dall'autorita' che l'ha formata.

2. Detta autorita' da' comunicazione scritta dell'avvenuta convocazione al militare inquisito o al suo difensore e trasmette, contemporaneamente, ai componenti della commissione l'ordine di convocazione e al presidente gli atti dell'inchiesta, tra i quali sono comprese le eventuali difese scritte dal giudicando.

3. La commissione di disciplina si riunisce nel luogo indicato nell'ordine di convocazione.

4. Il presidente, dopo avere esaminato gli atti, redige dichiarazione in tal senso, invita quindi gli altri membri a fare altrettanto.

5. Redatta la dichiarazione scritta di cui al comma 4 e ricevute le dichiarazioni scritte degli altri membri della commissione, il presidente fissa, almeno venti giorni prima, il giorno e l'ora della riunione e invita per iscritto il militare sottoposto alla commissione di presentarsi, con l'avvertenza che:

- a) egli ha facolta' di intervenirvi, con l'assistenza di un ufficiale difensore, per svolgere oralmente le proprie difese e di far pervenire alla commissione, almeno cinque giorni prima della seduta, eventuali scritti o memorie difensive;
- b) se alla data stabilita non si presentera' ne' fara' constare di essere legittimamente impedito, si procedera' in sua assenza.

#### Art. 1388. - Procedimento davanti alla commissione di disciplina

1. Aperta la seduta, il presidente richiama l'attenzione dei membri della commissione sull'importanza dei giudizi che sono chiamati a esprimere; avvisa, inoltre, che devono astenersi, nel chiedere chiarimenti, dal fare apprezzamenti.

2. Fa introdurre quindi il militare, se presente, e:

- a) legge l'ordine di convocazione;
- b) legge le dichiarazioni scritte dell'avvenuto esame, la parte propria e degli altri membri, degli atti dell'inchiesta formale;
- c) fa leggere dal segretario la relazione riepilogativa;
- d) chiede se i membri della commissione o il giudicando e l'ufficiale difensore desiderano che sia letto qualsiasi atto dell'inchiesta e, se lo ritiene necessario, ne autorizza la lettura.

3. Il presidente e i membri della commissione previa autorizzazione del presidente possono chiedere al militare chiarimenti sui fatti a lui addebitati.

4. Il giudicando puo' presentare una memoria, preparata in precedenza e firmata, contenente la sua difesa e puo' produrre eventuali nuovi documenti. Se non intende valersi di dette facolta' ne rilascia dichiarazione scritta.

5. La memoria e i documenti sono letti da uno dei componenti della commissione e allegati agli atti.

6. Il giudicando, se presente, e' ammesso a esporre, anche a mezzo dell'ufficiale difensore, le ragioni a difesa.

7. Il presidente chiede al giudicando, se presente, se ha altro da aggiungere.

8. Udite le ragioni a difesa ed esaminati gli eventuali nuovi documenti, il presidente fa ritirare il militare.

9. La commissione, se ritiene di non poter esprimere, il proprio giudizio senza un supplemento di istruttoria, sospende il procedimento e restituisce gli atti all'autorita' che ha ordinato la convocazione, precisando i punti sui quali giudica necessarie nuove indagini.

10. Non verificandosi l'ipotesi di cui al comma 9, il presidente mette alternativamente ai voti i seguenti quesiti:

- a) <<Il ................ e' meritevole di conservare il grado?>>;
- b) <<Il ................ e' meritevole di permanere in ferma (o in rafferma)?>>;

11. La votazione si svolge con modalita' tali da garantire la segretezza del voto di ciascun membro. Il giudizio della commissione e' espresso a maggioranza assoluta e non e' motivato.

12. Il segretario compila subito il verbale della seduta col giudizio della commissione; il verbale e' letto e firmato dai componenti della commissione.

13. Il presidente scioglie la commissione e trasmette gli atti direttamente al Ministero della difesa.

14. I componenti della commissione sono vincolati al segreto di ufficio.

#### Art. 1389. - Decisione del Ministro della difesa

1. Il Ministro della difesa:

- a) puo' discostarsi, per ragioni umanitarie, dal giudizio della commissione di disciplina a favore del militare;
- b) se ritiene, per gravi ragioni di opportunita', che deve essere inflitta la sanzione della perdita del grado per rimozione ovvero la cessazione dalla ferma o dalla rafferma, ordina, per una sola volta, la convocazione di una diversa commissione di disciplina, ai sensi dell'articolo 1387; in tale caso il procedimento disciplinare deve concludersi nel termine perentorio di ((,90 giorni)).

#### Art. 1390. - Norme per i militari residenti all'estero

1. Agli effetti dell'instaurazione dell'inchiesta formale e dell'eventuale deferimento al giudizio della commissione di disciplina, per il militare residente all'estero si considera come residenza l'ultima da lui avuta nel territorio della Repubblica.

2. L'istanza di ricusazione puo' essere presentata dal militare residente all'estero fino a trenta giorni dalla data in cui egli ha ricevuto comunicazione della convocazione della commissione.

3. Il militare residente all'estero che e' sottoposto a commissione di disciplina, se ritiene di non potersi presentare alla seduta della commissione, ne da' partecipazione al presidente al quale puo' far pervenire una memoria a difesa.

#### Art. 1391. - Procedimenti a carico di militari di diverse categorie

1. In caso di corresponsabilita' tra militari di diverse categorie per fatti che configurino un illecito disciplinare il procedimento e' unico.

2. Il Ministro, fino a quando non e' convocata la commissione di disciplina, puo' ordinare per ragioni di convenienza la separazione dei procedimenti.

#### Art. 1392. - Termini del procedimento disciplinare di stato

1. Il procedimento disciplinare di stato a seguito di giudizio penale, ((salvo il caso in cui l'amministrazione abbia gia' proceduto disciplinarmente ai sensi dell'articolo 1393, comma 1,)) deve essere instaurato con la contestazione degli addebiti all'incolpato, entro 90 giorni dalla data in cui l'amministrazione ha avuto conoscenza integrale della sentenza o del decreto penale irrevocabili, che lo concludono, ovvero del provvedimento di archiviazione.

2. Il procedimento disciplinare di stato a seguito di infrazione disciplinare deve essere instaurato con la contestazione degli addebiti all'incolpato, entro 60 giorni dalla conclusione degli accertamenti preliminari, espletati dall'autorita' competente, nei termini previsti dagli articoli 1040, comma 1, lettera d), numero 19 e 1041, comma 1, lettera s), numero 6 del regolamento.

3. Il procedimento disciplinare di stato, instaurato a seguito di giudizio penale, deve concludersi entro 270 giorni dalla data in cui l'amministrazione ha avuto conoscenza integrale della sentenza o del decreto penale, divenuti irrevocabili, ovvero del provvedimento di archiviazione.

4. In ogni caso, il procedimento disciplinare si estingue se sono decorsi novanta giorni dall'ultimo atto di procedura senza che nessuna ulteriore attivita' e' stata compiuta.

#### Art. 1393. - (( (Rapporti fra il procedimento disciplinare e il procedimento penale). ))

((

1. Il procedimento disciplinare, che abbia ad oggetto, in tutto o in parte, fatti in relazione ai quali procede l'autorita' giudiziaria, e' avviato, proseguito e concluso anche in pendenza del procedimento penale. Per le infrazioni disciplinari di maggiore gravita', punibili con la consegna di rigore di cui all'articolo 1362 o con le sanzioni disciplinari di stato di cui all'articolo 1357, l'autorita' competente, solo nei casi di particolare complessita' dell'accertamento del fatto addebitato al militare ovvero qualora, all'esito di accertamenti preliminari, non disponga di elementi conoscitivi sufficienti ai fini della valutazione disciplinare, promuove il procedimento disciplinare al termine di quello penale. Il procedimento disciplinare non e' comunque promosso e se gia' iniziato e' sospeso fino alla data in cui l'Amministrazione ha avuto conoscenza integrale della sentenza o del decreto penale irrevocabili, che concludono il procedimento penale, ovvero del provvedimento di archiviazione, nel caso in cui riguardi atti e comportamenti del militare nello svolgimento delle proprie funzioni, in adempimento di obblighi e doveri di servizio. Rimane salva la possibilita' di adottare la sospensione precauzionale dall'impiego di cui all'articolo 916, in caso di sospensione o mancato avvio del procedimento disciplinare.

2. Se il procedimento disciplinare, non sospeso, si conclude con l'irrogazione di una sanzione e, successivamente, il procedimento penale e' definito con una sentenza irrevocabile di assoluzione che riconosce che il fatto addebitato al dipendente non sussiste o non costituisce illecito penale o che il militare non lo ha commesso, l'autorita' competente, ad istanza di parte, da proporsi entro il termine di decadenza di sei mesi dall'irrevocabilita' della pronuncia penale, riapre il procedimento disciplinare per modificarne o confermarne l'atto conclusivo in relazione all'esito del giudizio penale.

3. Se il procedimento disciplinare si conclude senza l'irrogazione di sanzioni e il processo penale con una sentenza irrevocabile di condanna, l'autorita' competente riapre il procedimento disciplinare per valutare le determinazioni conclusive all'esito del giudizio penale. Il procedimento disciplinare e' riaperto, altresi', se dalla sentenza irrevocabile di condanna risulta che il fatto addebitabile al dipendente in sede disciplinare puo' comportare la sanzione di stato della perdita del grado per rimozione, ovvero la cessazione dalla ferma o dalla rafferma, mentre e' stata irrogata una diversa sanzione.

4. Nei casi di cui ai commi 1, primo periodo, 2 e 3 il procedimento disciplinare e', rispettivamente, avviato o riaperto entro novanta giorni dalla data in cui l'Amministrazione ha avuto conoscenza integrale della sentenza ovvero dalla presentazione dell'istanza di riapertura ed e' concluso entro duecentosettanta giorni dall'avvio o dalla riapertura. La riapertura avviene mediante il rinnovo della contestazione dell'addebito da parte dell'autorita' competente e il procedimento prosegue secondo le ordinarie modalita' previste.))

#### Art. 1394. - Ricostruzione di carriera

1. Si procede alla ricostruzione della carriera del militare, secondo le disposizioni dettate dall'articolo 921, in caso di:

- a) omessa instaurazione del procedimento disciplinare successivamente alla cessazione degli effetti della sospensione precauzionale;
- b) eccedenza della sospensione precauzionale sofferta rispetto a quella irrogata a titolo di sanzione disciplinare;
- c) annullamento del procedimento disciplinare non seguito da rinnovazione;
- d) assoluzione con formula ampia a seguito di giudizio penale di revisione.

2. In presenza di domanda di ricostruzione della carriera presentata dai familiari eredi del militare deceduto prima della conclusione del giudizio penale o del procedimento disciplinare ovvero durante lo svolgimento del procedimento di revisione penale, l'amministrazione valuta, in contraddittorio con i familiari eredi, la spettanza dei benefici economici discendenti dalla eventuale ricostruzione di carriera.

#### Art. 1395. - Disposizioni per il tempo di guerra o di grave crisi internazionale

1. In tempo di guerra o di grave crisi internazionale, per i procedimenti disciplinari si applicano le norme di cui ai precedenti articoli, salvo quanto stabilito dai commi che seguono.

2. Per l'ufficiale di grado da sottotenente a tenente colonnello, o di grado corrispondente dipendente per l'impiego da comandante di armata o da comandante di divisione autonoma o da comandante di unita' corrispondenti della Marina militare e dell'Aeronautica militare, la decisione di sottoporre l'ufficiale a inchiesta formale, le decisioni da adottare in seguito all'inchiesta stessa, anche per il deferimento a commissione di disciplina, la competenza a formare e a convocare la commissione spettano ai comandanti suddetti.

3. Per l'ufficiale generale o colonnello, o ufficiale di grado corrispondente, dipendente per l'impiego da uno dei comandanti suddetti o da comandante di corpo d'armata o di unita' corrispondenti della Marina militare e dell'Aeronautica militare, il Ministro puo' delegare il Capo di stato maggiore della Forza armata interessata a formare e a convocare la commissione di disciplina.

4. Per gli ufficiali di cui ai commi precedenti la commissione di disciplina e' composta di cinque membri, scelti dall'autorita' cui spetta di formare la commissione tra gli ufficiali in servizio permanente da essa dipendenti.

5. Per il sottufficiale, il graduato o il militare di truppa:

- a) la commissione di disciplina puo' essere composta anche con ufficiali dell'ausiliaria o della riserva, richiamati in servizio;
- b) la competenza a disporre l'inchiesta formale, le decisioni da adottare in seguito all'inchiesta stessa, la competenza a formare e a convocare la commissione di disciplina spettano al comandante di divisione autonoma o al comandante di unita' corrispondenti della Marina militare e della Aeronautica militare, dai quali l'interessato dipende per ragioni di impiego.

### SEZIONE III - PROCEDIMENTO DISCIPLINARE DI CORPO

#### Art. 1396. - Autorita' militari competenti

1. La consegna di rigore puo' essere inflitta esclusivamente dal comandante del corpo o dell'ente presso il quale il militare che subisce la punizione presta servizio.

2. La consegna puo' essere inflitta dal comandante di corpo e dal comandante di reparto.

3. Il rimprovero puo' essere inflitto, oltre che dalle autorita' militari di cui al comma 2, anche da:

- a) l'ufficiale comandante di distaccamento;
- b) il sottufficiale comandante di distaccamento, avente le attribuzioni di comandante di reparto.

4. Le punizioni agli ufficiali generali e ammiragli, ai colonnelli, ai capitani di vascello, ai comandanti di corpo e agli ufficiali che non dipendono da un comando di corpo sono inflitte dal superiore militare diretto o da altra autorita' militare indicata di volta in volta da ciascuna Forza armata o Corpo armato.

5. I militari comandati o aggregati presso un reparto, corpo o ente dipendono disciplinarmente da tale reparto, corpo o ente. Ogni decisione in materia disciplinare e' devoluta all'autorita' militare che ne ha la competenza e dalla quale il militare dipende all'atto della decisione stessa.

6. Anche ai soli fini disciplinari, ciascuna Forza armata o Corpo armato, in relazione alle esigenze funzionali, stabilisce le unita' organizzative aventi il rango di reparto o di distaccamento.

#### Art. 1397. - Procedura da seguire nel rilevare l'infrazione

1. Ogni superiore che rilevi l'infrazione disciplinare, per la quale non e' egli stesso competente a infliggere la sanzione, deve far constatare la mancanza al trasgressore, procedere alla sua identificazione e fare rapporto senza ritardo allo scopo di consentire una tempestiva instaurazione del procedimento disciplinare.

2. Il rapporto deve indicare con chiarezza e concisione ogni elemento di fatto obiettivo, utile a configurare esattamente l'infrazione. Il rapporto non deve contenere proposte relative alla specie e alla entita' della sanzione.

3. Se il superiore che ha rilevato l'infrazione e il militare che l'ha commessa appartengono allo stesso corpo, il rapporto e' inviato:

- a) direttamente al comandante di reparto, se comune a entrambi i militari;
- b) per via gerarchica al comandante del corpo, se trattasi di militare di altro reparto.

4. Per il personale imbarcato il rapporto e' inviato al comando della nave.

5. Negli altri casi il superiore, tramite il proprio comando di corpo o ente, invia il rapporto al comando di corpo da cui il trasgressore dipende; se egli si trova fuori dalla propria sede il rapporto deve essere presentato, per l'inoltro, al locale comando di presidio.

6. I generali, gli ammiragli, i colonnelli, i capitani di vascello e gli ufficiali di grado inferiore investiti delle funzioni di comandante di corpo, anche se di Forza armata o di Corpo armato diversi, inviano il rapporto direttamente al comandante del corpo da cui dipende il militare che ha commesso l'infrazione.

7. Se l'infrazione indicata nel suddetto rapporto e' prevista tra i comportamenti punibili con la consegna di rigore il comandante di corpo e' obbligato a instaurare il procedimento disciplinare.

#### Art. 1398. - Procedimento disciplinare

1. Il procedimento disciplinare deve essere instaurato senza ritardo:

- a) dalla conoscenza dell'infrazione;
- b) ((LETTERA SOPPRESSA DAL D.LGS. 26 APRILE 2016, N. 91));
- c) ((LETTERA SOPPRESSA DAL D.LGS. 26 APRILE 2016, N. 91));
- d) ovvero dal rinvio degli atti al comandante di corpo ((all'esito della valutazione operata dall'autorita' competente ai sensi dell'articolo 1393 di non avviare il procedimento disciplinare di stato o al termine dell'inchiesta formale)).

((

1-bis. Il procedimento disciplinare, nei casi di cui all'articolo 1393, comma 1, periodi secondo e terzo, e' instaurato o ripreso senza ritardo dalla data in cui l'Amministrazione ha avuto conoscenza integrale della sentenza o del decreto penale irrevocabili, che lo concludono, ovvero del provvedimento di archiviazione.

))

2. Il procedimento disciplinare si svolge, anche oralmente, attraverso le seguenti fasi:

- a) contestazione degli addebiti;
- b) acquisizione delle giustificazioni ed eventuali prove testimoniali;
- c) esame e valutazione degli elementi contestati e di quelli addotti a giustificazione;
- d) decisione;
- e) comunicazione all'interessato.

3. L'autorita' competente, se ritiene che sussistono gli estremi per infliggere la sanzione della consegna di rigore, procede a norma dell'articolo 1399.

4. La decisione dell'autorita' competente e' comunicata verbalmente senza ritardo all'interessato anche se l'autorita' stessa non ritiene di far luogo all'applicazione di alcuna sanzione.

5. Al trasgressore e' comunicato per iscritto il provvedimento sanzionatorio contenente la motivazione, salvo che sia stata inflitta la sanzione del richiamo.

6. La motivazione deve essere redatta in forma concisa e chiara e configurare esattamente l'infrazione commessa indicando la disposizione violata o la negligenza commessa e le circostanze di tempo e di luogo del fatto.

7. L'autorita' procedente, se accerta la propria incompetenza in relazione all'irrogazione della sanzione disciplinare, deve darne immediata comunicazione all'interessato e all'autorita' competente rimettendole gli atti corredati di una sintetica relazione.

8. Le decisioni adottate a seguito di rapporto sono rese note al compilatore del rapporto stesso.

#### Art. 1399. - Procedure per infliggere la consegna di rigore

1. Dopo aver provveduto agli adempimenti indicati nell'articolo 1400, il comandante di corpo o di ente convoca l'incolpato, il difensore e la commissione.

2. Il procedimento si svolge, quindi, come segue:

- a) contestazione da parte del comandante di corpo o di ente degli addebiti;
- b) esposizione da parte dell'incolpato delle giustificazioni in merito ai fatti addebitatigli;
- c) eventuale audizione di testimoni ed esibizione di documenti;
- d) intervento del militare difensore.

3. Il comandante, congedati gli eventuali testimoni, l'incolpato e il difensore, sentita la commissione, la invita a ritirarsi per formulare il parere di competenza. Se non vi e' accordo tra i componenti della commissione, il parere e' espresso a maggioranza.

4. I componenti la commissione sono tenuti al segreto sulle opinioni espresse nel proprio ambito.

5. Il parere e' reso noto verbalmente al comandante di corpo o di ente entro il tempo massimo di due ore.

6. Il parere non e' vincolante.

7. Il comandante di corpo o di ente deve rendere nota la propria decisione possibilmente entro lo stesso giorno. La decisione e' comunicata senza ritardo all'interessato anche quando non sono applicate sanzioni.

8. Quando previsto, la comunicazione e' effettuata anche per iscritto.

9. Successivamente alla seduta, il comandante di corpo fa redigere e firma apposito verbale nel quale, oltre alla motivazione della decisione e al parere della commissione, sono precisate le generalita' dei componenti della commissione e del militare difensore.

#### Art. 1400. - Commissione di disciplina

1. Il comandante di corpo o di ente, tutte le volte che si trova a dover giudicare una infrazione per la quale e' prevista la sanzione della consegna di rigore, ha l'obbligo di sentire, prima della sua decisione, il parere di apposita commissione disciplinare.

2. La commissione:

- a) e' composta da tre militari, di cui due di grado superiore e un pari grado del militare che ha commesso la mancanza;
- b) e' nominata dal comandante di corpo;
- c) e' presieduta dal piu' elevato in grado o dal piu' anziano dei componenti a parita' di grado.

3. Se presso il corpo o l'ente non esistono, in tutto o in parte, militari del grado prescritto per la costituzione della commissione, il comandante di corpo o di ente richiede al comando o all'ente, immediatamente superiore in via disciplinare, l'indicazione dei citati militari.

4. La commissione e' edotta delle generalita' dell'incolpato e degli addebiti a lui contestati.

5. Nel caso in cui piu' militari hanno commesso la stessa mancanza la commissione e' unica.

6. Non possono far parte della commissione il superiore che ha rilevato la mancanza e il militare offeso o danneggiato.

#### Art. 1401. - Provvedimenti provvisori a titolo precauzionale

1. In caso di necessita' e urgenza, il comandante di corpo, se rileva una mancanza tale da comportare la consegna o la consegna di rigore, o se ne viene edotto, puo' disporre, a titolo precauzionale, l'immediata adozione di provvedimenti provvisori, della durata massima di quarantotto ore, in attesa che venga definita la sanzione disciplinare.

2. Il superiore che adotta il provvedimento provvisorio deve informare senza ritardo l'autorita' competente a irrogare la sanzione, affinche' essa provveda alla conferma o meno del provvedimento, in attesa di procedere ai sensi degli articoli 1398.

3. La durata del provvedimento provvisorio va compresa nel computo della sanzione definitiva.

## CAPO V - ONORIFICENZE MILITARI E RICOMPENSE

### SEZIONE I - ORDINE MILITARE D'ITALIA

#### Art. 1402. - Finalita'

1. L'Ordine Militare d'Italia ha lo scopo di ricompensare mediante il conferimento di decorazioni le azioni distinte compiute in guerra da unita' delle Forze armate nazionali di terra, di mare e dell'aria o da singoli militari a esse appartenenti, che hanno dato sicure prove di perizia, di senso di responsabilita' e di valore.

2. Le decorazioni dell'Ordine Militare d'Italia possono essere conferite anche per operazioni di carattere militare compiute in tempo di pace, se sono strettamente connesse alle finalita' per le quali le Forze militari dello Stato sono costituite.

3. Le decorazioni dell'Ordine Militare d'Italia possono essere conferite anche alla memoria.

#### Art. 1403. - Organizzazione

1. Capo dell'Ordine Militare d'Italia e' il Presidente della Repubblica.

2. Cancelliere e Tesoriere dell'Ordine Militare d'Italia e' il Ministro della difesa.

3. L'Ordine ha un consiglio composto da un presidente e da ((cinque)) membri. Il presidente e i membri del consiglio sono nominati tra ufficiali decorati dell'Ordine, con una uguale rappresentanza delle Forze armate.

4. E' segretario dell'Ordine Militare d'Italia un ufficiale appartenente a una delle classi dell'Ordine.

#### Art. 1404. - Classi

1. L'Ordine Militare d'Italia comprende cinque classi:

- a) Cavalieri di Gran Croce;
- b) Grandi Ufficiali;
- c) Commendatori;
- d) Ufficiali;
- e) Cavalieri.

2. Il regolamento fissa le condizioni per il conferimento delle singole classi di decorazioni e stabilisce il modello delle insegne e dei nastrini corrispondenti a ciascuna classe.

#### Art. 1405. - Conferimento

1. Le decorazioni dell'Ordine Militare d'Italia sono conferite con decreto del Presidente della Repubblica, su proposta del Ministro della difesa, sentito il Consiglio dell'Ordine, salvo quanto stabilito dall'articolo 1406.

#### Art. 1406. - Militari stranieri

1. Le decorazioni dell'Ordine Militare d'Italia possono essere concesse, con decreto del Presidente della Repubblica su proposta del Ministro della difesa, a militari stranieri benemeriti dello Stato italiano per servizi resi in guerra.

2. Agli anzidetti militari non e' corrisposta la pensione straordinaria di cui all'articolo 1921.

#### Art. 1407. - Conferimento alla Bandiera

1. Nel caso di azioni di guerra particolarmente distinte e gloriose compiute da unita' delle Forze armate di terra, di mare e dell'aria, puo' essere conferita <<alla Bandiera>> la croce di Cavaliere dell'Ordine Militare d'Italia ma non decorazioni di classi superiori.

#### Art. 1408. - Cessazione dall'Ordine

1. Il militare appartenente all'Ordine Militare d'Italia cessa di far parte dell'Ordine se e' privato del suo grado militare.

2. Le disposizioni relative alla perdita delle medaglie e della croce di guerra al valor militare contenute nella sezione II del presente capo, sono estese, in quanto applicabili, ai decorati dell'Ordine Militare d'Italia, sostituito il ((parere del Consiglio dell'Ordine a quello previsto dall'articolo 1426)).

#### Art. 1409. - Disposizioni regolamentari

1. Il regolamento disciplina le disposizioni di attuazione concernenti l'Ordine Militare d'Italia.

### SEZIONE II - RICOMPENSE AL VALOR MILITARE

#### Art. 1410. - Istituzione

1. Le decorazioni al valor militare sono istituite per esaltare gli atti di eroismo militare, segnalando come degni di pubblico onore gli autori di essi e suscitando, a un tempo, lo spirito di emulazione negli appartenenti alle Forze militari.

#### Art. 1411. - Tipologia

1. Le decorazioni al valor militare sono:

- a) la medaglia d'oro;
- b) la medaglia d'argento;
- c) la medaglia di bronzo;
- d) la croce al valor militare.

2. La croce al valor militare assume la denominazione di croce di guerra al valor militare quando si conferisce per fatti compiuti durante lo stato di guerra o di grave crisi internazionale.

#### Art. 1412. - Concessione

1. Le decorazioni al valor militare sono concesse a coloro i quali, per compiere un atto di ardimento che avrebbe potuto omettersi senza mancare al dovere e all'onore, hanno affrontato scientemente, con insigne coraggio e con felice iniziativa, un grave e manifesto rischio personale in imprese belliche.

2. La concessione di dette decorazioni ha luogo solo se l'atto compiuto e' tale da poter costituire, sotto ogni aspetto, un esempio degno di essere imitato.

#### Art. 1413. - Concessione in tempo di pace

1. Le medaglie d'oro, d'argento, di bronzo e la croce al valor militare possono essere concesse anche per imprese di carattere militare compiute in tempo di pace, se in esse ricorrono le caratteristiche di cui all'articolo 1412.

2. In tempo di pace il carattere militare deve essere riconosciuto a ogni impresa strettamente connessa alle finalita' per le quali le Forze armate dello Stato sono istituite, qualunque sia la condizione e la qualita' dell'autore.

3. Se l'impresa tende soltanto a fini filantropici o tipicamente professionali, estranei o non strettamente connessi alle finalita' per le quali sono istituite le Forze armate dello Stato, si fa luogo alla concessione di ricompense di altra natura, anche se l'autore e' un militare in servizio.

#### Art. 1414. - Criteri per la concessione

1. Il grado della decorazione al valor militare si commisura alla entita' dell'atto di valore compiuto, quale e' determinata dagli elementi che lo costituiscono e, segnatamente, dalla elevatezza degli intendimenti dell'autore, dalla gravita' del rischio e dal modo con il quale esso e' stato affrontato, e dalla somma dei risultati conseguiti.

2. La perdita della vita puo' essere la dimostrazione piu' evidente della gravita' del rischio; tuttavia essa non puo', da sola, costituire titolo a una decorazione al valor militare ne' indurre a una supervalutazione dell'impresa compiuta, quale risulta dal complesso di tutti gli altri elementi.

#### Art. 1415. - Atto di conferimento

1. Il conferimento delle decorazioni al valor militare si effettua con decreto del Presidente della Repubblica.

2. La potesta' di conferire le dette decorazioni puo', in tempo di guerra o di grave crisi internazionale, essere delegata agli alti comandi militari, non inferiori ai comandi di armata e denominazioni corrispondenti; anche in tale caso, il conferimento deve essere sanzionato con decreto del Presidente della Repubblica.

3. I decreti di conferimento di decorazioni al valor militare quando non sono emessi motu proprio, sono emanati su proposta del Ministro della difesa o del Ministro dell'economia e delle finanze per gli appartenenti al Corpo della Guardia di finanza.

#### Art. 1416. - Proposta

1. Per i militari in servizio l'iniziativa della proposta puo' essere presa dal superiore immediato, o da altro superiore piu' elevato.

2. Le proposte, corredate da tutti i documenti necessari per comprovare la realta' e le circostanze del fatto e per porre in evidenza tutti gli elementi del valore, sono avanzate per la via gerarchica, onde le autorita' superiori possano esprimere il proprio parere.

3. Esse sono trasmesse al Ministero competente entro il termine perentorio di sei mesi dalla data del fatto, salvo che ricorrano particolari e giustificati motivi, nel qual caso il detto termine e' prolungato fino a nove mesi.

4. Nelle proposte e nelle concessioni di decorazioni al valor militare sono tenute presenti le disposizioni dell'articolo 1425, circa i casi in cui si incorre nella perdita di diritto o discrezionale di esse. ((47))

-------------- AGGIORNAMENTO (47) Il D.Lgs. 15 marzo 2010, n. 66 ha disposto (con l'art. 1, comma 1) che "In deroga all'articolo 1416 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, relativo alla presentazione di proposte di onorificenze al valor militare, in occasione del settantesimo anniversario della Liberazione d'Italia e' concessa la medaglia d'oro al valor militare per la Resistenza alla Brigata ebraica, formazione militare alleata, composta da volontari di cittadinanza italiana o straniera, inquadrata nell'Esercito britannico, che opero' durante la seconda guerra mondiale e offri' un notevole contributo alla liberazione della Patria e alla lotta contro gli invasori nazisti".

#### Art. 1417. - Militari in congedo ed estranei alle Forze armate

1. Per i militari in congedo e per gli estranei alle Forze armate che hanno compiuto un atto di valore militare, l'iniziativa della proposta e' assunta dalle autorita' militari locali o, in mancanza di esse, anche da autorita' civili.

2. La proposta e' rimessa al comandante militare competente per territorio, di grado non inferiore a ufficiale generale o corrispondente che, completata l'istruttoria, la trasmette per la via gerarchica al Ministero competente.

3. Anche per tali proposte valgono le disposizioni dell'articolo 1416 per quanto riguarda termini e modalita'.

#### Art. 1418. - ((Parere in materia di ricompense al valor militare))

((

1. La proposta da parte del Ministro competente, deve essere preceduta dal parere del Capo di Stato maggiore della difesa per il personale delle Forze armate, ovvero del Comandante generale del Corpo della Guardia di finanza per gli appartenenti al medesimo Corpo, i quali si pronunciano sulla convenienza della concessione e sul grado della decorazione da conferire.

))

#### Art. 1419. - Stato di guerra o di grave crisi internazionale

1. In tempo di guerra o di grave crisi internazionale, se l'entita' dell'atto di valore e lo svolgimento delle vicende belliche lo consigliano, puo' farsi luogo al conferimento di decorazioni al valor militare immediatamente dopo il fatto o con procedura singolarmente accelerata, da determinarsi con apposite disposizioni.

#### Art. 1420. - Concessioni alla memoria

1. Se l'autore di un atto di valore militare e' rimasto vittima del proprio eroismo, o quando, comunque, e' deceduto dopo il compimento dell'atto di valore, la decorazione al valor militare puo' essere concessa alla sua memoria.

2. Le insegne e i brevetti delle decorazioni al valor militare, concesse alla memoria di persona deceduta, sono attribuite in proprieta', secondo il seguente ordine di preferenza:

- a) al coniuge superstite, nei confronti del quale non e' stata pronunciata sentenza di separazione con addebito;
- b) al primogenito tra i figli e le figlie;
- c) al piu' anziano tra i genitori;
- d) al maggiore tra i fratelli e le sorelle.

3. Se mancano detti congiunti prossimi, le insegne e i brevetti del deceduto sono attribuiti in proprieta' al Corpo cui egli apparteneva, se militare; ovvero al Comune di nascita, se egli era estraneo alle Forze armate dello Stato.

4. In caso di morte della persona alla quale furono attribuite in proprieta' le insegne e i brevetti delle decorazioni concesse alla memoria, i passaggi di proprieta' delle insegne e dei brevetti medesimi sono regolati dalle comuni disposizioni di legge sulle successioni. Tali disposizioni si applicano per detti passaggi, anche nel caso di morte del decorato gia' in possesso delle insegne e dei brevetti.

#### Art. 1421. - Atti di valore reiterati

1. Gli atti di valore militare reiterati, se non comportano una ricompensa di altra natura, possono essere premiati ciascuno con una appropriata decorazione al valor militare e senza limitazione di numero.

2. Non e' consentito il conferimento di piu' decorazioni per un solo fatto d'armi, anche se molteplici sono stati gli atti di ardimento compiuti in tale fatto d'armi dalla stessa persona.

3. La commutazione di piu' decorazioni di grado inferiore in una di grado superiore non e' ammessa.

#### Art. 1422. - Requisiti dei congiunti

1. E' necessario non aver riportato sentenza di condanna per delitto non colposo ed essere di condotta morale incensurabile per ottenere:

- a) l'assegnazione delle insegne e dei brevetti delle decorazioni al valor militare concesse alla memoria, di cui all'articolo 1420;
- b) la reversibilita' dell'assegno annuo annesso alle medaglie, di cui all'articolo 1926;
- c) l'autorizzazione a indossare le insegne.

#### Art. 1423. - Concessione ai reparti

1. Le decorazioni al valor militare possono essere concesse anche a interi reparti non inferiori alle compagnie o a comandi che si sono collettivamente distinti per valore in azioni belliche.

2. Le insegne sono appese alla bandiera o al labaro se il reparto decorato ne e' dotato.

#### Art. 1424. - Pubblicazioni

1. A cura del Ministero competente, delle singole concessioni di decorazioni al valor militare e' data pubblica notizia con inserzione nel proprio bollettino, nel sito istituzionale e nella Gazzetta Ufficiale. Di esse e' inoltre data particolare partecipazione, con la comunicazione integrale delle motivazioni, al comune di nascita del decorato.

2. Spetta a detto comune l'obbligo di portare a conoscenza della popolazione ogni concessione con apposita affissione nell'albo pretorio e anche con la inserzione nelle pubblicazioni che eventualmente emanino dall'amministrazione comunale, e con ogni altro mezzo ritenuto opportuno.

#### Art. 1425. - Perdita delle ricompense e incapacita' a conseguirle

1. Sono incapaci di conseguire tutte le ricompense di cui alla presente sezione, ovvero incorrono nella perdita di diritto delle stesse, coloro che sono stati condannati a pene che, ai sensi dell'articolo 622, li rendono indegni di appartenere alle Forze armate dello Stato.

2. Su proposta del Ministro competente, incorrono nella perdita delle ricompense di cui al presente capo:

- a) i condannati, per qualsiasi reato, alla reclusione o alla reclusione militare per la durata superiore a due anni;
- b) coloro che hanno perduto la cittadinanza italiana;
- c) i condannati, in applicazione dei codici penali militari, per i reati di diserzione, di rivolta, di ammutinamento, di procurata infermita' o di abbandono di posto;
- d) i condannati con sentenze pronunciate all'estero da giudici stranieri per delitti di natura disonorante o a pene che hanno per effetto, secondo la legge italiana, la interdizione anche temporanea dai pubblici uffici, previo esame delle eventuali giustificazioni addotte;
- e) coloro che hanno perduto il grado in seguito a provvedimento disciplinare per fatti disonorevoli, ovvero in seguito a condanna da cui gia' non consegue la perdita delle decorazioni stesse.

#### Art. 1426. - Pareri

1. Le proposte di perdita delle ricompense al valore, nei casi di cui all'articolo 1425, sono formulate dal Ministro competente, sentito il ((Capo di stato maggiore della difesa per il personale delle Forze armate, ovvero il Comandante generale del Corpo della Guardia di finanza per gli appartenenti al medesimo Corpo)).

#### Art. 1427. - Casi di sospensione

1. Se nei casi sotto elencati non e' decretata la perdita delle decorazioni, di cui all'articolo 1425, il Ministro competente puo' disporre con sua determinazione la sospensione della facolta' di fregiarsi delle dette decorazioni, e di godere dell'annesso beneficio economico, per tutta la durata della pena principale e accessoria o della misura disciplinare o di prevenzione:

- a) condanna a pena restrittiva della liberta' personale, eccedente i sei mesi, o che ha per effetto la interdizione temporanea dai pubblici uffici;
- b) sospensione disciplinare dall'impiego o dalle funzioni del grado;
- c) applicazione di misura di prevenzione definitiva.

#### Art. 1428. - Perdita di altre ricompense

1. Coloro che si trovano nelle condizioni previste dall'articolo 1425, comma 1, incorrono di diritto anche nella perdita di tutte le distinzioni onorifiche di guerra, specificate nell'articolo 785, comma 2, del regolamento, ovvero sono incapaci di conseguirle.

2. Per coloro, invece, che si trovano nelle condizioni previste dai precedenti articoli 1425, comma 2 e 1427, la perdita delle dette distinzioni onorifiche di guerra, o la sospensione del diritto di fregiarsene, e' inflitta come conseguenza necessaria della gia' decretata perdita o sospensione delle decorazioni di cui agli articoli 1425 e 1427; oppure e' determinata, caso per caso, dal Ministro competente quando si tratta di militari non insigniti delle dette decorazioni al valore.

#### Art. 1429. - Decorrenza della perdita

1. La perdita delle decorazioni prevista dall'articolo 1425, comma 1, insieme a quella dei benefici connessi, e la perdita delle distinzioni onorifiche di guerra, prevista dall'articolo 1428, comma 1, decorrono dalla data di passaggio in cosa giudicata della sentenza di condanna.

2. La perdita o la sospensione delle ricompense al valore militare, decretate a termine dei precedenti articoli 1425, comma 2 e 1428, insieme a quella dei benefici connessi, e la perdita o la sospensione delle distinzioni onorifiche di guerra prevista dall'articolo 1428, comma 2, decorrono dalla data del relativo decreto presidenziale o della relativa determinazione ministeriale.

#### Art. 1430. - Riabilitazione

1. La riabilitazione del condannato ripristina a tutti gli effetti, dal giorno in cui e' decretata, le perdute concessioni delle decorazioni, di cui all'articolo 1425, o delle distinzioni onorifiche di guerra ed elimina l'incapacita' a conseguirle.

2. Se la privazione di dette decorazioni e distinzioni deriva dalla perdita della cittadinanza o del grado militare, il riacquisto della cittadinanza, o la reintegrazione nel grado, producono i medesimi effetti della riabilitazione.

#### Art. 1431. - Nuovi atti di valore

1. Possono essere attribuiti agli ulteriori, o cospicui, o reiterati atti di valore, compiuti da chi e' incorso nella perdita delle decorazioni di cui all'articolo 1425 o delle distinzioni onorifiche di guerra, o che e' stato ritenuto incapace a conseguirle, gli stessi effetti della riabilitazione, su proposta o con provvedimento del Ministro competente, ((sentito il Capo di stato maggiore della difesa per il personale delle Forze armate, ovvero il Comandante generale del Corpo della Guardia di finanza per gli appartenenti al medesimo Corpo)).

#### Art. 1432. - Norma di rinvio

1. Nel regolamento sono contenute le disposizioni per la esecuzione delle norme della presente sezione.

### SEZIONE III - RICOMPENSE AL VALORE E AL MERITO DELL'ESERCITO

#### Art. 1433. - Istituzione

1. Gli atti di coraggio compiuti in attivita' militari non belliche svolte dall'Esercito italiano, diretti a salvare vite umane, a impedire sinistri o ad attenuarne le conseguenze, nonche' le imprese e gli studi volti allo sviluppo e al progresso dell'Esercito italiano, ovvero singole azioni caratterizzate da somma perizia, da cui sono derivati lustro e decoro all'Esercito italiano, sono premiati con le seguenti ricompense:

- a) medaglia d'oro al valore dell'Esercito;
- b) medaglia d'argento al valore dell'Esercito;
- c) medaglia di bronzo al valore dell'Esercito.
- d) croce d'oro al merito dell'Esercito;
- e) croce d'argento al merito dell'Esercito;
- f) croce di bronzo al merito dell'Esercito.

2. Le ricompense di cui al comma 1 possono essere concesse a cittadini italiani e stranieri nonche' a comandi, corpi o enti che, partecipando collettivamente a imprese particolarmente difficili, hanno contribuito ad aumentare il prestigio dell'Esercito italiano.

#### Art. 1434. - Medaglie al valore dell'Esercito

1. Le medaglie d'oro e d'argento al valore dell'Esercito sono concesse a coloro che, in condizioni di estrema difficolta', hanno dimostrato spiccato coraggio e singolare perizia, esponendo la propria vita a manifesto rischio per salvare una o piu' persone in grave pericolo oppure per impedire o diminuire comunque il danno di grave disastro.

2. Per l'attribuzione della medaglia d'oro si richiede il concorso di circostanze tali da rendere l'atto compiuto meritorio e commendevole in sommo grado e la condizione essenziale che ne sia derivato grande onore all'Esercito italiano.

3. La medaglia di bronzo e' concessa per atti e imprese di particolare coraggio e perizia, compiuti senza manifesto pericolo di vita.

#### Art. 1435. - Croce al merito

1. La croce al merito dell'Esercito e' destinata a ricompensare il concorso particolarmente intelligente, ardito ed efficace a imprese e studi di segnalata importanza, volti allo sviluppo e al progresso dell'Esercito italiano, da cui sono derivati a quest'ultimo spiccato lustro e decoro.

2. Il grado della ricompensa e' commisurato all'importanza degli effetti conseguiti e alle difficolta' superate nel corso dell'attivita' svolta.

3. La croce al merito dell'Esercito puo' essere concessa <<alla memoria>>; in tal caso si applicano le norme previste dall'articolo 1449.

### SEZIONE IV - RICOMPENSE AL VALORE E AL MERITO DI MARINA

#### Art. 1436. - Istituzione

1. Gli atti di coraggio diretti a salvare vite umane in mare, a impedire sinistri marittimi o ad attenuarne le conseguenze, le attivita' e gli studi volti allo sviluppo e al progresso della Marina militare italiana, nonche' le singole azioni di merito caratterizzate da spiccata perizia da cui sono derivati lustro e decoro alla marineria italiana, sono premiati con le seguenti ricompense:

- a) medaglia d'oro al valor di marina;
- b) medaglia d'argento al valor di marina;
- c) medaglia di bronzo al valor di marina;
- d) medaglia d'oro al merito di marina;
- e) medaglia d'argento al merito di marina;
- f) medaglia di bronzo al merito di marina.

2. Le ricompense di cui al comma 1 possono essere concesse a cittadini italiani e stranieri nonche' a comandi, corpi o enti che, partecipando collettivamente a imprese particolarmente difficili, hanno contribuito ad aumentare il prestigio della Marina militare.

#### Art. 1437. - Medaglie al valore di Marina

1. Le medaglie d'oro e di argento al valor di marina sono destinate a ricompensare coloro che nel compiere atti di coraggio in mare hanno dimostrato perizia marinaresca ed esposto la propria vita a manifesto pericolo.

2. Per la medaglia d'oro si richiede il concorso di circostanze tali da rendere l'atto compiuto meritorio e commendevole in sommo grado.

3. La medaglia di bronzo e', invece, destinata a ricompensare atti di coraggio compiuti con perizia marinaresca, ma senza manifesto pericolo di vita.

#### Art. 1438. - Medaglie al merito di Marina

1. La medaglia al merito di marina e' destinata a ricompensare coloro che hanno svolto attivita' e studi finalizzati allo sviluppo e al progresso della Marina militare, ovvero coloro che hanno compiuto singole azioni, caratterizzate da notevole perizia, da cui sono derivati lustro e decoro alla marineria italiana.

2. Il grado della ricompensa e' commisurato all'importanza dei risultati conseguiti e alle difficolta' superate nel corso dell'attivita' svolta.

### SEZIONE V - RICOMPENSE AL VALORE E AL MERITO AERONAUTICO

#### Art. 1439. - Istituzione

1. Per atti e imprese di singolare coraggio e perizia compiuti a bordo di aeromobili in volo, sono istituite le seguenti ricompense:

- a) medaglia d'oro al valore aeronautico;
- b) medaglie d'argento al valore aeronautico;
- c) medaglia di bronzo al valore aeronautico.

2. E' istituita la medaglia (d'oro, d'argento e di bronzo) al merito aeronautico allo scopo di premiare attivita' e studi volti allo sviluppo e al progresso dell'aviazione e, in particolare, di quella italiana, ovvero singole azioni da cui e' derivato lustro e decoro all'aviazione italiana.

3. Le medaglie al merito aeronautico possono essere concesse a cittadini italiani e stranieri, a comandi, corpi o enti.

#### Art. 1440. - Medaglie al valore aeronautico

1. Le ((medaglie)) d'oro e d'argento al valore aeronautico sono concesse:

- a) ai militari e ai civili che in circostanze particolarmente difficili, hanno compiuto atti di coraggio e dimostrata singolare perizia esponendo la loro vita durante il volo a eccezionale pericolo;
- b) ai reparti non inferiori alle squadriglie, ai comandi e agli enti che partecipando collettivamente a imprese aviatorie particolarmente difficili, hanno contribuito ad aumentare il prestigio dell'Aeronautica militare italiana.

2. Per la concessione della medaglia d'oro si richiede il concorso di circostanze tali da rendere le imprese e gli atti compiuti meritevoli e commendevoli in sommo grado e la condizione essenziale che ne e' derivato grande onore all'Aeronautica militare.

3. La medaglia di bronzo al valore aeronautico e' concessa ai militari e ai civili per atti di singolare coraggio e perizia, o ai predetti reparti, comandi ed enti per imprese particolarmente commendevoli.

### SEZIONE VI - RICOMPENSE AL VALORE E AL MERITO DELL'ARMA DEI CARABINIERI

#### Art. 1441. - Istituzione

1. Gli atti di coraggio compiuti in attivita' militari non belliche svolte dall'Arma dei carabinieri diretti a salvare vite umane, a impedire sinistri o ad attenuare le conseguenze, nonche' le imprese e gli studi volti allo sviluppo e al progresso dell'Arma dei carabinieri ovvero singole azioni caratterizzate da somma perizia, da cui sono derivati lustro e decoro all'Arma dei carabinieri sono premiati con le seguenti ricompense:

- a) ricompense al valore: 1) medaglia d'oro al valore dell'Arma dei carabinieri; 2) medaglia d'argento al valore dell'Arma dei carabinieri; 3) medaglia di bronzo al valore dell'Arma dei carabinieri;
- b) ricompense al merito per imprese, studi e azioni caratterizzate da somma perizia: 1) croce d'oro al merito dell'Arma dei carabinieri; 2) croce d'argento al merito dell'Arma dei carabinieri; 3) croce di bronzo al merito dell'Arma dei carabinieri.

2. Le medaglie al valore e le croci al merito dell'Arma dei carabinieri possono essere concesse a cittadini italiani e stranieri nonche' a comandi, corpi o enti che, partecipando collettivamente a imprese particolarmente difficili, hanno contribuito ad aumentare il prestigio dell'Arma dei carabinieri.

#### Art. 1442. - Medaglie al valore dell'Arma dei carabinieri

1. Le medaglie d'oro e d'argento al valore dell'Arma dei carabinieri sono concesse a coloro che, in attivita' militari non belliche e in condizioni di estrema difficolta', hanno dimostrato spiccato coraggio e singolare perizia, esponendo la propria vita a manifesto rischio per:

- a) salvare persone esposte a imminente e grave pericolo oppure per impedire o diminuire il danno di un grave disastro;
- b) garantire l'applicazione della legge, anche internazionale, con particolare riferimento alla tutela dei diritti umani;
- c) tenere alti il nome e il prestigio dell'Arma dei carabinieri, anche all'estero.

2. Per l'attribuzione della medaglia d'oro si richiede il concorso di circostanze tali da rendere l'atto compiuto meritorio e degno di massima lode nonche' la condizione essenziale che ne e' derivato grande onore all'Arma dei carabinieri.

3. La medaglia di bronzo e' concessa per atti e imprese compiuti senza manifesto pericolo di vita.

#### Art. 1443. - Croci al merito dell'Arma dei carabinieri

1. La croce al merito dell'Arma dei carabinieri e' destinata a ricompensare il concorso particolarmente intelligente, ardito ed efficace a imprese e studi di segnalata importanza, volti allo sviluppo e al progresso dell'Arma dei carabinieri, da cui sono derivati a quest'ultima spiccato lustro e decoro.

2. Il grado della ricompensa e' commisurato all'importanza degli effetti conseguiti e alle difficolta' superate nel corso dell'attivita' svolta.

### SEZIONE VII - NORME COMUNI ALLE RICOMPENSE AL VALORE E AL MERITO DI FORZA ARMATA

#### Art. 1444. - Definizioni

1. Ai fini della presente sezione sono considerate ricompense:

- a) al valore di Forza armata le seguenti ricompense: 1) medaglia d'oro al valore dell'Esercito; 2) medaglia d'argento al valore dell'Esercito; 3) medaglia di bronzo al valore dell'Esercito; 4) medaglia d'oro al valor di marina; 5) medaglia d'argento al valor di marina; 6) medaglia di bronzo al valor di marina; 7) medaglia d'oro al valore aeronautico; 8) medaglie d'argento al valore aeronautico; 9) medaglia di bronzo al valore aeronautico; 10) medaglia d'oro al valore dell'Arma dei carabinieri; 11) medaglia d'argento al valore dell'Arma dei carabinieri; 12) medaglia di bronzo al valore dell'Arma dei carabinieri;
- b) al merito di Forza armata le seguenti ricompense: 1) croce d'oro al merito dell'Esercito; 2) croce d'argento al merito dell'Esercito; 3) croce di bronzo al merito dell'Esercito; 4) medaglia d'oro al merito di marina; 5) medaglia d'argento al merito di marina; 6) medaglia di bronzo al merito di marina; 7) medaglia d'oro al merito aeronautico; 8) medaglie d'argento al merito aeronautico; 9) medaglia di bronzo al merito aeronautico; 10) croce d'oro al merito dell'Arma dei carabinieri; 11) croce d'argento al merito dell'Arma dei carabinieri; 12) croce di bronzo al merito dell'Arma dei carabinieri.

2. L'ordine di successione delle insegne e' stabilito nel regolamento.

#### Art. 1445. - ((Ricompense al valore o al merito di Forza armata))

((

1. Il parere sulla concessione delle ricompense al valore o al merito di Forza armata e' espresso dal rispettivo Capo di stato maggiore ovvero dal Comandante generale dell'Arma dei carabinieri, all'atto dell'inoltro della relativa proposta, secondo le modalita' di cui all'articolo 86 del regolamento.

2. Se i Capi di stato maggiore di Forza armata o il Comandante generale dell'Arma dei carabinieri non riscontrano nell'azione compiuta gli estremi di cui ai precedenti articoli 1434, 1435, 1437, 1438, 1439, comma 2, 1440, 1442 e 1443, ove comunque si tratta di atti di coraggio, puo' proporre l'invio dei documenti relativi al Ministero dell'interno per l'eventuale concessione di ricompense al valore o al merito civile.

))

#### Art. 1446. - Atto di conferimento

1. Le ricompense al valore di Forza armata sono conferite con decreto del Presidente della Repubblica, su proposta del Ministro della difesa.

2. Le ricompense al merito di Forza armata sono concesse dal Ministro della difesa.

3. E' concessa, su proposta del Ministro della difesa, di concerto con il Ministro delle infrastrutture e dei trasporti, la medaglia al merito di marina, quando e' destinata a premiare attivita' o azioni compiute da personale appartenente alla gente di mare.

4. E' concessa dal Ministro della difesa di concerto con il Ministro delle infrastrutture e dei trasporti la medaglia al merito aeronautico, quando e' destinata a premiare attivita' o azioni interessanti l'aviazione civile.

#### Art. 1447. - Pubblicazioni

1. Delle singole concessioni di decorazioni previste nella presente sezione e' data pubblicazione con inserzione nella Gazzetta Ufficiale della Repubblica.

2. Il Ministero della difesa partecipa, di volta in volta, ai comuni di nascita dei decorati, la concessione delle ricompense previste dalla presente sezione, dando comunicazione integrale delle relative motivazioni.

3. I comuni interessati:

- a) prendono nota nei registri di anagrafe delle concessioni di ricompense al valore e al merito di Forza armata e ne fanno annotazione nei certificati di rito da rilasciarsi su richiesta dell'autorita' giudiziaria;
- b) portano a conoscenza della popolazione ogni concessione con apposita affissione nell'albo pretorio e anche con l'inserzione nelle pubblicazioni eventualmente emanate dall'amministrazione comunale, e con ogni altro mezzo ritenuto opportuno.

#### Art. 1448. - Opposizione

1. E' ammessa opposizione da parte degli interessati avverso le decisioni relative a proposte di ricompense previste dalla presente sezione.

2. L'opposizione deve essere presentata al Ministro della difesa entro due anni dalla data di pubblicazione della concessione o della comunicazione fatta all'interessato nel caso di decisione negativa.

((

3. Sull'opposizione di cui al comma 2, il Ministro della difesa decide in via definitiva, previo parere del rispettivo Capo di stato maggiore di Forza armata o del Comandante generale dell'Arma dei carabinieri, che si esprimono secondo le modalita' di cui all'articolo 86 del regolamento.

))

#### Art. 1449. - Concessione alla memoria

1. Le ricompense al valore e al merito di Forza armata possono essere concesse alla memoria di colui che e' rimasto vittima della propria azione generosa o che e' deceduto in conseguenza di essa.

2. Nei predetti casi, l'insegna e il brevetto sono attribuiti in proprieta', secondo il seguente ordine di preferenza:

- a) al coniuge superstite, nei confronti del quale non e' stata pronunciata sentenza di separazione con addebito;
- b) al primogenito tra i figli e le figlie;
- c) al piu' anziano tra i genitori;
- d) al maggiore tra i fratelli e le sorelle.

3. In mancanza dei predetti congiunti, l'insegna e il brevetto del deceduto sono attribuiti in proprieta':

- a) al corpo, comando o ente cui egli apparteneva, se militare dell'Esercito italiano, della Marina militare o dell'Aeronautica militare;
- b) al Museo storico dell'Arma dei carabinieri, se militare dell'Arma stessa;
- c) al comune di nascita, se estraneo alle Forze armate dello Stato.

#### Art. 1450. - Assegnazione di insegne e brevetti ai congiunti

1. E' data facolta', ai sensi dell'articolo 1449, di fregiarsi dell'insegna della medaglia al valore di Forza armata, concessa alla memoria di deceduto:

- a) al coniuge superstite;
- b) al primogenito, se maggiorenne;
- c) al piu' anziano dei genitori.

2. Per ottenere l'assegnazione delle insegne e dei brevetti delle medaglie al valore di Forza armata concessi alla memoria e l'autorizzazione a fregiarsene, e' necessario essere di condotta morale incensurabile.

3. Non possono altresi' ottenere l'assegnazione delle insegne e dei brevetti delle medaglie al valore di Forza armata, ne' l'autorizzazione a fregiarsene coloro i quali si trovino nelle condizioni previste dall'articolo 58, comma 1, del testo unico delle leggi sull'ordinamento degli enti locali, di cui al decreto legislativo 18 agosto 2000, n. 267.

#### Art. 1451. - Impedimenti al conseguimento delle ricompense e perdita delle stesse

1. Non possono conseguire le ricompense di cui alla presente sezione e, avendole conseguite, le perdono di diritto coloro che sono incorsi nell'interdizione perpetua dai pubblici uffici, salvo il caso di riabilitazione.

2. Coloro che sono incorsi nell'interdizione temporanea dai pubblici uffici, non possono, durante il tempo dell'interdizione, conseguire le ricompense predette ne', avendole conseguite, possono fregiarsene.

3. Le sentenze di condanne che comportino l'interdizione perpetua o temporanea dai pubblici uffici, emanate a carico di coloro che hanno ottenuto le ricompense al valore o al merito di Forza armata, sono inviate in copia dalle cancellerie delle autorita' giudiziarie competenti al Ministero della difesa, entro il termine di trenta giorni dalla data in cui sono divenute definitive; quest'ultima circostanza deve risultare da espressa dichiarazione della competente cancelleria, apposta sulla detta copia.

#### Art. 1452. - Riacquisto delle ricompense

1. Per il riacquisto delle ricompense al valore e al merito di Forza armata si applicano gli articoli 1430 e 1431, nonche' le disposizioni penali in tema di riabilitazione militare e le norme speciali in materia di riabilitazione dei condannati applicabili alle ipotesi di riacquisto delle ricompense al valor militare.

#### Art. 1453. - Norma di rinvio

1. Nel regolamento sono disciplinati:

- a) le caratteristiche delle decorazioni;
- b) le autorita' autorizzate a formulare le proposte per il conferimento delle stesse;
- c) il rilascio dei brevetti;
- d) le modalita' di consegna delle ricompense;
- e) l'uso delle insegne.

### SEZIONE VIII - CROCE AL MERITO DI GUERRA

#### Art. 1454. - Istituzione

((

1. Fatti salvi i riconoscimenti in favore dei partecipanti alla guerra 1914-18 e alle guerre precedenti, insigniti dell'Ordine di Vittorio Veneto e iscritti nell'apposito Albo, la croce al merito di guerra e' concessa a coloro che hanno tenuto nello svolgimento delle operazioni belliche, terrestri, marittime o aeree, una condotta militare che li rende degni di pubblico encomio.

))

2. Possono essere proposti per tale distinzione coloro che:

- a) per non meno di un anno, cumulativamente, sono stati in modo esemplare in trincea o altrimenti a contatto col nemico;
- b) sono stati feriti in combattimento, se la ferita da' diritto al conferimento dell'apposito distintivo;
- c) hanno onorevolmente partecipato a piu' fatti d'armi di qualche importanza;
- d) si sono abitualmente segnalati per atti di ardimento, senza raggiungere gli estremi per il conferimento di una medaglia al valor militare.

#### Art. 1455. - Conferimento

1. La croce al merito di guerra e' concessa motu proprio dal Presidente della Repubblica, o, in seguito a proposta circostanziata delle dipendenti autorita' gerarchiche, dalle seguenti autorita' militari:

- a) comandanti di unita' militari di livello almeno pari al corpo d'armata e corrispondenti;
- b) Capi stato maggiore di Forza armata o Comandante generale.

#### Art. 1456. - Reclamo

1. E' ammesso il reclamo per mancata concessione. Tale reclamo e' deciso dal Ministero della difesa, quando le autorita' militari mobilitate, che avrebbero potuto far luogo alla concessione, presa visione delle ragioni dell'interessato, non le hanno ritenute valide.

2. In tali casi, come in ogni altro, il Ministero della difesa puo', dopo i necessari accertamenti, far luogo alla concessione della croce.

#### Art. 1457. - Normativa applicabile

1. Sono estese a questa decorazione le disposizioni della sezione III del presente capo, per quanto riguarda i casi in cui si perde o e' sospeso il diritto di fregiarsene.

#### Art. 1458. - Caratteristiche della croce al merito di guerra

1. Nel regolamento sono disciplinati:

- a) le caratteristiche delle decorazioni;
- b) le modalita' di concessione;
- c) il rilascio dei brevetti;
- d) l'uso delle insegne.

### SEZIONE IX - MEDAGLIA MAURIZIANA

#### Art. 1459. - Istituzione

1. Agli ufficiali e ai sottufficiali delle Forze armate e del Corpo della Guardia di finanza puo' essere concessa la medaglia mauriziana al merito di dieci lustri di carriera militare.

2. La medaglia mauriziana e' concessa, con decreto del Presidente della Repubblica, su proposta del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze per i militari appartenenti al Corpo della Guardia di finanza.

#### Art. 1460. - Computo degli anni di servizio militare

1. Per il computo degli anni di servizio sono validi:

- a) il servizio militare comunque prestato;
- b) le campagne di guerra;
- c) il servizio prestato in zone d'intervento per conto dell'ONU o in forza di accordi multinazionali;
- d) il 50 per cento dell'effettivo servizio di pilotaggio per i piloti, navigatori e osservatori;
- e) il 50 per cento del servizio prestato quale componente degli equipaggi fissi, sperimentatori e collaudatori con obbligo di volo e dei reparti paracadutisti, con percezione della relativa indennita';
- f) il 50 per cento del periodo totale di reparto di campagna e di imbarco (e' sufficiente a tale scopo l'appartenenza a tali unita' e con qualsiasi incarico);
- g) per intero il servizio in comando o in direzione;
- h) per intero i corsi universitari, per tutti gli ufficiali delle Forze armate per i quali e' richiesto il possesso del diploma di laurea ai fini del reclutamento, e il corso superiore di teologia per i cappellani militari.

2. Tali norme sono applicabili anche agli ufficiali e sottufficiali del Corpo della Guardia di finanza.

3. Le maggiorazioni previste dalle lettere b), c), d), e) f) e h) non sono fra loro cumulabili, quando coincidono nel tempo.

#### Art. 1461. - Caratteristiche della medaglia mauriziana

1. Nel regolamento sono stabilite:

- a) le caratteristiche della medaglia ((, che comunque non e' coniata in oro));
- b) le disposizioni esecutive delle norme della presente sezione.

### SEZIONE X - ENCOMI, ELOGI E ALTRE RICOMPENSE

#### Art. 1462. - Encomi ed elogi

1. Le ricompense per lodevole comportamento e per particolare rendimento sono:

- a) encomio solenne;
- b) encomio semplice;
- c) elogio.

2. L'encomio solenne consiste in una lode particolare per atti eccezionali ed e' pubblicato nell'ordine del giorno del corpo, di unita' e di comandi superiori, affinche' tutti ne traggano esempio; e' tributato da autorita' di grado non inferiore a generale di corpo d'armata o equivalente.

3. L'autorita' che concede l'encomio solenne ne detta la motivazione e ne dispone la pubblicazione; la motivazione deve essere trascritta sui documenti personali del militare.

4. L'encomio semplice consiste nella lode per un atto speciale ovvero per meriti particolari che esaltino il prestigio del corpo o dell'ente di appartenenza. E' tributato da un generale o ammiraglio della linea gerarchica.

5. L'encomio semplice deve essere pubblicato nell'ordine del giorno del corpo ed e' trascritto nei documenti personali dell'interessato.

6. L'encomio semplice e l'encomio solenne possono essere tributati anche collettivamente.

7. L'encomio collettivo tributato a un intero reparto non va trascritto sui documenti personali dei singoli componenti del reparto stesso.

8. L'elogio consiste nella lode, verbale o scritta, per costante lodevole comportamento nell'adempimento dei propri doveri ovvero per elevato rendimento in servizio. Esso puo' essere tributato da qualsiasi superiore. E' trascritto nei documenti personali solo quando e' tributato, per iscritto, dal comandante del corpo.

9. Il superiore che ritenga il comportamento di un subordinato meritevole di una delle predette ricompense e non e' competente a tributarle ne fa proposta al superiore competente.

#### Art. 1463. - Croce d'onore alle vittime di atti di terrorismo o di atti ostili impegnate in operazioni militari e civili all'estero

1. Al personale militare si applicano le disposizioni della legge 10 ottobre 2005, n. 207.

#### Art. 1464. - ((Distinzioni onorifiche e altre ricompense))

1.((Nel regolamento sono disciplinate le seguenti distinzioni onorifiche e ricompense:)) a) medaglia al merito di lungo comando; b) medaglia d'onore per lunga navigazione; c) medaglia di lunga navigazione aerea; d) croce per anzianita' di servizio; e) distintivo d'onore per mutilati e feriti di guerra; f) distintivo d'onore per i genitori dei caduti in guerra; g) distintivo d'onore per gli orfani dei caduti in guerra; h) distintivo d'onore per mutilati in servizio; i) distintivo d'onore per deceduti in servizio; l) distintivo d'onore per feriti in servizio; m) distintivo d'onore dei Volontari della liberta' previsto dal decreto luogotenenziale 3 maggio 1945, n. 350, concesso ai militari deportati nei campi di concentramento tedeschi dopo 1'8 settembre 1943, che rinunciarono alla liberazione e, non collaborando comunque volontariamente ne' con i tedeschi ne' con i fascisti, contribuirono alla lotta di Resistenza.

## TITOLO IX ESERCIZIO DEI DIRITTI CAPO I DISPOSIZIONI GENERALI

### Art. 1465. - Diritti riconosciuti dalla Costituzione

1. Ai militari spettano i diritti che la Costituzione della Repubblica riconosce ai cittadini. Per garantire l'assolvimento dei compiti propri delle Forze armate sono imposte ai militari limitazioni nell'esercizio di alcuni di tali diritti, nonche' l'osservanza di particolari doveri nell'ambito dei principi costituzionali.

2. Lo Stato predispone misure effettive volte a tutelare e promuovere lo sviluppo della personalita' dei militari nonche' ad assicurare loro un dignitoso trattamento di vita.

3. Deve essere sempre garantita nei rapporti personali la pari dignita' di tutti i militari.

### Art. 1466. - Limitazioni all'applicabilita' di sanzioni disciplinari

1. L'esercizio di un diritto ai sensi del presente codice e del regolamento esclude l'applicabilita' di sanzioni disciplinari.

### Art. 1467. - Applicazione del principio di pari opportunita'

1. Nell'ordinamento delle Forze armate deve essere assicurata la realizzazione del principio delle pari opportunita' uomo-donna, nel reclutamento del personale militare, nell'accesso ai diversi gradi, qualifiche, specializzazioni e incarichi del personale delle Forze armate e del Corpo della Guardia di finanza.

### Art. 1468. - Discriminazioni e molestie

1. E' vietata nei confronti dei militari ogni forma di discriminazione diretta o indiretta, di molestia anche sessuale, secondo quanto disposto dai decreti legislativi 9 luglio 2003, n. 215, 9 luglio 2003, n. 216 e 11 aprile 2006, n. 198.

2. Nei confronti dei militari, in sede di attribuzione di incarico, di assegnazioni o di trasferimento a comandi, a enti, a reparti, ad armi o a specializzazioni, sono vietate le discriminazioni per motivi politici, ideologici, religiosi, razziali, etnici, per l'orientamento sessuale o per la differenza di genere.

## CAPO II - LIBERTA' FONDAMENTALI

### Art. 1469. - Liberta' di circolazione e sede di servizio

1. Per imprescindibili esigenze di impiego ai militari puo' essere vietato o ridotto in limiti di tempo e di distanza l'allontanamento dalla localita' di servizio.

2. La potesta' di vietare o limitare nel tempo e nella distanza l'allontanamento dei militari dalla localita' di servizio e' esercitata dal comandante di corpo o da altra autorita' superiore, nonche' dal comandante di distaccamento o posto isolato solo per urgenti necessita' operative o in presenza di oggettive situazioni di pericolo.

3. I militari che intendono recarsi all'estero, anche per breve tempo, devono ottenere apposita autorizzazione.

4. L'obbligo di alloggiare nella localita' sede di servizio e' disposto dall'articolo 744 del regolamento.

### Art. 1470. - Liberta' di riunione

1. Sono vietate riunioni non di servizio nell'ambito dei luoghi militari o comunque destinati al servizio, salvo ((quanto previsto dall'articolo 1480-bis per l'esercizio del diritto di associazione sindacale riconosciuto ai militari.))

2. Fuori dai predetti luoghi sono vietate assemblee o adunanze di militari che si qualificano esplicitamente come tali o che sono in uniforme.

### Art. 1471. - Liberta' di culto

1. I militari possono esercitare il culto di qualsiasi religione e ricevere l'assistenza dei loro ministri.

2. La partecipazione alle funzioni religiose nei luoghi militari e' facoltativa, salvo che nei casi di servizio.

3. In ogni caso, compatibilmente con le esigenze di servizio il comandante del corpo o altra autorita' superiore rende possibile ai militari che vi hanno interesse la partecipazione ai riti della religione professata e a quelle iniziative rivolte ai militari, sia singolarmente sia collettivamente, che sono proposte e dirette dal personale addetto all'assistenza spirituale alle Forze armate.

4. Se un militare infermo, o per esso i suoi familiari, richiede i conforti della sua religione, i Ministri di questa sono chiamati ad assisterlo.

5. Rimane ferma la disciplina introdotta dalle leggi di autorizzazione alla ratifica ed esecuzione del Concordato lateranense, nonche' dalle leggi che recepiscono le intese con le confessioni religiose diverse da quella cattolica.

### Art. 1472. - Liberta' di manifestazione del pensiero

1. I militari possono liberamente pubblicare loro scritti, tenere pubbliche conferenze e comunque manifestare pubblicamente il proprio pensiero, salvo che si tratti di argomenti a carattere riservato di interesse militare ((o di)) servizio per i quali deve essere ottenuta l'autorizzazione.

2. Essi possono, inoltre, trattenere presso di se', nei luoghi di servizio, qualsiasi libro, giornale o altra pubblicazione periodica.

3. Nei casi previsti dal presente articolo resta fermo il divieto di propaganda politica.

### Art. 1473. - Autorita' competente al rilascio della autorizzazione

1. L'autorizzazione di cui all'articolo 1472 deve essere richiesta per via gerarchica ed e' rilasciata:

- a) per l'Esercito italiano, per la Marina militare, per l'Aeronautica militare dai rispettivi Stati maggiori;
- b) per l'Arma dei carabinieri, dal Comando generale;
- c) per il Corpo della Guardia di finanza, dal Comando generale;
- d) per i militari in servizio presso lo Stato maggiore della difesa e i dipendenti organismi interforze, dallo Stato maggiore della difesa;
- e) per i militari in servizio presso il Segretariato generale della difesa e i dipendenti enti e organismi, dal Segretariato generale della difesa;
- e-bis) per i militari in servizio presso la Direzione nazionale degli armamenti e i dipendenti enti e organismi, dalla Direzione nazionale degli armamenti;
- f) per i militari non dipendenti dai comandi o strutture di cui alle lettere a), b), c), d) ((, e) ed e-bis))), dall'autorita' piu' elevata in grado dalla quale essi dipendono.

2. La richiesta di autorizzazione, da inoltrare con congruo anticipo, deve contenere l'indicazione dell'argomento da trattare e dei limiti nei quali la trattazione sara' contenuta. La risposta dell'autorita' competente deve pervenire al richiedente in tempo utile.

### Art. 1474. - Diritto di informazione e di istruzione

1. Lo Stato promuove l'elevamento culturale, la formazione della coscienza civica e la preparazione professionale dei militari e ne predispone le condizioni per l'effettivo perseguimento.

2. A tal fine e' prevista, in particolare, l'istituzione di corsi di istruzione, di biblioteche e di rivendite di pubblicazioni a carattere culturale, politico e ricreativo.

### Art. 1475. - Limitazioni all'esercizio del diritto di associazione e divieto di sciopero

1. La costituzione di associazioni o circoli fra militari e' subordinata al preventivo assenso del Ministro della difesa.

2. In deroga al comma 1, i militari possono costituire associazioni professionali a carattere sindacale per singola Forza armata o Forza di polizia a ordinamento ((militari o interforze, secondo le disposizioni previste dal capo III del titolo IX del presente libro, e dal relativo regolamento di attuazione adottato con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n 400)).

3. I militari non possono aderire ad associazioni considerate segrete a norma di legge e a quelle incompatibili con i doveri derivanti dal giuramento prestato.

4. I militari non possono esercitare il diritto di sciopero.

## CAPO III - ((ASSOCIAZIONI PROFESSIONALI A CARATTERE SINDACALE TRA MILITARI)) ((

### SEZIONE I)) ((PRINCIPI GENERALI E COMPETENZE))

#### Art. 1476. - (( (Diritto di associazione professionale a carattere sindacale in ambito militare). ))

((

1. Il diritto di libera organizzazione sindacale, di cui all'articolo 39 della Costituzione, e' esercitato dagli appartenenti alle Forze armate e alle Forze di polizia a ordinamento militare, con esclusione del personale della riserva e in congedo assoluto, nel rispetto dei doveri e dei principi previsti dall'articolo 52 della Costituzione.

2. Gli appartenenti alle Forze armate e alle Forze di polizia a ordinamento militare non possono aderire ad associazioni professionali a carattere sindacale diverse da quelle costituite ai sensi delle disposizioni del presente capo.

3. Gli appartenenti alle Forze armate e alle Forze di polizia a ordinamento militare possono aderire a una sola associazione professionale a carattere sindacale tra militari, di seguito "APCSM".

4. L'adesione alle APCSM e' libera, volontaria e individuale.

5. Non possono aderire alle APCSM coloro che ricoprono le cariche di vertice di cui agli articoli 25, 29, 32, 40 e 44-bis, il Comandante generale del Corpo della guardia di finanza, i militari di truppa di cui all'articolo 627, comma 8, limitatamente agli allievi.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1476-bis. - (( (Principi generali). ))

((

1. Le APCSM operano nel rispetto dei principi di democrazia, trasparenza, partecipazione e nel rispetto dei principi di coesione interna, neutralita', efficienza e prontezza operativa delle Forze armate e delle Forze di polizia a ordinamento militare.

2. Gli statuti delle APCSM sono improntati ai seguenti principi:

- a) democraticita' dell'organizzazione sindacale ed elettivita' delle relative cariche, orientate al rafforzamento della partecipazione femminile;
- b) neutralita' ed estraneita' alle competizioni politiche e ai partiti e movimenti politici;
- c) assenza di finalita' contrarie ai doveri derivanti dal giuramento prestato dai militari;
- d) trasparenza del sistema di finanziamento e assenza di scopo di lucro;
- e) rispetto degli altri requisiti previsti dalle disposizioni del presente capo.

3. L'attivita' sindacale e' volta alla tutela degli interessi collettivi degli appartenenti alle Forze armate e alle Forze di polizia a ordinamento militare.

4. I comandanti o i responsabili di unita' garantiscono il rispetto delle disposizioni del presente capo, favorendo l'esercizio delle attivita' delle APCSM. Tali attivita' non possono comunque interferire con lo svolgimento dei compiti operativi o con la direzione dei servizi.

))

#### Art. 1476-ter. - (( (Competenze). ))

((

1. Le APCSM curano la tutela collettiva dei diritti e degli interessi dei propri rappresentati nelle materie di cui al comma 2, garantendo che essi assolvano ai compiti propri delle Forze armate e delle Forze di polizia a ordinamento militare e che l'adesione alle associazioni non interferisca con il regolare svolgimento dei servizi istituzionali.

2. Sono di competenza delle APCSM le materie concernenti:

- a) i contenuti del rapporto di impiego del personale militare, di cui agli articoli 4 e 5 del decreto legislativo 12 maggio 1995, n. 195, nonche' all'articolo 46, comma 2, del decreto legislativo 29 maggio 2017, n. 95;
- b) l'assistenza fiscale e la consulenza relativamente alle prestazioni previdenziali e assistenziali a favore dei propri iscritti;
- c) l'inserimento nell'attivita' lavorativa di coloro che cessano dal servizio militare;
- d) le provvidenze per gli infortuni subiti e per le infermita' contratte in servizio e per causa di servizio;
- e) le pari opportunita';
- f) le prerogative sindacali di cui all'articolo 3 del decreto legislativo 9 aprile 2008, n. 81, sulle misure di tutela della salute e della sicurezza del personale militare nei luoghi di lavoro;
- g) gli spazi e le attivita' culturali, assistenziali, ricreative e di promozione del benessere personale dei rappresentati e dei loro familiari.

3. Sono comunque escluse dalla competenza delle APCSM le materie concernenti l'ordinamento militare, l'addestramento, le operazioni, il settore logistico-operativo, il rapporto gerarchico-funzionale nonche' l'impiego del personale in servizio.

4. In relazione alle materie di cui al comma 2, le APCSM possono:

- a) presentare ai Ministeri competenti osservazioni e proposte sull'applicazione delle leggi e dei regolamenti e segnalare le iniziative di modifica da esse eventualmente ritenute opportune;
- b) essere ascoltate dalle Commissioni parlamentari del Senato della Repubblica e della Camera dei deputati, secondo le norme dei rispettivi regolamenti;
- c) chiedere di essere ricevute dai Ministri competenti e dagli organi di vertice delle Forze armate e delle Forze di polizia a ordinamento militare.

))

#### Art. 1476-quater. - (( (Limitazioni). ))

((

1. Alle APCSM e' fatto divieto di:

- a) assumere la rappresentanza di lavoratori non appartenenti alle Forze armate o alle Forze di polizia a ordinamento militare;
- b) preannunciare o proclamare lo sciopero, o azioni sostitutive dello stesso, o parteciparvi, anche se proclamato da organizzazioni sindacali estranee al personale militare;
- c) promuovere manifestazioni pubbliche in uniforme o con armi di servizio o sollecitare o invitare gli appartenenti alle Forze armate o alle Forze di polizia a ordinamento militare a parteciparvi;
- d) assumere la rappresentanza in via esclusiva di una o piu' categorie di personale, anche se facenti parte della stessa Forza armata o Forza di polizia a ordinamento militare. In ogni caso, la rappresentanza di una singola categoria all'interno di un'APCSM non deve superare il limite del 75 per cento dei suoi iscritti;
- e) promuovere iniziative di organizzazioni politiche o dare supporto, a qualsiasi titolo, a campagne elettorali afferenti alla vita politica del Paese;
- f) stabilire la propria sede o il proprio domicilio sociale presso unita' o strutture del Ministero della difesa o del Ministero dell'economia e delle finanze o del Ministero delle infrastrutture e dei trasporti;
- g) aderire ad associazioni sindacali diverse da quelle costituite ai sensi delle disposizioni del presente capo o federarsi, affiliarsi o avere relazioni di carattere organizzativo o convenzionale, anche per il tramite di altri enti od organizzazioni, con le medesime associazioni;
- h) assumere denominazioni o simboli che richiamano, anche in modo indiretto, categorie di personale, specialita', corpi o altro che non sia la Forza armata o la Forza di polizia a ordinamento militare di appartenenza, ovvero organizzazioni sindacali, per cui sussiste il divieto di adesione ai sensi delle disposizioni del presente capo, od organizzazioni politiche.

))

### ((SEZIONE II)) ((COSTITUZIONE, ARTICOLAZIONI PERIFERICHE E CARICHE DIRETTIVE))

#### Art. 1477. - (( (Costituzione). ))

((

1. Ai fini dell'esercizio delle attivita' previste dallo statuto e della raccolta dei contributi sindacali nelle forme previste dall'articolo 1480-quater, e' istituito presso il Ministero della difesa l'apposito albo per l'iscrizione delle APCSM. Analogo albo e' istituito presso il Ministero dell'economia e delle finanze per l'iscrizione delle APCSM riferite al personale del Corpo della guardia di finanza.

2. Le APCSM, entro cinque giorni lavorativi dalla loro costituzione, depositano lo statuto presso il Ministero della difesa o, per le associazioni tra appartenenti al Corpo della guardia di finanza, presso il Ministero dell'economia e delle finanze, i quali, accertati i requisiti previsti dalle disposizioni del presente capo, entro i sessanta giorni successivi ne dispongono l'iscrizione nel relativo albo. Per le APCSM riferite a personale di una o piu' Forze armate e del Corpo della guardia di finanza l'accertamento e' svolto dal Ministero della difesa di concerto con il Ministero dell'economia e delle finanze. Non sono consentiti, nelle more del predetto procedimento, l'esercizio delle attivita' sindacali e la raccolta dei contributi sindacali.

3. In caso di accertate previsioni statutarie in contrasto con le disposizioni vigenti, il Ministero competente ne da' tempestiva e motivata comunicazione all'associazione, che puo' presentare, entro quindici giorni e per iscritto, formali osservazioni. Entro i successivi trenta giorni, il Ministero adotta il provvedimento finale.

4. Le APCSM comunicano entro quindici giorni ogni successiva modifica statutaria al competente Ministero, che ne valuta la conformita' ai requisiti previsti secondo le modalita' di cui ai commi 2 e 3. Il Ministero competente accerta, almeno ogni tre anni, la permanenza dei requisiti previsti.

5. In caso di successivo accertamento della perdita anche di uno solo dei requisiti o di violazione delle prescrizioni di legge, il Ministero competente ne da' tempestiva e motivata comunicazione all'APCSM, che puo' presentare, entro quindici giorni e per iscritto, le proprie osservazioni. Entro i successivi trenta giorni, il Ministero competente adotta il provvedimento finale, informandone, nel caso di un provvedimento di cancellazione dall'albo di cui al comma 1, il Ministro per la pubblica amministrazione.

6. L'APCSM incorsa nel provvedimento di cancellazione di cui al comma 5 decade dalle prerogative sindacali e non puo' esercitare alcuna delle attivita' previste. Conseguentemente perdono efficacia le deleghe rilasciate dagli associati per il pagamento dei contributi sindacali ai sensi dell'articolo 1480-quater.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1477-bis. - (( (Articolazioni periferiche). ))

((

1. Le APCSM possono prevedere articolazioni periferiche.

2. Gli statuti definiscono, entro gli ambiti di competenza sindacale di cui all'articolo 1476-ter, le competenze delle articolazioni periferiche, nei limiti dei relativi ambiti regionali o territoriali, nelle seguenti materie:

- a) informazione e consultazione degli iscritti;
- b) esercizio delle prerogative sindacali di cui all'articolo 3 del decreto legislativo 9 aprile 2008, n. 81, sulle misure di tutela della salute e della sicurezza del personale militare nei luoghi di lavoro;
- c) rispetto e applicazione della contrattazione nazionale, interloquendo con l'amministrazione di riferimento.

3. Ferme restando le specifiche peculiarita' organizzative, le articolazioni periferiche delle APCSM riconosciute rappresentative ai sensi dell'articolo 1478 si relazionano con le articolazioni di ciascuna amministrazione militare competenti a livello areale e comunque non inferiore al livello regionale, con riferimento a tematiche di competenza sindacale aventi esclusiva rilevanza locale, senza alcun ruolo negoziale.

))

#### Art. 1477-ter. - (( (Cariche direttive). ))

((

1. Le cariche direttive delle APCSM sono elettive, rispettano il principio di parita' di genere, e possono essere ricoperte solo da militari in servizio effettivo, che abbiano compiuto almeno cinque anni di servizio nelle Forze armate o nelle Forze di polizia a ordinamento militare e da militari in ausiliaria iscritti all'associazione stessa.

2. Non sono eleggibili e non possono comunque ricoprire le cariche di cui al comma 1:

- a) i militari che hanno riportato condanne per delitti non colposi o sanzioni disciplinari di stato;
- b) i militari che si trovano in una delle condizioni di cui all'articolo 10, comma 1, del testo unico di cui al decreto legislativo 31 dicembre 2012, n. 235;
- c) i militari che si trovano in stato di sospensione dall'impiego o di aspettativa non sindacale, salvi i casi di aspettativa per malattia o patologia che comunque consentano il rientro in servizio incondizionato;
- d) gli ufficiali che rivestono l'incarico di comandante di Corpo.

3. La durata delle cariche direttive e' di quattro anni e non puo' essere frazionata. Non e' consentita la rielezione per piu' di due mandati consecutivi. Coloro che hanno ricoperto per due mandati consecutivi le cariche di cui al comma 1 sono nuovamente rieleggibili trascorsi tre anni dalla scadenza del secondo mandato.

4. Nessun militare puo' essere posto in distacco sindacale per piu' di cinque volte.

))

### ((SEZIONE III)) ((ASSOCIAZIONI PROFESSIONALI A CARATTERE SINDACALE TRA MILITARI RAPPRESENTATIVE A LIVELLO NAZIONALE))

#### Art. 1478. - (( (Rappresentativita').))

((

1. Le APCSM per essere considerate rappresentative a livello nazionale devono raggiungere un numero di iscritti almeno pari al 4 per cento della forza effettiva complessiva della Forza armata o della Forza di polizia a ordinamento militare di riferimento, rilevata al 31 dicembre dell'anno precedente a quello in cui si rende necessario determinare la rappresentativita' delle associazioni medesime.

2. Se l'APCSM e' invece costituita da militari appartenenti a due o piu' Forze armate o Forze di polizia a ordinamento militare, per essere considerata rappresentativa a livello nazionale, essa deve raggiungere un numero di iscritti non inferiore al 3 per cento della forza effettiva della singola Forza armata o Forza di polizia a ordinamento militare, rilevata alla medesima data di cui al comma 1. In mancanza del numero di iscritti di cui al primo periodo, l'APCSM puo' essere considerata rappresentativa a livello nazionale delle sole Forze armate o Forze di polizia a ordinamento militare per le quali raggiunge la quota minima di iscritti del 4 per cento.

3. Ai fini della consistenza associativa, sono conteggiate esclusivamente le deleghe per un contributo sindacale non inferiore allo 0,5 per cento dello stipendio.

4. Ai fini del calcolo della consistenza associativa, la forza effettiva complessiva delle Forza armata e della Forza di polizia a ordinamento militare si calcola escludendo il personale che, ai sensi dell'articolo 1476, comma 5, non puo' aderire alle APCSM.

5. Le APCSM in possesso dei requisiti di cui al presente articolo sono riconosciute rappresentative a livello nazionale con decreto del Ministro per la pubblica amministrazione, sentiti, per quanto di rispettiva competenza, i Ministri della difesa e dell'economia e delle finanze.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1479. - (( (Procedure di contrattazione). ))

((1. Alle APCSM riconosciute rappresentative ai sensi dell'articolo 1478 sono attribuiti i poteri negoziali al fine della contrattazione nazionale di comparto. La procedura di contrattazione si applica alle Forze armate e alle Forze di polizia a ordinamento militare negli ambiti riservati all'amministrazione di appartenenza, per tutto il personale militare in servizio e in particolare con l'osservanza delle disposizioni di cui al decreto legislativo 12 maggio 1995, n. 195, e all'articolo 46 del decreto legislativo 29 maggio 2017, n. 95.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1479-bis. - (( (Diritti e tutela dei militari che ricoprono cariche elettive). ))

((

1. I militari che ricoprono cariche elettive nelle APCSM riconosciute rappresentative ai sensi dell'articolo 1478:

- a) non sono perseguibili in via disciplinare per le opinioni espresse nello svolgimento dei compiti connessi con l'esercizio delle loro funzioni, fatti salvi i limiti della correttezza formale e i doveri derivanti dal giuramento prestato, dal grado, dal senso di responsabilita' e dal contegno da tenere, anche fuori del servizio, a salvaguardia del prestigio istituzionale;
- b) non possono essere trasferiti a un'altra sede o a un altro reparto ovvero essere sostituiti nell'incarico ricoperto al momento dell'elezione, se non previa intesa con l'APCSM alla quale appartengono, salvi i casi di incompatibilita' ambientale o di esigenza di trasferimento dovuta alla necessita' di assolvere i previsti obblighi di comando, attribuzioni specifiche, servizio presso enti o reparti e imbarco necessari per l'avanzamento di carriera e salvi i casi straordinari di necessita' e urgenza, anche per dichiarazione dello stato di emergenza;
- c) non possono essere impiegati in territorio estero singolarmente, fatte salve le esigenze delle unita' di appartenenza;
- d) possono manifestare il loro pensiero in ogni sede e su tutte le questioni non soggette a classifica di segretezza che riguardano la vita militare, nei limiti previsti dal presente capo e nelle materie di cui all'articolo 1476-ter; possono interloquire con enti e associazioni di carattere sociale, culturale o politico, anche estranei alle Forze armate e alle Forze di polizia a ordinamento militare, e partecipare a convegni e assemblee aventi carattere sindacale, nei modi e con i limiti previsti dal presente capo;
- e) possono inviare comunicazioni scritte al personale militare sulle materie di loro competenza, nonche' visitare le strutture e i reparti militari presso i quali opera il personale da essi rappresentato quando lo ritengono opportuno, concordandone le modalita', almeno trentasei ore prima, con i comandanti competenti.

))

#### Art. 1479-ter. - (( (Obblighi informativi). ))

((

1. Le amministrazioni militari del Ministero della difesa e del Ministero dell'economia e delle finanze comunicano alle APCSM riconosciute rappresentative ai sensi dell'articolo 1478 il contenuto delle circolari e delle direttive da emanare in riferimento alle materie indicate nell'articolo 1476-ter, comma 2.

2. Le procedure di informazione e consultazione delle APCSM riconosciute rappresentative ai sensi dell'articolo 1478 sono disciplinate con il regolamento di attuazione di cui all'articolo 1475, comma 2.

))

### ((SEZIONE IV)) ((ATTIVITÀ SINDACALI, FINANZIAMENTO E TRASPARENZA DEI BILANCI))

#### Art. 1480. - (( (Svolgimento dell'attivita' di carattere sindacale).))

((

1. I rappresentanti delle APCSM svolgono l'attivita' sindacale fuori dal servizio.

2. Alle APCSM riconosciute rappresentative ai sensi dell'articolo 1478 puo' essere concesso, informate le associazioni, l'uso di un locale comune da adibire a ufficio delle associazioni stesse nella sede centrale e in quelle periferiche di livello areale e comunque non inferiore al livello regionale, compatibilmente con le disponibilita' e senza oneri per l'amministrazione. Le modalita' di concessione dell'uso del locale comune sono disciplinate con il regolamento di attuazione di cui all'articolo 1475, comma 2.

3. Ai fini dello svolgimento dell'attivita' sindacale, ai rappresentanti sindacali delle APCSM rappresentative ai sensi dell'articolo 1478 sono riconosciuti distacchi e permessi sindacali retribuiti nonche' permessi e aspettative sindacali non retribuiti, assegnati con le modalita' di cui ai commi 4 e 5, sulla base dell'effettiva rappresentativita' del personale calcolata ai sensi dell'articolo 1478.

4. Con la contrattazione di cui all'articolo 1479, nell'ambito delle risorse ad essa destinate, sono stabiliti:

- a) il contingente massimo dei distacchi autorizzabili per ciascuna Forza armata e Forza di polizia a ordinamento militare nonche' il numero massimo annuo dei permessi retribuiti per i rappresentanti delle associazioni rappresentative;
- b) la misura dei permessi e delle aspettative sindacali non retribuiti che possono essere concessi ai rappresentanti sindacali.

5. Il contingente dei distacchi sindacali e dei permessi retribuiti di cui al comma 4 e' ripartito tra le APCSM con criterio proporzionale, sulla base della rappresentativita' calcolata ai sensi dell'articolo 1478, con decreto del Ministro per la pubblica amministrazione, sentiti i Ministri della difesa e dell'economia e delle finanze, nell'ambito delle rispettive competenze, e le APCSM.

6. Le richieste di distacco o di aspettativa sindacale non retribuita sono presentate dalle APCSM rappresentative ai sensi dell'articolo 1478 alla Forza armata o alla Forza di polizia a ordinamento militare cui appartiene il personale interessato, la quale, accertati i requisiti oggettivi previsti dalle disposizioni del presente capo, provvede, entro il termine massimo di trenta giorni dalla richiesta, a darne comunicazione al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri e al Ministero della difesa o, per il personale del Corpo della guardia di finanza, al Ministero dell'economia e delle finanze, per i conseguenti provvedimenti di stato.

7. Le APCSM possono procedere alla revoca dei distacchi e delle aspettative in ogni momento, comunicandola alla Forza armata o alla Forza di polizia a ordinamento militare di riferimento nonche' al Ministero della difesa ovvero al Ministero dell'economia e delle finanze e al Dipartimento della funzione pubblica della Presidenza del Consiglio dei ministri per i provvedimenti conseguenti. Le variazioni relative ai distacchi e alle aspettative devono essere comunicate entro il 31 gennaio di ogni anno.

8. Sono vietati l'utilizzo della ripartizione dei distacchi in forma compensativa nonche' il loro utilizzo in forma frazionata.

9. I distacchi e le aspettative sindacali non retribuite possono durare non piu' di tre anni. Nessun militare puo' essere posto in distacco o in aspettativa sindacale non retribuita piu' di cinque volte. Tra ciascun distacco o aspettativa sindacale non retribuita deve intercorrere almeno un triennio di servizio effettivo.

10. Le modalita' di impiego del militare che riprende servizio al termine di ogni periodo di distacco sindacale o aspettativa sindacale non retribuita sono disciplinate con il regolamento di attuazione di cui all'articolo 1475, comma 2.

11. I dirigenti delle APCSM rappresentative ai sensi dell'articolo 1478 che intendono fruire dei permessi sindacali di cui al presente articolo, devono darne comunicazione scritta al proprio comandante, individuato nell'autorita' deputata alla concessione della licenza, almeno cinque giorni prima o, in casi eccezionali, almeno quarantotto ore prima, tramite l'associazione di appartenenza. Il comandante autorizza il permesso sindacale salvo che non ostino prioritarie e improcrastinabili esigenze di servizio e sempre che venga garantita la regolare funzionalita' del servizio.

12. E' vietata ogni forma di cumulo dei permessi sindacali, giornalieri od orari.

13. L'effettiva utilizzazione dei permessi sindacali deve essere certificata entro tre giorni all'autorita' individuata ai sensi del comma 11 da parte del dirigente dell'APCSM che ha chiesto e utilizzato il permesso.

14. I permessi sindacali sono equiparati al servizio. Tenuto conto della specificita' delle funzioni istituzionali e della particolare organizzazione delle Forze armate e delle Forze di polizia a ordinamento militare, i permessi sono autorizzati in misura corrispondente al turno di servizio giornaliero e non possono superare mensilmente, per ciascun rappresentante sindacale, nove turni giornalieri di servizio.

15. Per i permessi sindacali retribuiti e' corrisposto il trattamento economico corrispondente a quello di servizio, con esclusione delle indennita' e dei compensi per il lavoro straordinario e di quelli collegati all'effettivo svolgimento delle prestazioni.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1480-bis. - (( (Diritto di assemblea).))

((

1. Per l'esercizio del diritto di associazione sindacale:

- a) fuori dal servizio, i militari possono tenere riunioni: 1) anche in uniforme, in locali messi a disposizione dall'amministrazione, che ne concorda le modalita' d'uso; 2) in luoghi aperti al pubblico, senza l'uso dell'uniforme.
- b) durante il servizio, sono autorizzate riunioni con ordine del giorno su materie di competenza delle APCSM nel limite di dieci ore annue individuali, secondo le disposizioni che regolano l'assenza dal servizio, previa comunicazione, con almeno cinque giorni di anticipo, ai comandanti delle unita' o dei reparti interessati da parte dell'associazione professionale a carattere sindacale tra militari richiedente.

2. Le modalita' di tempo e di luogo per lo svolgimento delle riunioni sono concordate con i comandanti al fine di renderle compatibili con le esigenze di servizio.

))

#### Art. 1480-ter. - (( (Informazione e pubblicita').))

((

1. Le deliberazioni, le votazioni, le relazioni, i processi verbali e i comunicati delle APCSM, le dichiarazioni dei militari che ricoprono cariche elettive e ogni notizia relativa all'attivita' sindacale sono resi pubblici secondo le modalita' previste dai rispettivi statuti.

2. I dirigenti delle APCSM possono avere rapporti con gli organi di stampa e rilasciare dichiarazioni esclusivamente in merito alle materie di loro competenza e oggetto di contrattazione nazionale di settore.

3. Negli ordinamenti didattici degli enti di formazione di base e delle accademie militari e' inserita la materia "elementi di diritto del lavoro e di diritto sindacale in ambito militare".

))

#### Art. 1480-quater. - (( (Finanziamento e trasparenza dei bilanci).))

((

1. Le APCSM sono finanziate esclusivamente con i contributi sindacali degli iscritti, corrisposti nelle forme previste dal presente articolo, e con le attivita' di assistenza fiscale e consulenza relativamente alle prestazioni previdenziali e assistenziali a favore dei propri iscritti. Le associazioni non possono ricevere eredita' o legati, donazioni o sovvenzioni in qualsiasi forma, fatta eccezione per la devoluzione del patrimonio residuo in caso di scioglimento di altra APCSM.

2. Per la corresponsione del contributo sindacale, i militari rilasciano delega, esente dall'imposta di bollo e dalla registrazione, a favore dell'APCSM alla quale aderiscono, per la riscossione di una quota mensile della retribuzione, nella misura stabilita dai competenti organi statutari. Resta fermo il disposto dell'articolo 70 del testo unico delle leggi concernenti il sequestro, il pignoramento e la cessione degli stipendi, salari e pensioni dei dipendenti dalle pubbliche amministrazioni, di cui al decreto del Presidente della Repubblica 5 gennaio 1950, n. 180.

3. La delega ha validita' dal primo giorno del mese successivo a quello del rilascio fino al 31 dicembre di ogni anno e si intende tacitamente rinnovata se non e' revocata dall'interessato entro il 31 ottobre. La revoca della delega deve essere trasmessa, in forma scritta, all'amministrazione e all'APCSM.

4. Le modalita' di versamento alle APCSM delle trattenute sulla retribuzione, operate dall'amministrazione in base alle deleghe rilasciate, sono stabilite con decreto del Ministro della difesa per le associazioni riferite al personale di una o piu' Forze armate, compresa l'Arma dei carabinieri, ovvero del Ministro dell'economia e delle finanze per le associazioni riferite al personale del Corpo della guardia di finanza.

5. Le APCSM predispongono annualmente il bilancio preventivo, entro il 31 dicembre dell'anno precedente a quello cui l'esercizio si riferisce, e il rendiconto della gestione precedente, entro il 30 aprile dell'anno successivo; entrambi devono essere approvati dagli associati e resi conoscibili al pubblico, non oltre dieci giorni dalla loro approvazione, mediante idonee forme di pubblicita'.

))

### ((SEZIONE V)) ((GIURISDIZIONE E TENTATIVO DI CONCILIAZIONE))

#### Art. 1481. - (( (Giurisdizione). ))

((

1. Sono devolute alla giurisdizione esclusiva del giudice amministrativo le controversie relative all'esercizio della liberta' sindacale del personale delle Forze armate e delle Forze di polizia a ordinamento militare, anche quando la condotta antisindacale incide sulle prerogative dell'APCSM, nonche' le controversie aventi ad oggetto i provvedimenti di cancellazione dell'APCSM dall'albo di cui all'articolo 1477 e quelle relative all'esercizio del diritto di assemblea di cui all'articolo 1480-bis.

2. Alle APCSM e' attribuita legittimazione attiva quando sussiste un interesse diretto in relazione alla controversia promossa nell'ambito disciplinato dalle disposizioni di cui al presente capo.

3. Ai giudizi aventi ad oggetto le controversie di cui al comma 1 si applicano le disposizioni relative al rito abbreviato di cui al decreto legislativo 2 luglio 2010, n. 104, ai sensi dell'articolo 119, comma 1, lettera m-octies) del medesimo decreto legislativo.

4. Per le controversie nelle materie di cui al comma 1, la parte ricorrente e' tenuta al versamento, indipendentemente dal valore della causa, del contributo unificato di importo fisso di cui all'articolo 13, comma 6-bis, lettera e), del testo unico delle disposizioni legislative e regolamentari in materia di spese di giustizia, di cui al decreto del Presidente della Repubblica 30 maggio 2020, n. 115.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1482. - (( (Tentativo di conciliazione). ))

((

1. L'APCSM legittimata ad agire ai sensi dell'articolo 1481 puo' promuovere un previo tentativo di conciliazione presso la commissione individuata ai sensi dell'articolo 1482-bis, se la controversia riguarda condotte antisindacali consistenti nel diniego ingiustificato dei diritti e delle prerogative sindacali di cui alle disposizioni del presente capo.

2. La notificazione della richiesta di tentativo di conciliazione interrompe la prescrizione e sospende il decorso di ogni termine di decadenza, ivi inclusi quelli per la proposizione del ricorso al giudice amministrativo, fino alla conclusione della procedura di conciliazione ovvero alla rinuncia espressa alla procedura stessa presentata dall'associazione proponente.

3. Per promuovere il tentativo di conciliazione, la parte ricorrente e' tenuta a versare, con le modalita' definite dal regolamento di cui all'articolo 1482-bis, comma 3, un contributo pari a euro 155 per le procedure dinnanzi alle commissioni centrali di cui all'articolo 1482-bis, comma 1, lettera a), e pari a euro 105 per le procedure dinnanzi alle commissioni periferiche di cui all'articolo 1482-bis, comma 1, lettera b).

4. La richiesta del tentativo di conciliazione, sottoscritta da chi ha la rappresentanza legale dell'associazione, deve indicare:

- a) la denominazione e la sede dell'APCSM, nonche' il nome del legale rappresentante e l'atto statutario che gli conferisce i poteri rappresentativi;
- b) il luogo dove e' sorta la controversia;
- c) l'esposizione dei fatti e delle ragioni poste a fondamento della pretesa.

5. La richiesta di cui al comma 4 e' notificata, tramite posta elettronica certificata, sottoscritta digitalmente, ai sensi del codice dell'amministrazione digitale, di cui al decreto legislativo 7 marzo 2005, n. 82, oppure mediante raccomandata con avviso di ricevimento, alla commissione di conciliazione competente, che cura l'invio di copia digitale della richiesta all'articolazione della Forza armata o della Forza di polizia a ordinamento militare interessata.

6. L'articolazione della Forza armata o della Forza di polizia a ordinamento militare interessata dalla controversia deposita presso la commissione di conciliazione, entro dieci giorni dal ricevimento della copia della richiesta, una memoria contenente le difese e le eccezioni in fatto e in diritto. Entro i dieci giorni successivi a tale deposito, la commissione fissa, per una data compresa nei successivi trenta giorni, la comparizione dell'APCSM e dell'articolazione dell'amministrazione interessata per il tentativo di conciliazione. Dinnanzi alla commissione, per l'APCSM deve presentarsi il legale rappresentante ovvero altro militare ad essa appartenente appositamente delegato. Non e' ammessa la partecipazione di soggetti non appartenenti all'APCSM.

7. Se il tentativo di conciliazione ha esito positivo, e' redatto un processo verbale che riporta il contenuto dell'accordo raggiunto. Il processo verbale, sottoscritto dalle parti e dal presidente della commissione di conciliazione, costituisce titolo esecutivo. Se non e' raggiunto l'accordo, la medesima controversia puo' costituire oggetto di ricorso innanzi al giudice amministrativo ai sensi dell'articolo 1481.))

--------------- AGGIORNAMENTO (88) La L. 28 aprile 2022, n. 46 ha disposto (con l'art. 19, comma 1) che "Dalla data di entrata in vigore del decreto di cui all'articolo 16, comma 4, della presente legge sono abrogati gli articoli da 1476 a 1482 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66".

#### Art. 1482-bis. - (( (Commissioni di conciliazione). ))

((

1. Ai fini dell'espletamento del tentativo di conciliazione di cui all'articolo 1482, sono istituite:

- a) per le controversie aventi rilievo nazionale, la commissione centrale di conciliazione presso il Ministero della difesa, ovvero presso il Ministero dell'economia e delle finanze per le controversie riferite al personale del Corpo della guardia di finanza;
- b) per le controversie aventi rilievo locale, almeno cinque commissioni periferiche di conciliazione presso unita' organizzative di livello non inferiore a quello regionale o paritetico delle Forze armate e delle Forze di polizia a ordinamento militare.

2. Le commissioni di conciliazione:

- a) sono presiedute, con funzione di garanzia, da un presidente nominato con decreto del Ministro della difesa o, per le commissioni riferite al personale del Corpo della guardia di finanza, del Ministro dell'economia e delle finanze, sentite le Commissioni parlamentari competenti per materia, scelto tra gli iscritti in un elenco appositamente istituito presso i citati Ministeri e comprendente magistrati, avvocati iscritti all'albo speciale degli avvocati ammessi al patrocinio dinnanzi alle giurisdizioni superiori e professori universitari in materie giuridiche;
- b) sono composte da militari appartenenti alla Forza armata o alla Forza di polizia a ordinamento militare di riferimento e da militari designati, nell'ambito dei propri iscritti, dalle APCSM riconosciute rappresentative ai sensi dell'articolo 1478. I militari appartenenti alle commissioni di conciliazione svolgono tale attivita' per servizio e sono individuati, con incarico non esclusivo, fra coloro che sono impiegati nell'ambito della regione amministrativa nella quale ha sede la commissione di cui sono componenti.

3. Le modalita' di costituzione e funzionamento delle commissioni di conciliazione sono definite con regolamento adottato con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400.

4. Le amministrazioni interessate provvedono all'istituzione e al funzionamento delle commissioni di conciliazione nell'ambito delle risorse umane, finanziarie e strumentali disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica. Ai rispettivi componenti non spettano compensi, gettoni di presenza, rimborsi di spese o altri emolumenti comunque denominati.

))

## ((CAPO IIIBIS)) ((PARTICOLARI LIMITAZIONI ALL'ESERCIZIO DELL'ATTIVITA' DI CARATTERE SINDACALE))

### Art. 1482-ter.

(( (Limitazioni per il personale impiegato in attivita' operative o missioni). ))

1. ((Le limitazioni di cui al presente articolo si applicano alle attivita' operative e alle missioni, intese come tutte quelle attivita' connesse alle seguenti missioni delle Forze armate e delle Forze di polizia a ordinamento militare: a) difesa dell'integrita' del territorio, di tutte le aree soggette alla sovranita' nazionale e alla tutela degli interessi vitali nazionali e delle vie di comunicazione ovunque minacciati; b) contributi a garanzia della difesa collettiva dell'Alleanza atlantica, alle operazioni nell'ambito dell'Unione europea, alle operazioni svolte sotto l'egida dell'Agenzia europea della guardia di frontiera e costiera denominata "Frontex", alle operazioni di supporto alla pace (comprese l'imposizione della pace), alle attivita' di stabilizzazione e ricostruzione, nonche' a tutte le operazioni militari condotte in modo autonomo o in coalizione; c) interventi nelle attivita' di supporto alla pace, di assistenza umanitaria, nella cooperazione militare e nella diplomazia militare per incrementare la stabilizzazione internazionale attraverso la cooperazione e lo sviluppo con altri Paesi; d) attivita' delle Forze armate, di natura straordinaria o concorsuale, riguardanti la salvaguardia delle libere istituzioni, il supporto all'autorita' di pubblica sicurezza nazionale per servizi connessi al mantenimento dell'ordine e della sicurezza pubblica, gli interventi in situazioni di pubbliche calamita' e in altri casi di straordinaria necessita' o urgenza, il supporto nel settore della pubblica utilita' e della tutela ambientale, nonche' le attivita' del Corpo delle capitanerie di porto - Guardia costiera - a spiccata connotazione operativa di direzione, di coordinamento e di esecuzione delle operazioni connesse alla ricerca e soccorso e alle emergenze in mare e nei porti, le operazioni di polizia giudiziaria e di polizia marittima, ambientale e ispettiva di competenza del medesimo corpo; e) attivita' delle Forze di polizia a ordinamento militare, denotate da particolare complessita' e articolate su piu' giorni, nell'ambito dell'assolvimento dei servizi d'istituto connessi con i compiti di polizia giudiziaria, di pubblica sicurezza e mantenimento dell'ordine pubblico, di concorso nel soccorso pubblico e nella protezione civile nonche' le attivita' denotate da particolare complessita' e articolate su piu' giorni per l'attuazione e il coordinamento da parte della Guardia di finanza dei servizi di ordine e sicurezza pubblica in mare e nell'azione di sorveglianza sull'immigrazione clandestina, nelle acque territoriali e nella zona contigua al fine di assolvere, in via esclusiva, le funzioni operative della sicurezza del mare.))

2. ((Il personale impiegato nelle attivita' di cui al comma 1: a) se ricopre cariche direttive nell'ambito delle APCSM: 1) non puo' essere collocato in distacco o in aspettativa sindacale e non puo' fruire dei permessi sindacali; 2) non puo' esercitare la facolta' prevista dall'articolo 1480-ter, comma 2, ne' quella di visitare le strutture e i reparti presso i quali opera il personale da esso rappresentato di cui all'articolo 1479-bis, comma 1, lettera e); b) non puo' esercitare il diritto di assemblea.))

3. ((Le limitazioni di cui al comma 2 trovano applicazione anche con riferimento al personale: a) incluso negli assetti di alta e altissima prontezza operativa, ai fini dell'assolvimento delle attivita' di cui al comma 1; b) non inquadrato in unita' organiche che, singolarmente o in piccole aliquote, e' impiegato nell'ambito di missioni internazionali, organismi internazionali in Italia e all'estero, nei comandi multinazionali di contingenza o in altre tipologie di servizio prestato all'estero previste dalla normativa vigente.))

4. ((Durante la fase propedeutica, intesa come l'insieme delle attivita', comunque denominate, svolte in fase antecedente e in vista dell'impiego nelle attivita' operative e missioni di cui al comma 1, il personale di cui ai commi 2 e 3: a) se ricopre cariche direttive nell'ambito delle APCSM: 1) non puo' essere collocato in distacco o in aspettativa sindacale; 2) compatibilmente con le prioritarie attivita' da svolgere, puo' esercitare la facolta' prevista dall'articolo 1480-ter, comma 2, puo' fruire di permessi sindacali ed esercitare la facolta' di visitare le strutture e i reparti presso i quali opera il personale da esso rappresentato di cui all'articolo 1479-bis, comma 1, lettera e); b) puo' esercitare il diritto di assemblea, compatibilmente con le prioritarie attivita' da svolgere.))

### Art. 1482-quater. - (( (Limitazioni per il personale impiegato in attivita' addestrative o esercitative). ))

1. ((Le limitazioni di cui al presente articolo si applicano al personale impiegato in tutte le attivita' addestrative o esercitative svolte in Italia ovvero all'estero tese a raggiungere o mantenere la capacita' per l'assolvimento delle missioni fondamentali indicate nell'articolo 1482-ter, comma 1, incluse le esercitazioni svolte in ambiente ONU, NATO, dell'Unione europea, multinazionale e di coalizione ovvero per l'acquisizione o il mantenimento di particolari competenze connesse con l'assolvimento dei compiti d'istituto propri delle Forze di polizia a ordinamento militare.))

2. ((Il personale militare impiegato nelle attivita' di cui al comma 1, nell'ambito dell'unita' di appartenenza o di unita' di formazione o singolarmente, nel corso dell'addestramento o dell'esercitazione: a) se ricopre cariche direttive nell'ambito delle APCSM rappresentative ai sensi dell'articolo 1478: 1) non puo' essere collocato in distacco o in aspettativa sindacale; 2) non puo' fruire dei permessi sindacali; 3) non puo' esercitare la facolta', prevista dall'articolo 1479-bis, comma 1, lettera e), di visitare le strutture e i reparti presso i quali opera il personale da esso rappresentato; b) non puo' esercitare il diritto di assemblea.))

3. ((Durante la fase propedeutica alle attivita' di cui al comma 1, intesa come l'insieme delle attivita', comunque denominate, svolte in fase antecedente e in vista dell'impiego nelle attivita' addestrative o esercitative, il personale militare: a) se ricopre cariche direttive nell'ambito delle APCSM rappresentative ai sensi dell'articolo 1478 non puo' essere collocato in distacco o in aspettativa sindacale; b) compatibilmente con le prioritarie esigenze di servizio connesse con l'assolvimento delle specifiche attivita', puo': 1) partecipare alle assemblee di carattere sindacale; 2) fruire di permessi sindacali; 3) esercitare la facolta', prevista dall'articolo 1479-bis, comma 1, lettera e), di visitare le strutture e i reparti presso i quali opera il personale da esso rappresentato.))

4. ((Il personale militare impiegato con compiti di addestramento esercita il diritto di assemblea compatibilmente con l'assolvimento delle prioritarie attivita' addestrative o esercitative previste e programmate.))

### Art. 1482-quinquies. - (( (Limitazioni per il personale impiegato in attivita' formativa). ))

1. ((Le limitazioni di cui al presente articolo si applicano al personale impiegato nelle attivita' formative, comunque denominate, volte all'acquisizione, allo sviluppo o al mantenimento delle capacita' o delle professionalita', ivi inclusi i corsi di specializzazione, abilitazione, qualificazione, di carattere informativo, a qualunque titolo svolti.))

2. ((La frequenza dei corsi di formazione non puo' essere oggetto di rinvio per ragioni connesse con lo svolgimento di attivita' sindacale.))

3. ((Il personale che frequenta corsi: a) di formazione di base, ad esclusione dei militari di truppa di cui all'articolo 627, comma 8, limitatamente agli allievi: 1) puo', compatibilmente con l'assolvimento delle prioritarie attivita' formative previste e programmate, partecipare alle assemblee sindacali; 2) non puo' fruire di permessi sindacali ne' essere posto in distacco o aspettativa sindacale; b) successivi alla formazione di base: 1) non puo' essere posto in distacco o aspettativa sindacale; 2) compatibilmente con lo svolgimento dell'attivita' formativa, puo' fruire dei permessi sindacali e partecipare alle assemblee sindacali, fermo restando il limite massimo di assenze stabilite dal corso.))

4. ((Il personale militare impiegato con compiti di formazione esercita il diritto di assemblea, compatibilmente con l'assolvimento delle prioritarie attivita' formative previste e programmate.))

## CAPO IV - ESERCIZIO DEI DIRITTI POLITICI

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1483. - Esercizio delle liberta' in ambito politico

1. Le Forze armate devono in ogni circostanza mantenersi al di fuori dalle competizioni politiche.

2. Ai militari ((che si trovino nelle condizioni di cui al comma 2 dell'articolo)) 1350, e' fatto divieto di partecipare a riunioni e manifestazioni di partiti, associazioni ((...)) e organizzazioni politiche, nonche' di svolgere propaganda a favore o contro partiti, associazioni ((...)), organizzazioni politiche o candidati a elezioni politiche e amministrative.

### SEZIONE II - ELETTORATO PASSIVO

#### Art. 1484. - Esercizio del diritto di elettorato passivo

1. I militari candidati a elezioni per il Parlamento europeo, a elezioni politiche o amministrative possono svolgere liberamente attivita' politica e di propaganda al di fuori dell'ambiente militare e in abito civile. Essi sono posti in apposita licenza straordinaria per la durata della campagna elettorale. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1485. - (( (Cause di ineleggibilita' al Parlamento) ))

((

1. Le cause di ineleggibilita' degli ufficiali generali, degli ammiragli e degli ufficiali superiori delle Forze armate dello Stato sono disciplinate dagli articoli 7 e seguenti del decreto del Presidente della Repubblica 30 marzo 1957, n. 361, e successive modificazioni, in quanto applicabili.

))

#### Art. 1486. - Cause di ineleggibilita' alla carica di consigliere regionale

1. Non sono eleggibili a consigliere regionale nel territorio nel quale esercitano il comando, gli ufficiali generali, gli ammiragli, e gli ufficiali superiori delle Forze armate.

2. La causa di ineleggibilita' non ha effetto se l'interessato cessa dalle funzioni per dimissioni, trasferimento, revoca dell'incarico o del comando, collocamento in aspettativa non retribuita, non oltre il giorno fissato per la presentazione delle candidature.

3. Si applicano gli articoli 2 e seguenti della legge 23 aprile 1981, n. 154, compatibilmente con lo stato di militare.

#### Art. 1487. - Cause di ineleggibilita' a cariche amministrative

1. Non sono eleggibili a sindaco, presidente della provincia, consigliere comunale, provinciale e circoscrizionale, nel territorio nel quale esercitano il comando, gli ufficiali generali, gli ammiragli e gli ufficiali superiori delle Forze armate dello Stato.

2. La causa di ineleggibilita' non ha effetto se l'interessato cessa dalle funzioni per dimissioni, trasferimento, revoca dell'incarico o del comando, collocamento in aspettativa non retribuita, non oltre il giorno fissato per la presentazione delle candidature.

3. Si applica, per quanto non previsto, il decreto legislativo 18 agosto 2000, n. 267, compatibilmente con lo stato di militare.

#### Art. 1488. - Collocamento in aspettativa e trattamento economico

1. Il personale militare eletto al Parlamento europeo, al Parlamento nazionale e nei consigli regionali e' collocato obbligatoriamente in aspettativa non retribuita ai sensi dell'articolo 68 del decreto legislativo 30 marzo 2001, n. 165.

2. Al personale militare eletto alle cariche amministrative si applica il decreto legislativo 18 agosto 2000, n. 267 e successive modifiche e integrazioni, compatibilmente con lo stato di militare.

3. I militari che non sono membri del Parlamento e sono chiamati all'ufficio di Ministro o di Sottosegretario di Stato, sono collocati in aspettativa per il periodo durante il quale esercitano le loro funzioni.

4. Il trattamento economico del personale militare eletto al Parlamento europeo, al Parlamento nazionale, ai consigli regionali, ovvero nominato Ministro, Vice Ministro o Sottosegretario di Stato e' disciplinato dalla normativa vigente.

5. Il collocamento in aspettativa per elezioni in cariche politiche o amministrative e' disciplinato dagli articoli 903 e 904.

### SEZIONE III - ELETTORATO ATTIVO

#### Art. 1489. - Esercizio del diritto di voto per i militari in servizio di ordine pubblico

1. Ai militari comandati in servizio di ordine pubblico si applica la disciplina prevista dall'articolo 48 del decreto del Presidente della Repubblica 30 marzo 1957, n. 361.

#### Art. 1490. - Esercizio del diritto di voto per i militari in servizio

1. Il personale militare e' ammesso a votare nel comune in cui si trova per causa di servizio.

2. I militari possono esercitare il voto in qualsiasi sezione elettorale, in soprannumero agli elettori iscritti nella relativa lista e con precedenza, previa esibizione del certificato elettorale. Sono iscritti in una lista aggiunta.

3. La loro iscrizione nelle relative liste e' fatta a cura del presidente del seggio elettorale.

4. E' fatto loro divieto di recarsi inquadrati o armati nelle sezioni elettorali.

#### Art. 1491. - Esercizio del diritto di voto per i militari temporaneamente all'estero per motivi di servizio o missioni internazionali

1. Il personale militare temporaneamente all'estero per servizio o impegnato nello svolgimento di missioni internazionali esercita, per le elezioni al Parlamento europeo, al Parlamento nazionale, ai Consigli regionali e degli enti locali, il diritto di voto ai sensi e nei limiti delle disposizioni vigenti.

### SEZIONE IV - LIMITAZIONI ALL'ACCESSO A TALUNI UFFICI PUBBLICI

#### Art. 1492. - Ufficio di giudice popolare e di componente di seggio elettorale

1. Gli appartenenti alle Forze armate in servizio non possono assumere l'ufficio di giudice popolare.

((

2. Gli appartenenti alle Forze armate in servizio sono esclusi dalle funzioni di presidente dell'ufficio elettorale di sezione, di scrutatore e di segretario, ai sensi dell'articolo 38, primo comma, lettera c), del decreto del Presidente della Repubblica 30 marzo 1957, n. 361.

))

## CAPO V - DIRITTI SOCIALI

### SEZIONE I - TUTELA DELLA MATERNITA' E DELLA PATERNITA'

#### Art. 1493. - Estensione della normativa per il personale della Pubblica Amministrazione

1. Al personale militare femminile e maschile si applica, tenendo conto del particolare stato rivestito, la normativa vigente per il personale delle pubbliche amministrazioni in materia di maternita' e paternita', nonche' le disposizioni dettate dai provvedimenti di concertazione.

2. Il personale femminile in ferma prefissata in stato di gravidanza, se non puo' essere impiegato in attivita' compatibili con tale stato, e' collocato in licenza straordinaria a decorrere dalla data di presentazione all'ente di appartenenza della certificazione medica attestante lo stato di gravidanza e fino all'inizio del periodo di licenza di maternita'. Il periodo di licenza straordinaria non e' computato nel limite massimo previsto per le licenze straordinarie.

#### Art. 1494. - Disposizioni particolari

1. Fatto salvo il divieto di adibire al lavoro le donne nei periodi previsti dagli articoli 16 e 17, comma 1, del decreto legislativo 26 marzo 2001, n. 151, durante il periodo di gravidanza e fino a sette mesi successivi al parto il personale militare femminile non puo' svolgere incarichi pericolosi, faticosi, insalubri, secondo quanto disposto da decreti adottati, dal Ministro della difesa, sentito il Consiglio interforze sulla prospettiva di genere, di concerto con i Ministri del lavoro e delle politiche sociali e per le pari opportunita' per il personale delle Forze armate, nonche' con il Ministro delle infrastrutture e dei trasporti per il personale delle capitanerie di porto, e dal Ministro dell'economia e delle finanze, di concerto con il Ministro del lavoro e delle politiche sociali e per le pari opportunita' per il personale del Corpo della Guardia di finanza.

2. Il personale femminile che frequenta i corsi regolari delle accademie, delle scuole e i corsi di formazione iniziale degli istituti e delle scuole delle Forze armate e del Corpo della Guardia di finanza, nonche' il personale femminile volontario in fase di addestramento e specializzazione iniziale, e' posto in licenza straordinaria per maternita' a decorrere dalla presentazione all'amministrazione della certificazione attestante lo stato di gravidanza, fino all'inizio del periodo di congedo per maternita' di cui all'articolo 16 del decreto legislativo 26 marzo 2001, n. 151. Il periodo di assenza dal servizio trascorso in licenza straordinaria per maternita' non e' computato nel limite massimo previsto per le licenze straordinarie.

3. Il personale militare femminile che frequenta i corsi regolari delle accademie, delle scuole e i corsi di formazione iniziale degli istituti e delle scuole delle Forze armate e del Corpo della Guardia di finanza, posto in licenza straordinaria per maternita' ai sensi del comma 2, puo' chiedere di proseguire il periodo formativo con esenzione da qualsiasi attivita' fisica, fino all'inizio del periodo di congedo di maternita' di cui all'articolo 16 del decreto legislativo 26 marzo 2001, n. 151. L'accoglimento della domanda e' disposto dal comandante di corpo, in relazione agli obiettivi didattici da conseguire e previo parere del dirigente del servizio sanitario dell'istituto di formazione.

4. La licenza straordinaria per maternita' di cui al comma 2 e' assimilata ai casi di estensione del divieto di adibire le donne al lavoro previsti dall'articolo 17, comma 2, lettera c), del decreto legislativo 26 marzo 2001, n. 151. Al personale militare femminile, nel predetto periodo di assenza, e' attribuito il trattamento economico di cui all'articolo 22 del decreto legislativo 26 marzo 2001, n. 151, ovvero, se piu' favorevole, quello stabilito dai provvedimenti indicati dall'articolo 2, commi 1 e 2, del decreto legislativo 12 maggio 1995, n.195.

5. Il personale militare femminile appartenente alle Forze armate e al Corpo della Guardia di finanza che, ai sensi degli articoli 16 e 17 del decreto legislativo 26 marzo 2001, n. 151, non puo' frequentare i corsi previsti dalle relative normative di settore, e' rinviato al primo corso utile successivo e, se lo supera con esito favorevole, assume l'anzianita' relativa al corso originario di appartenenza.

((

5-bis. Il personale femminile appartenente alle Forze armate e al Corpo della guardia di finanza che si trova in stato di gravidanza durante la partecipazione ai concorsi per l'accesso a ruolo superiore e non puo' essere sottoposto agli accertamenti per l'idoneita' fisio-psico-attitudinale al servizio militare ai sensi del regolamento, ove previsti, e' ammesso d'ufficio, anche in deroga per una sola volta ai limiti di eta', a svolgere i predetti accertamenti nell'ambito del primo concorso utile successivo alla cessazione di tale stato di temporaneo impedimento. Il provvedimento di rinvio puo' essere revocato su istanza di parte quando tale stato di temporaneo impedimento cessa in data compatibile con i tempi necessari per la definizione della graduatoria dell'originario concorso. Le candidate rinviate risultate idonee e nominate vincitrici nella graduatoria finale di merito del concorso per il quale hanno presentato istanza di partecipazione sono avviate alla frequenza del primo corso di formazione utile in aggiunta ai vincitori del concorso cui sono state rinviate.

5-ter. Le vincitrici dei concorsi rinviate ai sensi del comma 5-bis sono immesse in servizio con la medesima anzianita' assoluta, ai soli fini giuridici, dei vincitori del concorso per il quale hanno presentato istanza di partecipazione. La relativa posizione di graduatoria nell'ambito del corso originario e' determinata, ove previsto, sulla base del punteggio ottenuto nella graduatoria finale al termine del periodo di formazione. Gli effetti economici della nomina sono riconosciuti, in ogni caso, con la stessa decorrenza prevista per i militari appartenenti al corso di formazione effettivamente frequentato.

))

#### Art. 1495. - Effetti sullo stato giuridico

1. Le assenze dal servizio per motivi connessi allo stato di maternita', disciplinate ((dalla presente sezione)), non pregiudicano la posizione di stato giuridico del personale in servizio permanente delle Forze armate e del Corpo della Guardia di finanza, fatto salvo quanto previsto dal comma 2.

2. I periodi di congedo di maternita', previsti dagli articoli 16 e 17 del decreto legislativo 26 marzo 2001, n. 151 sono validi a tutti gli effetti ai fini dell'anzianita' di servizio. Gli stessi periodi sono computabili ai fini della progressione di carriera, salva la necessita' dell'effettivo compimento nonche' del completamento degli obblighi di comando, di attribuzioni specifiche, di servizio presso enti o reparti e di imbarco, previsti dalla normativa vigente.

3. Il personale militare che si assenta dal servizio per congedo parentale e per la malattia del figlio e' posto in licenza straordinaria, rispettivamente, per congedo parentale e per malattia del figlio, equiparata a tutti gli effetti a quanto previsto dagli articoli 32 e 47 del decreto legislativo 26 marzo 2001, n. 151. Il periodo trascorso in tale licenza e' computabile, ai fini della progressione di carriera, nei limiti previsti relativamente al periodo massimo di assenza che determina la fine del servizio.

### SEZIONE II - DIRITTO ALLA SALUTE

#### Art. 1496. - Diritto alla salute e alla sicurezza sui luoghi di lavoro

1. La tutela della salute e della sicurezza sui luoghi di lavoro e' garantita in base alle norme del decreto legislativo 9 aprile 2008, n. 81, in quanto compatibili con le disposizioni del presente codice e del regolamento.

2. Al fine di agevolare le prime operazioni di soccorso medico, relativamente all'impiego in missioni internazionali o in altre situazioni di potenziale esposizione a pericolo, la tessera di riconoscimento del personale militare, rilasciata in formato elettronico ai sensi dell'articolo 66, comma 8, del decreto legislativo 7 marzo 2005, n. 82, contiene, previo consenso dell'interessato al trattamento dei dati personali, i dati sanitari di emergenza, quali lo stato vaccinale, le terapie in atto, le allergie, le intolleranze, gli impianti, le trasfusioni. La medesima tessera di riconoscimento puo' contenere anche il consenso del militare per la donazione degli organi. Con decreto del Ministro della difesa, ovvero del Ministro dell'economia e delle finanze per il personale del Corpo della guardia di finanza, sentito il Garante per la protezione dei dati personali, sono individuate le modalita' di caricamento dei dati nella tessera, i livelli e le modalita' di accesso selettivo ai dati, nonche' le specifiche misure volte a garantire la sicurezza dei dati.

#### Art. 1497. - Sanitario di fiducia

1. In caso di malattia che determina un ricovero per cura in ospedale militare, il militare, o un suo familiare, ha il diritto di chiedere al direttore dello stabilimento, se le condizioni lo consentono, il trasferimento in altro luogo di cura civile di sua scelta, assumendosene il relativo onere di spesa. In ogni caso di ricovero per cura in ospedale militare, il militare, o un suo familiare, puo' richiedere, sempre a proprie spese, l'intervento di un consulente di fiducia.

((

1-bis. In materia di rilascio e trasmissione delle certificazioni di malattia al personale militare si applicano le disposizioni di cui all'articolo 748, comma 2, del regolamento.

))

#### Art. 1498. - Attivita' di informazione e prevenzione in materia di sostanze stupefacenti, psicotrope, alcoliche e dopanti

1. Le attivita' di informazione e prevenzione in materia di sostanze stupefacenti, psicotrope, alcoliche e dopanti sono disciplinate dagli articoli 202 e 203.

#### Art. 1499. - Stato di dipendenza dei militari in ferma o in servizio permanente effettivo

1. Il militare riconosciuto tossicodipendente, alcooldipendente o dopato, che dichiari la sua disponibilita' a sottoporsi a trattamenti di recupero socio-sanitario, e' posto in licenza di convalescenza straordinaria e successivamente, se del caso, in aspettativa per il periodo massimo previsto dalla normativa in vigore. Al termine del trattamento e' sottoposto a controlli sanitari intesi a stabilire la sua idoneita' al servizio militare.

2. Per i militari di cui al presente articolo sono realizzate attivita' di sostegno e di educazione sanitaria.

3. Le funzioni di polizia giudiziaria ai fini della prevenzione e repressione dei reati previsti dal decreto del Presidente della Repubblica 9 ottobre 1990, n. 309, commessi da militari in luoghi militari, spettano ai soli comandanti di corpo con grado non inferiore a ufficiale superiore.

4. Tutti gli interventi previsti in materia di sostanze stupefacenti, psicotrope, dopanti e di alcooldipendenza sono svolti nel rispetto del diritto alla riservatezza dei soggetti interessati.

### SEZIONE III - LICENZE E PERMESSI

#### Art. 1500. - Allievi degli istituti militari

1. Le licenze e i permessi per gli allievi degli istituti militari di istruzione e formazione sono concessi in base a quanto previsto dal regolamento e dalla normativa dei rispettivi istituti di istruzione e formazione.

#### Art. 1501. - Permessi per i volontari in ferma prefissata

((1. Compatibilmente con le esigenze di servizio, puo' essere concesso ai volontari in ferma prefissata, che ne facciano richiesta in tempo utile, il permesso di assentarsi durante l'orario di servizio per una durata non superiore a 36 ore nel corso dell'anno di ferma. I permessi concessi devono essere recuperati entro il mese successivo a quello nel quale sono stati fruiti secondo le disposizioni di Forza armata. Per i volontari in ferma prefissata triennale i permessi possono anche essere detratti dalle ore di recupero compensativo))

2. Ai volontari in ferma prefissata che ne facciano richiesta motivata, salvo imprescindibili esigenze di impiego o procedimenti disciplinari in corso, possono essere concessi:

- a) permessi per l'anticipazione o la proroga dell'orario della libera uscita;
- b) permessi speciali notturni;
- c) permessi speciali per trascorrere fuori della sede il fine settimana o le festivita' infrasettimanali, con decorrenza dal termine delle attivita' dell'ultimo giorno lavorativo della settimana o precedente la festivita'.

3. Sono considerati giorni festivi le domeniche e gli altri giorni riconosciuti come tali agli effetti civili, nonche' la ricorrenza del Santo Patrono del comune sede di servizio, se cade in giorno feriale.

((3-bis. I volontari in ferma prefissata che prestano servizio nei giorni festivi di cui al comma 3 hanno diritto al recupero della festivita'))

#### Art. 1502. - Licenza ordinaria per i volontari in ferma prefissata

1. I volontari in ferma prefissata in servizio hanno diritto, per ogni anno di servizio, a un periodo di licenza ordinaria, durante il quale spetta la normale retribuzione, escluse le indennita' che non sono corrisposte per dodici mensilita'. La durata della licenza ordinaria e' la seguente:

- a) se l'orario settimanale di servizio e' distribuito su un periodo di sei giorni: 1) ventotto giorni lavorativi, per i volontari in ferma prefissata ((iniziale)) e in rafferma annuale; 2) trenta giorni lavorativi, per i volontari in ferma prefissata ((triennale)); 3) ((NUMERO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119));
- b) se l'orario settimanale di servizio e' distribuito su un periodo di cinque giorni: 1) ventiquattro giorni lavorativi, per i volontari in ferma prefissata ((iniziale)) e in rafferma annuale; 2) ventisei giorni lavorativi, per i volontari in ferma prefissata ((triennale)); 3) ((NUMERO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119)).

2. Se l'orario settimanale di servizio e' distribuito su periodi rispettivamente maggiori o minori di quelli di cui al comma 1, lettere a) e b), la durata della licenza ordinaria di cui ai (( numeri 1) e 2) )) delle stesse lettere a) e b) del comma 1 e', rispettivamente, aumentata ovvero diminuita di quattro giorni per ogni giorno del periodo in piu' o in meno.

3. I periodi di licenza ordinaria di cui ai commi 1 e 2 sono comprensivi delle due giornate previste dall'articolo 1, comma 1, lettera a), della legge 23 dicembre 1977, n. 937.

4. I periodi di licenza ordinaria sono maturati in proporzione ai dodicesimi di anno di servizio prestato. Le frazioni di mese superiori a quindici giorni sono considerate come mese intero nei seguenti casi:

- a) nei riguardi dei volontari ammessi al prolungamento della ferma ((o rafferma));
- b) nei riguardi dei volontari in ferma ((triennale)), quando il primo ovvero l'ultimo anno della ferma non coincidono con l'anno solare;
- c) nei riguardi dei volontari prosciolti dalla ferma.

5. L'assenza per infermita', anche se protratta per l'intero anno solare, non riduce la durata della licenza ordinaria spettante.

6. La licenza ordinaria e' frazionabile in piu' periodi, anche di durata pari a un giorno.

7. Se la licenza ordinaria non e' goduta entro il 31 dicembre dell'anno in cui e' maturata a causa di imprescindibili esigenze di impiego ovvero di motivate esigenze di carattere personale, essa deve essere fruita, compatibilmente con le esigenze di servizio e nei limiti della ferma contratta, entro ((l'anno)) successivo.

((8. La licenza ordinaria e' un diritto irrinunciabile e non e' monetizzabile. Si applica l'articolo 5, comma 8, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135))

9. La licenza ordinaria e' interrotta nei casi di ricovero ospedaliero, infortuni e malattie superiori a tre giorni, tempestivamente comunicati all'amministrazione e documentati. L'interruzione non opera nei confronti dei volontari ai quali e' stato notificato il provvedimento di proscioglimento dalla ferma.

10. La revoca della licenza ordinaria per imprescindibili esigenze di impiego comporta il diritto al rimborso, sulla base della documentazione fornita, delle spese connesse al mancato viaggio e soggiorno sostenute successivamente alla concessione della licenza stessa e non altrimenti recuperabili.

11. Il richiamo dalla licenza ordinaria per imprescindibili esigenze di impiego comporta il diritto al rimborso delle spese anticipate per il periodo di licenza non goduto, la corresponsione del trattamento previsto in occasione di servizi isolati fuori sede, nonche' il rimborso delle spese di viaggio per il rientro in sede ed eventualmente per il ritorno nella localita' ove il personale fruiva della licenza ordinaria.

12. In aggiunta ai periodi di licenza ordinaria di cui ai commi 1 e 2, nel corso di ciascun anno di ferma sono attribuiti quattro giorni di riposo, di cui alla legge 23 dicembre 1977, n. 937, da considerare maturati in ragione di uno ogni tre mesi di servizio quando il primo ovvero l'ultimo anno di ferma non coincidono con l'anno solare.

13. Ai volontari in ferma prefissata che frequentano corsi di formazione si applicano le disposizioni previste al riguardo dagli ordinamenti di Forza armata.

14. Ai volontari in ferma prefissata in servizio all'estero o presso organismi internazionali anche con sede in Italia, compresi i contingenti ONU, competono le licenze previste dalle leggi e accordi internazionali che ne disciplinano l'impiego ovvero dalle norme dell'organismo internazionale accettate dall'autorita' nazionale. La licenza non fruita nel corso dell'anno per imprescindibili esigenze di impiego puo' essere fruita, nei limiti della ferma contratta, entro l'anno successivo.

#### Art. 1503. - Licenza straordinaria per i volontari in ferma prefissata

1. La licenza straordinaria e' disciplinata secondo le disposizioni recate dai provvedimenti di concertazione, emanati ai sensi del decreto legislativo 12 maggio 1995, n. 195.

2. La licenza straordinaria di convalescenza non e' compresa nel tetto massimo annuale fissato per la licenza straordinaria. Il periodo di temporanea inidoneita' al servizio e' computato entro le seguenti misure massime: ((a) fino a quattro mesi per ogni anno di servizio per i volontari in ferma prefissata iniziale)); b) fino a quattro mesi per i volontari in rafferma annuale; ((c) fino a dodici mesi per i volontari in ferma prefissata triennale)); d) ((LETTERA ABROGATA DALLA L. 5 AGOSTO 2022, N. 119)); ((e) fino a quindici giorni per ciascun mese di prolungamento del servizio, non cumulabili con gli eventuali residui dei mesi precedenti, per i volontari ammessi al prolungamento della ferma o rafferma)).

3. Sono esclusi dal computo dei periodi massimi di temporanea inidoneita' al servizio quelli per infermita' riconosciute dipendenti da causa di servizio ovvero in attesa del giudizio sulla eventuale dipendenza da causa di servizio.

4. La licenza straordinaria di convalescenza non puo' comunque superare complessivamente i due anni nell'ultimo quinquennio di servizio prestato.

5. Prima dell'invio in licenza straordinaria di convalescenza l'interessato puo' fruire, a domanda, della licenza ordinaria.

6. Durante la licenza straordinaria di convalescenza:

- a) se l'infermita' dipende da causa di servizio, e' dovuto il trattamento economico del pari grado in attivita' di servizio;
- b) se l'infermita' non dipende da causa di servizio, esclusi i periodi di ricovero in luogo di cura: 1) ai volontari in ferma prefissata ((iniziale)) la paga e' dovuta in misura intera per i primi due mesi, in misura ridotta alla meta' per il mese successivo; a decorrere dal quarto mese la paga non e' piu' dovuta; ((2) ai volontari in ferma prefissata triennale lo stipendio e gli altri assegni di carattere fisso e continuativo di cui all'articolo 1791, comma 3, sono dovuti in misura intera per i primi sei mesi, in misura ridotta alla meta' per i successivi tre mesi e, a decorrere dal decimo mese, non sono piu' dovuti)).

7. Agli effetti previdenziali la licenza straordinaria di convalescenza e' computata per intero.

8. La licenza straordinaria di convalescenza spetta anche al personale che si sottopone alla donazione di organi, compresa la donazione di midollo osseo.

9. La licenza straordinaria per prigionia di guerra ovvero nei casi di restrizione della liberta' personale nel corso di operazioni militari all'estero non e' compresa nel tetto massimo fissato per la licenza straordinaria.

10. I volontari in ferma prefissata possono fruire dei periodi di licenza per eventi e cause particolari di cui all'articolo 4 della legge 8 marzo 2000, n. 53.

11. La licenza straordinaria per gravi motivi concessa ai volontari in ferma prefissata impiegati nell'ambito di un contingente militare in missione all'estero comporta il diritto al rimborso delle spese sostenute per i viaggi di andata e ritorno.

#### Art. 1504. - Licenza per l'elevazione e aggiornamento culturale dei volontari in ferma prefissata

1. In aggiunta ai normali periodi di licenza straordinaria per esami, ai volontari in ferma prefissata ((triennale)), che intendono conseguire un diploma di istruzione secondaria di secondo grado o universitario ovvero partecipare a corsi di specializzazione post-universitari o ad altri corsi istituiti presso le scuole pubbliche o parificate nella stessa sede di servizio, sono concessi periodi pari complessivamente a 150 ore annuali da dedicare alla frequenza dei corsi stessi, fatte salve le esigenze operative, addestrative e di servizio. In materia di diritto allo studio si applicano i provvedimenti di concertazione, emanati ai sensi del decreto legislativo 12 maggio 1995, n. 195.

2. I periodi di cui al comma 1 sono detratti dai periodi previsti per la normale attivita' d'impiego, secondo le esigenze prospettate dall'interessato al comando di appartenenza almeno due giorni prima dell'inizio dei corsi. Se l'interessato non dimostra, attraverso idonea documentazione, di avere frequentato il corso di studi per il quale ha ottenuto il beneficio, il beneficio stesso e' revocato e il periodo fruito e' detratto dalla licenza ordinaria dell'anno in corso o dell'anno successivo.

3. ((COMMA ABROGATO DALLA L. 5 AGOSTO 2022, N. 119)).

#### Art. 1505. - Permessi speciali notturni

1. Ai volontari in ferma prefissata, che pur non avendo l'obbligo dell'accasermamento fruiscono degli alloggiamenti di reparto o di unita' navale, possono essere concessi permessi speciali notturni, a domanda e tenuto conto delle esigenze di servizio e dei procedimenti disciplinari in corso.

#### Art. 1506. - Norma di salvaguardia

1. Al personale militare, con i limiti e le modalita' stabiliti nella presente sezione, sono riconosciuti oltre a quanto gia' previsto dal presente codice:

- a) un periodo di licenza per prestazioni idrotermali, ai sensi dell'articolo 13, comma 4 del decreto-legge 12 settembre 1983, n. 463, convertito, con modificazioni, dalla legge 11 novembre 1983, n. 638;
- b) un periodo di licenza per protezione sanitaria contro i pericoli delle radiazioni ionizzanti, di cui all'articolo 5 della legge 23 dicembre 1994, n. 724;
- c) il congedo straordinario senza assegni per dottorato di ricerca, di cui all'articolo 2 della legge 13 agosto 1984, n. 476, e successive modificazioni;
- d) il congedo straordinario senza assegni per i vincitori di borse di studio per la frequenza di corsi di perfezionamento e delle scuole di specializzazione, per lo svolgimento di attivita' di ricerca dopo il dottorato e per i corsi di perfezionamento all'estero, di cui all'articolo 6, comma 7 della legge 30 novembre 1989, n. 398, e successive modificazioni;
- e) l'applicazione della disciplina relativa all'impiego delle organizzazioni di volontariato nelle attivita' di pianificazione, soccorso, simulazione, emergenza e formazione teorico-pratica, di cui all'articolo 9 del decreto del Presidente della Repubblica 8 febbraio 2001, n. 194, e all'articolo 1 della legge 18 febbraio 1992, n. 162, e successive modificazioni;
- f) i congedi per eventi e cause particolari, di cui all'articolo 4 della legge 8 marzo 2000, n. 53, e successive modificazioni;
- g) il congedo per la formazione, di cui all'articolo 5 della legge 8 marzo 2000, n. 53;
- h) i permessi e le licenze per mandato elettorale, di cui all'articolo 1488 e all'articolo 79 del decreto legislativo 18 agosto 2000, n. 267, e successive modificazioni;
- h-bis) i permessi mensili retribuiti previsti dall'articolo 33, comma 3, della legge 5 febbraio 1992, n. 104. In costanza di riconoscimento del diritto a fruire di tali permessi, il militare interessato non e' impiegabile in operazioni in ambito internazionale o in attivita' addestrative propedeutiche alle stesse;
- i) l'astensione dal lavoro per donazione di sangue ed emocomponenti, ai sensi dell'articolo 1 della legge 13 luglio 1967, n. 584.

((

1-bis. Ai militari in ferma prefissata dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applica l'articolo 13 del decreto del Presidente della Repubblica 13 settembre 2007, n. 171, fermo restando il limite temporale della ferma contratta.

1-ter. Al personale in ferma dell'Arma dei carabinieri si applica l'articolo 31 del decreto del Presidente della Repubblica 11 settembre 2007, n. 170.

))

## CAPO VI - PROTEZIONE DEI DATI PERSONALI

### Art. 1507. - Esercizio del diritto alla protezione dei dati personali

1. Il diritto alla protezione dei dati personali nei confronti del personale militare e' tutelato in base alle norme del decreto legislativo 30 giugno 2003, n. 196.

## TITOLO X PERSONALE DELLE BANDE MUSICALI CAPO I RECLUTAMENTO E FORMAZIONE

### Art. 1508. - Reclutamento e trasferimento ad altri ruoli

1. Nel regolamento sono determinate le modalita' per il reclutamento e il trasferimento ad altri ruoli del personale delle bande musicali delle Forze armate, nonche' le condizioni per le sponsorizzazioni individuali e collettive, con l'osservanza dei seguenti criteri:

- a) valutazione della specifica professionalita' e di titoli di studio rilasciati da Conservatori di musica;
- b) previsione che il personale non piu' idoneo alle attivita' delle bande musicali, ma idoneo ai servizi d'istituto, possa essere impiegato in altre attivita' istituzionali o trasferito in altri ruoli delle amministrazioni di appartenenza;
- c) assicurare criteri omogenei di valutazione per l'autorizzazione delle sponsorizzazioni e di destinazione dei proventi, tenuto conto di quanto previsto dall'articolo 43, comma 7, della legge 27 dicembre 1997, n. 449.

((

1-bis. Nel concorso per l'accesso alla banda dell'Arma dei carabinieri, tra i titoli di merito assume particolare rilevanza, per quanto concerne l'attribuzione del relativo punteggio, l'aver prestato servizio senza demerito nella specializzazione di musicante.

))

### Art. 1509. - Reclutamento e formazione di personale musicante

1. Ciascuna Forza armata puo' disporre della relativa banda per il reclutamento, ovvero per la formazione di personale musicante da destinare al soddisfacimento di altre esigenze di Forza armata.

2. La preparazione dei militari che aspirano a partecipare ai concorsi per l'ammissione nella relativa banda e' curata nei rispettivi centri di addestramento musicale sotto la direzione del maestro direttore della banda, coadiuvato dal maestro vice direttore.

## CAPO II - RUOLI E ORGANICI

### Art. 1510. - Ruoli dei musicisti

1. Presso ciascuna Forza armata sono rispettivamente istituiti i ruoli dei musicisti, cui appartengono i componenti delle bande musicali con qualifica di orchestrali e archivisti.

2. La consistenza organica del personale di cui al comma 1 e' inclusa in quella del rispettivo ruolo dei marescialli.

### Art. 1511. - Organici delle Bande

1. La dotazione organica di ciascuna banda musicale di Forza armata e' cosi' determinata:

- a) un maestro direttore;
- b) un maestro vice direttore;
- c) centodue orchestrali;
- d) un archivista.

2. Il personale della banda e' compreso nell'organico della Forza armata di appartenenza.

3. Alla banda non possono essere assegnati, nemmeno in qualita' di orchestrali aggregati o di allievi orchestrali, militari in eccedenza all'organico stabilito al comma 1.

### Art. 1512. - Maestro direttore e maestro vice direttore

1. I maestri direttori e i maestri vice direttori delle bande musicali appartengono agli organici degli ufficiali in servizio permanente effettivo e sono inquadrati in un apposito profilo dei seguenti ruoli:

- a) per l'Esercito italiano, ruolo speciale delle armi di fanteria, cavalleria, artiglieria, genio e trasmissioni;
- b) per la Marina militare, ruolo speciale del Corpo di stato maggiore;
- c) per l'Aeronautica militare, ruolo speciale delle armi;
- d) per l'Arma dei carabinieri, ruolo ((normale)).

### Art. 1513. - Funzioni del maestro direttore

1. Al maestro direttore della banda sono attribuite le funzioni specifiche di concertazione, strumentazione, scelta del repertorio, direzione artistica e musicale, con le responsabilita' a esse attinenti.

### Art. 1514. - Funzioni del maestro vice direttore

1. Il maestro vice direttore:

- a) sostituisce il maestro direttore in caso di assenza o impedimento;
- b) svolge, su incarico del maestro direttore, le attivita' di revisione del repertorio musicale, di preparazione delle singole classi strumentali e dell'insieme di esse, nonche' di trascrizione del repertorio musicale;
- c) sovrintende alle attivita' di archivio.

### Art. 1515.

Orchestrali ((e archivisti))

1. Il ruolo ((dei musicisti)) delle bande musicali e' articolato in tre parti e sei qualifiche, che assumono le seguenti denominazioni:

- a) I parte: I parte A, primo maresciallo e gradi corrispondenti; I parte B: maresciallo capo e gradi corrispondenti;
- b) II parte: II parte A e II parte B: maresciallo capo e gradi corrispondenti;
- c) III parte: III parte A e III parte B: maresciallo ordinario e gradi corrispondenti.

2. L'archivista e' inserito ai fini della progressione di carriera e del trattamento economico, nella terza parte B.

## CAPO III - STATO GIURIDICO

### Art. 1516. - Inidoneita' tecnica

1. L'ufficiale direttore e l'ufficiale vice direttore delle bande, che per fondati motivi non sono piu' ritenuti in grado di assicurare un soddisfacente rendimento artistico, sono sottoposti ad accertamenti da parte di apposite e distinte commissioni nominate con decreto del direttore della Direzione generale per il personale militare su proposta formulata rispettivamente da:

- a) il Sottocapo di stato maggiore dell'Esercito, per l'Esercito italiano;
- b) il Capo ufficio affari generali dello Stato maggiore della Marina, per la Marina militare;
- c) il Sottocapo di stato maggiore dell'Aeronautica, per l'Aeronautica militare;
- d) il Comandante generale, per l'Arma dei carabinieri.

2. ((Le)) commissioni di cui al comma 1, sono composte in base a quanto disposto dagli articoli 948 e 949 del regolamento.

3. Gli orchestrali e l'archivista delle bande, che a giudizio del maestro direttore di banda non sono piu' ritenuti tecnicamente idonei per la parte di appartenenza, su proposta del medesimo, sono sottoposti ad accertamenti da parte di una commissione nominata in base a quanto disposto dall'articolo 950 del regolamento.

4. Il maestro direttore della banda e il maestro vice direttore della banda, giudicati dalle rispettive commissioni non piu' idonei, sono collocati nella riserva; in alternativa si applicano le apposite disposizioni del regolamento.

5. L'orchestrale della banda, giudicato dalla commissione non piu' idoneo per la parte di appartenenza ma idoneo per quella inferiore, transita in quest'ultima anche se non vi sia disponibilita' di posti, salvo riassorbire l'eccedenza al verificarsi della prima vacanza di un suonatore dello stesso strumento; l'orchestrale conserva il grado e l'anzianita' posseduti.

6. Gli orchestrali e l'archivista, giudicati dalla commissione non piu' idonei, cessano di fare parte della banda e sono collocati nella riserva; in alternativa si applicano le apposite disposizioni del regolamento.

### Art. 1517. - Uniforme e impiego

1. Il personale della banda, in servizio, indossa le uniformi stabilite dagli appositi regolamenti.

2. Il relativo armamento del personale della banda dell'Arma dei carabinieri non e' portato nella esecuzione dei concerti.

3. Al personale delle bande musicali e' vietato svolgere qualsiasi attivita' esterna alla banda stessa, senza esplicita preventiva autorizzazione delle autorita' dalle quali dipende l'impiego della rispettiva banda.

4. Agli orchestrali puo' essere richiesto, in caso di necessita', di espletare temporaneamente altra parte o di suonare strumento affine.

5. Sono considerati strumenti affini:

- a) flauto, ottavino;
- b) oboe, corno inglese;
- c) l'intera famiglia dei clarinetti e l'intera famiglia dei saxofoni;
- d) fagotto, contrabasso ad ancia;
- e) corno;
- f) tromba in Sib, tromba in Fa, ((...)), flicorno sopranino in Mib, flicorno soprano in Sib; flicorno contratto in Mib;
- g) ((tromba in Sib basso,)) trombone tenore, trombone basso in Fa, flicorno tenore, flicorno basso, flicorno basso grave in Fa e in Mib, flicorno contrabasso, trombe contrabasso;
- h) percussioni in generale (compreso il pianoforte).

### Art. 1518. - Trattenimento in servizio del maestro direttore

1. Il Ministro della difesa puo', di anno in anno, disporre il trattenimento in servizio permanente del maestro direttore che ha compiuto il 61° anno di eta'; l'ufficiale non puo' essere trattenuto in servizio permanente oltre il 65° anno di eta'.

## CAPO IV - AVANZAMENTO

### Art. 1519. - (( (Avanzamento del maestro direttore). ))

((

1. L'avanzamento dell'ufficiale maestro direttore di banda ha luogo:

- a) ad anzianita', per l'Esercito italiano, la Marina militare e l'Aeronautica militare, e a scelta, per l'Arma dei carabinieri, al grado di tenente colonnello e gradi corrispondenti;
- b) a scelta, al grado di colonnello e gradi corrispondenti.

2. L'ufficiale e' valutato dalla rispettiva e competente commissione di avanzamento al compimento di otto anni di permanenza nel grado; se giudicato idoneo e iscritto in quadro, e' promosso al grado superiore in soprannumero rispetto alle promozioni annuali, con decorrenza dal giorno successivo al compimento del periodo minimo di permanenza nel grado rivestito.

3. Il colonnello maestro direttore della banda non e' computato ai fini del calcolo delle eccedenze di cui all'articolo 906.

))

### Art. 1520. - Avanzamento del maestro vice direttore

1. L'avanzamento dell'ufficiale maestro vice direttore di banda ha luogo ad anzianita', fino al grado di ((maggiore)) e gradi corrispondenti.

2. Il predetto ufficiale e' valutato dai superiori gerarchici, al compimento di ((cinque)) anni di anzianita' di grado; l'eventuale eccedenza

### Art. 1521. - Progressione di carriera dei sottufficiali

1. La progressione di carriera dei sottufficiali orchestrali e del sottufficiale archivista delle bande musicali ha luogo ad anzianita', previo giudizio di idoneita' espresso dalla rispettiva commissione permanente di avanzamento.

2. I periodi minimi di servizio dalla nomina nella parte sono cosi' stabiliti:

- a) da maresciallo ordinario a maresciallo capo e gradi corrispondenti: 3^ parte A e 3^ parte B: ((sei anni));
- b) da maresciallo capo a primo maresciallo e gradi corrispondenti: 1) 1^ parte B: ((un anno)); 2) 2^ parte A:((cinque anni)); 3) 2^ parte B: ((sette anni)); 4) 3^ parte A: ((cinque anni)); 5) 3^ parte B: ((sette anni)).
- b-bis) da primo maresciallo a luogotenente e gradi corrispondenti: 1) 1^ parte A: due anni; 2) tutte le rimanenti parti: quattro anni.

3. I sottufficiali della banda, giudicati idonei dalla rispettiva commissione permanente di avanzamento conseguono il grado con decorrenza dal giorno successivo al periodo di permanenza stabilito nel comma 2.

4. Il sottufficiale giudicato non idoneo all'avanzamento e' nuovamente valutato dopo che sia trascorso un anno dalla precedente valutazione e, se giudicato ancora non idoneo, e' valutato una terza volta dopo che sia trascorso un altro anno dalla precedente valutazione.

5. Il sottufficiale giudicato idoneo all'avanzamento in occasione della seconda o terza valutazione consegue il grado con decorrenza ritardata, rispettivamente di dodici e di ventiquattro mesi, rispetto a quella che gli sarebbe spettata ove fosse stato giudicato idoneo in occasione della prima valutazione.

### Art. 1522. - Attribuzione della qualifica di primo luogotenente e qualifiche corrispondenti

1. Le disposizioni sull'attribuzione della qualifica ai luogotenenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e dell'Arma dei carabinieri, di cui agli articoli 1323 e 1325-bis si applicano, rispettivamente e in quanto compatibili, al personale dei ruoli dei musicisti, dopo due anni di permanenza nel grado.

((

1-bis. I requisiti per l'attribuzione della qualifica di cui agli articoli 1323, comma 1, lettera c) e 1325-bis, comma 1, lettera c), sono riferiti all'ultimo biennio.

))

### Art. 1523. - Norma finale

1. Al personale delle bande musicali, secondo il grado rivestito, si applicano le disposizioni sullo stato e l'avanzamento degli ufficiali e dei sottufficiali, di cui ai titoli V e VII del presente libro, per quanto non previsto nel presente titolo.

## TITOLO XI PERSONALE DEI GRUPPI SPORTIVI

### Art. 1524. - Reclutamento e trasferimento ad altri ruoli

1. Nel regolamento sono determinate le modalita' per il reclutamento e il trasferimento ad altri ruoli, per sopravvenuta inidoneita' alle specifiche mansioni, del personale dei gruppi sportivi delle Forze armate, nonche' le condizioni per le sponsorizzazioni individuali e collettive, con l'osservanza dei seguenti criteri:

- a) valutazione, per il personale da reclutare nei gruppi sportivi, dei risultati di livello almeno nazionale ottenuti nell'anno precedente;
- b) previsione che i gruppi sportivi delle Forze armate, firmatari di apposite convenzioni con il Comitato olimpico nazionale italiano (CONI) e rappresentati nel Comitato sportivo militare, possano essere riconosciuti ai fini sportivi e possano ottenere l'affiliazione alle federazioni sportive sulla base delle disposizioni dello statuto del CONI, anche in deroga ai principi e alle disposizioni per l'affiliazione e il riconoscimento delle societa' e delle associazioni sportive dilettantistiche;
- c) previsione che il personale non piu' idoneo alle attivita' dei gruppi sportivi, ma idoneo ai servizi d'istituto, possa essere impiegato in altre attivita' istituzionali o trasferito in altri ruoli delle Amministrazioni di appartenenza;
- d) assicurare criteri omogenei di valutazione per l'autorizzazione delle sponsorizzazioni e di destinazione dei proventi, tenuto conto di quanto previsto dall'articolo 43, comma 7, della legge 27 dicembre 1997, n. 449.

2. Al personale dei gruppi sportivi si applicano le disposizioni del presente libro, salvo quanto previsto dal regolamento. Per particolari discipline sportive indicate dal bando di concorso, i limiti minimo e massimo di eta' per il reclutamento degli atleti dei gruppi sportivi delle Forze armate sono fissati, rispettivamente, in diciassette e trentacinque anni. Il personale reclutato ai sensi del presente articolo non puo' essere impiegato in attivita' operative fino al compimento del diciottesimo anno di eta'. ((Il limite di eta' per il reclutamento degli istruttori dei gruppi sportivi delle Forze armate e' fissato in trentacinque anni.))

## LIBRO QUINTO PERSONALE CIVILE E PERSONALE AUSILIARIO DELLE FORZE ARMATE TITOLO I DISPOSIZIONI GENERALI

### Art. 1525. - Rapporti con l'ordinamento generale del lavoro alle dipendenze delle amministrazioni pubbliche

1. Fatte salve le disposizioni contenute nel titolo II, al personale civile del Ministero della difesa si applica la disciplina comune relativa al rapporto di lavoro alle dipendenze delle pubbliche amministrazioni.

2. Il personale ausiliario delle Forze armate e' disciplinato dalle disposizioni del presente libro.

## TITOLO II PERSONALE CIVILE CAPO I DOTAZIONE ORGANICA

### Art. 1526. - Determinazione della dotazione organica

1. Le dotazioni organiche del personale civile dell'Amministrazione della difesa sono stabilite dal capo I del titolo I del libro V del regolamento.

### Art. 1527. - Reimpiego del personale civile

1. Il reimpiego del personale civile del Ministero della difesa, conseguente ai processi di ristrutturazione, e' effettuato secondo i criteri fissati in sede di contrattazione decentrata di amministrazione prevista dal vigente contratto collettivo nazionale di lavoro del comparto del personale dipendente dai Ministeri.

2. Per il personale con qualifica dirigenziale i criteri di reimpiego sono fissati in sede di contrattazione decentrata, secondo quanto previsto dal relativo contratto collettivo nazionale di lavoro.

### Art. 1528. - Procedura di reimpiego

1. Nell'ambito dei criteri definiti con le modalita' di cui all'articolo 1527, a fronte di provvedimenti di ristrutturazione, sono effettuati incontri, ove possibile per settori o aree omogenee, tra l'amministrazione e le organizzazioni sindacali aventi titolo alla contrattazione decentrata per l'esame del piano di reimpiego predisposto dall'amministrazione.

### Art. 1529. - Ambito e ulteriori modalita' per il reimpiego

1. Al fine di evitare negative ricadute sociali, il reimpiego del personale civile e' effettuato in enti del Ministero della difesa in ambito comunale, provinciale e regionale, nei limiti dei posti disponibili, tenendo anche conto delle prevedibili vacanze organiche che si determinano, nonche' delle esigenze funzionali complessive dell'ente.

2. Per le finalita' di cui al comma 1, congiuntamente alla riqualificazione del personale, le cui modalita' applicative, in ambito Difesa, sono definite con decreto del Ministro della difesa, previa contrattazione ai sensi del decreto legislativo 30 marzo 2001, n. 165, e' avviata la riconversione professionale, nell'ambito della stessa posizione economica, dei dipendenti coinvolti nei processi di reimpiego a seguito di ristrutturazione di cui all'articolo 1527, in aderenza alle nuove esigenze organiche del Ministero della difesa, secondo i criteri che sono definiti dalla contrattazione collettiva di comparto.

3. Sono fatte salve le possibilita' di passaggio nei ruoli di altre amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, anche attraverso la realizzazione degli accordi di mobilita'.

### Art. 1529-bis. - (( (Formazione). ))

((

1. La formazione e' il complesso delle attivita' con cui si migliorano ed indirizzano le risorse umane attraverso l'acquisizione di capacita' e competenze che consentono al personale civile di svolgere adeguatamente il proprio ruolo professionale. La formazione deve essere tesa all'accrescimento e alla valorizzazione delle professionalita' acquisite, al fine di soddisfare i compiti istituzionalmente previsti nell'ambito delle articolazioni della Difesa, sia in ambito nazionale che internazionale.

2. Le attivita' di formazione si sviluppano attraverso, l'implementazione dei moduli formativi di base, specializzazione, aggiornamento e riconversione professionale.

3. I criteri e le modalita' di selezione per i candidati alla frequenza del corso di cui al comma 1 dell'articolo 751 sono determinati con decreto del Ministro della difesa.

))

## CAPO II - DOCENTI

### Art. 1530. - Profilo di docente presso le scuole di lingue estere

1. Ferme restando le dotazioni organiche del personale civile dell'Amministrazione della difesa e fatte salve le rideterminazioni delle medesime dotazioni, necessarie per assicurare la riduzione della spesa complessiva relativa ai posti in organico, ai sensi dell'articolo 1, comma 93 della legge 30 dicembre 2004, n. 311, in sede di contrattazione integrativa a livello di amministrazione, e' individuato un profilo relativo alle funzioni di docente di lingue estere.

2. La dotazione organica del personale del profilo professionale di cui al comma 1, per la Scuola di lingue estere dell'Esercito italiano, e' determinata in 33 unita'.

3. L'assunzione del personale del profilo professionale di cui al comma 1 avviene per pubblico concorso, per titoli ed esami. I requisiti per la partecipazione, i titoli di merito valutabili e le modalita' di svolgimento dei concorsi sono stabiliti con decreto del Ministro della difesa, di concerto con i Ministri dell'istruzione, dell'universita' e della ricerca, per la pubblica amministrazione e l'innovazione e dell'economia e delle finanze. Limitatamente al requisito della cittadinanza, si applica l'articolo 2, comma 8, del regolamento di cui al decreto del Presidente della Repubblica 23 marzo 2000, n. 117.

### Art. 1531. - Conferimento di incarichi a docenti civili per l'insegnamento di materie non militari presso scuole, istituti ed enti delle Forze armate

1. Anche in considerazione delle speciali e particolari esigenze connesse con la formazione e l'addestramento del personale militare impiegato nelle missioni internazionali, all'insegnamento delle materie non militari presso le scuole e gli istituti, individuati nel regolamento, si puo' provvedere, mediante convenzioni annuali stipulate con l'osservanza degli accordi nazionali di categoria ((, anche ai fini dei relativi compensi,)) e nei limiti degli stanziamenti di bilancio di previsione del Ministero della difesa destinati alle spese per la formazione e l'addestramento del personale di ciascuna Forza armata, con personale incaricato appartenente alle seguenti categorie:

- a) docenti universitari;
- b) magistrati ordinari, amministrativi, contabili, militari, avvocati e procuratori dello Stato;
- c) insegnanti di ruolo o non di ruolo abilitati di istituti e scuole statali, previo nulla osta del Ministero dell'istruzione, dell'universita' e della ricerca ((, o anche gia' destinatari delle disposizioni di cui al decreto del Presidente della Repubblica 18 novembre 1965, n. 1484, e alla legge 15 dicembre 1969, n. 1023));
- d) impiegati civili dell'amministrazione dello Stato in attivita' di servizio;
- e) lettori di lingua straniera;
- f) estranei all'amministrazione dello Stato, specificamente incaricati.

2. L'applicazione delle disposizioni di cui al comma 1 non puo' comportare la costituzione di rapporti di lavoro a tempo indeterminato.

3. Gli insegnanti di ruolo, impegnati nell'insegnamento per tutto l'orario scolastico, possono essere impiegati anche nella posizione di comando.

4. Nel regolamento sono stabiliti i criteri e le modalita' per la scelta dei docenti.

5. ((COMMA ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248)).

## CAPO III - TRATTAMENTO ECONOMICO

### Art. 1532. - Missione fuori sede

1. Al personale civile del Ministero della difesa comandato in missione fuori dall'ordinaria sede di servizio, per esigenze di servizio, si applica l'articolo 3, comma 7-quater, del decreto-legge 4 novembre 2009, n. 152, convertito, con modificazioni, dalla legge 29 dicembre 2009, n. 197.

## TITOLO III PERSONALE RELIGIOSO CAPO I PERSONALE DEL SERVIZO DI ASSISTENZA SPIRITUALE

### SEZIONE I - ORDINARIO MILITARE, VICARIO GENERALE E ISPETTORI

#### Art. 1533. - (( (Direzione del servizio di assistenza spirituale). ))

((

1. La direzione e il coordinamento del servizio di assistenza spirituale spettano all'Ordinario militare per l'Italia, il quale e' coadiuvato dal Vicario generale militare. L'Ordinario militare puo' avvalersi di cinque cappellani militari coordinatori presso gli Stati maggiori di Forza armata e i Comandi generali.

2. L'Ordinario militare e il Vicario generale militare sono assimilati di rango, rispettivamente, al grado di tenente generale e di maggiore generale.

3. Il Vicario generale militare sostituisce l'Ordinario militare nei casi di sede vacante, di assenza o di impedimento e lo rappresenta quando non puo' personalmente intervenire.

4. La giurisdizione ecclesiastica dell'Ordinario militare si esercita sui cappellani militari, sul personale religioso maschile e femminile addetto agli ospedali militari, sul personale delle Forze armate dello Stato e su quei Corpi la cui assistenza spirituale e' affidata all'Ordinario militare dalle autorita' governative d'intesa con la superiore autorita' ecclesiastica.

5. Il Ministro della difesa, sentito l'Ordinario militare, di concerto con il Ministro dell'economia e delle finanze se si tratta del Corpo della guardia di finanza, determina con apposito decreto le sedi ove e' prestata l'assistenza spirituale.

6. L'Ordinario militare individua la sede per ciascun cappellano militare, previa comunicazione all'autorita' militare competente))

#### Art. 1533-bis. - (( (Svolgimento del servizio di assistenza spirituale). ))

((

1. I cappellani militari attendono al loro ministero al fine di soddisfare le esigenze spirituali del personale individuato al comma 4 dell'articolo 1533 e dei relativi familiari che intendono fruire del loro ministero, nel pieno rispetto della liberta' religiosa e di coscienza. Hanno competenza parrocchiale nei riguardi del personale e del territorio sottoposto alla propria giurisdizione ecclesiastica e a tal fine curano la celebrazione dei riti liturgici, la catechesi, nonche' l'organizzazione di ogni opportuna attivita' pastorale, anche oltre l'orario di servizio, senza oneri aggiuntivi per l'amministrazione.

2. Per quanto riguarda la materia propriamente spirituale e pastorale, i cappellani militari sono tenuti ad osservare le norme sull'Ordinamento canonico e le direttive dell'Ordinario militare.

3. I cappellani militari, previa comunicazione alle autorita' militari competenti da parte dell'Ordinario militare, possono avvalersi, ai fini delle attivita' di culto, della collaborazione di altri sacerdoti in servizio della Diocesi competente per territorio, senza oneri aggiuntivi per l'amministrazione.

4. In caso di assenza, il cappellano militare e' sostituito dal parroco competente per la sede di servizio, previa comunicazione dell'Ordinario militare al comandante della sede, senza oneri aggiuntivi per l'amministrazione.

5. I cappellani militari risiedono in una delle sedi di servizio, salva dispensa dell'Ordinario militare. L'amministrazione di appartenenza garantisce loro l'alloggio))

#### Art. 1534. - (( (Nomina dell'Ordinario militare e del Vicario generale). ))

((1. La nomina dell'Ordinario militare e del Vicario generale militare e' effettuata, su designazione rispettivamente della Santa Sede e dell'Ordinario militare, nel rispetto delle disposizioni concordatarie, con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'interno e con il Ministro della difesa))

#### Art. 1534-bis. - (( (Designazione dei cappellani militari coordinatori). ))

((

1. I nominativi dei cappellani militari coordinatori sono comunicati dall'Ordinario militare al Ministro della difesa.

2. I cappellani militari coordinatori assolvono i compiti loro affidati dall'Ordinario militare e, a tal fine, accedono liberamente ai luoghi militari di loro pertinenza.

3. Il conferimento dell'incarico di funzione ai cappellani coordinatori non comporta alcuna modifica del trattamento economico))

#### Art. 1535.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1536. - Obbligo del giuramento

1. L'Ordinario militare presta giuramento nelle mani del Presidente della Repubblica; il Vicario generale militare ((presta)) giuramento nelle mani del Ministro della difesa.

#### Art. 1537. - Formula del giuramento dell'Ordinario militare

1. La formula del giuramento dell'Ordinario militare e' la seguente: <<Davanti a Dio e sui Santi Vangeli, io giuro e prometto, siccome si conviene a un Vescovo, fedelta' allo Stato italiano. Io giuro e prometto di rispettare e di far rispettare dal mio clero il Capo dello Stato italiano e il Governo stabilito secondo le leggi costituzionali dello Stato. Io giuro e prometto inoltre che non partecipero' ad alcun accordo, ne' assistero' ad alcun consiglio che possa recar danno allo Stato italiano e all'ordine pubblico, e che non permettero' al mio clero simili partecipazioni. Preoccupandomi del bene e dell'interesse dello Stato italiano, cerchero' di evitare ogni danno che possa minacciarlo>>.

#### Art. 1538. - Formula del giuramento del Vicario generale

1. La formula del giuramento del Vicario generale militare ((...)) e' la seguente: <<Davanti a Dio e sui Santi Vangeli, io giuro e prometto fedelta' allo Stato italiano. Io giuro e prometto di rispettare e di far rispettare da ogni cappellano militare il Capo dello Stato italiano e il Governo stabilito secondo le leggi costituzionali dello Stato. Io giuro e prometto inoltre che non partecipero' ad alcun accordo, ne' assistero' ad alcun consiglio che possa recar danno allo Stato italiano e all'ordine pubblico, e che non permettero' ad alcun cappellano militare simili partecipazioni. Preoccupandomi del bene e dell'interesse dello Stato italiano, cerchero' di evitare ogni danno che possa minacciarlo>>.

#### Art. 1539. - (( (Cessazione dall'ufficio per limiti di eta'). ))

((1. L'Ordinario militare e il Vicario generale militare possono conservare l'ufficio fino al compimento del sessantacinquesimo anno di eta'))

#### Art. 1540. - Cessazione dall'ufficio d'autorita'

1. Ancor prima del compimento dei limiti di eta' previsti dall'articolo 1539 e indipendentemente dalla durata del servizio prestato, l'Ordinario militare ((e il Vicario generale militare)) possono essere sollevati dall'ufficio d'autorita', previa intesa con la superiore autorita' ecclesiastica.

#### Art. 1541. - Trattamento di quiescenza

1. L'Ordinario militare ((e il Vicario generale militare)) che cessano dall'ufficio per eta' o d'autorita' hanno diritto al trattamento di quiescenza previsto dall'articolo 1625.

#### Art. 1542. - Norma di rinvio per il Vicario e gli ispettori

1. Salvo quanto previsto dalle disposizioni della presente sezione, per il Vicario generale ((...)) si osservano le norme sullo stato giuridico dei cappellani militari.

#### Art. 1543. - Cessazione dall'ufficio

1. L'Ordinario militare che cessa dall'ufficio per eta' o d'autorita' ne conserva la qualifica a titolo onorario.

((2. Il Vicario generale militare che cessa dall'ufficio per eta', d'autorita', per infermita' o a domanda, e' collocato nella riserva o in congedo assoluto, a seconda della idoneita'))

#### Art. 1544. - (( (Richiami in servizio). ))

((1. Il Vicario generale militare nella riserva puo' essere richiamato in servizio temporaneo, su proposta dell'Ordinario militare, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, se e' vacante il corrispondente posto organico))

#### Art. 1545. - (( (Collocamento in congedo assoluto). ))

((1. Il Vicario generale militare cessa di appartenere alla riserva ed e' collocato in congedo assoluto al compimento del sessantottesimo anno di eta'))

### SEZIONE II - DISPOSIZIONI GENERALI SUI CAPPELLANI MILITARI

#### Art. 1546. - (( (Gradi gerarchici). ))

((

1. L'ordinamento gerarchico dei cappellani militari e' costituito dai seguenti gradi:

- a) secondo cappellano militare capo, assimilato di rango al grado di tenente colonnello, per un numero complessivo di dieci unita';
- b) primo cappellano militare capo, assimilato di rango al grado di maggiore;
- c) cappellano militare capo, assimilato di rango al grado di capitano;
- d) cappellano militare addetto, assimilato di rango al grado di tenente;
- e) cappellano militare di complemento, assimilato di rango al grado di sottotenente.

2. L'attribuzione dei gradi gerarchici, per assimilazione di rango ai gradi militari:

a) garantisce al cappellano militare il riconoscimento della dignita' delle sue funzioni e consente al medesimo una piena agibilita' delle strutture militari allo scopo di assolvere il servizio di assistenza spirituale;

b) comporta che il cappellano militare non puo' esercitare poteri di comando o di direzione, ne' avere compiti di amministrazione nell'ambito delle Forze armate))

#### Art. 1547. - (( (Stato giuridico e organico). ))

((

1. Lo stato giuridico dei cappellani militari e' costituito dal loro stato di sacerdoti cattolici e dal complesso dei doveri e diritti inerenti al grado di cappellano militare, secondo le disposizioni del presente codice.

2. L'organico dei cappellani militari, integrato dall'Ordinario militare e dal Vicario generale, e' complessivamente determinato in centosessantadue unita'))

#### Art. 1548. - (( (Nomina). ))

((1. La nomina dei cappellani militari di complemento e' effettuata con decreto del Ministro della difesa, previa designazione dell'Ordinario militare))

#### Art. 1549. - (Requisiti per la nomina)

1. I sacerdoti cattolici, per poter conseguire la nomina al grado di cappellano militare di complemento, devono possedere il godimento dei diritti civili e politici, l'idoneita' all'incondizionato servizio militare e ((avere compiuto il venticinquesimo anno di eta')).

#### Art. 1550. - Giuramento

1. Il cappellano militare, all'atto di assumere servizio, presta giuramento con la formula e secondo le modalita' previste per gli ufficiali delle Forze armate dello Stato.

2. Per il cappellano militare che non presta giuramento si fa luogo alla revoca della nomina con effetto dalla data di decorrenza della nomina stessa.

#### Art. 1551. - Categorie

1. I cappellani militari si distinguono in:

- a) cappellani militari in servizio permanente;
- b) cappellani militari in congedo;
- c) cappellani militari in congedo assoluto.

2. I cappellani militari in congedo non sono vincolati da rapporto d'impiego e hanno gli obblighi di servizio previsti dal presente codice. I cappellani militari in congedo sono ripartiti in due categorie: cappellani militari di complemento e cappellani militari della riserva.

3. I cappellani militari in congedo assoluto non hanno piu' obblighi di servizio, ma conservano il grado e l'onore dell'uniforme e sono soggetti alle disposizioni del presente codice riflettenti il grado e la disciplina.

#### Art. 1552. - Ruoli

1. I cappellani militari del servizio permanente, di complemento e della riserva, sono iscritti rispettivamente in tre ruoli unici per tutte le Forze armate dello Stato, costituiti presso il Ministero della difesa.

2. L'iscrizione nei ruoli e' effettuata in ordine decrescente di grado e di anzianita'.

3. ((COMMA ABROGATO DALLA L. 22 APRILE 2021, N. 70)).

4. ((COMMA ABROGATO DALLA L. 22 APRILE 2021, N. 70)).

#### Art. 1553. - Anzianita' di grado

1. L'anzianita' di grado e' assoluta e relativa.

2. Per anzianita' assoluta si intende il tempo trascorso dal cappellano militare nel proprio grado, salve le eventuali detrazioni apportate ai sensi dell'articolo 1554.

3. Per anzianita' relativa si intende l'ordine di precedenza del cappellano militare fra i pari grado dello stesso ruolo.

4. L'anzianita' assoluta e' determinata dalla data del decreto di nomina o di promozione, se non e' altrimenti disposto dal decreto stesso.

5. A parita' di anzianita' assoluta l'anzianita' relativa, se non puo' essere stabilito altrimenti, e' determinata dall'eta'.

#### Art. 1554. - Detrazioni di anzianita'

1. Il cappellano militare che si trova in una delle condizioni previste dall'articolo 858 subisce nel ruolo una detrazione di anzianita' pari al periodo di durata delle condizioni stesse.

#### Art. 1555. - (( (Normativa penale e disciplinare). ))

((

1. I cappellani militari sono assoggettati alla giurisdizione penale militare soltanto in caso di mobilitazione totale o parziale e in caso di imbarco o di servizio presso unita' delle Forze armate dislocate fuori del territorio nazionale.

2. I cappellani militari sono soggetti alle specifiche disposizioni disciplinari contenute in un regolamento definito con decreto del Ministro della difesa di concerto con l'Ordinario militare, fatto salvo quanto previsto alla sezione IX.

3. L'autorita' giudiziaria, in caso di esercizio dell'azione penale nei confronti di un cappellano militare, ne informa l'Ordinario militare.

4. I cappellani militari non portano armi e indossano, di regola, l'abito ecclesiastico loro proprio, salvo situazioni speciali nelle quali sia necessario indossare la divisa militare))

#### Art. 1556. - Documentazione matricolare

1. Per i cappellani militari si osservano, in quanto applicabili, le disposizioni sulla documentazione matricolare stabilite dal codice e dal regolamento.

#### Art. 1557. - Documentazione caratteristica

1. L'autorita' dalla quale il cappellano militare direttamente dipende, redige alla fine di ogni anno un rapporto informativo nei riguardi del cappellano militare stesso; il rapporto e' altresi' redatto se cambia o cessa l'anzidetta dipendenza.

2. L'Ordinario militare o, per sua delega, il Vicario generale militare, sulla base del rapporto informativo e di ogni altro elemento a disposizione, compila, entro il mese di gennaio dell'anno successivo, le note caratteristiche per ciascun cappellano militare integrate da un giudizio complessivo espresso con le qualifiche di "ottimo", "buono", "mediocre", "insufficiente".

3. La qualifica di ottimo puo' essere conferita al cappellano militare che, spiccando per l'insieme delle sue qualita' positive, da' in servizio rendimento pieno e sicuro.

4. La qualifica di buono e' concessa al cappellano militare che da' in servizio soddisfacente rendimento.

5. Il cappellano militare di scarso o scarsissimo rendimento in servizio e' qualificato, rispettivamente, mediocre o insufficiente.

6. Se per uno o piu' anni non e' possibile compilare il rapporto informativo da parte degli organi competenti, la Commissione di cui all'articolo 1609, valutati gli elementi in possesso dell'amministrazione, esprime un giudizio complessivo.

#### Art. 1558. - Licenze

1. Per i cappellani militari si osservano, in quanto applicabili, le disposizioni relative alle licenze, vigenti per gli ufficiali della Forza armata presso la quale il cappellano presta servizio.

2. La licenza ordinaria e' concessa dall'Ordinario militare, previo nulla osta dell'autorita' dalla quale il cappellano militare direttamente dipende, la licenza straordinaria per gravi esigenze di carattere privato e' concessa, sentito il parere dell'Ordinario militare, dall'Amministrazione presso la quale il cappellano militare presta servizio.

### SEZIONE III - CAPPELLANI MILITARI IN SERVIZIO PERMANENTE

#### Art. 1559. - (Nomina)

1. La nomina a cappellano militare addetto in servizio permanente e' conferita, nei limiti dell'organico, con decreto del Ministro della difesa, previa designazione dell'Ordinario militare, ai cappellani militari di complemento che:

- a) presentano apposita domanda;
- b) hanno prestato almeno ((due)) anni di servizio continuativo riportando la qualifica di ottimo;
- c) ((LETTERA ABROGATA DALLA L. 18 SETTEMBRE 2025, N. 140)).

#### Art. 1560. - Disposizioni generali sull'impiego

1. L'impiego consiste nell'esercizio del ministero sacerdotale in qualita' di cappellano militare.

((2. L'impiego non puo' essere interrotto, sospeso o cessare se non nei casi e nei modi stabiliti dal presente codice))

#### Art. 1561. - Incompatibilita'

1. Con la qualita' di cappellano militare in servizio permanente e' incompatibile qualsiasi occupazione o attivita' che esula dai compiti relativi al servizio dell'assistenza spirituale alle Forze armate dello Stato.

2. Il Ministro della difesa, sentito l'Ordinario militare, puo' concedere l'autorizzazione ad accettare un incarico non retribuito, ritenuto conciliabile con i doveri di ufficio.

#### Art. 1562. - Posizioni di stato

1. Le posizioni del cappellano militare in servizio permanente sono:

- a) il servizio effettivo;
- b) l'aspettativa;
- c) la disponibilita';
- d) la sospensione dall'impiego.

#### Art. 1563. - Servizio effettivo

1. Il servizio effettivo e' la posizione del cappellano militare che, essendo idoneo al servizio incondizionato, e' provvisto d'impiego.

#### Art. 1564. - Idoneita' al servizio incondizionato

1. E' idoneo al servizio incondizionato il cappellano militare fornito dei requisiti fisici per poter bene esercitare in qualsiasi sede di servizio tutte le funzioni inerenti al proprio stato sia in tempo di pace sia in tempo di guerra.

2. L'idoneita' al servizio incondizionato e' accertata periodicamente in conformita' alle disposizioni vigenti per gli ufficiali delle Forze armate dello Stato.

#### Art. 1565. - Cause dell'aspettativa

1. L'aspettativa e' la posizione del cappellano militare esonerato temporaneamente dal servizio effettivo per una delle seguenti cause:

- a) prigionia di guerra;
- b) infermita' temporanee provenienti da cause di servizio;
- c) infermita' temporanee non provenienti da cause di servizio;
- d) motivi privati.

2. L'aspettativa e' disposta:

- a) di diritto, per la causa di cui alla lettera a) del comma 1;
- b) a domanda o d'autorita', per le cause di cui alle lettere b) e
- c) del comma 1; c) soltanto a domanda, per la causa di cui alla lettera d) del comma 1.

3. Le cause indicate alle lettere b) e c) sono accertate nei modi stabiliti dalle disposizioni vigenti in materia per gli ufficiali delle Forze armate dello Stato.

4. Prima del collocamento in aspettativa per infermita', al cappellano militare sono concessi i periodi di licenza non ancora fruiti.

5. L'aspettativa per motivi privati e' concessa, previo parere dell'Ordinario militare, subordinatamente alle esigenze del servizio, e non puo' avere durata inferiore a quattro mesi. Se l'aspettativa ha durata superiore a tale termine, trascorsi i primi quattro mesi, l'interessato puo' fare domanda di richiamo anticipato in servizio.

6. Il tempo trascorso in aspettativa per prigionia di guerra o per infermita' temporanea proveniente da causa di servizio e' computato per intero ai fini dell'avanzamento.

#### Art. 1566. - Durata dell'aspettativa

1. L'aspettativa non puo' avere una durata complessiva superiore a due anni, consecutivi o non, in un quinquennio, tranne il caso di prigionia di guerra, e cessa normalmente col cessare della causa che l'ha determinata.

2. Verificandosi una causa diversa da quella che determino' l'aspettativa, l'interessato puo' essere trasferito in altra aspettativa per questa nuova causa, osservandosi il disposto del comma 1.

3. Il cappellano militare che ha gia' fruito dell'aspettativa per motivi privati, per qualsiasi durata, non puo' esservi ricollocato se prima non sono trascorsi almeno due anni dal suo richiamo in servizio effettivo.

#### Art. 1567. - Decorso dell'aspettativa

1. L'aspettativa decorre dalla data fissata nel decreto, salvo l'aspettativa per prigionia di guerra, che decorre dalla data della cattura.

2. L'aspettativa e le eventuali proroghe non possono essere concesse che a mesi interi.

#### Art. 1568. - Scadenza dell'aspettativa

1. Allo scadere dell'aspettativa il cappellano militare e' richiamato in servizio effettivo.

2. Nei casi di aspettativa per infermita' si provvede tempestivamente agli accertamenti sanitari.

3. Se il cappellano militare e' giudicato ancora temporaneamente non idoneo al servizio incondizionato, l'aspettativa e' prorogata fino a raggiungere il periodo massimo previsto dall'articolo 1566.

4. Se alla scadenza di detto periodo massimo il cappellano militare e' ancora giudicato non idoneo al servizio incondizionato, si applicano le disposizioni dell'articolo 1579.

5. Le stesse disposizioni si applicano se il cappellano militare e' giudicato permanentemente inabile al servizio incondizionato anche prima della scadenza del periodo massimo d'aspettativa, ovvero quando, nel quinquennio, e' giudicato non idoneo al servizio incondizionato dopo aver fruito del periodo massimo di aspettativa e delle licenze eventualmente spettantigli.

#### Art. 1569. - Richiamo in servizio dall'aspettativa

1. Il cappellano militare in aspettativa per infermita' puo' essere richiamato anticipatamente in servizio effettivo, a domanda, previo giudizio di idoneita' a incondizionato servizio.

2. Nel caso di mobilitazione o di eccezionali esigenze, il cappellano militare in aspettativa puo' essere richiamato in servizio effettivo, purche' idoneo al servizio incondizionato, e anche in deroga al disposto dell'articolo 1565, comma 5.

#### Art. 1570. - Disposizioni generali sull'aspettativa

1. I collocamenti in aspettativa, le proroghe, i trasferimenti da una ad altra aspettativa e i richiami in servizio effettivo sono disposti con decreto ministeriale.

#### Art. 1571. - Disponibilita'

1. La disponibilita' e' la posizione del cappellano militare esonerato temporaneamente dal servizio effettivo per riduzione del ruolo organico.

2. Verificandosi una riduzione di organici, sono designati dall'Ordinario militare i cappellani da collocare in disponibilita'.

3. La disponibilita' non puo' durare piu' di due anni.

4. Al cappellano militare di cui al comma 1, in disponibilita', competono i quattro quinti dello stipendio e degli altri assegni a carattere fisso e continuativo.

#### Art. 1572. - Richiami dalla posizione di disponibilita'

1. Il cappellano militare in disponibilita' e' richiamato in servizio, sentito l'Ordinario militare, se entro i due anni dalla data di collocamento in tale posizione ha luogo una vacanza nel ruolo.

2. Il cappellano militare riassunto in servizio prende posto nel ruolo con l'anzianita' che aveva alla data del collocamento in disponibilita' e con lo stipendio inerente.

#### Art. 1573. - Cessazione dalla posizione di disponibilita'

1. Il cappellano militare in disponibilita' che, richiamato in servizio a norma dell'articolo 1572, non lo riassume, e' collocato nella riserva o in congedo assoluto, a seconda della idoneita', con diritto al trattamento di quiescenza previsto dall'articolo 1625.

2. Decorso il periodo massimo di disponibilita' senza richiami in servizio, il cappellano militare e' collocato nella riserva o in congedo assoluto, a seconda della idoneita', con diritto al trattamento di quiescenza di cui al comma 1.

#### Art. 1574. - Sospensione dall'impiego

1. La sospensione dall'impiego puo' avere carattere:

- a) precauzionale;
- b) disciplinare;
- c) penale.

2. La sospensione dall'impiego puo' essere applicata anche al cappellano militare in aspettativa o in disponibilita', trasferendolo dalla posizione in cui si trova in quella di sospensione dall'impiego.

#### Art. 1575. - Sanzioni disciplinari ecclesiastiche

1. Le sanzioni disciplinari ecclesiastiche, che sospendono il cappellano militare dall'esercizio totale o parziale del ministero sacerdotale, importano di diritto, per tutto il tempo in cui hanno effetto, la sospensione disciplinare dall'impiego, con privazione del trattamento economico.

#### Art. 1576. - Norma di rinvio in materia di sospensione dall'impiego

1. Per la sospensione ((precauzionale)) dall'impiego si osservano, in quanto applicabili, le disposizioni della sezione IV del capo III del titolo V del libro IV.

2. La sospensione precauzionale, tranne il caso previsto dall'articolo 915, e' disposta sentito il parere dell'Ordinario militare.

### SEZIONE IV - CESSAZIONE DAL SERVIZIO PERMANENTE DEI CAPPELLANI MILITARI

#### Art. 1577. - (( (Cause di cessazione dal servizio permanente). ))

((

1. Il cappellano militare cessa dal servizio permanente per il verificarsi di una delle seguenti cause:

- a) eta';
- b) infermita';
- c) domanda;
- d) d'autorita', per perdita dei diritti civili o politici;
- e) elevazione alla dignita' vescovile;
- f) per motivi disciplinari, ai sensi dell'articolo 1599, comma 1, lettera c);
- g) revoca della designazione da parte dell'autorita' ecclesiastica;
- h) dimissioni dallo stato clericale, in applicazione delle norme canoniche.

2. Il provvedimento di cessazione dal servizio permanente e' adottato con decreto del Ministro della difesa. Se il provvedimento e' disposto a domanda, ne e' fatta menzione nel decreto.

3. Si applica il disposto dell'articolo 923, comma 5))

#### Art. 1578. - Cessazione dal servizio permanente per eta'

1. Il cappellano militare, che ha compiuto il ((65°)) anno di eta', cessa dal servizio permanente ed e' collocato nella riserva o in congedo assoluto, a seconda della idoneita'.

#### Art. 1579. - Cessazione dal servizio permanente per infermita'

1. Il cappellano militare che e' divenuto permanentemente inabile al servizio incondizionato o che non ha riacquistato l'idoneita' allo scadere del periodo massimo di aspettativa o che, nel quinquennio, e' stato giudicato non idoneo al servizio incondizionato dopo aver fruito del periodo massimo di aspettativa e delle licenze eventualmente spettantigli, cessa dal servizio permanente ed e' collocato nella riserva o in congedo assoluto, a seconda della idoneita'.

#### Art. 1580. - Decorrenza del provvedimento di cessazione dal servizio per infermita'

1. Il provvedimento adottato in applicazione dell'articolo 1579, comma 1 decorre, a seconda dei casi, dalla data di scadenza del periodo massimo di aspettativa o dalla data dell'accertamento sanitario definitivo.

#### Art. 1581.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1582. - Cessazione dal servizio permanente a domanda

1. Il cappellano militare puo' chiedere di cessare dal servizio permanente; il diritto al trattamento di quiescenza e' disciplinato dall'articolo 1625.

2. L'accoglimento della domanda e' in ogni caso subordinato al parere favorevole dell'Ordinario militare e puo' essere sospeso per gravi motivi.

3. Il cappellano militare che cessa dal servizio permanente ai sensi del presente articolo e' collocato nella riserva o in congedo assoluto, a seconda dell'idoneita'.

#### Art. 1583. - Cessazione dal servizio permanente d'autorita'

1. Il cappellano militare puo' ((...)) essere collocato d'autorita' nella riserva; il diritto al trattamento di quiescenza e' disciplinato dall'articolo 1625.

#### Art. 1584. - Cessazione dal servizio permanente per nomina a vescovo

1. Il cappellano militare che e' rivestito della dignita' vescovile cessa dal servizio permanente ed e' collocato in congedo assoluto; il diritto al trattamento di quiescenza e' previsto dall'articolo 1625.

### SEZIONE V - CAPPELLANI MILITARI IN CONGEDO

#### Art. 1585. - Generalita'

1. I cappellani militari in congedo concorrono, secondo le necessita', al servizio dell'assistenza spirituale alle Forze armate in tempo di pace e in tempo di guerra.

#### Art. 1586. - Posizioni di stato

1. Il cappellano militare in congedo puo' trovarsi:

- a) in servizio temporaneo;
- b) in congedo illimitato;
- c) sospeso dalle funzioni del grado.

#### Art. 1587. - Doveri

1. Il cappellano militare in congedo, quando si trova in servizio temporaneo, e' soggetto alle disposizioni vigenti per i cappellani militari in servizio permanente, in quanto applicabili.

2. Il cappellano militare in congedo illimitato e' soggetto alle disposizioni riflettenti il grado, la disciplina e il controllo della forza in congedo.

#### Art. 1588. - Collocamento in congedo assoluto

1. Il cappellano militare in congedo che, prima del compimento del limite di eta' stabilito dall'articolo 1596, e' rivestito della dignita' vescovile o e' riconosciuto permanentemente inabile al servizio militare incondizionato, e' collocato in congedo assoluto. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1589. - Sospensione dalle funzioni del grado

1. Il cappellano militare in congedo puo' essere sospeso dalle funzioni del grado per motivi precauzionali, disciplinari, penali.

2. La sospensione dalle funzioni del grado precauzionale e disciplinare e' regolata dalle stesse norme, in quanto applicabili, stabilite per la sospensione dall'impiego dagli articoli 1575 e 1576.

3. La condanna a pena detentiva per tempo non inferiore a un mese ha per effetto la sospensione dalle funzioni del grado durante l'espiazione della pena.

#### Art. 1590. - Richiami in servizio

1. Il numero massimo dei cappellani militari di complemento o della riserva da chiamare in servizio temporaneo sia in tempo di pace sia in tempo di guerra, per le esigenze delle Forze armate, e' determinato, al principio di ogni anno, con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, su proposta dell'Ordinario militare.

2. Il numero di cui al comma 1 puo' essere aumentato durante il corso dell'anno, in dipendenza di nuove esigenze, con decreto adottato a norma del comma 1.

#### Art. 1591. - Provvedimenti di richiamo

1. Nei limiti di cui all'articolo 1590, le chiamate in servizio temporaneo e i collocamenti in congedo illimitato dei cappellani militari delle categorie di complemento e della riserva sono disposti con decreto del Ministro della difesa, su proposta dell'Ordinario militare.

### SEZIONE VI - CAPPELLANI MILITARI DI COMPLEMENTO

#### Art. 1592.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1593. - Domande di nomina

((1. Le domande per la nomina a cappellano militare di complemento sono dirette all'Ordinario militare munite dei seguenti documenti: a) certificato di nascita; b) certificato di cittadinanza italiana; c) certificato di godimento dei diritti civili e politici; d) certificato sanitario, rilasciato da un ufficiale medico in servizio, dal quale risulta che l'aspirante e' in possesso dell'idoneita' richiesta dall'articolo 1549))

2. Sull'accoglimento delle domande decide il Ministro della difesa, su designazione dell'Ordinario militare.

#### Art. 1594. - Cessazione dal complemento

1. Il cappellano militare di complemento e' collocato nella riserva al compimento del 55° anno di eta'. I cappellani militari di complemento che, dopo aver prestato ((due)) anni di servizio continuativo, hanno inoltrato domanda di transito nel servizio permanente ai sensi dell'articolo 1559, se non sono riconosciuti idonei a giudizio dell'Ordinario militare, cessano definitivamente dal servizio e sono collocati in congedo assoluto.

### SEZIONE VII - CAPPELLANI MILITARI DELLA RISERVA

#### Art. 1595. - Generalita'

1. La categoria della riserva comprende i cappellani militari che cessano dal servizio permanente nei casi previsti dal presente codice.

#### Art. 1596. - Collocamento in congedo assoluto

1. Il cappellano militare cessa di appartenere alla riserva ed e' collocato in congedo assoluto al compimento dei seguenti limiti di eta':

- a) 68 anni, se primo cappellano militare capo;
- b) 65 anni, se cappellano militare capo o cappellano militare addetto.

### SEZIONE VIII - PERDITA DEL GRADO

#### Art. 1597. - Cause di perdita del grado

(( 1. Il cappellano militare perde il grado per: a) dimissioni dallo stato clericale, in applicazione delle norme canoniche; b) cessazione dal servizio d'autorita' per perdita dei diritti civili o politici, ai sensi dell'articolo 1577, comma 1, lettera d); c) cessazione dal servizio per motivi disciplinari, ai sensi degli articoli 1577, comma 1, lettera f), e 1599, comma 1, lettera c) ))

2. In ogni caso la perdita del grado e' disposta con decreto del Ministro della difesa.

#### Art. 1598. - Reintegrazione nel grado

1. Il cappellano militare puo' essere reintegrato nel grado, previo giudizio favorevole dell'Ordinario militare, quando riacquista l'idoneita' alle funzioni sacerdotali e nei casi previsti dalla sezione IV del capo I del titolo V del libro IV.

2. La reintegrazione nel grado e' disposta con decreto del Ministro della difesa e decorre dalla data del decreto.

3. La reintegrazione nel grado del cappellano militare gia' in servizio permanente non importa di diritto la reiscrizione del cappellano stesso nel ruolo del servizio permanente.

### SEZIONE IX - DISCIPLINA

#### Art. 1599. - (( (Sanzioni disciplinari). ))

((1. Le sanzioni disciplinari che possono essere applicate al cappellano militare, in caso di infrazione delle regole disciplinari di cui al comma 2 dell'articolo 1555, e dei doveri di servizio, sono: a) la sospensione disciplinare dall'impiego, di cui all'articolo 1574; b) la sospensione dalle funzioni del grado, di cui all'articolo 1589; c) la cessazione dal servizio))

#### Art. 1600. - Inchiesta formale

1. L'inchiesta formale e' il complesso degli atti diretti all'accertamento di una infrazione disciplinare per la quale il cappellano militare puo' essere passibile di una delle sanzioni indicate all'articolo 1599.

2. L'inchiesta formale comporta la contestazione degli addebiti.

#### Art. 1601. - (( (Avvio dell'inchiesta formale). ))

((1. Ai fini dell'accertamento di un'infrazione disciplinare che comporta una delle sanzioni indicate all'articolo 1599, il cappellano e' sottoposto a inchiesta formale su rapporto dell'autorita' competente, a seconda della sede in cui si trova il cappellano))

#### Art. 1602. - Inquirente

((1. L'inchiesta formale e' affidata dal Ministro della difesa all'organo competente dell'Ordinariato militare))

2. In nessun caso l'inchiesta formale e' affidata all'Ordinario militare o al Vicario generale militare.

3. L'inquirente deve essere di grado o anzianita' superiore all'inquisito. ((PERIODO SOPPRESSO DALLA L. 22 APRILE 2021, N. 70)).

4. L'inquirente esperisce l'inchiesta formale secondo le disposizioni vigenti per gli ufficiali e, in ultimo, rimette il rapporto conclusivo, insieme con tutti gli atti dell'inchiesta e all'indice di essi, direttamente al Ministro ((, formulando una proposta motivata)).

#### Art. 1603. - (( (Decisioni del Ministro). ))

((1. Il Ministro, in base alle risultanze dell'inchiesta formale, decide, sentito il parere dell'Ordinario militare, se al cappellano militare deve o meno essere inflitta una delle sanzioni disciplinari di cui all'articolo 1599))

#### Art. 1604.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1605.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1606. - Norma di rinvio

1. Per quanto non contemplato dalla presente sezione, si osservano, in quanto applicabili, le disposizioni di cui al capo IV del titolo VIII del Libro IV.

### SEZIONE X - DISPOSIZIONI PER IL TEMPO DI GUERRA E DI GRAVE CRISI INTERNAZIONALE

#### Art. 1607. - Richiamo in servizio

1. In tempo di guerra e di grave crisi internazionale:

- a) il cappellano militare in congedo, a qualunque categoria appartenga, e' costantemente a disposizione per essere, all'occorrenza, richiamato in servizio;
- b) e' sospesa l'applicazione dell'articolo 1582.

### SEZIONE XI - AVANZAMENTO DEI CAPPELLANI MILITARI

#### Art. 1608. - (( (Modalita' di avanzamento). ))

((1. Le promozioni dei cappellani militari si effettuano: a) per anzianita' congiunta al merito, dal grado di cappellano militare di complemento sino al grado di cappellano militare capo; b) per merito comparativo, dal grado di cappellano militare capo al grado di secondo cappellano militare capo))

#### Art. 1609. - (( (Promozioni dei cappellani militari). ))

((

1. Le promozioni dei cappellani militari sono conferite con decreto del Ministro della difesa, previa designazione di una commissione di avanzamento, presieduta dall'Ordinario militare e della quale fanno parte il Vicario generale militare e tre secondi cappellani militari, di cui uno, prescelto dall'Ordinario militare, esercita le funzioni di segretario.

2. I secondi cappellani militari membri della commissione di avanzamento sono nominati dal Ministro della difesa, su proposta dell'Ordinario militare.

3. Per la validita' delle deliberazioni della commissione di avanzamento e' necessaria la presenza di almeno tre membri, compreso l'Ordinario militare.

4. Il verbale di ciascuna seduta e' sottoposto all'approvazione del Ministro della difesa, il quale indica, eventualmente, quali deliberazioni non approva, motivando in tal caso il suo giudizio))

#### Art. 1610. - Valutazioni, impedimenti e sospensioni

1. I cappellani militari sono scrutinati per la promozione nell'ordine di iscrizione ((nel ruolo)).

2. Non puo' essere scrutinato per la promozione il cappellano militare che e' sottoposto a procedimento penale o disciplinare, o che e' sospeso dall'impiego ((...)), o che si trova in disponibilita' ovvero in aspettativa per qualsiasi motivo.

3. E' sospesa la promozione del cappellano militare gia' scrutinato che, prima del conferimento della promozione, si trova in una delle condizioni indicate al comma 2. La sospensione della promozione annulla la valutazione gia' effettuata. All'interessato e' data comunicazione della sospensione della promozione e dei motivi che l'hanno determinata.

4. Al cessare della causa impeditiva il cappellano militare e' scrutinato o nuovamente scrutinato per la promozione e, se ha subito detrazione di anzianita' ai sensi dell'articolo 1554, deve risultare piu' anziano di pari grado gia' valutato.

5. Se il procedimento penale o disciplinare si e' concluso in senso favorevole o la sospensione dall'impiego o dalle funzioni del grado di carattere precauzionale e' stata revocata, o il cappellano militare e' stato in aspettativa per infermita' dipendente da causa di servizio, la commissione di avanzamento, se delibera che il cappellano scrutinato e' maggiormente meritevole almeno dell'ultimo promosso con lo scrutinio originario, lo designa per la promozione, indicando il posto che deve occupare in graduatoria. La promozione e' conferita, anche in soprannumero salvo riassorbimento, con decorrenza dalla stessa data delle promozioni disposte in base allo scrutinio originario. Se durante il periodo di esclusione si sono svolti piu' scrutini ai quali il cappellano avrebbe potuto essere sottoposto, la commissione di avanzamento valuta il cappellano per ciascuno dei successivi scrutini e stabilisce in quale di questi avrebbe potuto essere promosso. La data di decorrenza della promozione e' quella dello scrutinio per effetto del quale, a giudizio della commissione di avanzamento, si sarebbe dovuta conferire la promozione.

6. Se il cappellano militare e' stato in aspettativa per prigionia di guerra, egli e' scrutinato dopo che risulta scagionato penalmente e disciplinarmente in rapporto al fatto della cattura. Si applica il disposto del comma 5.

### SEZIONE XII - PROFILO DI CARRIERA DEI CAPPELLANI MILITARI IN SERVIZIO PERMANENTE

#### Art. 1611. - (Forme di avanzamento)

1. L'avanzamento dei cappellani militari in servizio permanente avviene:

- a) ad anzianita' congiunta al merito, per il grado di cappellano militare addetto;
- b) per merito comparativo, per i gradi di cappellano militare capo e primo cappellano militare capo.

2. Le promozioni al grado superiore dipendono da valutazioni di merito che hanno a oggetto la capacita' e l'idoneita' degli interessati, secondo il giudizio espresso dagli organismi competenti.

2-bis. Le promozioni da attribuire ai primi cappellani militari capo avvengono nei casi in cui vi sia una vacanza nell'organico dei secondi cappellani militari capo, come fissato dall'articolo 1546, comma 1, (( lettera a) )).

#### Art. 1612. - (( (Periodi di permanenza minima nel grado). ))

((1. Gli anni di anzianita' minima nel grado richiesta per l'inserimento nell'aliquota di valutazione sono i seguenti: a) cappellano militare addetto: cinque anni; b) cappellano militare capo: dieci anni; c) primo cappellano militare capo: dieci anni))

#### Art. 1613.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1614.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1615.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1616. - Modalita' per lo scrutinio

1. Nel procedere allo scrutinio per merito comparativo, la Commissione d'avanzamento determina preliminarmente, mediante coefficienti numerici, i criteri di valutazione dei titoli, con riguardo alle qualita' ecclesiastiche, al servizio prestato, agli eventuali particolari incarichi svolti, alla cultura e ai requisiti intellettuali e di preparazione professionale, alle benemerenze di guerra.

### SEZIONE XIII - AVANZAMENTO DEI CAPPELLANI MILITARI IN CONGEDO

#### Art. 1617.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

#### Art. 1618.

((ARTICOLO ABROGATO DALLA L. 22 APRILE 2021, N. 70))

### SEZIONE XIV - RUOLO D'ONORE

#### Art. 1619. - Iscrizione nel ruolo d'onore

1. Sono iscritti d'ufficio, in un ruolo d'onore, previo collocamento in congedo assoluto, i cappellani militari che sono riconosciuti permanentemente inabili al servizio militare per:

- a) mutilazioni o invalidita' riportate o aggravate per servizio di guerra, che hanno dato luogo a pensione vitalizia o ad assegno rinnovabile da ascriversi a una delle otto categorie previste dalla tabella A annessa alla legge 10 agosto 1950, n. 648;
- b) mutilazioni o invalidita' riportate in incidente di volo comandato, anche in tempo di pace, per cause di servizio e per le quali e' stato liquidato l'indennizzo privilegiato aeronautico di cui alla sezione II del capo IV del titolo III del libro VII del codice;
- c) mutilazioni o invalidita' riportate in servizio e per causa di servizio, che hanno dato luogo a pensione privilegiata ordinaria delle prime otto categorie.

2. I cappellani militari del ruolo d'onore possono essere richiamati in servizio col loro consenso, in tempo di guerra e in tempo di pace solo in casi particolari, per essere adibiti in incarichi o servizi compatibili con le condizioni fisiche.

## CAPO II - RELIGIOSE IN SERVIZIO PRESSO GLI STABILIMENTI SANITARI MILITARI

### Art. 1620. - Assunzione e servizio

1. L'assunzione delle suore presso gli stabilimenti sanitari militari e' disposta mediante convenzione da stipularsi dalla direzione dell'ospedale militare interessato con la casa madre cui le suore appartengono, in base alle istruzioni che saranno diramate dal Ministero della difesa.

2. Per disciplinare il servizio delle suore addette agli stabilimenti sanitari militari sono emanate particolareggiate istruzioni a cura del Ministero della difesa.

## CAPO III - TRATTAMENTO ECONOMICO

### SEZIONE I - PERSONALE DEL SERVIZIO DI ASSISTENZA SPIRITUALE

#### Art. 1621. - (( (Trattamento economico dell'Ordinario militare e dei cappellani militari). ))

((

1. Al personale del servizio di assistenza spirituale si applicano le disposizioni della presente sezione.

2. All'Ordinario militare compete il trattamento economico previsto per il grado di tenente generale.

3. Al Vicario generale militare spetta il trattamento economico di base degli ufficiali delle Forze armate, secondo il grado di assimilazione.

4. Ai cappellani militari spetta il trattamento economico di base degli ufficiali della Forza armata presso la quale prestano servizio, secondo il grado di assimilazione.

5. Ai cappellani militari sono altresi' corrisposte, secondo il grado di assimilazione, con esclusione di ogni altra, le seguenti indennita':

- a) l'indennita' integrativa speciale prevista dalla legge per il personale militare di grado corrispondente a quello di assimilazione;
- b) l'indennita' mensile di impiego operativo di base;
- c) l'indennita' di missione disposta dalle autorita' competenti;
- d) l'indennita' di imbarco disposta dalle autorita' competenti.

6. Il cappellano militare non percepisce compensi per lavoro straordinario in ordine all'assolvimento delle funzioni ministeriali in qualunque orario espletate, fermi restando gli eventuali obblighi assicurativi))

#### Art. 1622. - Riduzione o sospensione degli assegni

1. Lo stipendio e gli altri assegni spettanti al personale di cui all'articolo 1621((, commi 3 e 4,)) sono ridotti o sospesi, in relazione alle varie posizioni di stato per esso previste dal presente codice, secondo le norme in vigore per gli ufficiali della Forza armata a cui carico e' posto l'onere del trattamento economico.

### SEZIONE II - RELIGIOSE IN SERVIZIO PRESSO GLI STABILIMENTI SANITARI MILITARI

#### Art. 1623. - Retribuzione

1. Il compenso alle suore addette agli stabilimenti sanitari militari, assunte mediante convenzione stipulata ai sensi dell'articolo 1620, e' commisurato al trattamento economico determinato, ai fini contributivi, ai sensi dell'articolo 1 del decreto-legge 29 luglio 1981, n. 402, convertito, con modificazioni, dalla legge 26 settembre 1981, n. 537, che costituisce il limite minimo di retribuzione giornaliera del personale ausiliario dipendente dalle amministrazioni dello Stato e dalle altre pubbliche amministrazioni.

#### Art. 1624. - Trattamento economico di missione e trasferimento

1. Al personale indicato all'articolo 1623, in caso di missione o trasferimento, e' corrisposto il trattamento di missione vigente per il grado di maresciallo.

## CAPO IV - TRATTAMENTO PREVIDENZIALE

### Art. 1625. - (( (Pensioni normali e privilegiate del personale del servizio di assistenza spirituale). ))

((1. Per le pensioni normali, privilegiate, ordinarie e di guerra all'Ordinario, al Vicario generale e ai cappellani militari in servizio permanente, il trattamento previdenziale segue il trattamento economico principale, fermo restando che con la cessazione dal servizio al 65° anno di eta' si interrompe ogni progressione di carriera e di avanzamento economico))

## TITOLO IV PERSONALE DELLA CROCE ROSSA ITALIANA AUSILIARIO DELLE FORZE ARMATE CAPO I PERSONALE DEL CORPO MILITARE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1626. - Corpo speciale volontario

1. Per il funzionamento dei suoi servizi in tempo di pace, di guerra o di grave crisi internazionale, la Croce rossa italiana arruola proprio personale che costituisce un corpo speciale volontario, ausiliario delle Forze armate.

#### Art. 1627. - Ruoli del Corpo militare della Croce rossa italiana

1. Il personale militare della Croce rossa italiana e' iscritto in due distinti ruoli di anzianita': uno normale, l'altro speciale.

2. Il ruolo normale comprende il personale arruolabile per il servizio del tempo di pace, di guerra o di grave crisi internazionale, suddiviso in altri due ruoli: mobile e di riserva. Gli appartenenti al ruolo normale rimangono iscritti all'Associazione per tutta la durata del proprio arruolamento.

3. II ruolo speciale comprende il personale avente obblighi militari in tempo di guerra o di grave crisi internazionale. Gli iscritti in tale ruolo possono ottenere il passaggio nel ruolo normale in base al disposto dell'articolo 1665.

4. L'organico per il ruolo normale mobile e' stabilito, ogni due anni, con decreto del Ministro della difesa, d'intesa col Ministro dell'economia e delle finanze, su relazione del presidente nazionale dell'Associazione alle autorita' vigilanti.

#### Art. 1628. - Trasferimento tra ruoli

1. Gli iscritti nel personale direttivo, appartenenti al ruolo normale (mobile e di riserva) e al ruolo speciale, che si trovano nelle condizioni previste dall'articolo 1663, sono trasferiti in un ruolo degli indisponibili.

2. Gli iscritti nel personale direttivo appartenenti al ruolo normale mobile che si trovano nelle condizioni previste dagli articoli 1716 e seguenti sono trasferiti in un ruolo dei fuori quadro.

#### Art. 1629. - Gerarchia

1. La gerarchia nei gradi del personale militare della Croce rossa italiana e' la seguente:

- a) Personale direttivo (ufficiali): 1) maggior generale (medico o commissario); 2) colonnello (medico o commissario); 3) tenente colonnello (medico o commissario); 4) maggiore (medico, chimico-farmacista o commissario); 5) cappellano capo della Croce rossa italiana; 6) capitano (medico, chimico-farmacista, commissario contabile); 7) cappellano della Croce rossa italiana; 8) tenente (medico, chimico-farmacista, commissario contabile); 9) sottotenente (medico, chimico-farmacista, commissario contabile);
- b) Personale di assistenza (sottufficiali): 1) maresciallo maggiore; 2) maresciallo capo; 3) maresciallo ordinario; 4) sergente maggiore; 5) sergente;
- c) Personale di assistenza (militari di truppa): 1) caporal maggiore; 2) caporale (infermiere, meccanico, automobilista conducente, cuoco); 3) milite (infermiere, inserviente, portaferiti, trombettiere, lavandaio, aiuto di cucina).

2. Nel regolamento e' riportata la corrispondenza con i gradi delle Forze armate.

#### Art. 1630. - Grado

1. Nessuno puo' ricoprire uno dei gradi di cui all'articolo 1629 se non e' riconosciuto idoneo ad adempierne le funzioni e se non e' in condizioni compatibili col decoro del grado stesso.

2. Non sono concessi gradi onorari, ne' cambi di categoria.

### SEZIONE II - RECLUTAMENTO

#### Art. 1631. - Requisiti

1. Per essere ammesso nel personale dell'Associazione l'aspirante deve aver sempre tenuto una condotta, civile e morale, irreprensibile, valutata con giudizio definitivo delle autorita' alle quali e' devoluta la nomina.

#### Art. 1632. - Arruolamento nel ruolo normale

1. All'arruolamento nel ruolo normale, distintamente nel personale direttivo e in quello di assistenza, concorrono i cittadini:

- a) che, nei riguardi delle Forze armate dello Stato, sono esenti da obblighi di leva o in congedo assoluto e, tenuto presente il disposto dei successivi articoli 1639, comma 3, e 1661, non hanno compiuto: 1) il sessantesimo anno di eta', se aspiranti nell'arruolamento nel personale di assistenza; 2) il sessantacinquesimo anno di eta', se aspiranti all'arruolamento nel personale direttivo;
- b) che, nei riguardi delle Forze armate dello Stato, si trovano nella posizione di <<riformati>> e da apposita visita medica sono riconosciuti idonei ai servizi della Croce rossa italiana e, tenuto presente il disposto dei successivi articoli 1639, comma 3, e 1661: 1) hanno compiuto il ventinovesimo anno di eta' e non superato il sessantesimo, se aspiranti all'arruolamento nel personale di assistenza; 2) non hanno superato il sessantacinquesimo anno di eta', se aspiranti all'arruolamento nel personale direttivo;
- c) soggetti a obblighi militari verso le Forze armate dello Stato, che hanno compiuto: 1) il trentunesimo anno di eta' e non superato il cinquantacinquesimo, se aspiranti all'arruolamento nel personale di assistenza; 2) il quarantacinquesimo anno di eta', e non superato il sessantacinquesimo, se aspiranti all'arruolamento nel personale direttivo.

2. Il reclutamento di soggetti a obblighi militari e' contenuto nel numero che ogni due anni il Ministro della difesa stabilisce d'intesa con il Ministro dell'economia e delle finanze, distinguendovi le aliquote di arruolabili appartenenti a ciascuna Forza armata.

3. Per gli aspiranti che rivestono grado di ufficiale e per i sottoufficiali e militari di truppa che sono medici o farmacisti, l'arruolamento e' autorizzato caso per caso dal Ministro della difesa.

4. Il Ministero della difesa stabilisce inoltre tutte le altre limitazioni, modalita' e condizioni che ritiene opportuno.

#### Art. 1633. - Arruolamento nel ruolo speciale

1. All'arruolamento nel ruolo speciale, distintamente nel relativo personale direttivo o di assistenza, concorrono i cittadini aventi obblighi di servizio militare, quali iscritti di leva o appartenenti ai ruoli del congedo di qualsiasi Forza armata dello Stato o del Corpo della Guardia di finanza, dal diciottesimo anno di eta' fino alla cessazione di detti obblighi per raggiunti limiti di eta' o per riforma.

#### Art. 1634. - Personale militare in congedo

1. I soggetti da iscrivere nel ruolo normale o nel ruolo speciale, che rivestono un grado in una delle categorie in congedo delle Forze armate o del Corpo della Guardia di finanza, possono conseguire la nomina del corrispondente grado del personale della Croce rossa italiana conservando la propria anzianita', subordinatamente, per il personale di assistenza, al disposto degli articoli 1648 e 1657 e, per il personale direttivo, al possesso dei titoli di studio di cui agli articoli 1643, 1644 e 1645.

2. Per i medici e i farmacisti l'anzianita' di grado e' quella della data del superato esame di Stato per l'esercizio professionale, se non gia' ufficiali in congedo del corrispondente corpo o ruolo sanitario delle Forze armate o del Corpo della Guardia di finanza.

#### Art. 1635. - Nomina del personale di assistenza nei ruoli direttivi

1. Gli iscritti, di qualsiasi grado e ruolo, nel personale di assistenza, se hanno conseguito il titolo di studio indicato dagli articoli 1644, comma 1, lettera a) e 1645, comma 1, lettere a) e b), o la nomina a sottotenente di complemento delle Forze armate o del Corpo della Guardia di finanza, possono presentare domanda di arruolamento nel personale direttivo della Croce rossa italiana, seguendo le norme indicate dall'articolo 976 del regolamento e conseguirne la nomina con la procedura prescritta dagli articoli 1639 e 1641.

2. Avvenuta la nomina a ufficiale, ai sensi del comma 1, l'interessato e' cancellato dai ruoli del personale di assistenza dalla data del provvedimento di cui all'articolo 1639.

3. Gli iscritti, di qualsiasi grado e ruolo, nel personale di assistenza, se hanno conseguito il titolo di studio indicato dall'articolo 1643, rispettivamente per la nomina a sottotenente medico e a sottotenente chimico-farmacista della Croce rossa italiana, o hanno ottenuta la nomina a sottotenente medico o farmacista di complemento delle Forze armate o del Corpo della Guardia di finanza, sono cancellati dai ruoli del personale di assistenza dalla data del conseguimento del titolo di studio o della nomina a sottotenente di complemento.

4. Gli iscritti di cui al comma 3 possono presentare domanda di arruolamento nel personale direttivo, seguendo le norme indicate dall'articolo 976 del regolamento e conseguirne la nomina con la procedura prescritta dagli articoli 1639 e 1641; l'arruolamento nel personale direttivo del ruolo normale e' subordinato alle autorizzazioni, limitazioni e condizioni stabilite dall'articolo 1632 per l'iscrizione dei medici e farmacisti nel ruolo normale, personale direttivo.

#### Art. 1636. - Idoneita' fisica al servizio

1. Gli aspiranti all'arruolamento nel corpo militare della Croce rossa italiana, per essere ammessi, oltre a possedere l'idoneita' ai servizi nelle unita' mobili e territoriali dell'associazione, riconosciuta da visita eseguita da un ufficiale medico dell'associazione, appositamente delegato, devono risultare esenti da difetti incompatibili con l'uso della uniforme.

2. Per coloro che sono stati riformati in sede di arruolamento nelle Forze armate o nel Corpo della Guardia di finanza, l'infermita' che ha dato luogo alla riforma, se riconosciuta compatibile con il servizio della Croce rossa italiana non puo' essere addotta in seguito dall'interessato per ottenere l'esenzione dal servizio stesso, salvo casi di aggravamento riconosciuto. L'interessato rilascia in proposito apposita dichiarazione in calce al verbale di visita medica.

#### Art. 1637. - Non ammissioni e speciali autorizzazioni

1. Non sono ammessi nel personale dell'Associazione coloro ai quali e' concessa la dispensa di diritto da qualsiasi chiamata alle armi, perche' ricoprono una delle cariche o uno degli impieghi indicati con decreto del Ministro della difesa per i richiami alle armi per mobilitazione.

2. Possono essere ammessi coloro che ricoprono una delle cariche o uno degli impieghi, indicati nel predetto decreto, per i quali la dispensa e' concessa soltanto a richiesta dei capi degli uffici e tale concessione non e' ancora intervenuta o e' stata revocata.

3. L'arruolamento del personale di ruolo delle amministrazioni dello Stato, comprese quelle aventi ordinamento autonomo, in tempo di pace, di guerra o di grave crisi internazionale, non puo' aver luogo senza il preventivo consenso della amministrazione di appartenenza.

#### Art. 1638. - Incompatibilita'

1. Gli aspiranti all'arruolamento nel personale dell'Associazione devono dichiarare di non avere alcun impegno verso l'associazione dei cavalieri del sovrano militare Ordine di Malta e, se hanno appartenuto a detta associazione, devono indicare per qual motivo hanno cessato di farne parte.

### SEZIONE III - NOMINE

#### Art. 1639. - Generalita'

1. Le nomine degli appartenenti al personale direttivo della Croce rossa italiana sono effettuate con decreto del Presidente della Repubblica, in seguito a designazione del presidente nazionale dell'Associazione.

2. Le nomine degli appartenenti al personale di assistenza sono effettuate, con brevetti, dai comandanti dei centri di mobilitazione, per delegazione del presidente nazionale.

3. Le ammissioni sono consentite per il solo ruolo normale mobile e per il ruolo speciale. Non sono concesse ammissioni per il ruolo normale di riserva ne' per quello degli indisponibili.

4. Nel ruolo di riserva possono transitare soltanto gli iscritti nei ruoli mobili o in quelli degli indisponibili, nei casi previsti dal presente codice.

#### Art. 1640. - Domande di arruolamento

1. Le domande per l'arruolamento nel personale direttivo, da compilarsi su apposito stampato rilasciato dai comitati della Croce rossa italiana, sono indirizzate dagli aspiranti al presidente nazionale dell'associazione, al quale pervengono per il tramite dei centri di mobilitazione, nella cui circoscrizione territoriale e' domiciliato stabilmente il richiedente.

2. Le domande per l'arruolamento nel personale di assistenza, compilate sullo stampato suddetto, sono indirizzate al comandante del centro di mobilitazione, nella cui circoscrizione territoriale e' domiciliato il richiedente.

3. I comitati della Croce rossa italiana sono delegati a ricevere le domande di arruolamento, inoltrandole direttamente, con i documenti prescritti, al competente centro di mobilitazione. Se richiesti dagli interessati, rilasciano ricevuta per i documenti presentati.

4. Le modalita' di presentazione delle domande e la documentazione richiesta sono indicate nel regolamento.

#### Art. 1641. - Commissione centrale del personale

1. Tutte le domande di ammissione nel personale direttivo della Croce rossa italiana, trasmesse dai centri di mobilitazione, secondo l'articolo 1640, al presidente nazionale, sono sottoposte all'esame di una commissione centrale del personale, nominata dal consiglio direttivo dell'associazione, la quale da' il proprio parere sulla ammissibilita' degli aspiranti all'arruolamento.

2. Quando il parere della commissione e' favorevole ed e' approvato dal presidente nazionale, e' inoltrata al Ministero della difesa la designazione per la nomina dell'aspirante, di cui all'articolo 1639 .

3. Nel regolamento e' disciplinata la composizione della commissione e sono riportate ulteriori norme sulle nomine.

#### Art. 1642. - Numero delle nomine

1. Il numero delle nomine nel personale direttivo e in quello di assistenza e' limitato ai posti che si rendono annualmente vacanti, in base all'organico stabilito dall'articolo 1627, comma 4, per il ruolo normale mobile.

2. I ruoli diversi da quelli di cui al comma 1 non hanno limitazioni organiche.

### SEZIONE IV - ARRUOLAMENTO DEL PERSONALE DIRETTIVO

#### Art. 1643. - Ufficiali medici e farmacisti

1. Possono ottenere la nomina a sottotenenti medici della Croce rossa italiana gli aspiranti in possesso del diploma di abilitazione all'esercizio della professione di medico chirurgo.

2. Possono ottenere la nomina a sottotenente chimico-farmacista della Croce rossa italiana gli aspiranti in possesso del diploma di abilitazione all'esercizio della professione di farmacista.

#### Art. 1644. - Ufficiali commissari

1. Possono ottenere la nomina a sottotenenti commissari della Croce rossa italiana gli aspiranti che si trovano nelle seguenti condizioni:

- a) hanno conseguito il diploma di maturita' classica o scientifica o un titolo equipollente stabilito dalle disposizioni emanate dal Ministero della difesa di concerto con i Ministeri dell''istruzione, dell'universita' e della ricerca e dell'economia e delle finanze;
- b) sono sottufficiali congedati dall'Esercito italiano, che hanno ottenuto dalla competente commissione di avanzamento una dichiarazione comprovante che, per condotta e per qualita' militari, morali e intellettuali, sono meritevoli di coprire il grado di sottotenenti di complemento e che sono in possesso di uno dei titoli di studio richiesti per poter aspirare all'ammissione ai corsi allievi ufficiali di complemento dell'Esercito italiano.

2. In mancanza del titolo di studio, il sottufficiale deve sostenere, con successo, un esame di cultura generale, in base al disposto dall'articolo 1705, dinanzi ad apposita commissione.

#### Art. 1645. - Ufficiali contabili

1. Possono ottenere la nomina a sottotenente contabile della Croce rossa italiana gli aspiranti che si trovano nelle condizioni seguenti:

- a) hanno conseguito il diploma di ragioneria;
- b) hanno conseguito un diploma di istruzione secondaria di secondo grado e danno prova di aver disimpegnato almeno per un anno, funzioni effettive di ragioneria presso un ufficio pubblico o presso una importante azienda privata;
- c) pur non avendo i titoli di studio di cui alle lettere a) e b), hanno ottenuto il passaggio all'ultimo corso d'istituto tecnico o di liceo scientifico e ricoprono un impiego nei quadri organici di ragioneria di un'amministrazione pubblica o dei principali istituti di credito, ovvero di importanti ditte commerciali, con funzioni direttive.

#### Art. 1646. - Cappellani

1. Possono ottenere la nomina a cappellani i sacerdoti cattolici che ne fanno domanda e che si trovano nelle condizioni volute dalle disposizioni della sezione II del presente capo.

2. Le nomine dei cappellani hanno il preventivo nulla osta dell'Ordinario militare per l'Italia, al quale sono trasmesse le domande degli interessati dal presidente nazionale dell'associazione.

3. Il cappellano capo e' nominato fra i cappellani che hanno almeno tre anni di anzianita' di grado, su designazione dell'Ordinario militare e del presidente nazionale.

4. Al cappellano capo e ai cappellani della Croce rossa italiana chiamati in servizio e' dovuto il trattamento economico spettante agli ufficiali della Croce rossa italiana, cui sono rispettivamente assimilati, e quello disciplinare e morale che compete ai cappellani militari in servizio presso le Forze armate o la Guardia di finanza.

5. L'assimilazione a grado militare del personale per l'assistenza spirituale non assoggetta alla giurisdizione penale militare e disciplinare militare, se non in caso di mobilitazione totale o parziale e in caso di imbarco sulle navi militari.

### SEZIONE V - ARRUOLAMENTO DEL PERSONALE DI ASSISTENZA

#### Art. 1647. - Nomina a maresciallo

1. Possono aspirare alla nomina a maresciallo ordinario, maresciallo capo, maresciallo maggiore della Croce rossa italiana i marescialli in congedo delle Forze armate o del Corpo della Guardia di finanza.

2. E' data la preferenza a coloro che hanno disimpegnato, almeno per un anno, le funzioni contabili. Essi conservano il grado ricoperto nelle Forze armate o nel Corpo della Guardia di finanza e la relativa anzianita'.

3. Possono inoltre aspirare alla nomina a maresciallo ordinario della Croce rossa italiana coloro che:

- a) hanno conseguito idoneo titolo di studio, determinato con decreto del Ministro della difesa;
- b) danno prova di aver disimpegnato attribuzioni di contabile in un ufficio pubblico o privato importante;
- c) dimostrano, sottoponendosi a un apposito esperimento pratico, da determinarsi dalla presidenza nazionale dell'associazione, di ben conoscere la disciplina e i regolamenti militari.

#### Art. 1648. - Nomina a sergente o a sergente maggiore

1. Possono aspirare alla nomina a sergente maggiore o a sergente della Croce rossa italiana i sottufficiali del corrispondente grado delle Forze armate o del Corpo della Guardia di finanza, in congedo. Essi si obbligano a seguire con profitto il corso d'istruzione, di cui all'articolo 1657.

2. In aggiunta ai soggetti di cui al comma 1, possono inoltre aspirare alla nomina a sergente della Croce rossa italiana, senza seguire il corso teorico pratico sanitario, di cui all'articolo 1651, gli studenti di medicina e chirurgia che hanno compiuto il 4° anno di universita' e che danno prova di conoscere le norme della disciplina militare.

#### Art. 1649. - Nomina a caporal maggiore

1. Possono aspirare alla nomina a caporale maggiore della Croce rossa italiana, senza seguire il corso teorico pratico di cui all'articolo 1651:

- a) gli studenti in medicina e chirurgia che hanno compiuto il 2° anno di universita' e danno prova di conoscere la disciplina militare;
- b) i militari in congedo che hanno frequentato il corso di aiutanti di sanita', riportando la classifica di ottimo.

#### Art. 1650. - Nomina a caporale

1. Possono aspirare alla nomina a caporale della Croce rossa italiana, senza seguire il corso teorico pratico, di cui all'articolo 1651:

- a) gli studenti di farmacia che hanno compiuto il primo anno di corso e danno prova di conoscere la disciplina militare;
- b) i militari in congedo che hanno frequentato il corso di aiutanti di sanita', riportando la classifica di ottimo;
- c) gli infermieri di professione, che svolgono servizio in un ospedale civile importante.

#### Art. 1651. - Nomina a milite

1. Gli aspiranti infermieri che non presentano certificato comprovante la loro attitudine a tale servizio, si obbligano a seguire, oltre al corso di cui all'articolo 1657, un corso speciale di istruzione teorico pratico per l'assistenza dei malati e feriti in guerra e per i servizi di pronto soccorso, secondo apposito programma stabilito dalla presidenza nazionale.

2. Per essere nominati trombettieri, inservienti, lavandai, cuochi, meccanici e conducenti, gli aspiranti devono dar prova della necessaria attitudine.

### SEZIONE VI - STATO GIURIDICO

#### Art. 1652. - Anzianita' di grado

1. Per determinare le anzianita' di grado, assolute e relative, per la iscrizione nei ruoli degli appartenenti al personale direttivo, valgono, in quanto applicabili, le disposizioni stabilite in materia dalla sezione II del capo I del titolo V del libro IV.

#### Art. 1653. - Normativa penale e disciplinare applicabile

1. Gli iscritti nei vari ruoli del personale militare dell'associazione, escluso il personale per l'assistenza spirituale, chiamati in servizio, sono militari e sono sottoposti alle norme della disciplina militare e dei codici penali militari.

2. Le chiamate in servizio e i collocamenti in congedo degli iscritti suddetti sono effettuati dai centri di mobilitazione con provvedimento definitivo. Le chiamate sono disposte con precetto adottato in seguito ad autorizzazione del presidente nazionale.

3. Ai mancanti alla chiamata disposta ai sensi del comma 2 sono applicate le disposizioni penali sancite per i militari.

4. I centri di mobilitazione rendono edotti sia gli aspiranti all'arruolamento, sia gli arruolati precettati, di tale loro stato giuridico e si assicurano, prima di equipaggiarli, della perfetta conoscenza da parte degli stessi delle norme essenziali della disciplina militare.

#### Art. 1654. - Qualifica di pubblico ufficiale

1. Gli iscritti al personale della Croce rossa italiana, quando prestano servizio, sono considerati pubblici ufficiali.

2. Il personale direttivo, non in servizio, e' soggetto alle disposizioni disciplinari stabilite dal codice e dal regolamento per gli ufficiali in congedo ai quali e' equiparato.

#### Art. 1655. - Giuramento

1. Tanto il personale direttivo, quanto il personale di assistenza, dopo nominato, presta giuramento in conformita' al disposto dell'articolo 621, comma 6 e con le formalita' stabilite dal regolamento.

2. Il giuramento e' effettuato alla presenza del comandante del centro di mobilitazione o di un ufficiale della Croce rossa italiana appositamente delegato.

#### Art. 1656. - Obblighi del personale direttivo

1. Tutti gli aspiranti a un grado nel personale direttivo partecipano, prima dell'ammissione o successivamente, ai corsi di istruzione che sono tenuti, presso i comitati, sul servizio della Croce rossa italiana e su quanto concerne la disciplina militare.

2. Sono provvisti, a tale scopo e a loro spese, degli speciali regolamenti di servizio.

3. Gli iscritti nel personale direttivo possono inscriversi all'Unione nazionale ufficiali in congedo d'Italia.

4. Dopo l'ammissione, ed entro due anni dalla medesima, gli appartenenti al personale direttivo prestano un servizio di prima nomina di almeno quindici giorni in un ufficio o stabilimento designato dal presidente nazionale dell'Associazione. Essi sono tenuti a dotarsi dell'uniforme ordinaria di servizio.

#### Art. 1657. - Obblighi del personale di assistenza

1. Tutti gli arruolati nel personale di assistenza dell'associazione seguono un corso di:

- a) istruzione sui servizi speciali e sui materiali della Croce rossa italiana;
- b) istruzione militare e disciplina militare.

2. Dal corso di cui al comma 1, lettera b) sono dispensati i militari che hanno prestato servizio effettivo sotto le armi per un periodo non inferiore a tre mesi e che danno prova di conoscere le norme disciplinari e l'istruzione militare.

3. I corsi di cui al comma 1 hanno la durata e i programmi che sono stabiliti dalla presidenza nazionale dell'Associazione.

#### Art. 1658. - Durata dell'arruolamento per il personale direttivo

1. L'iscrizione all'Associazione degli appartenenti al personale direttivo non ha durata limitata. L'ufficiale puo' essere esonerato, in tempo di pace, dagli impegni assunti verso l'Associazione, dietro presentazione, per via gerarchica, di una domanda di dimissioni, nella quale e' indicato il motivo delle dimissioni stesse. Egli e' libero dal vincolo d'arruolamento tre mesi dopo la data di presentazione dell'istanza al centro di mobilitazione cui e' iscritto, che ne rilascia ricevuta all'interessato.

2. La presidenza nazionale, se esigenze del momento lo richiedono, ha facolta' di sospendere l'accettazione delle dimissioni di cui al comma 1.

3. In tempo di mobilitazione parziale o totale non possono accettarsi domande di dimissioni per nessun motivo.

4. I centri di mobilitazione, per i necessari controlli e per comprovare la regolarita' della permanenza nei ruoli del personale direttivo, richiedono, in seguito a disposizione del comitato centrale, o anche direttamente quando vi e' qualche dubbio sulla condotta morale di appartenenti al personale direttivo, le informazioni di cui all'articolo 976, comma 4 del regolamento.

#### Art. 1659. - Durata dell'arruolamento del personale di assistenza

1. La durata dell'arruolamento nella Croce rossa italiana per il personale di assistenza e' di due anni, a far data dal 1° gennaio successivo al giorno in cui e' stato firmato il brevetto di nomina.

2. Coloro che, arruolandosi nel primo semestre dell'anno, non desiderano assumere un obbligo superiore ai due anni, possono ottenere che la ferma decorra dal 1° gennaio dell'anno nel quale contraggono l'arruolamento.

3. Scaduto il primo biennio di arruolamento, la ferma e' rinnovata previa visita medica e previo consenso da parte della presidenza del comitato e dell'interessato, il quale, in ogni caso, sottoscrive un nuovo atto di arruolamento (rafferma) per altri due anni, e cosi' di seguito.

4. Il presidente nazionale, se esigenze del servizio lo richiedono, ha facolta' di sospendere temporaneamente la scadenza della ferma.

5. In tempo di mobilitazione parziale o totale, la scadenza della ferma resta sospesa, per tutti gli arruolati, fino al termine della mobilitazione stessa.

6. Nessun iscritto puo' essere sciolto, per qualsiasi motivo, dai vincoli assunti, prima dello scadere della ferma, salvo il disposto dell'articolo 1667.

7. I centri di mobilitazione, allo scadere delle singole ferme, hanno cura d'invitare gli interessati a rinnovarle, se si tratta di iscritti che ritengono meritevoli di rafferma.

8. Periodicamente e, in ogni modo, prima di procedere alla rafferma, i comitati assumono le informazioni di cui all'articolo 976, comma 4 del regolamento.

9. Se necessario, i comitati sottopongono a visita medica il personale da raffermare.

#### Art. 1660. - Dipendenti di pubbliche amministrazioni

1. I dipendenti di pubbliche amministrazioni iscritti nei ruoli del personale della Croce rossa italiana, se prestano servizio con consenso della propria amministrazione, che deve essere dato per iscritto, anche se non hanno obblighi militari, in caso di guerra o di grave crisi internazionale, si considerano a ogni effetto come in congedo e se, sempre col consenso della propria amministrazione, prestano servizio in tempo di pace in circostanze temporanee di pubblica necessita', usufruiscono del medesimo trattamento prescritto per i richiamati alle armi per servizio temporaneo.

2. Al personale della Croce rossa italiana chiamato comunque in servizio in tempo di pace in circostanze temporanee di necessita' pubblica e per istruzioni, le pubbliche amministrazioni e le aziende private sono obbligati a conservare l'impiego, ai sensi dell'articolo 990.

3. Le chiamate si effettuano mediante precetti appositi, da presentarsi dagli interessati ai rispettivi datori di lavoro pubblici o privati.

#### Art. 1661. - Transito nel ruolo di riserva

1. Il personale direttivo iscritto nel ruolo normale transita d'ufficio dal ruolo mobile al ruolo di riserva, conservando il grado e l'anzianita', e puo' essere impiegato per i servizi territoriali, quando raggiunge i limiti di eta' indicati nella seguente tabella:

- a) maggior generale (medico o commissario): anni 65;
- b) colonnello (medico o commissario): anni 65;
- c) tenente colonnello (medico o commissario): anni 65;
- d) maggiore (medico, chimico-farmacista, commissario): anni 63;
- e) cappellano capo della Croce rossa italiana: anni 65;
- f) capitano (medico, chimico-farmacista, commissario, contabile): anni 60;
- g) cappellano della Croce rossa italiana: anni 65;
- h) tenente (medico, chimico-farmacista, commissario, contabile): anni 58;
- i) sottotenente (medico, chimico-farmacista, commissario, contabile): anni 58.

#### Art. 1662. - Non idoneita' al servizio del personale direttivo

1. Il personale direttivo, ruolo normale, che non e' piu' riconosciuto idoneo al servizio delle unita' mobili, e' trasferito nei ruoli di riserva, conservando il grado e l'anzianita', ed e' impiegato per i servizi territoriali, anche prima di raggiungere il limite di eta' stabilito dall'articolo 1661, conservando l'idoneita' richiesta per tali servizi.

2. La non idoneita' deve risultare, oltre che dalle note caratteristiche, anche da motivati rapporti dei comandanti e degli ispettori delle unita', muniti del parere del presidente del comitato. La non idoneita' per ragioni fisiche e' dichiarata in seguito a parere di un collegio medico.

3. Per il passaggio nel ruolo di riserva per motivi indipendenti dall'eta', pronuncia il parere la commissione centrale del personale di cui all'articolo 1641.

4. La decisione definitiva relativa ai passaggi di ruolo spetta al presidente nazionale.

5. Coloro che non sono giudicati idonei per i servizi territoriali sia per motivi fisici, sia per inidoneita' alle funzioni del grado, sono cancellati dai ruoli, a norma dell'articolo 1667 .

#### Art. 1663. - Transito nel ruolo degli indisponibili

1. Gli appartenenti al personale direttivo dell'Associazione, iscritti tanto nel ruolo normale (mobile e riserva) quanto nel ruolo speciale, che sono dichiarati indisponibili per effetto delle disposizioni sulla dispensa dai richiami alle armi per mobilitazione o sono dispensati dalle chiamate alle armi, sono trasferiti, dalla data della concessione, conservando il loro grado e la loro anzianita', nel ruolo degli indisponibili.

2. Sono trasferiti nel ruolo degli indisponibili gli ufficiali non aventi obblighi militari i quali, dopo il loro arruolamento nell'Associazione, hanno assunto impieghi che, per gli aventi obblighi militari, importano l'indisponibilita' per effetto delle disposizioni sulla dispensa dai richiami alle armi per mobilitazione.

3. Il provvedimento di trasferimento nel ruolo degli indisponibili e' definitivo.

#### Art. 1664. - Collocamento fuori quadro

1. Se vengono meno i motivi che hanno provocato il trasferimento nel ruolo degli indisponibili, di cui all'articolo 1663, i provenienti dal ruolo normale mobile sono collocati fuori quadro, applicando loro le disposizioni degli articoli 1718, 1722 e 1723. Il collocamento fuori quadro e' subordinato alla inesistenza di vacanze nel ruolo normale-mobile del quale i gia' indisponibili tornano a far parte.

2. I provenienti invece dal ruolo normale di riserva e dal ruolo speciale sono trasferiti direttamente nel rispettivo ruolo di provenienza, seguendovi l'ultimo iscritto di pari grado e anzianita'.

#### Art. 1665. - Transito dal ruolo speciale al ruolo normale

1. Gli appartenenti al personale direttivo iscritti nel ruolo speciale possono concorrere all'iscrizione nel ruolo normale-mobile, previo passaggio nel ruolo dei fuori quadro, subordinatamente alle limitazioni e alle condizioni stabilite per detto arruolamento dalle disposizioni della sezione II del presente capo. In caso di iscrizione conservano grado e anzianita'. Non si effettua il passaggio nel ruolo fuori quadro quando vi sono corrispondenti vacanze nell'organico.

2. Gli appartenenti al personale di assistenza del ruolo speciale possono concorrere, subordinatamente alle limitazioni e alle condizioni di cui alle disposizioni della sezione II del presente capo, all'iscrizione nel personale di assistenza del ruolo normale, nel limite di un terzo dei posti annualmente disponibili in ciascun grado.

#### Art. 1666. - Cessazione dal ruolo di riserva

1. Gli iscritti nel ruolo di riserva cessano di appartenervi al compimento del settantottesimo anno di eta' per il grado di maggior generale, del settantatreesimo anno di eta' se ufficiali superiori medici o farmacisti, del settantesimo anno di eta' se ufficiali superiori amministrativi e del sessantottesimo anno di eta' se ufficiali inferiori, conservando a titolo di onore il proprio grado e l'uso dell'uniforme.

2. Gli iscritti al personale di assistenza, raggiunto il cinquantottesimo anno di eta', possono essere impiegati per i servizi territoriali. Gli stessi cessano di appartenere al personale dell'Associazione, al compimento del sessantottesimo anno di eta'.

#### Art. 1667. - Perdita del grado

1. Gli appartenenti al personale della Croce rossa italiana perdono il grado, oltre che per le cause indicate dall'articolo 861, anche per una delle cause seguenti:

- a) per non aver risposto, senza giustificato motivo, alle chiamate in servizio;
- b) per riforma, su verbale di apposito collegio medico, accettato dall'interessato, che ha diritto a una visita collegiale di appello presso la commissione superiore medica di controllo del comitato centrale, la cui decisione e' definitiva. Alla riforma del personale si fa luogo quando l'iscritto e' riconosciuto non idoneo ai servizi territoriali. Sulla riforma si pronuncia sempre una commissione superiore medica di controllo;
- c) per cancellazione dai ruoli per motivi disciplinari, previo conforme parere della commissione di disciplina;
- d) per il personale di assistenza che ha conseguito l'iscrizione nel personale direttivo.

2. La perdita del grado per gli appartenenti al personale direttivo e' effettuata con decreto del Ministro della difesa, in seguito a designazione fattagli dal presidente nazionale dell'associazione.

3. Per gli appartenenti al personale di assistenza, la detta sanzione e' adottata con provvedimento del presidente nazionale dell'associazione.

4. Si applicano, in quanto compatibili, le disposizioni della sezione III del capo I del titolo V del libro IV.

### SEZIONE VII - OBBLIGHI DI SERVIZIO

#### Art. 1668. - Chiamate in servizio

1. Le chiamate in servizio del personale militare della Croce rossa italiana sono effettuate mediante precetti rilasciati dai centri di mobilitazione o dagli altri comitati a cio' autorizzati, previe disposizioni del comitato centrale o del centro di mobilitazione, il quale a sua volta riceve l'ordine direttamente dal comitato centrale.

2. In nessun caso si puo' precettare personale senza l'autorizzazione di cui al comma 1.

3. E' fatta eccezione per il personale facente parte delle squadre di pronto soccorso, comprese le squadre di riserva, mobilitato per prestazioni di soccorso in caso di gravi disastri o calamita' pubbliche; per questi casi, in conformita' alle norme impartite dalla presidenza nazionale dell'associazione, i comitati hanno l'obbligo di intervenire immediatamente.

4. Nelle circostanze di cui al comma 3, il personale presentatosi si intende mobilitato con precetto: esso assume quindi senz'altro la qualita' di militare in servizio attivo e i comitati preparano tempestivamente i precetti di chiamata per la consegna, che puo' effettuarsi anche dopo la presentazione in servizio degli interessati.

#### Art. 1669. - Mobilitazione urgente

1. Nel caso di mobilitazione urgente, di cui all'articolo 1668, i comitati informano immediatamente il comitato centrale (ufficio personale) e il centro di mobilitazione della effettuata mobilitazione di personale, inviando a essi l'elenco nominativo del personale precettato.

2. I centri di mobilitazione provvedono a completare l'elenco di cui al comma 1 con i dati matricolari relativi e ne trasmettono al piu' presto una nuova copia completata al comitato centrale, ufficio personale.

### SEZIONE VIII - DISCIPLINA

#### Art. 1670. - Speciali obblighi disciplinari

1. Il personale militare della Croce rossa italiana, oltre alla normativa disciplinare contemplata per tutti i militari dal titolo VIII del libro IV e dal titolo VIII del libro IV del regolamento, osserva gli speciali obblighi disciplinari indicati nel regolamento.

#### Art. 1671. - Sospensione dal grado

1. Al personale del Corpo militare della Croce rossa italiana puo' essere inflitta la sospensione dal grado.

2. L'anzianita' del militare sospeso dal grado e' ridotta di un periodo di tempo uguale a quello della durata della sospensione.

3. La sospensione dal grado e' inflitta in seguito a designazione del presidente nazionale dell'Associazione.

4. Si applicano, in quanto compatibili, le disposizioni sulla sospensione dall'impiego di cui alla sezione IV del capo II del titolo V del libro IV.

#### Art. 1672. - Commissione di disciplina per il personale in servizio

1. Se si verifica la necessita' di convocare una commissione di disciplina per giudicare un ufficiale o un sottufficiale della Croce rossa italiana chiamato in servizio, si applicano, in quanto compatibili, le disposizioni di cui al capo IV del titolo VIII del libro IV.

2. Le disposizioni di cui al comma 1 si applicano anche se, durante l'inchiesta disciplinare, l'ufficiale o il sottufficiale inquisito e' stato inviato in congedo e anche se gli addebiti nei quali egli e' incorso durante il servizio militare, vengono a risultare dopo il suo invio in congedo.

3. Dopo i provvedimenti di competenza dell'autorita' militare, il Ministero della difesa trasmette gli atti del procedimento disciplinare compiuto, in comunicazione, alla presidenza nazionale della Croce rossa italiana, per la cancellazione dai ruoli dell'Associazione dell'ufficiale o del sottufficiale incorso nella perdita del grado.

#### Art. 1673. - Inchiesta disciplinare nei confronti del personale in congedo

1. Se un appartenente al personale della Croce rossa italiana in congedo si e' reso responsabile di atti presunti incompatibili con il suo grado o che, comunque, possono costituire mancanza punibile con la cancellazione dai ruoli, l'ente dell'Associazione da cui egli dipende provvede con sollecitudine agli accertamenti necessari e alla raccolta di tutti i dati ed elementi che e' possibile rintracciare e che valgono a determinare le circostanze del caso.

2. Il deferimento di un ufficiale della Croce rossa italiana in congedo al giudizio della commissione di disciplina e' rimesso alle decisioni del presidente nazionale dell'Associazione. Per il personale di assistenza in congedo l'ordine di deferimento a una commissione di disciplina e' emanato dal comandante del centro di mobilitazione.

#### Art. 1674. - Commissioni di disciplina per il personale in congedo

1. Allorche' si tratta di giudicare personale in congedo le commissioni di disciplina sono costituite come segue:

- a) per gli ufficiali, funziona da commissione di disciplina la commissione centrale del personale, composta a norma dell'articolo 977 del regolamento. In nessun caso puo' un ufficiale dell'Associazione, anche se membro della commissione, giudicare sulla condotta di altro ufficiale a lui superiore in grado o piu' anziano. Verificandosi tale circostanza si provvede alla sostituzione dei membri incompatibili da parte del presidente nazionale. La commissione puo' essere convocata soltanto dal presidente nazionale dell'Associazione;
- b) per il personale di assistenza, le commissioni di disciplina sono formate di volta in volta e convocate presso ogni centro di mobilitazione dal rispettivo comandante. Esse sono composte da: 1) un tenente colonnello o maggiore della Croce rossa italiana, presidente; 2) un capitano della Croce rossa italiana; un ufficiale subalterno della Croce rossa italiana, membri; il subalterno funge da segretario.

2. La commissione e' costituita con ufficiali comandati per turno di anzianita', tra i presenti alla sede del centro di mobilitazione, effettivi allo stesso.

3. Se gli ufficiali presenti non bastano a costituire la commissione, se ne riferisce al presidente nazionale dell'Associazione che designa, con provvedimento definitivo, ufficiali di un centro viciniore, nel numero necessario.

4. Gli ufficiali chiamati a far parte della commissione di disciplina non hanno diritto ad alcun compenso.

5. Quando per un medesimo fatto, o per piu' fatti connessi, sono sottoposti a commissione di disciplina piu' iscritti non in servizio, e' convocata un'unica commissione, dal comandante del centro di mobilitazione presso cui e' iscritto l'inquisito di grado piu' elevato o, a parita' di grado, piu' anziano.

#### Art. 1675. - Incompatibilita'

1. Non possono far parte della commissione centrale del personale, riunita in commissione di disciplina, o della commissione di disciplina di cui all'articolo 1674:

- a) persone che prestano servizio permanente presso il comitato centrale o il centro di mobilitazione, cui spetta di convocare la commissione;
- b) persone che sono tra loro parenti o affini sino al terzo grado incluso;
- c) l'offeso o il danneggiato e le persone che sono parenti o affini, fino al quarto grado incluso, con l'inquisito o con l'offeso o danneggiato;
- d) chiunque ha presentato rapporti o eseguito indagini sui fatti che hanno determinato il procedimento disciplinare, e chi per ufficio ha dato parere in merito;
- e) persone che, in qualsiasi modo, hanno avuto parte in un precedente giudizio penale o disciplinare per lo stesso fatto ovvero sono state sentite come testimoni nel giudizio disciplinare di cui trattasi.

#### Art. 1676. - Procedimento disciplinare di stato

1. Per quanto riguarda il funzionamento delle commissioni di disciplina di cui agli articoli 1672 e 1674 e il procedimento dinanzi alle stesse si applicano, in quanto compatibili, le disposizioni della sezione II del capo IV del titolo VIII del libro IV.

2. Il quesito da porsi in votazione e' cosi' formulato: <<Il ..................... (grado, categoria, cognome e nome dell'inquisito) e' meritevole di restare nei ruoli del personale della Croce rossa italiana?>>.

3. Il presidente nazionale dell'Associazione o il comandante del centro di mobilitazione, esaminati gli atti della commissione di disciplina, si assicura che nello svolgimento della procedura sono state osservate tutte le disposizioni regolamentari e decide con provvedimento definitivo. Egli puo' discostarsi dal parere della commissione soltanto a favore dell'inquisito.

4. Per la cancellazione dai ruoli degli appartenenti al personale della Croce rossa italiana e' applicato l'articolo 1667, commi 2 e 3.

### SEZIONE IX - DOCUMENTAZIONE PERSONALE

#### Art. 1677. - Ruoli matricolari

1. L'impianto, l'aggiornamento e la tenuta dei ruoli matricolari del personale militare della Croce rossa italiana da parte dei competenti comandi territoriali delle Forze armate sono stabiliti con decreto del Ministro della difesa.

#### Art. 1678. - Variazioni matricolari

1. I centri di mobilitazione della Croce rossa italiana comunicano ai competenti comandi militari territoriali delle Forze armate, indicati nel decreto del Ministro della difesa di cui all'articolo 1677, le variazioni matricolari che si riferiscono:

- a) alla chiamata in servizio di ciascun iscritto;
- b) a promozioni;
- c) a modificazioni dello stato giuridico;
- d) a liquidazione di pensione privilegiata di guerra;
- e) a eventi di carattere penale;
- f) ai ricollocamenti in congedo;
- g) a cancellazioni dai ruoli della Croce rossa italiana.

2. Nel regolamento sono riportate le disposizioni relative alle comunicazioni di carattere matricolare.

#### Art. 1679. - Variazioni matricolari del personale in servizio presso altri enti

1. Le variazioni matricolari relative ai singoli iscritti nel personale della Croce rossa italiana, destinati a prestare servizio presso le Forze armate o altri enti, sono comunicate, di volta in volta, dalle autorita' dalle quali essi dipendono ai competenti centri di mobilitazione.

2. I centri di mobilitazione provvedono alle eventuali ulteriori comunicazioni.

#### Art. 1680. - Servizio matricolare

1. L'Associazione italiana della Croce rossa italiana, per il proprio personale, impianta e tiene al corrente un servizio matricolare, con norme analoghe a quelle previste dal capo II del titolo VI del libro IV, da emanarsi a cura dalla presidenza nazionale.

2. I documenti matricolari servono a comprovare i servizi che ciascun iscritto, ufficiale, sottufficiale o militare di truppa del corpo, ha prestato, per tutti gli effetti di legge.

### SEZIONE X - DISPOSIZIONI GENERALI IN MATERIA DI AVANZAMENTO

#### Art. 1681. - Requisiti generali

1. Nessun iscritto nei ruoli del personale della Croce rossa italiana puo' conseguire l'avanzamento al grado superiore, se non e' riconosciuto pienamente idoneo ad adempierne le funzioni e in possesso, in modo spiccato, dei necessari requisiti di carattere, di intelligenza, di prestanza fisica e di cultura.

2. L'idoneita' a disimpegnare bene le funzioni del proprio grado e' condizione indispensabile, ma non sufficiente, per ottenere l'avanzamento al grado superiore.

#### Art. 1682. - Promozioni

1. L'avanzamento del personale della Croce rossa italiana ha luogo, con promozioni successive, da ciascun grado a quello immediatamente superiore, nella misura e con le norme di seguito indicate.

#### Art. 1683. - Nomina dell'ispettore nazionale del Corpo militare

1. L'ispettore nazionale del Corpo militare della Croce rossa italiana e' prescelto fra i colonnelli in servizio provenienti dal medesimo corpo ed e' nominato, con il contestuale conferimento del grado di maggiore generale, con decreto del Presidente della Repubblica, su proposta del Ministro della difesa, su designazione del presidente nazionale dell'Associazione.

### SEZIONE XI - AVANZAMENTO DEL PERSONALE DIRETTIVO

#### Art. 1684. - Modalita' di avanzamento

1. L'avanzamento del personale direttivo ha luogo ad anzianita', a scelta e a scelta per meriti eccezionali.

2. L'avanzamento ad anzianita' si effettua in tutti i gradi, salvo quanto previsto dall'articolo 1689, secondo l'ordine in cui gli ufficiali sono iscritti nei rispettivi ruoli, in relazione al numero dei posti vacanti nei ruoli stessi e in base al disposto degli articoli 1685, 1686 e 1688.

3. L'avanzamento a scelta si effettua, per le promozioni ai gradi previsti dall'articolo 1689, secondo l'ordine in cui gli ufficiali sono iscritti nei rispettivi ruoli, in relazione al numero dei posti vacanti nei ruoli stessi e in base al disposto degli articoli 1685, 1686 e 1688. E' concesso soltanto a quegli ufficiali che sono giudicati in possesso, in modo spiccato, di tutti i requisiti necessari per adempiere degnamente le funzioni del grado superiore.

4. Agli iscritti nel personale direttivo che hanno conseguito una promozione come ufficiali delle categorie in congedo delle Forze armate e del Corpo della Guardia di finanza, puo' essere conferito l'avanzamento al corrispondente grado nell'Associazione con la stessa anzianita' fissata nella promozione anzidetta, indipendentemente dal possesso o meno dei requisiti e titoli prescritti, per ciascun grado, dagli articoli 1685, comma 3 e 1689 e sempre con il concorso, in base alla normale procedura, del favorevole giudizio definitivo ai sensi dell'articolo 1692.

5. Agli ufficiali medici e farmacisti il comma 4 si applica solo se la promozione nelle Forze armate e nel Corpo della Guardia di finanza e' stata conseguita nei rispettivi corpi o ruoli sanitari.

6. Se l'anzianita' del grado rivestito dall'interessato nei ruoli dell'Associazione non e' compresa nei limiti di anzianita' stabiliti ai sensi del comma 8, l'ufficiale promosso ai sensi dei commi 4 e 5 e' collocato fuori quadro e il suo rientro nel ruolo di provenienza avviene secondo il disposto degli articoli 1722 e 1723.

7. L'avanzamento a scelta per meriti eccezionali si effettua nei casi e con la procedura di cui all'articolo 1693, promuovendo l'ufficiale, se compreso nel primo terzo del ruolo cui appartiene, con scavalcamento dei pari grado che lo precedono nel ruolo, in deroga a ogni altra prescrizione o limitazione stabilita nel presente titolo.

8. Nel mese di gennaio di ogni anno il presidente nazionale dell'Associazione, tenuto conto dell'organico generale e del numero dei posti resisi vacanti, determina, per le singole categorie del personale direttivo, i limiti di anzianita' entro i quali sono comprese, per ciascun grado, le proposte di avanzamento ad anzianita' e a scelta, e li comunica ai centri di mobilitazione. Nel computo dei posti disponibili si tiene presente il disposto degli articoli 1663 e 1665.

#### Art. 1685. - Profilo di carriera e periodi di permanenza minima nel grado

1. Le promozioni al grado superiore possono effettuarsi:

- a) fino al grado di colonnello per i medici;
- b) fino al grado di maggiore per i farmacisti;
- c) fino al grado di colonnello per i commissari;
- d) fino al grado di capitano per i contabili.

2. I capitani contabili, se posseggono tutti i requisiti richiesti per far parte del ruolo degli ufficiali commissari e se sono riconosciuti idonei per competenza e per qualita' tecniche e organizzative a ben disimpegnare le funzioni dell'ufficiale superiore commissario, possono essere proposti per l'avanzamento al grado di maggiore commissario. A loro e' riservato solo un quinto dei posti disponibili.

3. Per essere presi in esame agli effetti dell'avanzamento, i candidati devono avere una permanenza minima in ciascun grado cosi' stabilita:

- a) ad anzianita': 1) nel grado di sottotenente (medico, chimico farmacista, commissario, contabile): 4 anni; 2) nel grado di tenente (medico, chimico farmacista, commissario, contabile): 7 anni; 3) nel grado di capitano (medico, chimico farmacista): 7 anni; 4) nel grado di maggiore (medico): 4 anni;
- b) a scelta: 1) nel grado di capitano (commissario): 7 anni; 2) nel grado di maggiore (commissario): 4 anni; 3) nel grado di tenente colonnello (medico e commissario): 3 anni.

#### Art. 1686. - Giudizi di avanzamento

1. I giudizi per l'avanzamento sono dati su appositi specchi di proposta:

- a) da un componente del centro di mobilitazione, delegato al personale (giudizio di primo grado). Nel caso di candidati richiamati in servizio occorre il parere o la proposta del direttore dell'unita' o servizio;
- b) dalla commissione del personale del centro di mobilitazione di cui all'articolo 1691 (giudizio di secondo grado);
- c) dalla commissione centrale del personale di cui all'articolo 1641 (giudizio di terzo grado).

2. Gli specchi di proposta contengono la seguente formula, seguita dal giudizio sull'avanzamento:

- a) per l'avanzamento ad anzianita': "L'ufficiale possiede tutti i requisiti necessari per adempiere le funzioni del grado superiore?". Il giudizio si esprime con un si', o un no
- b) per l'avanzamento a scelta: "L'ufficiale possiede in modo spiccato tutti i requisiti necessari per adempiere degnamente le funzioni del grado superiore?". Il giudizio si esprime con un si', o con un no.

3. I suddetti giudizi sono seguiti dalle parole: "prescelto", oppure "non prescelto."

#### Art. 1687. - Impedimenti e sospensioni

1. Il giudizio sull'avanzamento e la promozione dell'ufficiale che e' gia' stato prescelto sono sospesi:

- a) quando, in seguito ad accertamenti sanitari, l'ufficiale risulta temporaneamente inabile al servizio di istituto. In tal caso il giudizio sull'avanzamento o la promozione non possono essere tenuti sospesi per piu' di tre anni consecutivi. Se permane l'inidoneita' oltre tale limite, l'ufficiale e' definitivamente dichiarato non promuovibile e inidoneo al servizio di istituto e proposto per la riforma.
- b) quando sono in corso accertamenti penali o disciplinari che possono comportare provvedimenti riguardanti lo stato dell'ufficiale.

2. Se l'esito del procedimento penale o disciplinare e' favorevole, l'ufficiale, previo nuovo giudizio d'avanzamento se gia' giudicato prescelto, e' promosso e gli e' assegnata la data e la sede di anzianita' che avrebbe conseguito qualora la promozione non fosse stata sospesa.

#### Art. 1688. - Elementi di giudizio

1. I requisiti richiesti per l'avanzamento sono desunti dagli stati di servizio, dalle note caratteristiche, dai rapporti informativi, dalle informazioni sulla condotta, competenza, cultura dell'ufficiale, che possono essere assunte dal centro di mobilitazione, e dai particolari titoli eventualmente prodotti dall'interessato.

2. Le autorita' giudicatrici dell'avanzamento, nel prendere in esame l'ufficiale si assicurano che:

- a) ha bene assolto, in caso di prestato servizio, le funzioni inerenti al suo grado;
- b) e' in possesso di tutti i requisiti fisici, morali, intellettuali, di carattere e di cultura, per adempiere degnamente alle funzioni del grado superiore;
- c) e' degno e meritevole di conseguire la promozione per la condotta tenuta.

#### Art. 1689. - Requisiti speciali per l'avanzamento

1. Per l'avanzamento a scelta al grado di colonnello medico, oltre alle condizioni di cui all'articolo 1688, e' necessario il possesso di almeno uno dei titoli seguenti:

- a) essere in possesso di dottorato di ricerca;
- b) essere o essere stato aiuto o assistente ordinario di cliniche o istituti scientifici universitari;
- c) essere dirigente responsabile di struttura sanitaria complessa o essere stato primario o aiuto di ospedale, regolarmente assunto mediante pubblico concorso;
- d) impiego di ruolo tecnico o sanitario presso le Amministrazioni pubbliche, a seguito di assunzione mediante pubblico concorso.

2. Per l'avanzamento a scelta degli ufficiali commissari ai gradi superiori a capitano, fino a quello di colonnello, oltre alle condizioni di cui all'articolo 1688, e' necessario il possesso di almeno uno dei seguenti titoli o requisiti:

- a) laurea in giurisprudenza, in economia e commercio, in scienze politiche o in ingegneria ((o equipollenti));
- b) incarico dirigenziale presso le Amministrazioni pubbliche;
- c) pubblicazioni amministrative, scientifiche, o altro, la cui importanza dimostra la preparazione dell'ufficiale a ricoprire il grado superiore;
- d) direttori di istituti bancari o dirigenti di aziende industriali o commerciali.

#### Art. 1690. - Formazione degli elenchi per l'avanzamento

1. I centri di mobilitazione, ricevuta la comunicazione presidenziale di cui all'articolo 1684, comma 8, e tenuto conto del termine stabilito dall'articolo 1692, compilano degli elenchi distinti per categorie e gradi iscrivendovi per ordine di anzianita', tutti gli ufficiali compresi nei fissati limiti di anzianita'.

2. Per coloro che non possono essere presi in esame, ne indicano il motivo nell'elenco. Per tutti gli altri intestano uno specchio singolo di proposta di avanzamento, raggruppando tali specchi in ciascun elenco.

3. Ogni specchio di proposta d'avanzamento e' corredato dei seguenti documenti:

- a) titoli accademici, di studio o di carriera;
- b) copia dello stato di servizio;
- c) copia delle note caratteristiche;
- d) ogni altro documento utile al giudizio da formularsi nei riguardi del candidato.

4. Gli elenchi, con i relativi specchi e documenti, sono poi consegnati al consigliere delegato al personale, cui spetta, a norma dell'articolo 1686, di formulare il giudizio di primo grado.

#### Art. 1691. - Commissione per il personale

1. In ogni centro di mobilitazione, il comandante convoca la commissione per il personale, la quale e' cosi' composta:

- a) presidente: il comandante del centro di mobilitazione;
- b) membri: due ufficiali superiori della Croce rossa italiana, uno medico e uno amministrativo.

2. I membri della Commissione rimangono in carica tre anni e possono essere riconfermati.

3. Il comandante puo' delegare a presiedere la commissione un membro del centro di mobilitazione, fatta eccezione del delegato al personale; in tal caso le deliberazioni della commissione hanno il visto e l'approvazione del comandante del centro di mobilitazione.

4. Il funzionario addetto all'ufficio personale e mobilitazione del centro funge da segretario, senza voto.

5. Il candidato, per essere prescelto dalle commissioni dei centri di mobilitazione, deve riportare la maggioranza dei voti. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1692. - Decisioni

1. Tutti gli specchi di avanzamento, unitamente ai documenti indicati nell'articolo 1690, sono trasmessi dai centri di mobilitazione al presidente nazionale dell'Associazione nel termine di un mese dalla data della comunicazione presidenziale indicata nell'articolo 1684, comma 8, accompagnati dagli elenchi distinti per categorie e gradi di cui all'articolo 1690.

2. Scaduto il termine sopra indicato, qualsiasi proposta di promozione non puo' essere formulata ed e' rinnovata in occasione delle successive promozioni.

3. Le proposte dei centri di mobilitazione sono sottoposte dal presidente nazionale dell'Associazione all'esame della commissione centrale del personale, di cui all'articolo 1641, la quale puo' richiedere tutti i documenti o chiarimenti che ritiene necessari e pronuncia sulle singole proposte il suo giudizio, da riportarsi sullo specchio di avanzamento.

4. Il candidato e' dichiarato <<prescelto>> per l'avanzamento se ha riportato a suo favore la maggioranza dei voti.

5. Il presidente nazionale dell'Associazione sanziona, o meno, i giudizi di avanzamento. Trasmette in ogni caso la pratica, corredata dei documenti di cui all'articolo 1690, al Ministero della difesa per la definitiva approvazione dei giudizi. Se i predetti giudizi non sono approvati, quello decisivo e definitivo spetta al Ministro della difesa.

6. Le promozioni sono effettuate con decreto ministeriale.

#### Art. 1693. - Avanzamento per meriti eccezionali

1. La promozione a scelta per meriti eccezionali puo' essere proposta, in qualunque momento dell'anno, soltanto a favore dell'ufficiale che, avendo dato accertata e indubbia prova di possedere eccezionali qualita' organizzative, direttive - tecniche e militari - ovvero specialissime benemerenze nel campo scientifico, unite a spiccate doti morali, intellettuali e di carattere, da' sicuro affidamento di poter esercitare in modo particolarmente distinto le funzioni del grado superiore.

2. La proposta di cui al comma 1 puo' essere promossa dall'autorita' dalla quale l'ufficiale dipende. A tale scopo detta autorita' illustra e documenta, in un'apposita relazione, gli eccezionali requisiti e benemerenze dell'ufficiale.

3. Le autorita' alle quali gerarchicamente spetta il giudizio, esprimono in merito il loro parere motivato.

4. Il presidente nazionale, con sua speciale relazione riassuntiva, inoltra al Ministro della difesa la proposta.

#### Art. 1694. - Non prescelti

1. Il giudizio di non prescelto per l'avanzamento e' comunicato all'interessato dal comandante del centro di mobilitazione cui appartiene, con le seguenti motivazioni:

- a) avanzamento ad anzianita': <<perche' l'ufficiale non possiede tutti i requisiti richiesti dal codice dell'ordinamento militare>>;
- b) avanzamento a scelta: <<perche' l'ufficiale non possiede in modo spiccato tutti i requisiti richiesti dal codice dell'ordinamento militare>>.

2. Per l'ufficiale <<non prescelto>> per l'avanzamento e' scritta nel libretto personale la seguente variazione: <<Non prescelto per l'avanzamento per l'anno 20.. (segue la motivazione)>>.

3. L'ufficiale <<non prescelto>> per ragioni indipendenti dalle condizioni fisiche, e' preso in esame una seconda volta se e' stato richiamato in servizio per un periodo continuativo non inferiore a un mese o ha conseguito nuovi titoli o benemerenze valutabili per l'avanzamento.

4. Se e' nuovamente giudicato non prescelto, e' escluso definitivamente dall'avanzamento.

#### Art. 1695. - Qualifica di primo capitano

1. I capitani che hanno raggiunto l'anzianita' stabilita per i capitani delle Forze armate assumono la qualifica di primo capitano.

2. Per il conferimento della suddetta qualifica sono applicate, in quanto compatibili, le disposizioni della sezione I del capo XVII del titolo VII del libro IV.

3. La qualifica di primo capitano e' conferita per determinazione del presidente dell'Associazione.

#### Art. 1696. - Nomina a sottotenente

1. Gli studenti, gia' iscritti nel personale di assistenza, in qualita' di sottufficiali, dopo aver conseguito i titoli di cui all'articolo 1643, 1644 e 1645, possono essere nominati sottotenenti, nei limiti dei posti disponibili e con precedenza sugli altri candidati.

#### Art. 1697. - Ruolo degli indisponibili

1. Il personale iscritto nel ruolo normale degli indisponibili, di cui all'articolo 1628 non puo' conseguire promozioni.

#### Art. 1698. - Ruolo speciale

1. Gli ufficiali iscritti nel ruolo speciale, di cui all'articolo 1627, possono essere promossi, con analoga procedura a quella stabilita per gli iscritti nel ruolo normale mobile, e nei limiti di seguito indicati, solo se sono stati promossi tutti i pari grado della stessa anzianita' del detto ruolo normale, non tenendosi conto dei dichiarati non prescelti per l'avanzamento.

2. Il numero delle vacanze utili per le promozioni di cui al comma 1 e' calcolato tenendo presente che per ogni cento ufficiali di ciascuna categoria del ruolo speciale, sessanta devono essere ((sottotenenti e tenenti)), trenta capitani e dieci ufficiali superiori (maggiori, tenenti colonnelli e colonnelli).

### SEZIONE XII - AVANZAMENTO DEL PERSONALE DI ASSISTENZA

#### Art. 1699. - Modalita' di avanzamento

1. Le promozioni nel personale di assistenza hanno luogo esclusivamente a scelta, in base ai requisiti di cui agli articoli seguenti e ai ruoli normali e speciali di cui all'articolo 1627, compilati per gradi e secondo l'ordine di anzianita'. Gli idonei sono promossi seguendo l'ordine d'iscrizione nei ruoli suddetti.

2. Gli iscritti al ruolo speciale sono promossi solo se sono stati promossi tutti i pari grado della stessa anzianita' del ruolo normale, non tenendosi conto dei dichiarati non idonei.

3. Il numero delle vacanze utili per le promozioni di cui al comma 1 e' calcolato tenendo presente che per ogni cento appartenenti al personale di assistenza del ruolo speciale, sessantacinque devono essere militi, venti caporali o caporali maggiori, dieci sergenti o sergenti maggiori, e cinque marescialli dei tre gradi.

#### Art. 1700. - Procedimento di avanzamento

1. Annualmente, dopo la firma degli atti di rafferma del personale di assistenza e prima dell'invio al comitato centrale dell'elenco del personale di cui all'articolo 983 del regolamento, entro il mese di marzo, i centri di mobilitazione procedono all'accertamento dei posti vacanti in ciascun ruolo organico e grado e compilano, su tale dato, un prospetto indicante il numero dei posti da coprire. I predetti centri determinano, per ciascun grado, il limite di anzianita' fino al quale si puo' estendere la scelta per le proposte di avanzamento, tenendo presenti le disposizioni stabilite nell'articolo 1701.

2. Non possono aver luogo promozioni nel personale di assistenza del ruolo normale se non vi sono posti vacanti nei ruoli organici dei singoli gradi.

3. E' applicabile anche al personale di assistenza il disposto dell'articolo 1687.

#### Art. 1701. - Anzianita' di grado richiesta per l'avanzamento

1. L'anzianita' minima prescritta per conseguire l'avanzamento a ciascun grado e' stabilita come segue:

- a) un anno dall'arruolamento per la promozione a caporale;
- b) un anno nel grado di caporale per la promozione a caporal maggiore;
- c) un anno nel grado di caporal maggiore per la promozione a sergente;
- d) due anni nel grado di sergente per la promozione a sergente maggiore;
- e) due anni nel grado di sergente maggiore per la promozione a maresciallo;
- f) due anni in ciascuno dei gradi di maresciallo (maresciallo ordinario e maresciallo capo) per la promozione al grado superiore.

#### Art. 1702. - Requisiti per l'avanzamento

1. Per essere dichiarato idoneo all'avanzamento il milite, graduato o sottufficiale deve essere riconosciuto pienamente capace di esercitare, in ogni circostanza, le funzioni del grado che deve ricoprire; pertanto, oltre a possedere la necessaria attitudine e prestanza fisica e in relazione al grado proposto, egli deve:

- a) aver tenuto buona condotta in servizio e in congedo;
- b) possedere i requisiti morali, di carattere e culturali necessari;
- c) possedere il prestigio per bene comandare e mantenere la disciplina di un reparto;
- d) aver perfetta conoscenza delle attribuzioni determinate dai regolamenti e istruzioni.

2. I requisiti di cui al comma 1 devono essere posseduti in modo piu' elevato per le promozioni a sottufficiale e, se si tratta dell'avanzamento al grado di maresciallo, essi risultano da una esplicita dichiarazione della commissione del personale del competente centro di mobilitazione.

3. Per la promozione al grado di maresciallo ordinario e le successive promozioni a maresciallo capo e maresciallo maggiore, i sergenti maggiori e marescialli devono inoltre avere prestato almeno un periodo di servizio e avere dimostrato, oltre al possesso dei requisiti sopra citati, anche capacita' tecnica per il disimpegno delle mansioni, specialmente amministrative, devolute al grado superiore.

#### Art. 1703. - Promozione a sottotenenti commissari o contabili

1. I marescialli maggiori che, non avendo i titoli previsti dagli articoli 1644 e 1645 per la nomina a ufficiali amministrativi, sono ritenuti meritevoli di avanzamento per speciali requisiti personali, sono proposti dai centri di mobilitazione, con la prescritta procedura, per la promozione a sottotenenti commissari o sottotenenti contabili quando si trovano nelle seguenti condizioni:

- a) hanno l'idoneita' fisica al grado di ufficiale;
- b) hanno complessivamente almeno cinque anni di anzianita' nei vari gradi di maresciallo o, comunque, due anni di anzianita' di maresciallo maggiore;
- c) hanno preso parte almeno a tre servizi importanti di mobilitazione;
- d) hanno riportato sempre la qualifica di ottimo nelle note caratteristiche e la esplicita attestazione in esse di particolare attitudine al servizio di amministrazione e di idoneita' alla promozione;
- e) hanno superato, con esito favorevole, l'esame davanti ad apposita commissione, prescritto dall'articolo 1705, per l'accertamento della cultura generale, istruzione militare e conoscenza dei regolamenti della Croce rossa italiana, indispensabili per ricoprire il grado di ufficiale.

#### Art. 1704. - Giudizi di avanzamento

1. I giudizi d'avanzamento in tempo di pace sono formulati dalle autorita' seguenti:

- a) per i militi e graduati di truppa: 1) dal capo dell'unita' o servizio (giudizio di 1° grado); 2) dal consigliere delegato al personale del centro di mobilitazione (giudizio di 2° grado); 3) dalla commissione del personale del centro di mobilitazione di cui all'articolo 1691 (giudizio di 3° grado e decisivo); 4) se si tratta di candidati in congedo, il giudizio di 1° grado e' formulato dal consigliere delegato al personale e quello di 2° grado dalla commissione del personale;
- b) per i sottufficiali: 1) dal consigliere delegato al personale del centro di mobilitazione, in seguito a parere o proposta del capo dell'unita' o servizio (giudizio di 1° grado); 2) dalla commissione del personale del centro di mobilitazione (giudizio di 2° grado); 3) dal presidente nazionale dell'Associazione (giudizio di 3° grado e decisivo).

2. Per le promozioni a maresciallo ordinario, capo e maggiore, il giudizio di 3° grado e' dato dalla commissione centrale del personale di cui all'articolo 1641 e quello decisivo dal presidente nazionale.

3. Per le promozioni dal grado di maresciallo maggiore a sottotenente, di cui all'articolo 1703, oltre al parere del presidente nazionale, occorrono l'approvazione e il giudizio decisivo del Ministro della difesa, in conformita' al disposto dell'articolo 1692.

4. La commissione del personale dei centri di mobilitazione e la commissione centrale deliberano sulla idoneita' all'avanzamento di ciascun proposto a maggioranza di voti.

5. Il giudizio sull'avanzamento e' sintetizzato in una delle due seguenti formule: <<idoneo>> o <<non idoneo>>.

6. Il giudizio di non idoneita' e' sempre motivato dall'autorita' giudicante, specificando in quale dei requisiti indicati dall'articolo 1702 l'interessato e' giudicato insufficiente.

7. Per il tempo di guerra provvede l'articolo 1713.

#### Art. 1705. - Esami ed esperimenti

1. I requisiti indicati all'articolo 1702, comma 1, lettere b), c) e d), sono accertati mediante brevi esami ed esperimenti teorico-pratici.

2. L'accertamento della cultura generale per i candidati, di cui all'articolo 1703, e' effettuato con apposito esame sulle materie che sono stabilite dal comitato centrale anche in base ai programmi che sono eventualmente stabiliti dal Ministero della difesa per gli aspiranti alla nomina a sottotenente di complemento delle Forze armate in analoghe condizioni.

3. Spetta al comandante del centro di mobilitazione disporre per gli esami ed esperimenti di cui al comma 1 e all'articolo 1703, comma 1, lettera e), secondo i predetti programmi e le norme che sono stabilite dal comitato centrale. Detti esami hanno luogo dinanzi ad apposita commissione di cinque membri, nominata dal comandante suddetto e composta di tre persone, anche estranee all'Associazione, che hanno competenza specifica nelle materie d'esame, e di due ufficiali della Croce rossa italiana, uno medico e uno amministrativo, di grado non inferiore a capitano.

#### Art. 1706. - Elementi di giudizio

1. Le autorita' giudicatrici per l'avanzamento esaminano, per ciascun candidato, se egli possiede i requisiti stabiliti dai precedenti articoli e prendono, altresi', in esame:

- a) le annotazioni risultanti dai documenti matricolari e le note caratteristiche;
- b) il risultato ottenuto negli esami di cultura generale e negli esperimenti teorico-pratici;
- c) le informazioni, che sono richieste al comandante della unita' ospedaliera o ufficio presso cui ha prestato servizio il candidato, in merito alla sua condotta, prestigio e attitudine pratica ai vari servizi.

#### Art. 1707. - Elenchi e specchi di avanzamento

1. Gli uffici personale e mobilitazione dei centri di mobilitazione, compilato il prospetto indicante il numero dei posti vacanti per ciascun grado e gli elenchi, divisi per gradi e ruoli, dei candidati all'avanzamento, sottopongono tali documenti, con le proposte o pareri dei direttori delle unita' o dei servizi, con lo stato di servizio, con le note caratteristiche e con i rapporti informativi, e per i sottufficiali con lo specchio di avanzamento, al delegato al personale.

2. I giudizi delle autorita' giudicatrici per gli avanzamenti a graduati di truppa sono segnati negli elenchi, a fianco di ciascun candidato; per i sottufficiali i giudizi sono formulati sugli specchi d'avanzamento.

#### Art. 1708. - Decisioni

1. Per i candidati che hanno riportato i prescritti giudizi favorevoli, in caso di avanzamento a graduato di truppa, il comandante del centro di mobilitazione provvede al rilascio del brevetto; se si tratta di avanzamento a sottufficiale, rimette le proposte con i relativi documenti al comitato centrale per la definitiva approvazione dei giudizi da parte del presidente nazionale.

#### Art. 1709. - Non idoneita' all'avanzamento

1. Il milite, graduato o sottufficiale, che per due volte consecutive e' giudicato "non idoneo", resta escluso in modo definitivo dall'avanzamento.

2. Sono, inoltre, esclusi dall'avanzamento i militi, graduati o sottufficiali che, chiamati in servizio per istruzione, per tre volte consecutive non si sono presentati, anche se la loro assenza e' stata causata da un giustificato motivo.

### SEZIONE XIII - AVANZAMENTO IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

#### Art. 1710. - Avanzamenti straordinari nel ruolo

1. Possono essere effettuati, in tutti i gradi del personale direttivo e di assistenza, avanzamenti straordinari nel ruolo per meriti eccezionali debitamente accertati, di iscritti che hanno dato un eccezionale contributo alla preparazione e allo svolgimento dei servizi dell'Associazione.

2. Per gli spostamenti straordinari di sede nei ruoli puo' derogarsi dai limiti di anzianita' e dalla permanenza minima nei gradi di cui agli articoli 1685, 1684 e 1701.

3. Nello stesso grado possono essere conseguiti anche piu' avanzamenti straordinari, per nuovi meriti eccezionali successivamente acquisiti.

#### Art. 1711. - Proposte di avanzamento straordinario nel ruolo

1. Le proposte di avanzamento straordinario nel ruolo per meriti eccezionali a favore di ufficiali sono formulate, con apposita relazione, dai delegati dell'Associazione presso le Forze armate, ovvero dai comandanti dei centri di mobilitazione, rispettivamente per il personale in servizio presso unita' o uffici alle proprie dipendenze.

2. Le proposte a favore di appartenenti al personale di assistenza sono formulate, con apposita relazione, dal capo dell'unita' o servizio.

3. Le relazioni di cui ai commi 1 e 2 accompagnano i giudizi formulati dalle autorita' prescritte dall'articolo 1704.

#### Art. 1712. - Avanzamento straordinario di ruolo

1. L'avanzamento straordinario di ruolo per meriti eccezionali e' concesso con spostamento di sede dell'iscritto interessato nel ruolo, per un numero di posti pari a un terzo del ruolo del grado cui l'iscritto medesimo appartiene, calcolato per gli ufficiali secondo il disposto dell'articolo 1721.

2. Se, nell'effettuare detto spostamento, si entra nel ruolo del grado superiore, l'iscritto e' subito promosso; se non esiste vacanza e' promosso fuori quadro a norma degli articoli 1717 e 1721, se ufficiale, ovvero in soprannumero se appartiene al personale di assistenza.

#### Art. 1713. - Giudizi di avanzamento

1. I giudizi d'avanzamento sono formulati, per il personale chiamato in servizio, dalle autorita' seguenti:

- a) per gli ufficiali addetti a unita' o servizi dell'Associazione: 1) dal delegato dell'Associazione presso le Forze armate ovvero dall'ufficiale superiore preposto all'ispezione dell'unita', rispettivamente per il personale alle proprie dipendenze. Nei comitati, nella cui circoscrizione non funzioni un ispettore delle unita', dal consigliere delegato al personale (giudizio di 1° grado). Il giudizio e' provocato da una proposta del capo dell'unita' o servizio; 2) dal comandante del centro di mobilitazione, in sostituzione del giudizio della commissione del personale del centro stesso (giudizio di 2° grado); 3) dalla commissione centrale del personale (giudizio di 3° grado). Dopo tale giudizio si segue la procedura stabilita per le normali promozioni del tempo di pace;
- b) per gli ufficiali comandati presso le Forze armate dello Stato: 1) dall'autorita' militare preposta all'unita' o servizio (giudizio di 1° grado); 2) dalle autorita' dell'Associazione di cui alle lettera a), numeri 2) e 3);
- c) per i sottufficiali addetti a unita' o servizi dell'Associazione: 1) dalle autorita' di cui alla lettera a), numero 1) (giudizio di 1° grado); 2) dall'autorita' di cui alla lettera a), numero 2) (giudizio di 2° grado); 3) dal presidente nazionale dell'associazione (giudizio di 3° grado e decisivo). Per le promozioni ai gradi di maresciallo e sottotenente si applica l'articolo 1704, commi 2 e 3;
- d) per i militi e graduati di truppa addetti a unita' e servizi dell'Associazione: 1) dal capo dell'unita' o servizio (giudizio di 1° grado); 2) dalle autorita' di cui alla lettera a), numero 1) (giudizio di 2° grado); 3) dall'autorita' di cui alla lettera a), numero 2) (giudizio di 3° grado e decisivo);
- e) per il personale d'assistenza comandato presso le Forze armate dello Stato: 1) dall'autorita' militare preposta all'unita' o servizio (giudizio di 1° grado); 2) dall'autorita' dell'Associazione di cui alla lettera a), numero 1) per i militi e graduati di truppa e alla lettera a), numero 2) per i sottufficiali (giudizio di 2° grado); 3) dall'autorita' di cui alla lettera a), numero 2) per i militi e graduati di truppa; e di cui alla lettera c), numero 3) per i sottufficiali (giudizio di 3° grado e decisivo).

2. Per il personale non chiamato in servizio si segue la procedura ordinaria prescritta per il tempo di pace.

#### Art. 1714. - Procedimento di avanzamento

1. In occasione delle promozioni normali annue del personale direttivo e di assistenza, di cui rispettivamente agli articoli 1684 e 1699, gli uffici personale e mobilitazione dei centri di mobilitazione segnalano i candidati compresi nei fissati limiti di anzianita' alle autorita' competenti, per emettere il giudizio di primo grado a norma dell'articolo 1713 e trasmettono a dette autorita' gli specchi, elenchi e documenti previsti dall'articolo 1707.

2. Le autorita' che intendono formulare proposte di avanzamenti straordinari di ruolo per meriti eccezionali, chiedono preventivamente al competente centro di mobilitazione informazioni sulla sede di anzianita' dell'interessato nel ruolo e sulle pratiche conseguenze che la eventuale proposta avrebbe per l'interessato medesimo.

#### Art. 1715. - Disposizioni speciali

1. Agli ufficiali dell'Associazione eventualmente prigionieri di guerra o dispersi, sono applicate, in quanto compatibili, le disposizioni della sezione III del capo XVIII del titolo VII del libro IV.

2. Nel caso di sopraggiunta inabilita' fisica in servizio e per cause di servizio di guerra, sono applicate per analogia le disposizioni dell'articolo 1335.

### SEZIONE XIV - UFFICIALI FUORI QUADRO ((...))

#### Art. 1716. - Servizio presso le Forze armate o altri enti

1. Gli ufficiali della Croce rossa italiana, chiamati in servizio e comandati in tempo di pace o di mobilitazione a prestare servizio presso comandi, uffici o unita' delle Forze armate dello Stato o alle dipendenze della sanita' pubblica, sono collocati fuori quadro rispettivamente all'organico prescritto dall'articolo 1642. Essi sono presi in forza e amministrati dai comandi, uffici e unita' presso i quali sono stati comandati.

#### Art. 1717. - Altre ipotesi di fuori quadro

1. E' altresi' collocato fuori quadro il personale direttivo, che risulta eventualmente in eccedenza all'atto della prima applicazione dell'organico, di cui al predetto articolo 1642.

2. E' inoltre collocato fuori quadro, se non vi sono corrispondenti vacanze in organico, il personale direttivo del ruolo speciale che, subordinatamente alle limitazioni e alle condizioni di cui alle disposizioni della sezione II del presente capo, ha ottenuto l'autorizzazione per l'iscrizione nel ruolo normale.

3. E' collocato fuori quadro, a norma degli articoli 1684 e 1712, il personale direttivo che ha conseguito l'avanzamento ad anzianita' o a scelta, per effetto di promozione ottenuta come ufficiale in congedo delle Forze armate, ovvero l'avanzamento straordinario per meriti eccezionali, e ricorrono le circostanze previste rispettivamente nei menzionati articoli.

#### Art. 1718. - Transito nell'elenco dei fuori quadro

1. Fino a quando vi sono ufficiali fuori quadro ai sensi degli articoli precedenti, gli iscritti nel ruolo degli indisponibili, per i quali e' revocata la dispensa loro concessa, anziche' essere trasferiti direttamente nel ruolo normale-mobile transitano nell'elenco dei fuori quadro, seguendovi pero' l'ultimo iscritto di pari grado e anzianita'.

#### Art. 1719. - Elenco dei fuori quadro

1. Tutto il personale direttivo collocato fuori quadro e' iscritto in un unico elenco distinto per categorie e gradi, seguendo l'ordine dell'anzianita' di grado gia' posseduta o acquistata per promozione da ciascun ufficiale, salvo, per i provenienti dal ruolo degli indisponibili, il disposto dell'articolo 1718.

#### Art. 1720. - Avanzamento

1. L'avanzamento ad anzianita' o a scelta dell'ufficiale collocato fuori quadro ha luogo quando e' promosso al grado superiore un pari grado che lo segue nel ruolo normale. I provenienti dal ruolo degli indisponibili possono essere promossi soltanto se e' stato promosso l'ultimo iscritto nel ruolo normale, di pari grado e anzianita', dichiarato <<prescelto>>.

#### Art. 1721. - Norme applicabili per gli avanzamenti del personale fuori quadro

1. Per le promozioni ad anzianita', a scelta e per meriti eccezionali degli ufficiali fuori quadro, si applicano gli articoli 1684 e seguenti salvo, in tempo di guerra, il disposto degli articoli 1713 e 1714.

2. Per gli avanzamenti straordinari nel ruolo per meriti eccezionali del personale suddetto, in tempo di guerra o di grave crisi internazionale, l'aliquota di un terzo dei posti stabilita dall'articolo 1712 si calcola su un ruolo unico, il quale contiene ((gli iscritti nel ruolo normale e i fuori quadro)), che ricoprono il grado dell'interessato. Questi assume l'anzianita' del pari grado che, a spostamento effettuato, lo precede nel detto ruolo unico. In caso di promozione al grado superiore assume l'anzianita' che gli compete secondo le norme comuni.

#### Art. 1722. - Posti vacanti da assegnare agli ufficiali fuori quadro

1. Fino a quando vi sono ufficiali fuori quadro, la meta' dei posti resisi vacanti e devoluti all'avanzamento nei ruoli normali per ciascun grado (e in caso di numero dispari, la meta' piu' uno), e' destinata al loro ritorno nei ruoli suddetti. Tale trasferimento e' effettuato nel gennaio di ogni anno allorche' si procede a quanto dispone l'articolo 1684, comma 8.

2. La restante parte e' destinata agli avanzamenti normali.

#### Art. 1723. - Rientro nel ruolo normale

1. Il ritorno degli ufficiali fuori quadro nel ruolo normale avviene seguendo l'ordine di anzianita' di ciascun iscritto, il quale riprende la sede di anzianita' gia' eventualmente posseduta nel ruolo stesso, eccezione fatta per coloro che provengono dal ruolo degli indisponibili i quali rientrano nel ruolo normale-mobile, seguendovi l'ultimo iscritto di pari grado e anzianita' ai sensi dell'articolo 1664.

#### Art. 1724.

((ARTICOLO ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248))

#### Art. 1725.

((ARTICOLO ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248))

### SEZIONE XV - PRECETTAZIONI IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

#### Art. 1726. - Precettazioni e assegnazioni

1. Se, in tempo di guerra o di grave crisi internazionale, il numero di personale avente obblighi di leva e di chiamata alle armi che la Croce rossa italiana puo' arruolare nel ruolo normale, a norma dell'articolo 1632, non e' raggiunto con arruolamenti volontari, il Ministero della difesa puo' disporre la precettazione e l'assegnazione d'autorita' alla Croce rossa italiana - su sua segnalazione nominativa - di cittadini aventi obblighi militari di eta' dal 50° al 55° anno, escluso: ((a) il personale del servizio sanitario di cui agli articoli 208 e 209;)) b) il personale di sussistenza; c) coloro che sono stati ammessi a provvedimenti di esenzione dai richiami alle armi per mobilitazione; d) coloro che hanno una particolare destinazione di mobilitazione.

#### Art. 1727. - Accertamenti sanitari

1. Per gli eventuali accertamenti sanitari nei riguardi dei precettati per l'assegnazione d'autorita' alla Croce rossa italiana, valgono le stesse disposizioni in vigore per il personale delle Forze armate, precettato per mobilitazione.

#### Art. 1728. - Elenco transitorio

1. I precettati e assegnati ai centri di mobilitazione delle Croce rossa italiana ai sensi della presente sezione sono iscritti d'autorita' nel personale militare dei centri medesimi in apposito <<elenco transitorio>> valevole fino alla cessazione dello stato di guerra o di grave crisi internazionale e sono soggetti a tutte le norme che regolano il personale appartenente al ruolo normale dell'Associazione. Conseguentemente i comandi militari territoriali competenti annotano la relativa variazione sui documenti matricolari e nei fascicoli della forza in congedo degli interessati.

## CAPO II - PERSONALE DEL CORPO DELLE INFERMIERE VOLONTARIE

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 1729. - Generalita'

1. Le appartenenti al Corpo delle infermiere volontarie della Croce rossa italiana sono assimilate di rango al personale militare direttivo contemplato dall'articolo 1626.

#### Art. 1730. - Compiti delle infermiere volontarie

1. Le infermiere volontarie sono destinate a prestare servizio di assistenza e conforto agli infermi, in tutti i casi nei quali l'Associazione della Croce rossa italiana esplica la propria attivita', e particolarmente:

- a) nelle unita' sanitarie territoriali e mobili della Croce rossa italiana o delle Forze armate dello Stato;
- b) nella difesa civile e sanitaria delle popolazioni;
- c) nei soccorsi alle popolazioni in caso di epidemie e pubbliche calamita';
- d) in occasione di particolari prestazioni di assistenza della Croce rossa italiana a carattere temporaneo ed eccezionale;
- e) in occasione di tutte le azioni che nel campo igienico-sanitario e assistenziale in genere, nella profilassi delle malattie infettive, nell'assistenza sanitaria e nella educazione igienica a favore delle popolazioni, sono intraprese dalla Croce rossa italiana o da altri enti assistenziali ai quali la Croce rossa italiana presta il proprio concorso.

#### Art. 1731. - Servizio

1. Il servizio prestato dalle infermiere volontarie della Croce rossa italiana e' gratuito.

### SEZIONE II - ORDINAMENTO E NOMINE

#### Art. 1732. - Gerarchia

1. La gerarchia dei gradi del corpo infermerie volontarie della Croce rossa italiana e' la seguente:

- a) Ispettrice nazionale.
- b) Vice-ispettrice nazionale.
- c) Segretaria generale dell'ispettorato.
- d) ispettrice di centro di mobilitazione.
- e) vice-ispettrice di centro di mobilitazione.
- f) ispettrice di comitato.
- g) vice-ispettrice di comitato.
- h) infermiera volontaria.
- i) allieva infermiera volontaria.

#### Art. 1733. - Nomina dell'Ispettrice nazionale

1. L'ispettrice nazionale del Corpo delle infermiere volontarie e' nominata con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro della difesa e del Ministro della salute, nell'ambito di una terna di nomi indicata dal presidente nazionale della Croce rossa italiana.

2. L'ispettrice nazionale e' scelta tra le infermiere volontarie che hanno i requisiti di specifica preparazione tecnica e attitudini al comando, dura in carica quattro anni ed e' confermabile per non piu' di una volta consecutivamente.

#### Art. 1734. - Ufficio direttivo centrale

1. L'Ufficio direttivo centrale del Corpo delle infermiere volontarie, istituito presso l'ispettrice nazionale:

- a) collabora nell'emanazione delle disposizioni e delle direttive dell'ispettrice e ne esegue gli ordini;
- b) provvede per l'inquadramento, per il governo, per la disciplina e mobilitazione delle appartenenti al corpo;
- c) tiene aggiornati i ruoli attivo e di riserva, gli stati di servizio e le note caratteristiche delle singole infermiere.

2. L'Ufficio direttivo e' organo di collegamento con gli uffici del comitato centrale dell'Associazione, cui e' devoluta l'amministrazione del corpo e il suo impiego secondo le disposizioni delle competenti autorita' superiori.

3. L'Ufficio direttivo centrale e' diretto da una segretaria generale dell'Ispettorato.

4. Per il servizio d'ordine e d'archivio dell'ufficio vi e' adibito il numero di subalterne ritenuto necessario.

#### Art. 1735. - Provvedimenti di nomina e di cessazione delle appartenenti al Corpo

1. L'ispettrice nazionale per delegazione del presidente nazionale dell'Associazione:

- a) nomina le vice-ispettrici nazionali e la segretaria generale dell'Ispettorato, preposta all'Ufficio direttivo centrale;
- b) nomina le ispettrici di centro di mobilitazione;
- c) nomina su proposta delle ispettrici dei centri di mobilitazione le ispettrici di comitato, le vice-ispettrici, le infermiere di grado superiore e le infermiere volontarie;
- d) dispone, con provvedimento definitivo, la cessazione dalla carica delle ispettrici e vice-ispettrici anche prima della scadenza del termine previsto dal comma 2.

2. Le vice-ispettrici nazionali, la segretaria generale dell'ispettorato, le ispettrici di centro di mobilitazione, le ispettrici di comitato e le vice-ispettrici sono scelte tra le infermiere volontarie che hanno i requisiti di specifica preparazione tecnica e attitudini al comando, durano in carica quattro anni e possono essere confermate per non piu' di una volta consecutivamente --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1736. - Qualifiche di grado superiore

1. La qualifica di infermiera di grado superiore e' conferita a quelle infermiere volontarie che hanno dato prova di particolare capacita' e abnegazione, o che hanno prestato lodevole servizio in condizione di eccezionali difficolta' o che per dieci anni consecutivi hanno appartenuto al ruolo attivo, e hanno riportato nelle note caratteristiche la classifica di <<merito eccezionale>> o di <<ottima>>.

2. Le infermiere che sono nominate, ai sensi dell'articolo 1735, vice-ispettrici nazionali, segretaria generale dell'Ispettorato, ispettrici di centro di mobilitazione, ispettrici di comitato o vice-ispettrici, acquistano la qualifica di infermiera di grado superiore e la conservano al termine delle funzioni a cui sono state chiamate.

3. Fuori del caso previsto nel comma 2, le infermiere di grado superiore non esercitano funzioni diverse dalle altre infermiere volontarie, se non sono nominate capo-gruppo o capo-sala in base al regolamento.

#### Art. 1737. - Nomina delle infermiere volontarie

1. Possono essere nominate infermiere volontarie le socie della Croce rossa italiana che ne fanno domanda al comitato nella cui circoscrizione hanno la propria residenza e che:

- a) essendo state ammesse a frequentare i corsi di preparazione di cui all'articolo 1740 a tale scopo istituiti dalla Croce rossa italiana e avendoli frequentati, hanno superato i relativi esami;
- b) essendo munite del titolo di infermiera, conseguito in conformita' alle norme vigenti, relativamente all'esercizio delle professioni sanitarie, sono riconosciute idonee al servizio della Croce rossa italiana a giudizio definitivo dell'ispettrice nazionale.

2. L'ispettrice nazionale puo' decidere, in base alla valutazione del titolo, che l'aspirante deve essere invitata a sostenere, presso la commissione dei corsi, un esame di integrazione, specie per quanto riguarda il pronto soccorso ai feriti di guerra. In tal caso la domanda ha corso soltanto se l'aspirante supera il detto esame.

3. In tutti i casi, l'accoglimento o meno della domanda e' rimesso alla decisione definitiva dell'ispettrice nazionale.

4. La nomina dell'infermiera volontaria ha luogo mediante provvedimento emanato dall'ispettrice nazionale e di concerto con il presidente nazionale dell'Associazione.

5. Il relativo diploma e' rilasciato a cura dell'Ufficio direttivo centrale e reca le firme dell'ispettrice nazionale e del presidente nazionale.

6. Il diploma e' accompagnato dal distintivo e dalla tessera di cui agli articoli 1011 e 1022 del regolamento e importa il versamento della tassa di cui all'articolo 1744; il personale in possesso del diploma, equivalente all'attestato di qualifica di operatore socio-sanitario specializzato, esclusivamente nell'ambito dei servizi resi, nell'assolvimento dei compiti propri delle Forze armate e della Croce rossa italiana, e' abilitato a prestare servizio di emergenza e assistenza sanitaria con le funzioni e attivita' proprie della professione infermieristica. ((Il diploma, nel possesso dei requisiti richiesti e nel rispetto dell'ordinamento universitario, consente l'accesso ai corsi di laurea in infermieristica con il riconoscimento dei relativi crediti formativi acquisiti.))

#### Art. 1738. - Iscrizione nei ruoli

1. All'atto della consegna del diploma l'infermiera volontaria dichiara per iscritto se desidera essere iscritta nel ruolo di riserva o nel ruolo attivo.

2. In quest'ultimo caso si impegna a tenersi pronta a prestare servizio per un mese ogni anno in tempo di pace, per almeno un biennio. E' in facolta' dell'infermiera di aggiungere a tale impegno quello di tenersi pronta a partire entro ventiquattro ore dalla chiamata in servizio.

3. Le infermiere volontarie sono iscritte nel ruolo attivo o nel ruolo di riserva, a seconda della dichiarazione da loro fatta a norma del comma 1.

4. Scaduto l'impegno di arruolamento biennale assunto con la dichiarazione di cui al comma 1, sono iscritte nel ruolo di riserva se non rinnovano l'impegno stesso.

5. L'attribuzione della qualifica di infermiera di grado superiore non implica cessazione ne' modifica dell'impegno di arruolamento.

6. Le infermiere volontarie iscritte nel ruolo attivo che non prestano regolarmente servizio sono trasferite di ufficio, dalla ispettrice del comitato, nel ruolo di riserva; cio' indipendentemente dai provvedimenti disciplinari di cui possono essere oggetto. Del provvedimento e' subito informata l'ispettrice del centro di mobilitazione, che a sua volta ne informa l'ufficio centrale.

7. Le infermiere volontarie iscritte nel ruolo di riserva possono essere trasferite, a domanda, nel ruolo attivo, se assumono l'impegno di prestare servizio per un mese ogni anno, almeno per un biennio.

#### Art. 1739. - Cancellazione dai ruoli

1. Indipendentemente dalla radiazione prevista dagli articoli 1747 e 1749, l'infermiera volontaria e' cancellata dai ruoli nei casi seguenti:

- a) dimissioni volontarie, presentate per via gerarchica con domanda motivata diretta all'ispettrice nazionale e accettate dall'Ufficio direttivo centrale. Le dimissioni non sono accettate in tempo di mobilitazione totale o parziale; decorrono, se l'infermiera e' iscritta nel ruolo attivo, dalla scadenza dell'impegno di arruolamento. L'accettazione delle dimissioni puo' essere sospesa se esigenze del momento lo richiedono;
- b) interdizione, inabilitazione, amministrazione di sostegno o irreperibilita', accertate dall'ispettrice di centro di mobilitazione competente, che ne informa l'Ufficio direttivo centrale;
- c) riforma, su verbale di apposito collegio medico, riunito presso il centro di mobilitazione; verbale comunicato all'Ufficio direttivo centrale e accettato dall'interessata, che ha diritto a una visita collegiale d'appello di carattere definitivo, presso l'Ufficio direttivo centrale. La riforma puo' aver luogo soltanto se l'interessata e' stata riconosciuta non idonea neppure a mansioni ausiliarie o sedentarie;
- d) perdita della cittadinanza italiana, accertata dall'ispettrice di centro di mobilitazione, che ne informa l'Ufficio direttivo centrale;
- e) perdita della qualita' di socia della Croce rossa italiana a termini dello statuto dell'Associazione. Di tale perdita la presidenza nazionale dell'Associazione informa l'Ufficio direttivo centrale;
- f) cessazione volontaria della qualita' di socia della Croce rossa italiana.

### SEZIONE III - FORMAZIONE

#### Art. 1740. - Partecipazione ai corsi di preparazione

1. Possono essere ammesse ai corsi di studio per preparazione a infermiere volontarie le socie della Croce rossa italiana che, dichiarando di aver preso conoscenza delle disposizioni del presente capo e di quelle del capo II del titolo III del libro V del regolamento:

- a) ne fanno domanda al comitato nella cui circoscrizione hanno la propria residenza e presso il quale i corsi sono istituiti;
- b) hanno compiuto il ((18°)) anno di eta' e non hanno superato il 55°.

2. Alla domanda sono uniti i documenti elencati nel decreto del Ministro della salute, di concerto con il Ministro della difesa, di cui all'articolo 1743, comma 7.

3. Il termine per la presentazione delle domande per l'ammissione ai corsi per le infermiere volontarie scade il 30 novembre di ogni anno.

4. Entro il medesimo termine l'allieva infermiera che intende seguire il secondo corso provvede al versamento, nella cassa del comitato, della tassa d'iscrizione per il secondo anno.

#### Art. 1741. - Ammissione ai corsi di preparazione

1. Per le ammissioni ai corsi di preparazione sono costituite apposite commissioni di amministrazione, disciplinate dall'articolo 1003 del regolamento.

2. La commissione di amministrazione dei corsi, esaminati gli atti e assunte opportune informazioni sulla condotta morale e civile dell'aspirante, accoglie o respinge la domanda.

3. Se la respinge, l'aspirante ha facolta' di ricorrere al presidente nazionale dell'Associazione, che decide in via definitiva, sentita l'ispettrice nazionale.

4. Se la domanda e' respinta, l'importo della tassa scolastica versato e' restituito all'interessata.

5. La restituzione ha luogo se l'interessata, per ragioni gravi indipendenti dalla sua volonta', non puo' frequentare oltre la meta' del primo anno dei corsi.

#### Art. 1742. - Durata e superamento dei corsi di preparazione

1. L'insegnamento ha la durata di due anni ed e' ripartito in due corsi distinti, ciascuno della durata di un anno; alla fine del primo anno le allieve infermiere sostengono un esame: se promosse, sono ammesse a seguire l'insegnamento del secondo anno ed e' loro rilasciato un apposito certificato.

2. Alla fine del secondo anno le allieve infermiere sostengono l'esame definitivo: se promosse sono ammesse a presentare la domanda per nomina a infermiera volontaria.

3. Non sono ammesse agli esami le allieve che durante l'anno:

- a) hanno riportato note caratteristiche sfavorevoli;
- b) sono state assenti a piu' di un quarto delle lezioni teoriche
- c) non hanno compiuto nel biennio le ore di tirocinio previste dai programmi dei corsi di studio per le Infermiere volontarie della Croce rossa italiana.

4. Le allieve che impiegano piu' di due anni a conseguire il diploma, devono compiere altre trenta presenze pratiche ((di quattro ore ciascuna)) oltre alle prescritte.

#### Art. 1743. - Svolgimento dei corsi di preparazione

1. I corsi di istruzione teorica e pratica sono impartiti negli istituti sanitari della Croce rossa italiana, negli ospedali civili, negli ospedali militari e negli ambulatori.

2. In ciascun corso la parte didattica, che si svolge in un semestre, e' integrata da esercitazioni pratiche.

3. Alla fine del primo corso hanno luogo gli esami davanti una commissione composta da un delegato tecnico del comitato centrale della Croce rossa italiana, che presiede, dal direttore, da due insegnanti dei corsi e dalla ispettrice.

4. Della commissione degli esami di diploma fanno parte, oltre i precedenti commissari, anche il rappresentante del Ministero della salute, che presiede, nonche' un rappresentante della sanita' militare.

5. La votazione alla fine del primo corso e' effettuata in cinquantesimi, e ogni commissario puo' assegnare fino a dieci decimi. Sono promosse le candidate che hanno riportato una votazione media di almeno trentacinque cinquantesimi.

6. Per gli esami di diploma la votazione e' effettuata in settantesimi e ogni commissario puo' assegnare fino a 10 decimi. Sono promosse le candidate che hanno riportato una votazione media di almeno 49 settantesimi.

7. I programmi dei corsi di studio per la preparazione delle infermiere volontarie sono stabiliti con decreto del Ministero della salute, di concerto con il Ministero della difesa, su proposta dall'ispettrice nazionale d'intesa con il presidente nazionale della Croce rossa italiana.

#### Art. 1744. - Tassa di iscrizione

1. Per essere ammesse a ciascun corso le aspiranti devono versare una tassa d'iscrizione, stabilita dalla presidenza nazionale dell'Associazione.

2. Per il rilascio del diploma d'infermiera volontaria deve essere versata una tassa di diploma, stabilita dalla predetta presidenza.

3. Le tasse d'iscrizione al primo e al secondo anno sono conteggiate dal comitato in un capitolo speciale del suo bilancio; del capitolo e' reso conto ogni anno al comitato centrale della Croce rossa italiana.

4. Il provento delle tasse d'iscrizione costituisce un fondo speciale che la commissione d'amministrazione, su proposta del direttore dei corsi, devolve alla gestione dei corsi stessi, sia per far fronte alle spese necessarie per il loro esercizio, sia eventualmente, se si verifica un avanzo, per formare una riserva destinata a futuri bisogni.

5. Le tasse di diploma sono versate al comitato centrale della Croce rossa italiana.

#### Art. 1745. - Corsi di specializzazione

1. Oltre ai corsi di studio di cui agli articoli precedenti possono essere istituiti presso i comitati della Croce rossa italiana, con le stesse norme, anche corsi di specializzazione nei seguenti rami dell'assistenza infermieristica:

- a) tecnica di laboratorio con particolare riguardo alla tubercolosi e alla malaria;
- b) radioterapia e radiodiagnostica;
- c) ginnastica medica, ortopedia e terapia fisica;
- d) assistenza in sala operatoria: quest'ultimo corso prevalentemente di carattere pratico.

2. I corsi di specializzazione hanno ciascuno la durata di un semestre.

3. Sono ammesse ai corsi le infermiere volontarie gia' nominate che:

- a) ne fanno domanda al comitato presso il quale essi sono istituiti, versando la relativa tassa d'iscrizione;
- b) sono giudicate idonee dalla commissione d'amministrazione dei corsi;
- c) hanno conseguito il diploma d'infermiera volontaria, con votazione di almeno quarantotto sessantesimi.

4. Nel regolamento sono stabilite le disposizioni di attuazione del presente articolo.

### SEZIONE IV - DISCIPLINA

#### Art. 1746. - Incompatibilita' funzionali

1. Le infermiere volontarie esercitano le funzioni di infermiera solo a servizio della Croce rossa italiana.

2. L'infrazione al comma 1 e' aggravata dal fatto che l'infermiera:

- a) ha prestato l'opera propria in uniforme della Croce rossa italiana;
- b) ha accettato una retribuzione per l'opera prestata.

#### Art. 1747. - Sanzioni disciplinari

1. I provvedimenti disciplinari sono i seguenti:

- a) il rimprovero;
- b) la censura, cioe' il rimprovero inflitto con nota scritta che e' inserita nel fascicolo personale dell'infermiera;
- c) la sospensione dal servizio per un tempo non inferiore a due mesi e non superiore a dodici, inflitta con provvedimento scritto che e' inserito nel fascicolo personale dell'infermiera;
- d) la radiazione dai ruoli delle infermiere volontarie.

2. Le sanzioni disciplinari conseguono alle mancanze commesse in violazione dei doveri contemplati dal presente capo e dal capo II del titolo III del libro V del regolamento.

3. I provvedimenti disciplinari superiori al rimprovero sono presi tenuto conto delle particolari circostanze con le quali l'infrazione e' stata commessa, o del fatto che l'infrazione ricorre con carattere di recidivita'.

4. La radiazione dai ruoli e' pronunciata in caso di assoluta incompatibilita' del contegno dell'infermiera con i doveri e con il decoro inerenti alla sua qualita'.

5. Nessun provvedimento disciplinare puo' essere preso senza contestare l'infrazione all'interessata e senza aver acquisito e valutato le sue giustificazioni.

#### Art. 1748. - Potesta' sanzionatoria

1. Il rimprovero puo' essere inflitto da ogni superiore gerarchico.

2. La censura e' inflitta dall'ispettrice competente ai sensi dell'articolo 1016 del regolamento, su proposta della superiore immediata.

3. Contro i provvedimenti di cui ai commi 1 e 2 l'infermiera interessata puo' ricorrere all'ispettrice nazionale, la cui decisione e' definitiva.

4. La sospensione puo' essere inflitta solo dall'ispettrice nazionale, con decisione definitiva presa su proposta motivata dalla ispettrice competente.

5. La radiazione dai ruoli e' disposta dall'ispettrice nazionale di concerto con il presidente nazionale dell'Associazione, su proposta motivata dell'ispettrice competente, e dietro parere conforme di una commissione di disciplina che ha giudicato l'infermiera inquisita non meritevole di restare nei ruoli del personale della Croce rossa italiana.

#### Art. 1749. - Commissione di disciplina

1. La commissione di disciplina di cui all'articolo 1748 e' nominata di volta in volta dall'ispettrice nazionale e convocata presso l'Ufficio direttivo centrale.

2. La commissione e' composta da una vice-ispettrice nazionale, presidente, da due ufficiali medici superiori della Croce rossa italiana e da una ispettrice (infermiera di grado superiore) segretaria.

3. Per la costituzione e il funzionamento della commissione si osservano, in quanto applicabili, le disposizioni del capo IV del titolo VIII del libro IV.

#### Art. 1750. - Procedimento disciplinare

1. Le mancanze in servizio rilevate dai capi di reparto o dal personale direttivo dell'unita' sanitaria dove l'infermiera presta servizio, sono oggetto di un rapporto del direttore dell'unita' all'ispettrice o alla capo-gruppo che, a sua volta, espletate le indagini necessarie, provvede, informandone l'ispettrice competente ovvero, se occorre, sottomette a questa il caso.

2. La capo-gruppo da' partecipazione al direttore dell'unita' del proprio provvedimento o di quello dell'ispettrice.

### SEZIONE V - DOCUMENTAZIONE PERSONALE

#### Art. 1751. - Stato di servizio

1. Lo stato di servizio di ciascuna infermiera volontaria indica con precisione tutte le attivita' precedenti e susseguenti alla nomina a infermiera, i dati relativi alla cultura generale e specifica i titoli di studio, i diplomi, le benemerenze, le ricompense, le campagne e quanto altro possa permettere la esatta valutazione della capacita' e delle possibilita' di impiego dell'infermiera.

2. Nello stato di servizio e' annotato ogni cambiamento di residenza e di stato civile.

3. Lo stato di servizio e' redatto dall'ispettrice del comitato da cui l'infermiera volontaria dipende ai sensi dell'articolo 1016 del regolamento; un esemplare e' trasmesso all'Ufficio direttivo centrale per il tramite dell'ispettrice del centro di mobilitazione.

4. L'ispettrice comunica per il tramite dell'ispettorato del centro all'Ufficio direttivo centrale qualsiasi variazione effettuata nello stato di servizio.

#### Art. 1752. - Note caratteristiche

1. Le note caratteristiche sono redatte su modello stabilito dalla presidenza nazionale - Ufficio direttivo centrale del Corpo, in analogia a quanto previsto per il personale del Corpo militare:

- a) ogni tre anni per le infermiere di ruolo attivo;
- b) al termine di ogni servizio mobilitato, per le infermiere di ambedue i ruoli.

2. Le note sono compilate e firmate dall'ispettrice da cui l'infermiera dipende a norma dell'articolo 1016 del regolamento. Se compilate da una ispettrice di comitato sono trasmesse all'ispettrice del centro di mobilitazione, che le controfirma annotandole eventualmente con gli altri elementi a sua cognizione. Di tutte inoltra una copia all'Ufficio direttivo centrale.

3. Le note caratteristiche delle allieve sono ugualmente redatte dall'ispettrice al termine di ogni anno scolastico con le stesse modalita'.

4. Nel caso previsto dall'articolo 1016, comma 3 del regolamento le note sono compilate a seconda delle necessita', in duplice o in triplice copia, dalla capo-gruppo e trasmesse all'Ufficio direttivo centrale, che ne inoltra un esemplare alle ispettrici competenti. Le note delle capo-gruppo sono, nel caso medesimo, compilate dall'ispettrice nazionale.

5. Le note caratteristiche:

- a) pongono in evidenza le prove date dall'infermiera o dall'allieva di operosita', diligenza, capacita', iniziativa, la sua condotta, le sue qualita' morali;
- b) compendiano i giudizi espressi in una delle seguenti qualifiche complessive: insufficiente - mediocre - buona - ottima - di merito eccezionale.

### SEZIONE VI - DISPOSIZIONI FINALI

#### Art. 1753. - Chiamate in servizio

1. La chiamata delle infermiere volontarie iscritte nel ruolo attivo per il periodo annuale di servizio ordinario o per servizio locale di rappresentanza, ha luogo con provvedimento dell'ispettrice del comitato dal quale dipende l'infermiera volontaria.

2. Il servizio ordinario del periodo annuale e' prestato dall'infermiera volontaria, per quanto possibile, nel comune ove essa ha la propria residenza, o nel piu' vicino comune del medesimo centro di mobilitazione in cui trovasi una unita' sanitaria appropriata.

3. Se il comune piu' vicino e' situato fuori dell'ambito di competenza territoriale del comitato, l'ispettrice provoca il provvedimento di chiamata da parte dell'ispettrice del centro di mobilitazione.

4. Se occorre chiamare infermiere volontarie in servizio di guerra o di grave crisi internazionale, o in servizio straordinario in tempo di pace, si da' la precedenza a quelle che sono iscritte nel ruolo attivo.

5. La chiamata delle infermiere volontarie in servizio straordinario in tempo di pace o in servizio di guerra o di grave crisi internazionale ha luogo con provvedimento dell'ispettrice nazionale, emanato per delega del presidente nazionale dell'Associazione, e notificato all'interessata dall'ispettrice da cui dipende.

6. Nelle chiamate in servizio straordinario in tempo di pace si da' la precedenza alle infermiere volontarie che hanno la propria residenza piu' vicina al luogo ove il servizio e' prestato.

#### Art. 1754. - Servizio presso enti diversi

1. Le infermiere volontarie non possono prestare servizio di assistenza sanitaria, igienica o sociale, anche temporanea, presso enti diversi dalla Croce rossa italiana, e tanto meno essere iscritte nelle liste di tali enti, senza autorizzazione dell'ispettrice nazionale.

2. L'autorizzazione di cui al comma 1 cessa di avere effetto quando le infermiere volontarie sono chiamate in servizio dalla Croce rossa italiana in tempo di pace, in tempo di guerra o di grave crisi internazionale.

#### Art. 1755. - Assistenza sanitaria

1. Le infermiere volontarie che si ammalano durante il servizio hanno diritto all'assistenza medica e farmaceutica delle unita' sanitarie o formazioni speciali presso le quali prestano servizio.

#### Art. 1756. - Normativa applicabile

1. Sono applicabili alle infermiere della Croce rossa italiana le disposizioni dell'articolo 990.

## CAPO III - TRATTAMENTO ECONOMICO

### SEZIONE I - PERSONALE DEL CORPO MILITARE

#### Art. 1757. - Trattamento economico del personale del Corpo militare della Croce rossa italiana

1. In tempo di pace, il personale direttivo e di assistenza del Corpo militare della Croce rossa italiana, se richiamato dal congedo a norma dell'articolo 1668, riceve il trattamento economico stabilito per le forze di completamento dall'articolo 1799.

2. Per il tempo di guerra o di grave crisi internazionale, il trattamento economico del personale di cui al comma 1 e' equiparato a quello del personale delle Forze armate.

3. Il personale di cui al comma 1 assunto in servizio in tempo di pace negli stabilimenti o uffici dell'Associazione riceve le competenze stabilite dalla presidenza nazionale, in analogia a quanto praticato per il personale militare e delle amministrazioni statali.

### SEZIONE II - PERSONALE DEL CORPO DELLE INFERMIERE VOLONTARIE

#### Art. 1758. - Trattamento economico delle infermiere volontarie

1. Fermo restando il concetto della gratuita' delle prestazioni, le infermiere volontarie chiamate in servizio fuori del comune di residenza, ovvero obbligate, anche nel comune di residenza, ad alloggiare presso unita' sanitarie o formazioni speciali, fruiscono di vitto e alloggio a carico dell'Amministrazione, dell'unita' o della formazione.

2. In tempo di guerra o di grave crisi internazionale, le infermiere volontarie hanno diritto al trattamento economico di missione di cui al titolo IV, capo IV, sezione I del libro VI e, in tempo di pace, al rimborso delle spese di viaggio, per gli spostamenti dal luogo di residenza a quello di servizio e viceversa.

3. Mediante accordi annuali da stabilire con apposita convenzione tra il Ministero dell'economia e delle finanze e la presidenza nazionale della Croce rossa italiana, e' determinata una somma da versare dal Ministero suddetto all'Ispettorato del corpo infermiere volontarie a titolo di occorrenze speciali di equipaggiamento e per rimborso di altre spese vive.

## CAPO IV - TRATTAMENTO PREVIDENZIALE

### Art. 1759. - Valutazione del servizio prestato dal personale della Croce rossa italiana

1. Il servizio ((volontario)) prestato dal personale militare della Croce rossa italiana in tempo di pace non puo' essere in nessun caso valutato agli effetti di pensione come prestato allo Stato o ad altri enti pubblici.

2. Il servizio prestato dal personale di cui al comma 1 in tempo di guerra o di grave crisi internazionale, al seguito delle Forze armate dello Stato, e' considerato, a ogni effetto di pensione, come reso allo Stato.

3. Le ferite e le infermita' che sono state contratte per causa di servizio di guerra dal personale di cui al comma 1 conferiscono il diritto a pensione di guerra, ai sensi del decreto del Presidente della Repubblica 23 dicembre 1978, n. 915.

### Art. 1760. - Liquidazione delle pensioni per i servizi prestati in tempo di guerra o di grave crisi internazionale dal personale della Croce rossa italiana

1. Le pensioni normali correlate ai servizi prestati in tempo di guerra o di grave crisi internazionale dal personale militare della Croce rossa italiana sono liquidate secondo le disposizioni in vigore per il personale delle Forze armate.

## TITOLO V ASSOCIAZIONE DEI CAVALIERI ITALIANI DEL SOVRANO MILITARE ORDINE DI MALTA CAPO I PERSONALE MILITARE

### Art. 1761. - Cooperazione con i servizi sanitari

1. La cooperazione dell'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta ai servizi sanitari dello Stato e' stabilita da apposite convenzioni.

2. La facolta' di stipulare tali convenzioni con l'Associazione suddetta e' delegata ai Ministri competenti.

### Art. 1762. - Servizi in tempo di guerra o di grave crisi internazionale

1. Per il funzionamento dei suoi servizi in tempo di guerra o di grave crisi internazionale l'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta ha facolta' di arruolare personale volontario, esente da obblighi di leva e di chiamata alle armi e che non e' stato scelto dall'Amministrazione della difesa quale personale precettabile della mobilitazione civile ai sensi delle leggi di guerra.

2. Ove necessario, limitatamente al numero stabilito dal Ministero della difesa a seconda del bisogno, puo' arruolare personale dell'Esercito italiano avente obblighi di leva e chiamata alle armi, che ha raggiunto il quarantesimo anno di eta' o una eta' superiore.

### Art. 1763. - Servizi in tempo di pace

1. Per il funzionamento dei suoi servizi in tempo di pace l'associazione suddetta ha facolta' di arruolare personale volontario scelto tra i cittadini aventi anche obblighi militari.

2. In caso di chiamate alle armi indette dall'autorita' militare, gli aventi obblighi militari di cui al presente articolo devono sempre rispondere alla chiamata dell'autorita' stessa.

### Art. 1764. - Gradi gerarchici

1. La successione gerarchica dei gradi del personale dell'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta e' la seguente:

- a) generale direttore capo del personale;
- b) colonnello;
- c) tenente colonnello;
- d) maggiore;
- e) capitano;
- f) tenente;
- g) sottotenente;
- h) maresciallo maggiore;
- i) maresciallo capo;
- l) maresciallo ordinario;
- m) sergente maggiore;
- n) sergente;
- o) caporalmaggiore;
- p) caporale;
- q) milite.

2. Nel regolamento e' riportata la corrispondenza con i gradi delle Forze armate.

### Art. 1765. - Stato giuridico del personale

1. Gli iscritti nei ruoli dell'Associazione di cui agli articoli 1762 e 1763, compresi i cavalieri dell'ordine, chiamati in servizio, sono militari e come tali sottoposti alle norme della disciplina militare e della legge penale militare. Le chiamate in servizio sono effettuate dall'Associazione mediante precetti.

2. Ai mancanti alla chiamata disposta ai sensi del comma 1 sono applicate le disposizioni sancite per i militari delle Forze armate.

3. L'arruolamento da parte dell'Associazione dei dipendenti dalle amministrazioni dello Stato, comprese quelle aventi ordinamento autonomo, in tempo di pace, di guerra o di grave crisi internazionale, non puo' aver luogo senza il preventivo consenso dell'amministrazione di appartenenza.

### Art. 1766. - Convenzioni

1. Sono stabilite norme per disciplinare lo stato giuridico, il reclutamento, l'avanzamento, il trattamento economico e l'amministrazione del personale previsto dagli articoli precedenti, mediante apposita convenzione con l'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta.

2. La facolta' di stipulare la convenzione di cui al comma 1 con l'Associazione suddetta e' delegata al Ministro della difesa, di concerto col Ministro dell'economia e delle finanze.

### Art. 1767. - Qualifica di pubblico ufficiale

1. Gli iscritti al personale del sovrano militare Ordine di Malta, compresi i cavalieri dell'ordine, quando prestano servizio nella qualita' di appartenenti al personale stesso, sono considerati anche pubblici ufficiali.

### Art. 1768. - Limiti minimi di eta'

1. I limiti minimi di eta' perche' i cittadini soggetti a obblighi militari verso le Forze armate dello Stato possono concorrere all'arruolamento nel personale del ruolo <<normale>> dell'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta sono stabiliti come segue:

- a) 45 anni compiuti, per l'arruolamento nel personale direttivo (ufficiali);
- b) 31 anni compiuti, per l'arruolamento nel personale d'assistenza (sottufficiali e truppa).

## CAPO II - CORPO DELLE INFERMIERE VOLONTARIE

### Art. 1769. - Istituzione

1. E' istituito il <<Corpo delle infermiere volontarie dell'Associazione dei cavalieri italiani del sovrano militare Ordine di Malta>>.

2. Compito del Corpo e' quello di assicurare, in tempo di pace, di guerra o di grave crisi internazionale, il funzionamento dei servizi prestati dalla Associazione dei cavalieri italiani del sovrano militare Ordine di Malta in cooperazione con i servizi sanitari dello Stato.

### Art. 1770. - Reclutamento

1. Le infermiere volontarie sono reclutate fra il personale munito dei titoli richiesti e rilasciati dallo Stato.

### Art. 1771. - Servizio volontario

1. Il servizio prestato dalle infermiere volontarie e' gratuito.

## CAPO III - TRATTAMENTO ECONOMICO

### Art. 1772. - Trattamento economico degli associati

1. I dipendenti di una pubblica amministrazione, iscritti nei ruoli della Associazione dei cavalieri italiani del Sovrano militare ordine di Malta, se prestano servizio con il consenso della stessa, sia in tempo di pace, in circostanze temporanee di pubblica necessita', sia in caso di guerra o di grave crisi internazionale, usufruiscono del trattamento economico stabilito per le forze di completamento dall'articolo 1799.

2. I datori di lavoro privati sono obbligati ad assicurare la conservazione del posto di lavoro ai loro dipendenti appartenenti al personale dell'Associazione chiamati in servizio, sia in tempo di pace, in circostanze di pubblica necessita', sia in caso di guerra o di grave crisi internazionale.

## CAPO IV - TRATTAMENTO PREVIDENZIALE

### SEZIONE I - PERSONALE MILITARE

#### Art. 1773. - Valutazione del servizio prestato nell'Associazione dei cavalieri italiani del sovrano militare ordine di Malta

1. Il servizio prestato dal personale militare dell'Associazione dei cavalieri italiani del sovrano militare ordine di Malta, in tempo di pace, non puo' essere in nessun caso valutato agli effetti di pensione come prestato allo Stato o ad altri enti pubblici.

2. Il servizio prestato dal personale di cui al comma 1 in tempo di guerra o di grave crisi internazionale, al seguito delle Forze armate dello Stato, e' considerato, a ogni effetto di pensione, come reso allo Stato.

3. Le ferite e le infermita' contratte per causa di servizio di guerra dal personale di cui al comma 1 conferiscono il diritto a pensione di guerra, ai sensi del decreto del Presidente della Repubblica 23 dicembre 1978, n. 915.

#### Art. 1774. - Liquidazione delle pensioni per i servizi prestati in tempo di guerra nell'Associazione dei cavalieri italiani del sovrano militare ordine di Malta

1. Le pensioni normali correlate ai servizi prestati in tempo di guerra o di grave crisi internazionale dal personale militare dell'Associazione dei cavalieri italiani del sovrano militare ordine di Malta, sono liquidate secondo le disposizioni in vigore per il personale delle Forze armate.

### SEZIONE II - CORPO DELLE INFERMIERE VOLONTARIE

#### Art. 1775. - Servizio in tempo di guerra delle infermiere dell'Associazione dei cavalieri italiani del sovrano militare ordine di Malta

1. Le ferite e le infermita' contratte per causa di servizio di guerra dalle infermiere volontarie dell'Associazione dei cavalieri italiani del sovrano militare ordine di Malta conferiscono il diritto a pensione di guerra, ai sensi del decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, reversibile alle loro famiglie se da tali ferite, lesioni o infermita' deriva la morte. A tal fine, le infermiere volontarie sono equiparate al grado di sottotenente.

## LIBRO SESTO TRATTAMENTO ECONOMICO, ASSISTENZA E BENESSERE TITOLO I DISPOSIZIONI GENERALI

### Art. 1776. - Ambito soggettivo di applicazione

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applicano le disposizioni contenute nel presente libro.

### Art. 1777. - Rapporti con l'ordinamento generale del lavoro alle dipendenze delle amministrazioni pubbliche

1. Ferma restando, in quanto compatibile, la disciplina generale in materia di trattamento economico ((e di assegno per il nucleo familiare)) dei dipendenti pubblici prevista dalle disposizioni vigenti, al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applicano le disposizioni emanate a seguito delle procedure di concertazione previste dal decreto legislativo 12 maggio 1995, n. 195, nonche' le norme del presente libro che hanno efficacia ai soli fini del trattamento economico.((Al medesimo personale si applicano le disposizioni di cui all'articolo 2, comma 91, della legge 24 dicembre 2007, n. 244, che pongono a carico delle amministrazioni utilizzatrici gli oneri del trattamento economico fondamentale e accessorio del personale in posizione di comando appartenente alle Forze di polizia e al Corpo nazionale dei vigili del fuoco.))

### Art. 1778. - Assenze per malattia

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, si applicano le disposizioni di cui all'art. 71, commi 1 e 1-bis, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133.

### Art. 1779. - Attribuzione del trattamento economico

1. Il trattamento stipendiale al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e' attribuito con decreto dirigenziale agli ufficiali e con determinazione dirigenziale ai sottufficiali e ai graduati in servizio permanente.

### Art. 1780. - Principio di irreversibilita' stipendiale

1. In caso di passaggio a qualifiche o gradi di ruoli diversi dell'Amministrazione militare o di transito dai ruoli civili, senza soluzione di continuita', se gli emolumenti fissi e continuativi in godimento sono superiori a quelli spettanti nella nuova posizione, e' attribuito un assegno personale pari alla differenza, riassorbibile, salvo diversa previsione di legge, con i futuri incrementi stipendiali conseguenti a progressione di carriera o per effetto di disposizioni normative a carattere generale.

### Art. 1781. - Computo dell'anzianita' di grado

1. L'anzianita' di grado e' quella risultante dal decreto di nomina o di promozione, secondo quanto disposto dall'articolo 856.

2. Per i militari transitati di ruolo, l'anzianita' di grado e' computata, agli effetti della determinazione dello stipendio, dalla data di nomina o di promozione al grado stesso nel ruolo di provenienza, con le deduzioni di cui all'articolo 858.

3. Per i sottufficiali e i graduati in servizio permanente, l'anzianita' di grado e' computata secondo le disposizioni che regolano l'anzianita' stessa ai fini dell'avanzamento.

### Art. 1782. - Computo dell'anzianita' di servizio

1. L'anzianita' di servizio da ufficiale decorre dalla data del decreto di nomina, se nel decreto stesso non e' fissata una decorrenza diversa.

2. Per i sottufficiali e i graduati in servizio permanente, l'anzianita' di servizio decorre dalla data di immissione nei rispettivi ruoli, disposta con decreto ministeriale.

### Art. 1783. - Computo del servizio anteriormente prestato

1. Il servizio militare prestato anteriormente alla nomina a ufficiale, sottufficiale e graduato in servizio permanente, e' computato per intero, agli effetti della determinazione dello stipendio, in base all'anzianita' di servizio; agli stessi effetti, sono computati gli anni corrispondenti alla durata legale del corso di studi universitari, in favore degli ufficiali per la nomina dei quali e' richiesta una laurea o titolo equipollente ((se non coincidenti con il servizio militare)).

## TITOLO II PERSONALE DI LEVA

### Art. 1784. - Ripristino del servizio obbligatorio di leva

1. Le disposizioni del presente titolo si applicano al ripristino della coscrizione obbligatoria, in attuazione dell'articolo 1929.

### Art. 1785. - Trattamento economico dei militari in servizio obbligatorio di leva presso le Forze armate

1. Ai militari in servizio obbligatorio di leva presso le Forze armate compete il trattamento economico che sara' determinato dal Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, in caso di ripristino della coscrizione obbligatoria.

### Art. 1786. - Trattamento economico degli ufficiali di complemento

1. Al personale militare che adempie gli obblighi di leva nella posizione di ufficiale di complemento compete il trattamento economico determinato con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, in caso di ripristino della coscrizione obbligatoria.

2. Agli ufficiali di complemento, anche se transitati in servizio permanente effettivo, compete un premio di fine ferma pari al 15 per cento dello stipendio iniziale annuo lordo spettante al sottotenente di complemento o grado corrispondente, in servizio di prima nomina, per ogni semestre di ferma volontaria, ulteriore e successiva a quella iniziale, considerando come semestre intero la frazione di semestre superiore a tre mesi. Il premio non compete, limitatamente al servizio prestato nell'ultimo semestre, agli ufficiali prosciolti dalla ferma per motivi disciplinari o per scarso rendimento.

### Art. 1787. - Rimborso spese di viaggio ai militari di leva residenti all'estero

1. Ai militari di leva residenti all'estero che adempiono in Italia l'obbligo del servizio militare, e' concesso, per una sola volta nel corso della ferma, il rimborso delle spese di viaggio, con il mezzo piu' economico, per licenza da trascorrere nel Paese di residenza.

### Art. 1788. - Sospensione della paga

1. Ai graduati e ai militari di truppa dell'Esercito italiano, della Marina militare e dell'Aeronautica militare in servizio di leva, trattenuti o richiamati o in ferma prolungata, la paga e' dovuta durante i periodi di ricovero in luoghi di cura, durante la licenza ordinaria, le licenze brevi, le licenze straordinarie, quelle di convalescenza dipendente da causa di servizio, la licenza premio e le licenze per determinazione ministeriale, nonche' durante i giorni di viaggio di andata e ritorno nelle licenze di qualsiasi tipo.

2. Per i militari indicati al comma 1 la paga e' sospesa:

- a) quando, senza giustificato motivo, non raggiungono il Corpo di appartenenza o se ne assentano;
- b) quando sono detenuti in attesa di giudizio, salvo a essere loro corrisposta se il giudizio non e' seguito da condanna.

3. Il controvalore della razione viveri e' corrisposto al personale militare indicato al comma 1 quando e' in licenza con diritto alla paga, nonche' durante i giorni di viaggio di andata e ritorno nelle licenze di qualsiasi tipo.

### Art. 1789. - Assegni per il nucleo familiare

1. Gli assegni per il nucleo familiare spettanti ai dipendenti statali competono anche ai graduati e ai militari di truppa dell'Esercito italiano, della Marina militare e dell'Aeronautica militare in servizio di leva, trattenuti o richiamati o in ferma prolungata, che risultino con carico di famiglia.

### Art. 1790. - Premio di congedamento

1. Ai graduati e ai militari di truppa in ferma di leva prolungata e' corrisposto un premio di congedamento pari a due volte l'ultima paga mensile percepita per ogni anno o frazione superiore a sei mesi di servizio prestato, se gli stessi non sono transitati in servizio permanente effettivo.

## TITOLO III PERSONALE IN FERMA VOLONTARIA

### Art. 1791. - (( (Retribuzione base dei volontari in ferma prefissata). ))

((

1. Ai volontari in ferma prefissata iniziale e raffermati, con la qualifica di soldato, comune di 2ª classe e aviere, e' corrisposta una paga lorda giornaliera determinata nella misura percentuale dell'81,50 per cento riferita al valore giornaliero dello stipendio iniziale lordo e dell'indennita' integrativa speciale costituenti la retribuzione mensile del grado iniziale dei volontari in servizio permanente.

2. In aggiunta al trattamento economico di cui al comma 1, ai volontari in ferma prefissata iniziale e raffermati che prestano servizio nei reparti alpini e' attribuito un assegno mensile di 50 euro.

3. Ai volontari in ferma prefissata triennale sono attribuiti:

a) uno stipendio calcolato in misura pari all'80 per cento del parametro stipendiale spettante al grado iniziale dei volontari in servizio permanente;

b) gli assegni a carattere fisso e continuativo calcolati in misura pari all'80 per cento di quelli spettanti al grado iniziale dei volontari in servizio permanente))

--------------- AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 3) che le presenti modifiche hanno effetto a decorrere dal 1° gennaio 2017.

### Art. 1792. - (( (Retribuzione accessoria dei volontari in ferma prefissata). ))

((

1. Per i volontari in ferma prefissata iniziale e in rafferma, l'impiego oltre le normali attivita' giornaliere, disciplinato dalla normativa vigente in materia per le singole Forze armate, fatta salva la previsione di adeguati turni di riposo per il recupero psico-fisico, non da' luogo a recupero ed e' compensato mediante la corresponsione di un'indennita' forfetaria pari a euro 100 mensili, a decorrere dal 1° gennaio 2023. L'indennita' e' ridotta nella misura di un trentesimo per ogni giorno di corresponsione del compenso forfetario di impiego ai sensi dell'articolo 6 della legge 21 luglio 2016, n. 145. Analoga riduzione si applica nel caso di corresponsione di emolumenti che compensano impieghi prolungati.

2. Per i volontari in ferma prefissata triennale, le eventuali ore eccedenti l'orario di lavoro settimanale sono retribuite, entro i termini e con le modalita' previsti dai provvedimenti di concertazione emanati ai sensi del decreto legislativo 12 maggio 1995, n. 195, con il compenso per lavoro straordinario in misura pari al 70 per cento del compenso e nei limiti previsti per il grado iniziale dei volontari in servizio permanente. Le ore eccedenti l'orario di lavoro settimanale che non sono state retribuite sono recuperate secondo le modalita' previste dai provvedimenti di cui al precedente periodo.

3. Ai volontari in ferma prefissata triennale possono essere attribuiti, nell'ambito delle risorse a tal fine destinate, che costituiscono limiti di spesa, i compensi forfetari di guardia e di impiego, nei limiti e con le modalita' stabiliti in sede di concertazione, in misura pari al 70 per cento dell'importo previsto per il grado di graduato e gradi corrispondenti.

4. Le indennita' di impiego operativo fondamentali e supplementari, di cui agli articoli 3, 4, 5, 8, 9, 10, 11 e 16 della legge 23 marzo 1983, n. 78, ove spettanti, sono corrisposte ai volontari in ferma prefissata iniziale e in rafferma nelle misure fisse ivi previste.

5. Le indennita' di impiego operativo fondamentali e supplementari, di cui agli articoli 3, 4, 5, 8, 9, 10, 11 e 16 della legge 23 marzo 1983, n. 78, ove spettanti, sono corrisposte ai volontari in ferma prefissata triennale nelle misure ivi previste, calcolate sull'importo pari all'80 per cento dell'indennita' di impiego operativo di base spettante al grado iniziale dei volontari in servizio permanente.

6. Ai volontari in ferma prefissata spetta l'indennita' di rischio prevista dal regolamento di cui al decreto del Presidente della Repubblica 5 maggio 1975, n. 146.

7. La fruizione della mensa e degli alloggi collettivi di servizio e' a titolo gratuito per tutti i volontari in ferma prefissata.

8. Ai volontari in ferma prefissata non compete alcun premio di congedamento))

### Art. 1793.

((ARTICOLO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119))

### Art. 1794. - Rimborsi in caso di revoca della licenza ordinaria o richiamo dalla stessa

1. In caso di revoca della licenza per imprescindibili esigenze di impiego, il militare ha diritto al rimborso, sulla base della documentazione fornita, delle spese connesse al mancato viaggio e soggiorno sostenute successivamente alla concessione della licenza stessa e non altrimenti recuperabili.

2. Il richiamo dalla licenza ordinaria per imprescindibili esigenze di impiego comporta il diritto al rimborso delle spese anticipate per il periodo di licenza non goduto, la corresponsione del trattamento previsto in occasione di servizi isolati fuori sede, nonche' il rimborso delle spese di viaggio per il rientro in sede ed eventualmente per il ritorno nella localita' ove il personale fruiva della licenza ordinaria.

### Art. 1795.

Retribuzione ((stipendiale)) degli ufficiali in ferma prefissata

1. Ai sottotenenti e ai tenenti e gradi corrispondenti in ferma prefissata e in rafferma e' attribuito uno stipendio rispettivamente pari all'80,74 per cento e all'88,55 per cento dello stipendio parametrale dei pari grado in servizio permanente.

### Art. 1796. - Premio di fine ferma agli ufficiali in ferma prefissata

1. Agli ufficiali in ferma prefissata, anche se transitati in servizio permanente effettivo, spetta il premio di fine ferma di cui dall'articolo 1786, per ogni semestre di ferma volontaria, ulteriore e successiva a quella iniziale, considerando come semestre intero la frazione di semestre superiore a tre mesi. Il premio non compete, limitatamente al servizio prestato nell'ultimo semestre, agli ufficiali prosciolti dalla ferma per motivi disciplinari o per scarso rendimento.

### Art. 1797. - Premio di fine ferma agli ufficiali piloti e navigatori di complemento

1. Agli ufficiali piloti e navigatori di complemento, congedati al termine della ferma prevista dall'articolo 943, comma 1, ovvero prosciolti dalla ferma per motivi psico-fisici, e' corrisposto un premio di fine ferma, a condizione che non sia stato acquisito il diritto a pensione.

2. Tale premio spetta, per ogni semestre di servizio prestato posteriormente al compimento del quindicesimo mese di ferma per il quale sia stata percepita l'indennita' mensile di aeronavigazione, nella misura di seguito indicata:

- a) euro 180,76, per gli ufficiali che abbiano completato la ferma di dodici anni;
- b) euro 142,03, per gli ufficiali che abbiano prestato un periodo di ferma inferiore a dodici anni ma superiore a dieci;
- c) euro 103,29, per gli ufficiali che abbiano prestato un periodo di ferma pari o inferiore a dieci anni.

3. Il premio e' corrisposto nella misura di euro 51,65 a semestre agli ufficiali che ottengono il passaggio in servizio permanente effettivo, ai sensi dell'articolo 667.

4. Il semestre e' considerato come intero quando il servizio e' stato prestato per almeno tre mesi.

5. In caso di morte, la somma corrispondente al premio di fine ferma e' corrisposta, per la parte maturata, agli eredi aventi diritto.

6. Nel caso di cessazione d'autorita' per motivi disciplinari, si applicano le disposizioni contenute nell'articolo 945.

### Art. 1798. - Retribuzione degli allievi di scuole e accademie militari

1. Agli allievi ufficiali, agli allievi marescialli e agli allievi delle carriere iniziali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare sono attribuite le paghe nette giornaliere nella misura percentuale ((del 74 per cento riferita al valore giornaliero dello stipendio iniziale lordo e dell'indennita' integrativa speciale costituenti la retribuzione mensile del grado iniziale dei volontari in servizio permanente)).

2. Agli allievi ufficiali e agli allievi marescialli provenienti da altri ruoli senza soluzione di continuita', in luogo della paga prevista al comma 1, competono gli assegni del grado rivestito all'atto dell'ammissione all'accademia o alla frequenza dei corsi; se essi sono superiori a quelli spettanti nella nuova posizione, e' attribuito un assegno personale riassorbibile in applicazione del principio di cui all'articolo 1780.

3. Il trattamento economico di cui ai commi 1 e 2 e' corrisposto anche durante i periodi di interruzione dei corsi e di degenza in luoghi di cura o di licenza straordinaria per infermita', mentre ne e' ridotta o sospesa la corresponsione agli allievi durante i periodi di interruzione dei corsi o di degenza in luoghi di cura o di licenza straordinaria per infermita' non dipendenti da causa di servizio, secondo le prescrizioni di cui all'articolo 1503.

4. Agli allievi di cui al comma 1 spettano, nelle misure mensili sotto indicate:

- a) l'indennita' di impiego operativo di base: 37,18 euro;
- b) l'indennita' di impiego operativo per reparti di campagna: 44,62 euro;
- c) l'indennita' di impiego operativo di campagna per truppe alpine: 52,05 euro;
- d) l'indennita' di impiego operativo di imbarco su navi di superficie: 66,92 euro;
- e) l'indennita' di impiego operativo di imbarco su sommergibili: 104,10 euro;
- f) l'indennita' supplementare di marcia: 66,92 euro;
- g) l'indennita' supplementare per allievi piloti: 85,53 euro.

5. Agli allievi ufficiali in ferma prefissata compete il trattamento economico previsto per gli allievi ufficiali delle accademie.

6. Si applicano agli allievi delle scuole e delle accademie militari le disposizioni previste per i militari di cui all'articolo 1788, comma 1, in materia di sospensione della paga e di assegni per il nucleo familiare.

### Art. 1799. - Retribuzione delle forze di completamento

1. Agli ufficiali e ai sottufficiali delle Forze armate richiamati e' attribuito il trattamento economico dei pari grado in servizio permanente. ((PERIODO SOPPRESSO DALLA L. 5 AGOSTO 2022, N. 119)).

((1-bis. Ai militari richiamati provenienti dalle categorie dei militari di truppa in servizio di leva, dei volontari in ferma annuale e dei volontari in ferma prefissata di un anno e iniziale e' attribuito il trattamento economico dei pari grado appartenenti ai volontari in ferma prefissata iniziale. Ai militari richiamati provenienti dalle categorie dei volontari in ferma breve e in ferma prefissata triennale e quadriennale e' attribuito il trattamento economico dei pari grado appartenenti ai volontari in ferma prefissata triennale))

2. Agli ufficiali delle forze di completamento, che sono lavoratori dipendenti pubblici, spettano, in aggiunta alle competenze fisse ed eventuali determinate e attribuite ai sensi del comma 1, limitatamente al periodo di effettiva permanenza nella posizione di richiamo, anche lo stipendio e le altre indennita' a carattere fisso e continuativo, fatta eccezione per l'indennita' integrativa speciale, dovuti dall'amministrazione di origine, che ne assicura la diretta corresponsione all'interessato.

## TITOLO IV PERSONALE ((MILITARE FINO AL GRADO DI CAPITANO)) CAPO I TRATTAMENTO ECONOMICO STIPENDIALE

### Art. 1800. - Stipendio parametrale

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applicano le disposizioni in materia di parametri stipendiali previste dal decreto legislativo 30 maggio 2003, n. 193.

## CAPO II - TRATTAMENTO ECONOMICO STIPENDIALE AGGIUNTIVO

### Art. 1801. - Scatti per invalidita' di servizio

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare che, in costanza di rapporto di impiego, ha ottenuto il riconoscimento della dipendenza da causa di servizio per infermita' ascrivibile a una delle categorie indicate nella tabella A allegata al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, compete una sola volta, nel valore massimo, un beneficio stipendiale, non riassorbibile e non rivalutabile, pari al:

- a) 2,50 per cento dello stipendio per infermita' dalla I alla VI categoria;
- b) 1,25 per cento dello stipendio per infermita' dalla VII alla VIII categoria. ((113))

------------ AGGIORNAMENTO (113) La Corte Costituzionale, con sentenza 10 gennaio - 9 febbraio 2024, n. 13 (in G.U. 1ª s.s. 14/02/2023, n. 7) ha dichiarato "l'illegittimita' costituzionale dell'art. 1801 del decreto legislativo 15 marzo 2010, n. 66 (Codice dell'ordinamento militare), limitatamente all'inciso «,in costanza di rapporto di impiego,»".

### Art. 1802.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94))

### Art. 1803. - Incentivi agli ufficiali piloti in servizio permanente effettivo

1. Agli ufficiali in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare in possesso del brevetto di pilota militare, ammessi a contrarre le ferme volontarie biennali di cui all'articolo 966, e' corrisposto, per ciascun periodo di ferma volontaria contratta, un premio nei seguenti importi:

- a) 15.493,70 euro per il primo biennio da corrispondere per meta' all'atto dell'assunzione della ferma e per meta' dopo dodici mesi;
- b) 9.296,22 euro per il secondo biennio da corrispondere in unica soluzione;
- c) 11.362,05 euro per il terzo biennio da corrispondere in unica soluzione;
- d) 13.427,87 euro per il quarto biennio da corrispondere in unica soluzione;
- e) 15.493,70 euro per il quinto biennio da corrispondere in unica soluzione. ((30))

--------------- AGGIORNAMENTO (30) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 260) che "Gli importi dei premi previsti dagli articoli 1803, comma 1, lettere da a) ad e), 1804, comma 1, lettere da a) ad e), e 2161, comma 4, del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, sono ridotti alla meta'".

### Art. 1804. - Incentivi al personale addetto al controllo del traffico aereo

1. Agli ufficiali e ai sottufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare in possesso del massimo grado di abilitazione di controllore del traffico aereo in corso di validita', ammessi a contrarre le ferme volontarie biennali di cui all'articolo 970, e' corrisposto, per ciascun periodo di ferma volontaria contratta un premio nei seguenti importi:

- a) 10.329,14 euro per il primo biennio, da corrispondere per meta' all'atto di assunzione della ferma e per meta' dopo dodici mesi;
- b) 6.197,48 euro per il secondo biennio, da corrispondere in unica soluzione;
- c) 7.230,40 euro per il terzo biennio, da corrispondere in unica soluzione;
- d) 9.296,22 euro per il quarto biennio, da corrispondere in unica soluzione;
- e) 10.329,14 euro per il quinto biennio, da corrispondere in unica soluzione. ((30))

--------------- AGGIORNAMENTO (30) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 260) che "Gli importi dei premi previsti dagli articoli 1803, comma 1, lettere da a) ad e), 1804, comma 1, lettere da a) ad e), e 2161, comma 4, del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, sono ridotti alla meta'".

## CAPO III - TRATTAMENTO ECONOMICO ACCESSORIO

### Art. 1805. - Rinvio ai provvedimenti di concertazione in materia di trattamento economico accessorio

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applicano, in materia di indennita' di impiego operativo ((e di competenze accessorie)), le disposizioni emanate a seguito delle procedure di concertazione previste dal decreto legislativo 12 maggio 1995, n. 195, nonche' quelle previste dalla normativa vigente. ((Le indennita' operative previste dagli articoli 2, 3, 4, 5, 6 e 7, della legge 23 marzo 1983, n. 78, sono interamente computabili nella tredicesima mensilita'.))

### Art. 1805-bis. - (( (Fondo per la retribuzione della produttivita' del personale militare transitato nelle aree funzionali del personale civile del Ministero della difesa). ))

((

1. Per ciascun militare nell'anno di transito nel ruolo del personale civile del Ministero della difesa, annualmente e per l'intero periodo di permanenza del militare transitato in detti ruoli, e' versato al fondo per la retribuzione della produttivita' del personale civile stesso un importo corrispondente alla quota media pro capite delle risorse strutturali dei fondi per l'efficienza dei servizi istituzionali delle Forze armate comunque denominati.

))

## CAPO IV - TRATTAMENTO ECONOMICO EVENTUALE

### SEZIONE I - TRATTAMENTO ECONOMICO DI MISSIONE E DI TRASFERIMENTO

#### Art. 1806. - Rinvio ai provvedimenti di concertazione in materia di trattamento economico di missione e di trasferimento

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applicano, in materia di trattamento economico di missione e di trasferimento in ambito nazionale, le disposizioni emanate a seguito delle procedure di concertazione previste dal decreto legislativo 12 maggio 1995, n. 195, nonche' quelle previste dalla normativa vigente.((Allo stesso personale si applica, altresi', l'articolo 4, comma 98, della legge 12 novembre 2011, n. 183.))

### SEZIONE II - TRATTAMENTO ECONOMICO DI MISSIONE ALL'ESTERO

#### Art. 1807. - Indennita' di missione all'estero

1. Al personale militare inviato in missione all'estero e' corrisposta l'indennita' prevista dal regio decreto 3 giugno 1926, n. 941.

2. Al personale militare inviato in missione all'estero per un periodo non inferiore a sei mesi sono dovuti i rimborsi di cui alla lettera c) del comma 1 dell'articolo 1808. Se la missione e' inizialmente prevista di durata non inferiore a 15 mesi, e' dovuto anche il rimborso delle spese di viaggio e di trasporto bagaglio della famiglia, nei limiti e alle condizioni di cui al comma 4 dell'articolo 1808; in tale caso il trasferimento della famiglia all'estero deve avvenire entro i primi 10 mesi della missione.

#### Art. 1808. - Indennita' di lungo servizio all'estero

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare destinato isolatamente a prestare servizio per un periodo superiore a sei mesi presso delegazioni o rappresentanze militari nazionali costituite all'estero, ((...)) presso enti, comandi od organismi internazionali, ((ovvero per conto delle agenzie di cooperazione internazionale,)) dai quali non sono corrisposti stipendi o paghe, competono, oltre allo stipendio e agli altri assegni a carattere fisso e continuativo previsti per l'interno:

- a) un assegno di lungo servizio all'estero in misura mensile ragguagliata a 30 diarie intere come stabilito dalle norme in vigore per il Paese di destinazione;
- b) un'indennita' speciale eventualmente riconosciuta se l'assegno di lungo servizio all'estero non e' ritenuto sufficiente in relazione a particolari condizioni di servizio, in misura da fissarsi con decreto del Ministro della difesa, di concerto con i Ministri degli affari esteri e dell'economia e delle finanze, sentita la commissione permanente di finanziamento di cui all'articolo 172 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18;
- c) il rimborso delle spese effettivamente sostenute per il trasporto con i mezzi usuali e piu' economici del bagaglio e per la spedizione di mobili e masserizie secondo le misure vigente per i dipendenti dello Stato, fatte salve le disposizioni dettate in sede di Unione europea.

2. L'assegno di lungo servizio e l'indennita' speciale hanno natura accessoria e sono erogati per compensare disagi e rischi collegati all'impiego, obblighi di reperibilita' e disponibilita' ad orari disagevoli, nonche' in sostituzione dei compensi per il lavoro straordinario. ((PERIODO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 173)).

((

2-bis. Il trattamento di cui al comma 1 e' sospeso in caso di particolari indennita' o contributi alle spese connesse alla missione direttamente corrisposti ai singoli dai predetti enti, comandi, organismi e agenzie. In tali situazioni si provvede a integrare quanto erogato dai predetti enti, comandi, organismi e agenzie fino a concorrenza di quanto effettivamente spettante al militare ai sensi del comma 1.

))

3. L'assegno di lungo servizio all'estero compete dal giorno successivo a quello di arrivo nella sede di servizio all'estero a quello di cessazione dalla destinazione.

4. Se la durata della destinazione all'estero e' superiore a un anno, il militare puo' trasferire la famiglia all'estero, con diritto al rimborso delle spese di viaggio per il coniuge e i figli conviventi e fiscalmente a carico e delle spese di trasporto di un bagaglio, per ogni persona, nella stessa quantita' prevista per il dipendente.

5. Per coloro che nella sede all'estero usufruiscono di alloggio a titolo gratuito, l'assegno di lungo servizio all'estero e l'indennita' speciale possono essere ridotti in misura non eccedente il quarto e non inferiore all'ottavo, se l'alloggio e' arredato, al dodicesimo, se l'alloggio non e' arredato. La misura della riduzione e', in ogni caso, stabilita con decreto del Ministro della difesa.

6. Il personale inviato in licenza ordinaria conserva l'assegno di lungo servizio all'estero in misura ridotta al 50 per cento per tutto il periodo della licenza spettante, anche se prima di averla ultimata riassume servizio in Italia o cessa dal servizio. Tuttavia, in caso di cumulo di licenze, l'assegno anzidetto non puo' essere conservato per periodi superiori a sessanta giorni per ufficiali, sottufficiali e graduati e a quaranta giorni per militari di truppa.

7. Ai militari di truppa che vengono a trascorrere la licenza ordinaria in Italia sono rimborsate le spese di viaggio riferite ai mezzi di trasporto e alle classi previste per le missioni all'estero. Il rimborso e' concesso, anche se la licenza e' frazionata in vari periodi, per una sola volta l'anno o, se la sede e' situata fuori d'Europa o del bacino del Mediterraneo, per una sola volta ogni due anni.

8. L'assegno di lungo servizio all'estero non e' dovuto durante le licenze straordinarie; in caso di assenza per infermita', esso e' corrisposto per intero per i primi quarantacinque giorni e non e' dovuto per il restante periodo.

9. Agli ufficiali, ai sottufficiali e ai graduati, che per ragioni di servizio sono chiamati temporaneamente in Italia o vi sono trattenuti durante o allo scadere della licenza ordinaria, sono conservati, in relazione al periodo in cui prestano servizio in Italia, l'assegno di lungo servizio all'estero e l'indennita' speciale in misura intera per i primi dieci giorni, ridotti alla meta' per il periodo successivo, fino a un massimo di cinquanta giorni.

10. Ai militari di truppa nelle situazioni indicate al comma 9, l'assegno di lungo servizio e l'indennita' speciale sono conservati in misura intera per i soli primi dieci giorni. Per il periodo successivo, i militari di truppa sono aggregati, a tutti gli effetti, all'ente ove devono compiere il loro servizio.

11. Al personale militare che per ragioni di servizio venga chiamato temporaneamente in Italia, l'assegno di lungo servizio all'estero e l'indennita' speciale sono conservati anche durante i giorni strettamente indispensabili per il viaggio di andata e ritorno. Allo stesso personale sono rimborsate le spese di viaggio, riferite ai mezzi di trasporto e alle classi previste per le missioni all'estero.

12. Il personale di cui al comma 1, incaricato dal Ministero della difesa di missioni fuori della sede in cui presta servizio, sia nello Stato di residenza sia in altri Stati esteri, conserva l'assegno di lungo servizio all'estero e l'indennita' speciale e ha diritto:

- a) al rimborso delle spese di viaggio, con relativa maggiorazione fissa per spese accessorie, riferite ai mezzi di trasporto e alle classi previste per le missioni all'estero;
- b) al trattamento di missioni all'estero spettante a coloro che, in qualita' di addetti a enti o uffici all'estero, godano di particolari assegni o indennita'. ((62))

-------------- AGGIORNAMENTO (62) Il D.Lgs 29 maggio 2017, n. 95, come modificato dal D.Lgs 27 dicembre 2019, n. 172, ha disposto (con l'art. 44, comma 14-sexies) che "Le disposizioni di cui agli articoli 2164 e 1808 del decreto legislativo 15 marzo 2010, n. 66 si applicano anche agli appartenenti al Corpo di polizia penitenziaria".

#### Art. 1809. - Indennita' di servizio all'estero presso rappresentanze diplomatiche

1. Al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare destinato a prestare servizio presso le rappresentanze diplomatiche italiane all'estero, di cui al libro I, titolo III, capo III, sezione IV, compete, oltre allo stipendio e agli altri assegni a carattere fisso e continuativo previsti per l'interno, il seguente trattamento economico previsto dal decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, nei limiti e alle condizioni di quello spettante al personale del Ministero degli affari esteri in servizio presso le rappresentanze diplomatiche ove hanno sede gli uffici degli addetti:

- a) indennita' di servizio all'estero con gli aumenti per situazione di rischio e disagio, nonche' per situazione di famiglia, che ha natura accessoria ed e' erogata per compensare disagi e rischi collegati all'impiego, obblighi di reperibilita' e disponibilita' ad orari disagevoli, nonche' in sostituzione dei compensi per il lavoro straordinario;
- b) indennita' di sistemazione;
- c) indennita' di richiamo dal servizio all'estero;
- d) indennita' e rimborsi per licenze o congedi di cui all'articolo 39;
- e) ((maggiorazione)) spese per abitazione;
- f) ((LETTERA SOPPRESSA DAL D.LGS. 27 DICEMBRE 2019, N. 173));
- g) provvidenze scolastiche;
- h) ((contributo)) e rimborso per viaggi di trasferimento e di servizio comunque e dovunque compiuti;
- i) ((LETTERA SOPPRESSA DAL D.LGS. 27 DICEMBRE 2019, N. 173));
- l) indennizzo per danni subiti in conseguenza di disordini, fatti bellici, nonche' di eventi connessi con la posizione all'estero del personale;
- m) rimborsi delle spese di trasporto in Italia della salma dei familiari a carico o dei collaboratori familiari.

2. In caso di decesso del personale di cui al comma 1 spettano ai familiari le indennita' e i rimborsi previsti dall'articolo 207 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18.

3. All'applicazione dei commi 1 e 2 provvede il Ministero della difesa, di concerto, se occorre, con il Ministero dell'economia e delle finanze.

4. Il personale accreditato per piu' Forze armate nello stesso Stato di residenza ha diritto, in aggiunta al trattamento economico di cui al comma 1, all'indennita' per accreditamenti multipli, nelle misure lorde mensili indicate nella tabella 1 allegata al decreto legislativo 27 febbraio 1998, n. 62. A tale indennita' si applicano gli stessi coefficienti di maggiorazione fissati per l'indennita' di servizio all'estero.

5. Le indennita' base di servizio all'estero e relative maggiorazioni, gli assegni per oneri di rappresentanza, le indennita' e i rimborsi per viaggi di servizio e di trasferimento, nonche' le provvidenze scolastiche, sono attribuite tenendo conto della tabella 2, allegata al decreto legislativo 27 febbraio 1998, n. 62, riguardante gli allineamenti economici tra il personale del Ministero della difesa e quello del Ministero degli affari esteri in servizio all'estero.

6. Gli addetti aggiunti e gli assistenti che per ragioni di servizio risiedono in uno Stato diverso da quello in cui risiede l'addetto, percepiscono gli assegni con le maggiorazioni previste per la sede di residenza.

7. Per le sedi in cui manca il corrispondente posto di organico del personale del Ministero degli affari esteri, le maggiorazioni sono determinate con decreto del Ministro della difesa, di concerto con i Ministri degli affari esteri e dell'economia e delle finanze, sentita la commissione permanente di finanziamento, istituita presso il Ministero degli affari esteri, ai sensi dell'articolo 172 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18.

8. Il Ministero della difesa puo' prendere in locazione locali da adibire ad alloggi per il personale degli uffici degli addetti nelle stesse sedi determinate per il personale dell'Amministrazione degli affari esteri ai sensi dei commi 2 e 3 dell'articolo 84 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, e alle condizioni e nei limiti da esso previsti. Per la concessione in uso al personale dei locali stessi si applicano i commi 3 e 4 del predetto articolo.

9. Il trattamento economico previsto dal presente articolo compete dal giorno di assunzione delle funzioni in sede fino al giorno di cessazione definitiva delle funzioni stesse. Quando esigenze di servizio rendono necessaria, a giudizio del Ministero, la contemporanea presenza del personale cessante e di quello subentrante, al personale cessante sono conservate le indennita' in godimento per un periodo non eccedente i dieci giorni.

10. Al personale in licenza ordinaria si applicano le stesse norme sul trattamento economico per congedi ordinari o ferie e per rimborso delle relative spese di viaggio vigenti per il personale del Ministero degli affari esteri in servizio all'estero, compreso il periodo di tempo corrispondente ai giorni di viaggio per andata e ritorno dall'Italia stabilito per il personale del Ministero medesimo ai sensi del comma 3 dell'articolo 180 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18.

11. Il limite massimo di assenza dal servizio all'estero, con esclusione dei periodi di licenza ordinaria o di ferie, nonche' delle assenze connesse al servizio stesso, e' fissato in complessivi sessanta giorni per anno, limite aumentato fino a quattro mesi nei casi in cui per infermita' il personale non possa essere trasferito senza danno, durante i quali spetta il seguente trattamento economico:

- a) in caso di assenza per infermita', l'indennita' personale e' corrisposta per intero per i primi quarantacinque giorni ed e' sospesa per il restante periodo;
- b) in caso di altre assenze consentite dalle disposizioni applicabili ai pubblici dipendenti, per motivi diversi da quelli di salute, la corresponsione dell'indennita' personale e' sospesa.

11-bis. Trascorsi i periodi indicati al comma 11, nonche' quelli previsti dagli articoli 16, 17 e 21 del testo unico approvato con decreto legislativo 26 marzo 2001, n. 151, ulteriori assenze del dipendente, pur se consentite dall'attuale ordinamento, comportano la decadenza dall'organico dell'ufficio all'estero.

12. Alle lavoratrici madri in astensione dal lavoro ai sensi del decreto legislativo 26 marzo 2001, n. 151, nonche' ai lavoratori padri ai sensi della stessa normativa, spetta il seguente trattamento economico:

- a) in caso di astensione obbligatoria, l'indennita' personale e' corrisposta per intero;
- b) in caso di astensione facoltativa, l'indennita' personale e' sospesa.

12-bis. Al personale militare e civile si applicano per l'assistenza sanitaria e per le coperture dei rischi di morte, invalidita' permanente o gravi menomazioni causati da atti di natura violenta, le norme vigenti per il personale del Ministero degli affari esteri in servizio all'estero, di cui all'articolo 211 del decreto del Presidente della Repubblica 5 gennaio 1967, n. 18, e successive modificazioni. Al personale locale, assunto a contratto, si applicano l'articolo 158 del decreto del Presidente della Repubblica n. 18 del 1967 e il decreto legislativo 7 aprile 2000, n. 103, e successive modificazioni.

## TITOLO V ((UFFICIALI GENERALI E UFFICIALI SUPERIORI)) CAPO I TRATTAMENTO ECONOMICO STIPENDIALE

### Art. 1810. - Principio di onnicomprensivita'

1. E' fatto divieto di corrispondere ai ((maggiori, tenenti colonnelli e)) colonnelli e ai generali in servizio, oltre allo stipendio, ulteriori indennita', proventi o compensi dovuti a qualsiasi titolo in dipendenza della carica o per prestazioni comunque rese in rappresentanza dell'amministrazione; le indennita', i proventi o i compensi sono dovuti se:

- a) hanno carattere di generalita' per il personale statale;
- b) o sono espressamente previsti dal presente codice per il personale militare con qualifica dirigenziale.

2. L'importo delle indennita', dei proventi e dei compensi dei quali e' vietata la corresponsione e' versato direttamente in conto entrate del Ministero dell'economia e delle finanze.

### Art. 1810-bis. - (( (Stipendio). ))

((

1. Gli stipendi iniziali degli ufficiali generali e degli ufficiali superiori, salvo l'attribuzione dell'indennita' integrativa speciale e delle altre competenze previste dalle vigenti disposizioni per il personale militare, sono determinati nei seguenti importi annui lordi:

- a) generale e gradi corrispondenti, euro 53.906,05;
- b) generale di corpo d'armata e gradi corrispondenti, euro 48.381,53;
- c) generale di divisione e gradi corrispondenti, euro 39.587,41;
- d) generale di brigata e gradi corrispondenti, euro 33.837,38;
- e) colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 33.837,38;
- f) colonnello e gradi corrispondenti, euro 26.100;
- g) tenente colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 33.837,38;
- h) tenente colonnello e gradi corrispondenti con diciotto anni di servizio al conseguimento della nomina a ufficiale o della qualifica di aspirante euro 26.100,00;
- i) tenente colonnello e gradi corrispondenti con tredici anni di servizio al conseguimento della nomina a ufficiale o della qualifica di aspirante euro 23.290,00;
- l) tenente colonnello e gradi corrispondenti, euro 19.040,00;
- m) maggiore e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 33.837,38;
- n) maggiore e gradi corrispondenti con tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 23.290,00;
- o) maggiore e gradi corrispondenti, euro 17.050,00.

2. Al maggiore e gradi corrispondenti con meno di tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, fermo restando quanto previsto dall'articolo 1811-bis, comma 1, e' attribuito un incremento dell'importo stipendiale di cui al comma 1 del 3 per cento dopo tre anni di permanenza nel grado. Tale incremento e' attribuito fino al raggiungimento del livello stipendiale successivo.

3. Le misure degli importi stipendiali di cui al comma 1, fermo restando quanto previsto dall'articolo 1811-bis, comma 1, hanno effetto sui relativi aumenti periodici, sulla tredicesima mensilita', sulla indennita' di buonuscita, sulla determinazione dell'equo indennizzo e sull'assegno alimentare e negli altri casi previsti dalla normativa vigente.))

((44))

--------------- AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1810-ter. - (( (Indennita' integrativa speciale). ))

((

1. L'indennita' integrativa speciale e' attribuita al personale militare dell'Esercito italiano, della Marina militare e dell'Aeronautica militare nei valori annui lordi di seguito indicati:

- a) generale e gradi corrispondenti, euro 12.412,36;
- b) generale di corpo d'armata e gradi corrispondenti, euro 12.022,44;
- c) generale di divisione e gradi corrispondenti, euro 11.402,88;
- d) generale di brigata e gradi corrispondenti, euro 10.997,76;
- e) colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina ad ufficiale o qualifica di aspirante, euro 10.997,76;
- f) colonnello e gradi corrispondenti, euro 10.439,64;
- g) tenente colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina ad ufficiale o qualifica di aspirante, euro 10.997,76;
- h) tenente colonnello e gradi corrispondenti con tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante euro 10.439,64;
- i) tenente colonnello e gradi corrispondenti, euro 9.145,00;
- l) maggiore e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina ad ufficiale o qualifica di aspirante, euro 10.997,76;
- m) maggiore e gradi corrispondenti con tredici anni di servizio dal conseguimento della nomina ad ufficiale o qualifica di aspirante, euro 10.439,64;
- n) maggiore e gradi corrispondenti, euro 9.145,00;

2. Le misure di indennita' integrativa speciale di cui al comma 1 hanno effetto sui relativi adeguamenti periodici, sulla tredicesima mensilita', sulla indennita' di buonuscita e sull'assegno alimentare e negli altri casi previsti dalla normativa vigente.))

((44))

--------------- AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1811. - (( (Attribuzione stipendiale). ))

((

1. Agli ufficiali generali e agli ufficiali superiori, nel caso di promozione o maturazione dell'anzianita' di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, lo stipendio nella nuova posizione e' determinato considerando la differenza tra gli anni di servizio computabili e il numero degli anni di seguito indicati per ciascun grado:

- a) Esercito italiano e Marina militare: 1) generale di corpo d'armata e gradi corrispondenti, anni ventotto; 2) generale di divisione e gradi corrispondenti, anni ventisei; 3) generale di brigata e gradi corrispondenti, anni ventiquattro; 4) colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni ventiquattro; 5) colonnello e gradi corrispondenti, anni diciannove; 6) tenente colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni ventiquattro; 7) tenente colonnello e gradi corrispondenti, anni diciannove; 8) maggiore e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni ventiquattro; 9) maggiore e gradi corrispondenti con tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni quindici;
- b) Aeronautica militare: 1) generale di squadra aerea e gradi corrispondenti, anni ventisei; 2) generale di divisione aerea e gradi corrispondenti, anni venticinque; 3) generale di brigata aerea e gradi corrispondenti, anni ventiquattro; 4) colonnello con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni ventiquattro; 5) colonnello, anni diciannove; 6) tenente colonnello, con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni ventiquattro; 7) tenente colonnello, anni diciannove; 8) maggiore con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni ventiquattro; 9) maggiore con tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, anni quindici;

2. Le disposizioni di cui al comma 1 non si applicano al grado di generale e ammiraglio di cui all'articolo 628, comma 1, lettera l), per il quale continuano ad applicarsi le disposizioni di cui all'art. 4, comma 1 del decreto-legge 27 settembre 1982, n. 681, convertito con modificazioni dalla legge 20 novembre 1982 n. 869.

3. Agli ufficiali superiori con piu' di ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, la suddetta determinazione dello stipendio e' effettuata alla maturazione del venticinquesimo anno di servizio dal conseguimento della nomina a ufficiale o aspirante.))

((44))

--------------- AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1811-bis. - (( (Progressione economica). ))

((

1. Gli importi stipendiali iniziali annui lordi di ciascun livello di cui all'articolo 1810-bis, a esclusione del livello di maggiore e gradi corrispondenti con meno di tredici anni di servizio dal conseguimento della nomina a Ufficiale o della qualifica di aspirante, progrediscono in otto classi biennali del 6 per cento computate sul valore tabellare iniziale e in successivi aumenti biennali del 2,50 per cento computati sul valore della ottava classe.

2. Agli ufficiali che rivestono i gradi di maggiore e gradi corrispondenti, di tenente colonnello e gradi corrispondenti, di colonnello e gradi corrispondenti, al compimento dei ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, e' attribuito lo stipendio indicato all'articolo 1810-bis senza dar luogo ad alcun incremento in funzione degli anni di servizio computabili. L'inquadramento stipendiale e la relativa progressione economica sono determinate al compimento del venticinquesimo anno di servizio dal conseguimento della nomina a ufficiale o qualifica di aspirante.

3. I maggiori e gradi corrispondenti promossi al grado superiore prima del conseguimento del diciottesimo anno di sevizio dalla nomina a ufficiale o dall'attribuzione della qualifica di aspirante, ferma restando l'attribuzione degli altri istituti retributivi previsti per il grado rivestito, mantengono il trattamento stipendiale in godimento e le classi maturate antecedentemente alla promozione, continuando la progressione economica del grado di provenienza fino all'inquadramento nel grado di tenente colonnello con piu' di diciotto anni dal conseguimento della nomina ad ufficiale o della qualifica di aspirante.))

((44))

--------------- AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1812. - Progressione economica

1. Si applicano le norme vigenti per la dirigenza militare in materia di sviluppo della progressione economica, fermo restando il principio di irreversibilita' stipendiale di cui all'articolo 1780, in caso di promozione, se gli emolumenti fissi e continuativi in godimento sono superiori a quelli spettanti nella nuova posizione.

### Art. 1813.

Scatti per invalidita' di servizio ((agli ufficiali generali e agli ufficiali superiori)) ((44)) ((

1. Agli ufficiali generali e agli ufficiali superiori si applicano le norme previste per il personale militare di cui all'articolo 1801.)) ((44)) ((44))

--------------- AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che le presenti modifiche hanno effetto a decorrere dal 1° gennaio 2018.

### Art. 1814. - Scatti demografici

1. ((Agli ufficiali generali e agli ufficiali superiori)) si applicano le disposizioni in materia di scatti demografici previste dall'articolo 22 del regio decreto-legge 21 agosto 1937, n. 1542, convertito dalla legge 3 gennaio 1939, n. 1. ((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018

### Art. 1815. - ((Incentivi agli ufficiali generali e agli ufficiali superiori piloti in servizio permanente effettivo))

((44))

1. Agli ufficiali ((generali e agli ufficiali superiori)) piloti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare in servizio permanente effettivo si applicano le norme previste dall'articolo 1803. ((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che le presenti modifiche hanno effetto a decorrere dal 1° gennaio 2018.

### Art. 1816. - ((Incentivi agli ufficiali generali e agli ufficiali superiori addetti al controllo del traffico aereo))

((44))

1. ((Agli ufficiali generali e agli ufficiali superiori dell'Esercito italiano, della Marina militare e dell'Aeronautica militare addetti)) al controllo del traffico aereo si applicano le norme previste dall'articolo 1804. ((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che le presenti modifiche hanno effetto a decorrere dal 1° gennaio 2018.

### Art. 1817. - (( (Assegno pensionabile). ))

((1. E' attribuito agli ufficiali generali e agli ufficiali superiori appartenenti all'Esercito italiano, alla Marina militare e all'Aeronautica militare l'assegno pensionabile nelle seguenti misure mensili lorde, per tredici mensilita': a) generale e gradi corrispondenti, euro 345,94; b) generale di corpo d'armata e gradi corrispondenti, euro 345,94; c) generale di divisione e gradi corrispondenti, euro 293,93; d) generale di brigata e gradi corrispondenti, euro 259,26; e) colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 259,26; f) colonnello e gradi corrispondenti, euro 211,36; g) tenente colonnello e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 259,26; h) tenente colonnello e gradi corrispondenti con tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante e gradi corrispondenti euro 211,36; i) tenente colonnello, euro 199,81; l) maggiore e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 259,26; m) maggiore e gradi corrispondenti con tredici anni di servizio dal conseguimento della nomina a ufficiale o della qualifica di aspirante, euro 211,36; n) maggiore e gradi corrispondenti, euro 199,81.)) ((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1818. - Speciale indennita' pensionabile ai generali o ammiragli delle Forze armate

1. Ai generali e agli ammiragli delle Forze armate di cui all'articolo 1094, comma 3, e' attribuita una speciale indennita' commisurata a quella definita per le massime cariche della Pubblica amministrazione in attuazione di quanto disposto dalla legge 15 marzo 1997, n. 59. La speciale indennita' e' determinata con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

### Art. 1819. - Indennita' di posizione

1. In aggiunta al trattamento economico in godimento, fondamentale e accessorio, al generale, ai generali di corpo d'armata e ai generali di divisione e gradi corrispondenti, e' corrisposta un'indennita' di posizione in attuazione dell'articolo 1 della legge 2 ottobre 1997, n. 334.

((

1-bis. Gli importi dell'indennita' di cui al comma 1 sono aggiornati con decreto del Presidente del Consiglio dei Ministri su proposta del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze.

1-ter. Le modalita' e i criteri per l'attribuzione della indennita' di cui al comma 1 sono fissati con decreto del Ministro della difesa.

1-quater. Fino all'emanazione del decreto del Presidente del Consiglio dei ministri di cui al comma 1-bis e del decreto ministeriale di cui al comma 1-ter l'indennita' e' attribuita nella misura e secondo i principi fissati dall'articolo 1 della legge 2 ottobre 1997 n. 334.

))

### Art. 1820. - (( (Indennita' dirigenziale). ))

((

1. Ai generali di brigata, ai colonnelli, ai tenenti colonnelli, e ai maggiori e gradi corrispondenti, in aggiunta al trattamento economico in godimento, fondamentale e accessorio, e' corrisposta, in relazione al grado rivestito, una indennita' dirigenziale nelle seguenti misure annue lorde per tredici mensilita':

- a) generale di brigata e gradi corrispondenti, euro 21.658,21;
- b) colonnello e gradi corrispondenti, euro 13.214,75;
- c) tenente colonnello e gradi corrispondenti, euro 3.004,84;
- d) maggiore e gradi corrispondenti, euro 2.872,69.

2. Le misure indicate al comma 1 sono pensionabili ed hanno effetto sulla indennita' di buonuscita.))

((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1821. - Trattamento economico al personale in aspettativa per riduzione dei quadri

1. Al personale dirigente collocato in aspettativa per riduzione dei quadri ai sensi dell'articolo 909, competono, in aggiunta a qualsiasi beneficio spettante, gli assegni previsti nel tempo per i pari grado in servizio, ((comprensivi delle sole indennita' fisse e continuative in godimento il giorno antecedente il collocamento in aspettativa in relazione al grado e alle funzioni dirigenziali espletate,)) nella misura del 95 per cento, oltre all'indennita' integrativa speciale e all'assegno per nucleo familiare, in misura intera.

2. Il trattamento economico di cui al comma 1 compete anche agli ufficiali richiamati ai sensi dell'articolo 909, comma 6.

## CAPO II - TRATTAMENTO ECONOMICO ACCESSORIO

### Art. 1822. - (( (Indennita' operative). ))

((

1. L'indennita' di impiego operativo di base di cui alla tabella I allegata alla legge 23 marzo 1983, n. 78, e successive modificazioni, e' corrisposta nella misura mensile lorda di:

- a) euro 685,65 per generale, generale di corpo d'armata, generale di divisione e gradi corrispondenti;
- b) euro 640,44 per generale di brigata e gradi corrispondenti;
- c) euro 640,44 per colonnello, tenente colonnello e maggiore e gradi corrispondenti con ventitre' anni di servizio dal conseguimento della nomina a ufficiale o qualifica di aspirante;
- d) euro 595,23 per colonnello, tenente colonnello e maggiore e gradi corrispondenti con piu' di venticinque anni di servizio complessivamente prestato;
- e) euro 550,02 per colonnello, tenente colonnello e maggiore e gradi corrispondenti con piu' di tredici anni di servizio dal conseguimento della nomina a ufficiale o qualifica di aspirante;
- f) euro 371,85 per tenente colonnello e gradi corrispondenti;
- g) euro 343,44 per maggiore e gradi corrispondenti.

2. Agli importi di cui al comma 1 si applica l'adeguamento annuale di cui all'articolo 24, commi 1 e 2, della legge 23 dicembre 1998, n. 448.

3. Al personale di cui al comma 1 competono le indennita' fondamentali e supplementari calcolate sulle misure di cui al medesimo comma nei termini indicati dalla legge 23 marzo 1983, n. 78, e successive modificazioni.

4. Le indennita' previste dagli articoli 2, 3, 4, 5, 6 e 7 della stessa legge n. 78 del 1983, sono interamente computabili nella tredicesima mensilita', secondo le misure stabilite dalle vigenti disposizioni.

5. E' fatta salva l'applicazione dell'articolo 2, comma 2-bis, del decreto-legge 16 settembre 1987, n. 379, convertito, con modificazioni, dalla legge 14 novembre 1987, n. 468.

6. Ai generali di corpo d'armata e di divisione dell'Esercito italiano e gradi corrispondenti della Marina militare, in possesso di brevetto militare di pilota l'indennita' di aeronavigazione e' corrisposta soltanto quando sono direttamente preposti a comandi di unita' aeree.))

((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

## CAPO III - TRATTAMENTO ECONOMICO EVENTUALE

### SEZIONE I - TRATTAMENTO ECONOMICO DI MISSIONE, DI TRASFERIMENTO E DI MISSIONE ALL'ESTERO

#### Art. 1823. - (( (Missioni e trasferimento degli ufficiali generali e degli ufficiali superiori). ))

((1. Agli ufficiali generali e agli ufficiali superiori dell'Esercito italiano, della Marina militare e dell'Aeronautica militare si applicano le disposizioni vigenti in materia di missioni e di trasferimento. Il trattamento di missione all'estero e' disciplinato dal titolo IV, capo IV, sezione II, del presente libro. Allo stesso personale si applica, altresi', l'articolo 4, comma 98, della legge 12 novembre 2011, n. 183.)) ((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### SEZIONE II - ULTERIORI ISTITUTI ECONOMICI

#### Art. 1824. - (( (Assegni per il nucleo familiare agli ufficiali generali e agli ufficiali superiori). ))

((1. Agli ufficiali generali e agli ufficiali superiori competono gli assegni per il nucleo familiare secondo la disciplina vigente.)) ((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

#### Art. 1825. - ((Compenso per lavoro straordinario agli ufficiali generali e ufficiali superiori))

((44))

1. L'orario delle attivita' giornaliere ((degli ufficiali generali e degli ufficiali superiori)) dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, valido in condizioni normali, e' fissato in trentasei ore settimanali. ((44))

2. La prestazione lavorativa eccedente il normale orario di lavoro e' retribuita con il compenso per lavoro straordinario, nell'importo orario determinato con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, in misura proporzionale alla retribuzione mensile.

3. Il numero complessivo massimo di prestazioni orarie aggiuntive da retribuire come lavoro straordinario, nei limiti orari individuati per ciascuna unita' di personale, e' stabilito con decreto del Ministro della difesa, ovvero delle infrastrutture e dei trasporti per il personale del Corpo delle Capitanerie di porto, di concerto con il Ministro dell'economia e delle finanze, tenuto conto specificamente delle particolari situazioni delle Forze di superficie e subacquee in navigazione, di quelle impegnate in specifiche attivita' che hanno carattere di continuita' o che comunque impediscano recuperi orari, in relazione agli impegni connessi alle funzioni realmente svolte.

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che le presenti modifiche hanno effetto a decorrere dal 1° gennaio 2018.

#### Art. 1826. - ((Ulteriori istituti economici per gli ufficiali generali e ufficiali superiori))

((44))

1. ((Ove previsto da specifiche disposizioni di legge, agli ufficiali generali e agli ufficiali superiori sono attribuiti i seguenti emolumenti:)) ((44))

- a) indennita' di presenza festiva;
- b) indennita' di presenza per particolari festivita';
- c) indennita' di seconda lingua (tedesco);
- d) indennita' di seconda lingua (francese);
- e) assegno di studio e di apprendimento seconda lingua;
- f) indennita' premio di disattivazione.

((1-bis. Al medesimo personale sono altresi' attribuiti i compensi di cui al decreto del Presidente della Repubblica 9 maggio 1994, n. 487.))

((44))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che le presenti modifiche hanno effetto a decorrere dal 1° gennaio 2018.

#### Art. 1826-bis. - (Fondo)

1. Al fine di fronteggiare specifiche esigenze di carattere operativo ovvero di valorizzare l'attuazione di specifici programmi o raggiungimento di qualificati obiettivi per gli ufficiali superiori e gli ufficiali generali e' istituito apposito fondo per attribuire misure alternative al compenso per lavoro straordinario nonche' per riconoscere, solo a maggiori e tenenti colonnelli e gradi corrispondenti, specifici compensi.

2. Con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, sono definiti i criteri per l'attribuzione, le modalita' applicative e le misure dei compensi introdotti ai sensi del comma 1.

3. In fase di prima applicazione il fondo di cui al comma 1 e' alimentato con le risorse derivanti da:

- a) riduzione del fondo di cui all'articolo 3 della legge 29 marzo 2001 n. 86, pari a euro 7 milioni a decorrere dall'anno 2018;
- b) quota parte dei risparmi derivanti dalle misure di cui all'articolo 1, comma 5, secondo periodo, della legge 31 dicembre 2012, n. 244, pari a: euro 8,6 milioni per l'anno 2018, euro 10,5 milioni per l'anno 2019, euro 9,5 milioni per l'anno 2020, euro 9,9 milioni per l'anno 2021, euro 11,1 milioni per l'anno 2022, euro 10,2 milioni per l'anno 2023, euro 9,6 milioni per l'anno 2024, euro 9,5 milioni per l'anno 2025, euro 9,5 milioni a decorrere dall'anno 2026.

4. Le disponibilita' del fondo possono essere altresi' integrate con eventuali risorse aggiuntive derivanti dai provvedimenti annuali di adeguamento economico per il personale non contrattualizzato nonche' dai provvedimenti che prevedono la destinazione in favore del personale di quote di risparmio o economie di gestione. (44)((63))

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018. ------------ AGGIORNAMENTO (63) Il D.Lgs. 27 dicembre 2019, n. 173, ha disposto (con l'art. 11, comma 3) che "Le disponibilita' del fondo di cui all'articolo 1826-bis del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, sono incrementate di euro 550.905,00 a decorrere dall'anno 2025".

## TITOLO VI ASSISTENZA MORALE, BENESSERE E PROTEZIONE SOCIALE CAPO I ISTITUTI DI RETRIBUZIONE INDIRETTA

### Art. 1827. - Servizio di vettovagliamento

1. Il personale militare ha diritto al servizio di vettovagliamento a norma delle disposizioni dell'articolo 546.

### Art. 1828. - Alloggi di servizio

1. Al personale militare puo' essere concesso l'alloggio di servizio, gratuito o dietro versamento di un canone di concessione amministrativa, a norma delle disposizioni del libro II, titolo II, capo VII.

## CAPO II - INTERVENTI E ORGANISMI DI PROTEZIONE SOCIALE

### Art. 1829. - Promozione del benessere del personale militare

1. La promozione del benessere del personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, mediante interventi in favore del lavoratore, della sua famiglia e degli enti che svolgono attivita' culturali e ricreative nell'ambito dell'amministrazione di appartenenza, e' finalizzata all'incremento della produttivita' e al miglioramento della qualita' dei servizi.

### Art. 1830. - Competenza statale

1. Ai sensi dell'art. 24, comma 1, numero 3, del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, rientrano nella competenza dello Stato gli interventi di protezione sociale prestati ad appartenenti all'Esercito italiano, alla Marina militare e all'Aeronautica militare e ai loro familiari, da enti e organismi appositamente istituiti.

### Art. 1831. - Quadro degli interventi

1. Il ((Ministero)) della difesa e' autorizzato a concedere, con propri decreti, nei limiti degli appositi stanziamenti di bilancio:

- a) contributi e sovvenzioni in favore degli organismi di protezione sociale di cui al presente capo, per la realizzazione delle finalita' specificate con il regolamento;
- b) borse di studio, conferite mediante concorso pubblico, in favore dei figli del personale militare dipendente o in quiescenza, nonche' degli orfani del personale medesimo;
- c) contributi per il rimborso delle spese sostenute dal militare per le rette degli asili nido pubblici o privati;
- d) altri interventi di protezione sociale, anche diretti a promuovere, mediante la frequenza di corsi interni ed esterni, l'elevazione culturale e la preparazione professionale del personale militare.

2. I decreti relativi ai contributi e agli interventi di protezione sociale di cui al comma 1 sono emanati di concerto con il ((Ministero)) dell'economia e delle finanze.

### Art. 1832. - Formazione ed elevazione culturale

1. Al fine di promuovere la crescita culturale, la formazione della coscienza civica e la preparazione professionale dei militari, l'Amministrazione cura le iniziative disciplinate dall'articolo 1474.

### Art. 1833. - Organismi di protezione sociale

1. Per l'esercizio delle attivita' connesse con gli interventi di protezione sociale, il Ministero della difesa provvede mediante affidamento in concessione alle organizzazioni costituite tra il personale dipendente, ai sensi dell'articolo 1475, oppure a enti e terzi, con procedure negoziali semplificate, secondo le modalita' che sono stabilite nel regolamento.

### Art. 1834. - Concessione in uso di beni demaniali.

1. La concessione in uso alle organizzazioni costituite tra il personale dipendente dei locali demaniali, dei mezzi, delle strutture, dei servizi e degli impianti necessari strumentali agli interventi di protezione sociale a favore del personale militare e civile delle Forze armate e' disciplinata dall'articolo 547.

## CAPO III - MISURE DI SOSTEGNO ALLA FAMIGLIA

### Art. 1835. - Rimborso spese sostenute per rette di asili nido

1. Nell'ambito delle attivita' assistenziali nei confronti del personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e nei limiti degli stanziamenti di bilancio, l'Amministrazione, in luogo della istituzione di asili nido, puo' concedere il rimborso, anche parziale, delle rette relative alle spese sostenute dai dipendenti per i figli a carico.

### Art. 1836. - (Fondo casa).

1. Al fine di agevolare l'accesso alla concessione di mutui da parte di istituti di credito a favore del personale del Ministero della difesa per l'acquisto o la costruzione della prima casa, e' istituito, presso il Ministero della difesa, un fondo di garanzia denominato "fondo casa", alimentato dagli introiti derivanti dalla riassegnazione al bilancio dello Stato delle somme trattenute al personale del Ministero della difesa a titolo di canone di concessione degli alloggi di servizio, nella percentuale prevista dall'articolo 287, comma 2. La garanzia e' concessa nei limiti delle disponibilita' annuali del fondo.

2. Il fondo di cui al comma 1 costituisce garanzia di ultima istanza fino ad un massimo dell'80 per cento della quota capitale per i mutui concessi ai sensi del presente articolo. A tale scopo le somme di cui al comma 1 affluiscono ((ad apposita contabilita' speciale aperta presso la tesoreria dello Stato. La relativa gestione, che puo' essere affidata ai sensi dell'articolo 19, comma 5, del decreto-legge 1º luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102, ha natura di gestione fuori bilancio, assoggettata al controllo della Corte dei conti, ai sensi dell'articolo 9 della legge 25 novembre 1971, n. 1041)). In caso di escussione della garanzia il Ministero della difesa e' autorizzato a esercitare il diritto di rivalsa nei confronti del dipendente.

3. Con il regolamento sono stabilite le modalita' di gestione del fondo di cui al comma 1.

4. Le somme annualmente disponibili sul fondo di cui al comma 1 vengono accantonate in relazione alle garanzie prestate.

### Art. 1837. - Borse di studio

1. Nei confronti del personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare trovano applicazione le disposizioni in materia di borse di studio riservate alle vittime del terrorismo e della criminalita' organizzata, nonche' agli orfani e ai figli delle medesime, ai sensi dell'articolo 4, comma 1 della legge 23 novembre 1998, n. 407.

2. Restano ferme le disposizioni in materia di borse di studio universitarie previste per i dipendenti pubblici.

### Art. 1837-bis. - (( (Assistenza in favore delle famiglie dei militari). ))

((

1. I familiari dei militari impiegati in attivita' operative o addestrative prolungate possono essere autorizzati, durante il periodo di assenza del congiunto, ferme le esigenze di servizio, nell'ambito delle risorse disponibili e secondo i criteri e le modalita' stabiliti con decreto del Ministro della difesa, ad accedere prioritariamente agli organismi di protezione sociale e alle strutture sanitarie militari, a fruire di agevolazioni previste a favore del congiunto nonche', nei casi di necessita' e urgenza, a utilizzare temporaneamente infrastrutture, servizi e mezzi dell'amministrazione.

))

### Art. 1837-ter. - (( (Assistenza in favore del personale militare cessionario dei cani delle Forze armate riformati).))

((

1. A decorrere dal 2020, il personale militare conduttore dei cani delle Forze armate riformati, in quanto non piu' idonei al servizio, puo' ottenerne, in via prioritaria, la cessione a titolo gratuito. Il personale militare di cui al primo periodo fruisce dell'assistenza veterinaria ai sensi dell'articolo 533 del regolamento, entro il limite di spesa annuale di euro 1.200,00 per ciascun cane.

))

## LIBRO SETTIMO TRATTAMENTO PREVIDENZIALE E PER LE INVALIDITA' DI SERVIZIO TITOLO I DISPOSIZIONI GENERALI

### Art. 1838. - Ambito soggettivo di applicazione

1. Ferma restando la disciplina generale in materia di trattamento previdenziale dei dipendenti pubblici, ivi compreso il testo unico sulle pensioni di guerra, al personale militare, incluso quello appartenente alle Forze di polizia a ordinamento militare, si applicano le disposizioni contenute nel presente libro.

## TITOLO II TRATTAMENTO PREVIDENZIALE NORMALE CAPO I ACCESSO AI TRATTAMENTI

### Art. 1839. - Trattamento pensionistico normale

1. Il trattamento pensionistico normale, diretto e di reversibilita', e' corrisposto al personale militare e agli altri aventi diritto secondo le disposizioni stabilite per i dipendenti dello Stato, in quanto compatibili con le norme del presente codice.

### Art. 1840. - Cessazione dal servizio per limiti di eta'

1. Il personale militare e' collocato a riposo al compimento del sessantesimo anno di eta', fatti salvi gli speciali limiti di eta' previsti per gli ufficiali delle Forze armate dall'articolo 925 all'articolo 928 e per gli ufficiali del Corpo della Guardia di finanza dal decreto legislativo 19 marzo 2001, n. 69.

2. Il personale di cui al comma 1 e' collocato a riposo, con diritto a pensione, al raggiungimento del limite di eta', se in possesso dell'anzianita' contributiva stabilita dall'articolo 6 del decreto legislativo 30 dicembre 1992, n. 503.

### Art. 1841. - Cessazione dal servizio per infermita' non dipendente da causa di servizio

1. Il personale militare ((che)) cessa dal servizio permanente per infermita' non dipendente da causa di servizio ((ha diritto alla pensione normale)) al raggiungimento dell'anzianita' contributiva di cui all'articolo 52, comma 1, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

2. Al personale militare compete la pensione di inabilita' alle condizioni stabilite dall'articolo 2, comma 12, della legge 8 agosto 1995, n. 335.

### Art. 1842. - Cessazione dal servizio per infermita' dipendente da causa di servizio

1. Il personale militare cessa dal servizio permanente per infermita' dipendente da causa di servizio con diritto alla pensione di privilegio ordinaria a norma degli articoli 64 e seguenti del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1843. - Cessazione dal servizio a domanda

1. Il diritto alla pensione di anzianita' si consegue a norma dell'articolo 6, comma 2, del decreto legislativo 30 aprile 1997, n. 165.

### Art. 1844. - Cessazione dal servizio d'autorita'

1. In caso di cessazione dal servizio d'autorita' ai sensi dell'articolo 934, il diritto a pensione si consegue in applicazione delle disposizioni di cui all'articolo 1843.

### Art. 1845. - Indennita' per una volta tanto

1. Al personale militare che cessa dal servizio permanente senza aver conseguito diritto a pensione, spetta un'indennita' per una volta tanto ai sensi degli articoli 52, comma 5, e 54, comma 11, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

## CAPO II - VALUTAZIONE DEI SERVIZI

### SEZIONE I - SERVIZIO EFFETTIVO

#### Art. 1846. - Ritenuta INPDAP

1. Per il personale in servizio permanente e per il personale volontario in ferma l'Amministrazione provvede al versamento dei contributi previdenziali e assistenziali previsti dalla normativa vigente per i dipendenti dello Stato.

2. Sono assoggettati a ritenuta INPDAP tutti gli emolumenti che formano il trattamento economico fondamentale e accessorio, fatta salva l'applicazione dell'articolo 51 del decreto del Presidente della Repubblica 22 dicembre 1986, n. 917.

#### Art. 1847. - Computo del servizio effettivo

1. Il computo del servizio effettivo si effettua dalla data di assunzione del servizio sino a quella di cessazione dallo stesso.

2. Il tempo trascorso durante la sospensione dall'impiego e' computato in ragione della meta', ferma restando l'integrale non computabilita' dei periodi di detenzione per condanna penale, dei periodi di aspettativa per motivi privati e di quelli trascorsi in qualita' di richiamati senza assegni.

#### Art. 1848. - Riunione e ricongiunzione dei servizi

1. Al personale militare si applicano le norme in materia di riunione e ricongiunzione di servizi, riscatto, totalizzazione dei periodi assicurativi e prosecuzione volontaria previste per i dipendenti dello Stato, in quanto compatibili con le disposizioni del presente capo.

### SEZIONE II - AUMENTI NEL COMPUTO DEI SERVIZI

#### Art. 1849. - Maggiorazioni del servizio effettivo

1. Un periodo di servizio, di cui e' prevista la maggiorazione ai fini pensionistici, si considera una sola volta secondo la normativa piu' favorevole, ai sensi dell'articolo 39 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

2. Per la computabilita' degli aumenti dei periodi di servizio si applicano gli articoli 5 e 7 del decreto legislativo 30 aprile 1997, n. 165.

#### Art. 1850. - Servizio nei reparti di campagna

1. Il servizio prestato nei reparti di campagna di cui all'articolo 3 della legge 23 marzo 1983, n. 78, con percezione delle relative indennita', e' computato con l'aumento di un quinto.

#### Art. 1851. - Servizio di controllo dello spazio aereo

1. Il servizio di controllo dello spazio aereo di cui all'articolo 7 della legge 23 marzo 1983, n. 78, prestato con percezione delle relative indennita', e' computato con l'aumento di un quinto.

#### Art. 1852. - Servizio di navigazione

1. Il servizio di navigazione, prestato con percezione delle indennita' di imbarco di cui all'articolo 4 della legge 23 marzo 1983, n. 78, e' computato ai sensi dell'articolo 19 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

#### Art. 1853. - Servizio di volo

1. Il servizio di volo, prestato con percezione delle indennita' di aeronavigazione e di volo di cui agli articoli 5 e 6 della legge 23 marzo 1983, n. 78, e' computato ai sensi dell'articolo 20 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

#### Art. 1854. - Servizio prestato negli uffici disagiati di frontiera terrestre

1. Il servizio prestato dal personale delle Forze di polizia a ordinamento militare negli uffici disagiati di frontiera terrestre e' computato ai sensi degli articoli 21 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e 16 della legge 7 agosto 1990, n. 232.

#### Art. 1855. - Servizio prestato negli stabilimenti militari di pena

1. Il servizio del personale militare addetto agli stabilimenti militari di pena si computa con l'aumento di un quinto.

#### Art. 1856. - Servizio all'estero presso le rappresentanze diplomatiche

1. Al personale militare che presta servizio all'estero presso rappresentanze diplomatiche di cui all'articolo 1809 nelle sedi disagiate o particolarmente disagiate, si applicano gli aumenti previsti dall'articolo 23 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

#### Art. 1857. - Servizio prestato presso le Forze di polizia

1. Il servizio comunque prestato con percezione dell'indennita' pensionabile per le Forze di polizia di cui all'articolo 43, comma 3, della legge 1° aprile 1981, n. 121, e' computato ai sensi dell'articolo 3, comma 5, della legge 27 maggio 1977, n. 284.

#### Art. 1858. - Campagne di guerra

1. Per ogni campagna di guerra riconosciuta ai sensi delle disposizioni vigenti in materia, il servizio computabile e' aumentato a norma dell'articolo 18 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### SEZIONE III - SERVIZI COMPUTABILI A DOMANDA

#### Art. 1859. - Navigazione mercantile

1. Per coloro che hanno prestato servizio militare nella Marina militare e' computabile, in ragione della meta' della sua durata, il precedente servizio di navigazione su navi nazionali della marina mercantile.

#### Art. 1860. - Studi superiori richiesti agli ufficiali

1. La valutazione degli studi superiori compiuti dagli ufficiali e' effettuata ai sensi dell'articolo 32 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### SEZIONE IV - COSTITUZIONE DI POSIZIONE ASSICURATIVA

#### Art. 1861. - Diritto alla costituzione di posizione assicurativa

1. La costituzione della posizione assicurativa per il militare in servizio permanente e' effettuata ai sensi dell'articolo 124 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

2. Il personale volontario in ferma che cessa dal servizio senza aver acquisito diritto a pensione, ha diritto, all'atto dell'invio in congedo e per l'effettivo periodo di servizio prestato, alla costituzione della posizione assicurativa di cui al comma 1, effettuata a cura e a spese dell'INPDAP, mediante il versamento dei contributi determinati secondo le norme in vigore per la predetta assicurazione.

3. Se il personale di cui al comma 2 assume successivamente servizio pensionabile presso una amministrazione statale, si procede all'annullamento della posizione assicurativa e l'Istituto nazionale della previdenza sociale e' tenuto a rimborsare, senza interesse, l'ammontare dei suddetti contributi salvo che l'interessato rinunci al computo, ai fini della pensione statale, del servizio militare cui si riferiscono i contributi stessi. Se prima dell'assunzione in servizio pensionabile e' stata conseguita pensione di invalidita', l'interessato, per ottenere il computo del servizio militare ai fini della pensione statale, deve rinunciare alla pensione di invalidita' e rifondere all'Istituto nazionale della previdenza sociale le rate riscosse, senza interessi.

4. In favore degli ufficiali piloti e navigatori di complemento, congedati alla scadenza della ferma prevista dall'articolo 943, comma 1 ovvero prosciolti dalla ferma senza aver acquisito il diritto a pensione, l'INPDAP provvede, all'atto dell'invio in congedo e per l'effettivo periodo di servizio prestato, alla costituzione della posizione assicurativa nell'assicurazione obbligatoria per l'invalidita', la vecchiaia e i superstiti, mediante il versamento dei contributi stabiliti dalle norme vigenti. L'importo dei contributi nella misura del 50 per cento e' a carico del militare ed e' trattenuto sul premio di fine ferma eventualmente spettante ai sensi dell'articolo 1797; la parte eccedente rimane a carico dell'INPDAP. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1862. - Divieto di costituzione di posizione assicurativa

1. In aggiunta ai casi previsti dagli articoli 126 e 127 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, non si da' luogo alla costituzione di posizione assicurativa in caso di titolarita' di trattamento pensionistico privilegiato tabellare.

## CAPO III - SISTEMA DI CALCOLO DELLA PENSIONE

### Art. 1863. - Aumenti periodici di stipendio ai fini pensionistici

1. I sei aumenti periodici di stipendio, attribuiti all'atto della cessazione dal servizio, sono computati a norma dell'articolo 4 del decreto legislativo 30 aprile 1997, n. 165.

### Art. 1864. - Trattamento di quiescenza del personale in ausiliaria

1. Per il personale la cui pensione e' liquidata in tutto o in parte con il sistema contributivo, il trattamento pensionistico da attribuire all'atto del collocamento in ausiliaria viene determinato applicando il coefficiente di trasformazione indicato nella tabella A allegata alla legge 8 agosto 1995, n. 335, come periodicamente rideterminato ai sensi dell'articolo 1, comma 11 della stessa legge. Al termine del periodo di permanenza in tale posizione, il trattamento pensionistico viene rideterminato applicando il coefficiente di trasformazione corrispondente all'eta' di cessazione dall'ausiliaria.

### Art. 1865.

Trattamento di quiescenza del personale ((alternativo all'istituto dell'ausiliaria))

1. Per il personale militare ((...)) si applica l'articolo 3, comma 7, del decreto legislativo 30 aprile 1997, n. 165.

### Art. 1866. - Base contributiva e pensionabile

1. La pensione, nel sistema di calcolo retributivo, viene determinata sulla base dello stipendio, dell'indennita' integrativa speciale e degli emolumenti retributivi espressamente definiti pensionabili dalla legge, ai sensi dell'articolo 53 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

2. Al personale militare si applicano le disposizioni in materia di ampliamento della base contributiva e pensionabile previste dall'articolo 2, commi 9, 10 e 11 della legge 8 agosto 1995, n. 335, con decorrenza 1° gennaio 1996.

3. L'incremento previsto dal comma 2 trova applicazione ai fini della determinazione delle sole quote di pensione previste dall'articolo 13, comma 1, lettera b), del decreto legislativo 30 dicembre 1992, n. 503, e per la parte eccedente l'aumento del 18 per cento, calcolato sullo stipendio, esclusa l'indennita' integrativa speciale.

4. La maggiorazione del 18 per cento di cui al comma 3 e' assoggettata alla ritenuta INPDAP di cui all'articolo 1874, in applicazione dell'articolo 15, comma 1, della legge 23 dicembre 1994, n. 724.

### Art. 1867. - Aliquote di rendimento

1. Con effetto dal 1° gennaio 1998, l'aliquota annua di rendimento ai fini della determinazione della misura della pensione e' determinata ai sensi dell'articolo 17, comma 1, della legge 23 dicembre 1994, n. 724, ferma restando l'applicazione della riduzione di cui all'articolo 59, comma 1 della legge 27 dicembre 1997, n. 449, con la stessa decorrenza.

2. Ai sensi dell'articolo 2, comma 19, della legge 8 agosto 1995, n. 335, l'applicazione delle disposizioni di cui al comma 1 non puo' comportare un trattamento superiore a quello che sarebbe spettato in base all'applicazione delle aliquote di rendimento previste dalle norme di cui all'articolo 54 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1868. - Effetti pensionistici delle indennita' di impiego operativo

1. L'indennita' di impiego operativo di base di cui all'articolo 2 della legge 23 marzo 1983, n. 78, e' pensionabile.

2. Per i periodi di percezione delle indennita' operative di campagna, di imbarco e di controllo dello spazio aereo, di cui alla stessa legge, il predetto importo e' maggiorato, per ogni anno di servizio effettivo prestato con percezione delle relative indennita' e per un periodo massimo complessivo di 20 anni, secondo le seguenti percentuali:

- a) reparti di campagna: 0,75;
- b) reparti di campagna per truppe alpine: 1,25;
- c) imbarco su mezzi di superficie: 3,5; imbarco su sommergibili: 6;
- d) controllo dello spazio aereo: I grado di abilitazione: 1,25; II grado di abilitazione: 2; III grado di abilitazione: 3,75.

3. Se i predetti periodi risultano superiori al massimo di 20 anni computabili, si tiene conto delle indennita' piu' favorevoli percepite nel tempo dagli interessati.

4. Per il personale che si trova a operare nelle condizioni di impiego di cui agli articoli 17 e 13, commi 6 e 7, della stessa legge, la percentuale dell'indennita' meno favorevole e' pensionabile in proporzione agli anni di servizio prestato nelle predette condizioni.

### Art. 1869. - Maggiorazione per i percettori dell'indennita' di aeronavigazione o di volo

1. Per il personale militare che ha percepito le indennita' di aeronavigazione o di volo, la pensione normale e l'indennita' per una volta tanto sono aumentate di una aliquota corrispondente a tanti ventottesimi dei nove decimi delle indennita' di aeronavigazione o di volo percepite, calcolate ad anno, per quanti sono gli anni di servizio effettivo prestati con percezione di dette indennita' e con il massimo di venti ventottesimi, per i primi venti anni di servizio di aeronavigazione e di volo.

2. La pensione normale di cui al comma 1 e', altresi', aumentata di una ulteriore aliquota pari all'1,30 per cento delle indennita' di aeronavigazione o di volo spettanti all'atto della cessazione, per ogni anno di servizio di aeronavigazione o di volo successivo ai venti anni di cui al comma 1.

3. La somma degli aumenti di cui ai commi 1 e 2 non puo' superare l'80 per cento delle indennita' stesse.

4. A fini dell'applicazione del presente articolo si tiene conto del grado rivestito e dell'anzianita' di servizio aeronavigante o di volo maturata dall'interessato all'atto della cessazione dal sevizio. Il calcolo delle aliquote pensionabili delle indennita' di aeronavigazione e di volo, di cui ai commi 1 e 2, e' effettuato separatamente per ciascun periodo di impiego sui vari tipi di ((aeromobili)), tenendo conto della durata di ciascuno di tali periodi e sulla base delle corrispondenti indennita' nelle misure vigenti all'atto della cessazione dal servizio.

5. Per i periodi di servizio superiori al massimo pensionabile si tiene conto delle misure piu' favorevoli percepite, nel tempo, dagli interessati.

6. Per i periodi anteriori al 1° luglio 1970 l'attivita' di volo svolta sui velivoli da caccia e' assimilata a quella svolta sugli aviogetti.

7. Per gli ufficiali, i sottufficiali e i militari di truppa non appartenenti all'Aeronautica che hanno svolto attivita' di volo, di osservazione aerea o di paracadutismo e hanno percepito l'indennita' di aeronavigazione o di volo, la pensione e l'indennita' per una volta tanto sono aumentati di un'aliquota di dette indennita' nella misura e con i limiti previsti dai commi da 1 a 6.

8. La quota in pensione del trattamento accessorio, risultante dal cumulo della quota maturata delle indennita' di aeronavigazione o di volo e della quota in pensione risultante dall'applicazione dell'articolo 1868 non puo' superare l'importo dell'80 per cento, rispettivamente, delle indennita' di aeronavigazione o di volo previste dagli articoli 5 e 6 della legge 23 marzo 1983, n. 78.

### Art. 1870. - Calcolo dell'indennita' di ausiliaria

1. Al militare in ausiliaria compete, in aggiunta al trattamento di quiescenza, una indennita' annua lorda, pari al 50 per cento della differenza tra il trattamento di quiescenza percepito e il trattamento economico spettante nel tempo al pari grado in servizio dello stesso ruolo, e con anzianita' di servizio corrispondente a quella effettivamente posseduta dal militare all'atto del collocamento in ausiliaria.

2. Il trattamento economico spettante nel tempo al pari grado in servizio e' inteso come comprensivo di tutte le maggiorazioni e di tutte le indennita'.

3. Per il calcolo della predetta differenza non si tiene conto, con riferimento a entrambi i termini del raffronto:

- a) dell'indennita' integrativa speciale;
- b) della quota degli assegni per il nucleo familiare;
- c) degli scatti per ex combattenti previsti dalla legge 24 maggio 1970, n. 336;
- d) dell'eventuale pensione privilegiata;
- e) delle maggiorazioni che costituiscono trattamento economico aggiuntivo;
- f) degli aumenti periodici di stipendio di cui all'articolo 1863;
- g) delle quote aggiuntive previste dall'articolo 161 della legge 11 luglio 1980, n. 312, per il personale dirigente;
- h) degli incrementi corrisposti a titolo di perequazione automatica;
- i) dell'indennita' di posizione e dirigenziale; (44)
- l) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 94));
- m) della speciale indennita' pensionabile di cui all'articolo 1818.

4. L'indennita' di ausiliaria, nel sistema di calcolo retributivo, e' pensionabile al cessare della posizione di ausiliaria.

------------ AGGIORNAMENTO (44) Il D.Lgs. 29 maggio 2017, n. 94 ha disposto (con l'art. 11, comma 2) che la presente modifica ha effetto a decorrere dal 1° gennaio 2018.

### Art. 1871. - Riliquidazione al termine dell'ausiliaria del trattamento di quiescenza determinato con il sistema di calcolo retributivo

1. Il periodo di permanenza in ausiliaria e' computato per intero agli effetti della pensione come servizio effettivo, anche se il militare non e' stato nel periodo stesso richiamato in servizio. Non e' invece computato il periodo di tempo durante il quale il militare ha prestato altro servizio produttivo di pensione, salva l'opzione del medesimo ai fini della pensione militare.

2. Allo scadere del periodo di permanenza in ausiliaria, e' liquidato al militare un nuovo trattamento di quiescenza con il computo di detto periodo e sulla base degli assegni pensionabili che sono serviti ai fini della liquidazione del trattamento concesso all'atto della cessazione dal servizio permanente, maggiorati sia degli aumenti periodici del 2,50 per cento dello stipendio per ogni biennio trascorso in ausiliaria, sia dell'indennita' di cui articolo 1870.

3. Se il militare e' stato richiamato per almeno un anno, e' liquidato al termine del richiamo un nuovo trattamento di quiescenza sulla base degli assegni pensionabili percepiti durante il richiamo, maggiorati degli aumenti biennali inerenti al periodo di ausiliaria trascorso senza richiamo.

4. Per i militari collocati in ausiliaria per effetto dell'avvenuta cessazione del trattamento pensionistico di guerra, il periodo di permanenza in ausiliaria non e' computabile nei confronti di coloro che hanno gia' fruito dell'aumento di sei anni di cui all'articolo 63 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1872. - Riliquidazione al personale nella riserva o in congedo assoluto del trattamento di quiescenza determinato con il sistema di calcolo retributivo

1. L'ufficiale cessato dal servizio permanente per eta' o per invalidita' e collocato direttamente nella riserva o in congedo assoluto, al compimento in tali posizioni di un periodo corrispondente a quello massimo di permanenza in ausiliaria, ha diritto alla riliquidazione della pensione sulla base dello stipendio e degli altri assegni pensionabili da ultimo percepiti, maggiorati degli aumenti periodici del 2,50 per cento dello stipendio per ogni biennio trascorso nella predetta condizione.

2. Il diritto di cui al comma 1 spetta all'ufficiale collocato nella riserva o in congedo assoluto dalla categoria dell'ausiliaria, in applicazione dell'articolo 995, in relazione alla minore durata della permanenza in ausiliaria.

### Art. 1873. - Trattamento di quiescenza determinato con il sistema di calcolo retributivo al personale dirigente cessato dalla posizione di aspettativa per riduzione dei quadri

1. Agli ufficiali dirigenti che cessano dalla posizione di aspettativa per riduzione dei quadri competono, in aggiunta a qualsiasi altro beneficio spettante:

- a) il trattamento pensionistico che sarebbe loro spettato qualora fossero rimasti in servizio fino al limite di eta', compresi gli aumenti periodici e i passaggi di classe di stipendio commisurati al trattamento percepito all'atto della cessazione;
- b) l'indennita' di ausiliaria di cui all'articolo 1870.

2. Gli stessi ufficiali hanno diritto alla riliquidazione del trattamento di quiescenza al termine dell'ausiliaria, secondo le modalita' di cui all'articolo 1871.

### Art. 1874. - Ritenuta INPDAP sul trattamento di quiescenza

1. La ritenuta INPDAP e' operata, nella misura prevista per i dipendenti dello Stato in attivita' di servizio, sull'ammontare complessivo della pensione ((, dell'indennita' di ausiliaria)) e della tredicesima mensilita', esclusa la parte pensionabile delle indennita' di impiego operativo, percepite durante il periodo di permanenza in ausiliaria nonche' durante i corrispondenti periodi trascorsi nella riserva o nel congedo assoluto, se questi ultimi sono computabili ai fini degli aumenti periodici biennali del 2,50 per cento dello stipendio, nel sistema di calcolo retributivo. Se il collocamento nella riserva o in congedo assoluto e' stato determinato da ferite, lesioni o infermita' riportate o aggravate per causa di guerra, la ritenuta non e' operata.

2. Il trattamento corrisposto agli ufficiali in ausiliaria e' assoggettato al contributo previsto per il personale in servizio in favore della Gestione unitaria delle prestazioni creditizie e sociali presso l'INPDAP.

### Art. 1875. - Riliquidazione della pensione al personale richiamato dal congedo

1. Gli ufficiali, i sottufficiali e i militari di truppa provvisti di pensione normale e richiamati in servizio hanno diritto, all'atto del ricollocamento in congedo o in congedo assoluto, alla riliquidazione della pensione in relazione al nuovo servizio prestato; se il richiamo ha avuto una durata di almeno un anno intero, ai fini della riliquidazione si considera anche l'ultimo stipendio percepito, nel sistema di calcolo retributivo.

### Art. 1876.

Norma di salvaguardia per il personale ((trattenuto in servizio ovvero)) richiamato dal congedo o dall'ausiliaria

1. Al personale ((trattenuto in servizio ovvero)) richiamato con assegni dal congedo o dalla posizione ausiliaria spetta il trattamento economico di attivita', se piu' favorevole rispetto al trattamento di quiescenza e all'indennita' di ausiliaria in godimento.

### Art. 1877. - Non cumulabilita' delle rate di pensione con assegni di attivita' spettanti dopo la cessazione dal servizio

1. ((Al militare cessato dal servizio permanente ai sensi dell'articolo 929, comma 1, sono corrisposti per un periodo di tre mesi gli interi assegni spettanti al pari grado del servizio permanente.)) Si applica l'articolo 58 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, in materia di cumulo delle rate di pensione con gli assegni di attivita' spettanti dopo la cessazione dal servizio.

## TITOLO III TRATTAMENTI PER LE INVALIDITA' DI SERVIZIO CAPO I RICONOSCIMENTO DELLA CAUSA DI SERVIZIO

### Art. 1878. - Accertamento della causa di servizio

1. Ai procedimenti per la concessione, al personale militare, di benefici collegati al riconoscimento di causa di servizio, si applicano le disposizioni recate dal decreto del Presidente della Repubblica 29 ottobre 2001, n. 461, ((e dall'articolo 6 del decreto-legge 6 dicembre 2011, n. 201, convertito, con modificazioni, dalla legge 22 dicembre 2011, n. 214,)) fermo restando il regime di definitivita' delle pronunce su lesioni traumatiche da causa violenta secondo le disposizioni dell'articolo 1880.

### Art. 1879. - Accertamento diagnostico delle menomazioni

1. Gli accertamenti sanitari sull'entita' delle menomazioni dell'integrita' psicofisica del dipendente, propedeutici al giudizio di riconoscimento della causa di servizio, sono eseguiti dalle Commissioni mediche ospedaliere di cui all'articolo 193.

2. Restano ferme le disposizioni sulla composizione e il funzionamento del Collegio medico-legale presso il Ministero della difesa, ai sensi dell'articolo 189.

### Art. 1880. - Accertamento della dipendenza in caso di lesioni traumatiche da causa violenta

1. Il giudizio sulla dipendenza da causa di servizio delle lesioni traumatiche e' pronunciato dal direttore di una delle strutture sanitarie militari di cui all'articolo 195, sempre che dette lesioni siano immediate o dirette, con chiara fisionomia clinica e con i caratteri dell'infortunio da causa violenta, e abbiano determinato inizialmente il ricovero in una delle citate strutture ((o in una struttura pubblica del Servizio sanitario nazionale. Il citato giudizio puo' essere espresso anche sulla base degli accertamenti effettuati entro due giorni dall'evento da un'autorita' sanitaria militare o da struttura pubblica del Servizio sanitario nazionale anche quando non abbiano determinato inizialmente il ricovero. La medesima procedura e' applicabile alle lesioni traumatiche da causa violenta occorse nell'ambito di attivita' operativa o addestrativa svolta all'estero e che abbiano provocato il ricovero ovvero siano state accertate entro due giorni dall'evento presso struttura sanitaria estera militare o civile)).

2. Il giudizio di dipendenza di cui al comma 1 e' espresso sulla base di dati clinici rilevati e degli elementi e circostanze di fatto riportati nelle dichiarazioni a tale scopo formulate dal dirigente del servizio sanitario e dal Comandante del corpo e del reparto distaccato o dal capo del servizio presso il quale l'evento lesivo si e' verificato.

3. Il giudizio di cui al comma 1 deve essere espresso nel piu' breve tempo possibile e, comunque, durante la degenza dell'infermo.

4. Le complicanze e l'eventuale decesso, sopraggiunti durante il ricovero in uno dei suddetti luoghi di cura, devono formare oggetto di nuovo giudizio del direttore del luogo di cura, all'atto della dimissione o del decesso.

5. Delle conclusioni diagnostiche e medico legali e del relativo giudizio deve essere data partecipazione all'interessato.

6. In caso di non accettazione, viene eseguita, a domanda dell'interessato, la normale procedura di riconoscimento della dipendenza da causa di servizio di cui al decreto del Presidente della Repubblica 29 ottobre 2001, n. 461.

7. Se la lesione e' riconosciuta dipendente da causa di servizio, il giudizio sulla idoneita' al servizio e sulla eventuale assegnazione a una delle categorie di cui alle tabelle annesse al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e' devoluto alle Commissioni mediche ospedaliere di cui all'articolo 193.

### Art. 1881. - Rimborso spese di cura

1. Sono a carico dell'Amministrazione le spese di cura, comprese quelle per ricoveri in istituti sanitari e per protesi sostenute dal personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e delle Forze di polizia a ordinamento militare, ai sensi degli articoli 68, comma 8 del decreto del Presidente della Repubblica 10 gennaio 1957, n. 3, 34, comma 2 della legge 16 gennaio 2003, n. 3, 1, commi 219, 220 e 221 della legge 23 dicembre 2005, n. 266 e 1, comma 555, della legge 27 dicembre 2006, n. 296.

## CAPO II - EQUO INDENNIZZO

### Art. 1882. - Equo indennizzo

1. L'equo indennizzo e' corrisposto al personale militare, anche non in servizio permanente e agli allievi delle Forze di polizia a ordinamento militare, secondo le disposizioni stabilite per i dipendenti dello Stato.

### Art. 1883. - Anticipo dell'equo indennizzo

1. Ai superstiti dei militari deceduti a seguito di incidente di volo, aventi diritto all'equo indennizzo nella misura corrispondente alla 1^ categoria della tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e' concesso d'ufficio un anticipo nella misura pari ai nove decimi dell'ammontare globale del beneficio stesso, avuto riguardo alla misura in vigore al verificarsi dell'evento lesivo.

2. L'anticipo di cui al comma 1 e' concesso sul fondo scorta dell'ente che amministra il personale che ha subito l'incidente, non appena il competente organo medico legale ha giudicato che la morte e' avvenuta in servizio e per causa di servizio. Il suddetto anticipo e' reintegrato in sede di liquidazione definitiva dell'indennizzo.

## CAPO III - TRATTAMENTO PRIVILEGIATO ORDINARIO

### Art. 1884. - Pensione privilegiata

1. Il trattamento pensionistico privilegiato e' corrisposto al personale militare secondo le disposizioni stabilite per i dipendenti dello Stato, in quanto compatibili con le norme del presente codice.

### Art. 1885. - Pensione privilegiata per ufficiali, sottufficiali e graduati

1. La pensione privilegiata per ufficiali, sottufficiali e graduati e' disciplinata dall'articolo 67, commi 1-4, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1886. - Pensione privilegiata tabellare

1. La pensione privilegiata tabellare e' determinata ai sensi dell'articolo 67, comma 5, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

2. All'importo della pensione, si aggiunge l'indennita' integrativa speciale, corrisposta in via separata ai sensi dell'articolo 2 della legge 27 maggio 1959, n. 324.

3. La pensione privilegiata tabellare correlata a menomazioni verificatesi durante il servizio militare di leva e' esente da imposta sul reddito.

4. Il periodo di servizio che ha dato luogo alla pensione privilegiata tabellare, diverso da quello di leva, non puo' essere ulteriormente valutato ai fini di quiescenza.

### Art. 1887. - Pensione privilegiata per gli allievi delle accademie militari

1. La pensione privilegiata spettante agli allievi delle accademie militari e dell'accademia del Corpo della Guardia di finanza e' determinata ai sensi dell'articolo 76 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1888. - Computo delle indennita' di aeronavigazione e di volo

1. Per gli ufficiali e sottufficiali che hanno percepito le indennita' di aeronavigazione o di volo e relative indennita' supplementari, la pensione privilegiata di prima categoria e' aumentata dell'aliquota indicata nell'articolo 1869, con un minimo di aumento corrispondente a diciotto ventottesimi.

2. Per i militari di truppa l'aumento di cui al comma 1 e' stabilito nella misura di euro 82,63 se piloti, di euro 41,32 se specialisti.

3. L'aumento della pensione di categoria inferiore alla prima e' determinato applicando, alla misura dell'indennita' stabilita per la prima categoria, le percentuali di cui all'articolo 67 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

4. In nessun caso la pensione privilegiata puo' superare l'ultimo stipendio percepito, aumentato dell'ultima indennita' di aeronavigazione o di volo calcolata ad anno.

### Art. 1889. - Assegno rinnovabile per i militari

1. Se le infermita' o le lesioni ascrivibili a una delle categorie della tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, sono suscettibili di miglioramento, spetta al militare un assegno rinnovabile ai sensi degli articoli 68 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e 5 della legge 26 gennaio 1980, n. 9. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 1890. - Indennita' per una volta tanto al personale militare

1. Al militare che ha contratto infermita' o riportato lesioni, dipendenti da fatti di servizio e ascrivibili alla tabella B annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e' corrisposta una indennita' per una volta tanto ai sensi degli articoli 69, comma 1, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e 4, comma 2, della legge 26 gennaio 1980, n. 9. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 1891. - Criteri di applicazione delle tabelle A e B

1. Le infermita' non esplicitamente elencate nelle tabelle A e B annesse al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, devono ascriversi alle categorie che comprendono infermita' equivalenti tenendo conto di quanto indicato nei criteri di applicazione delle medesime tabelle A e B.

### Art. 1892. - Cumulo della pensione o dell'assegno rinnovabile con l'indennita' per una volta tanto

1. Il cumulo della pensione o dell'assegno rinnovabile con l'indennita' per una volta tanto e' disciplinato dall'articolo 69, comma 2, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1893. - Servizio in tempo di guerra

1. Il servizio in tempo di guerra non da' titolo al trattamento privilegiato ordinario, fatte salve le condizioni previste dall'articolo 80 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

### Art. 1894. - Assegni accessori alla pensione privilegiata ordinaria

1. Agli invalidi per servizio competono, in aggiunta alla pensione o all'assegno rinnovabile, gli assegni accessori previsti dal decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

## CAPO IV - TRATTAMENTI SPECIALI CORRELATI ALLA CAUSA DI SERVIZIO

### SEZIONE I - PROVVIDENZE AI FAMILIARI DI MILITARI VITTIME DEL SERVIZIO

#### Art. 1895. - Speciale elargizione ai superstiti del personale non in servizio permanente effettivo deceduto durante il servizio

1. Ai superstiti dei caduti durante il periodo di servizio, appartenenti a una delle seguenti categorie di personale non in servizio permanente, e' corrisposta la speciale elargizione di euro 25.822,84:

- a) militari in servizio di leva;
- b) richiamati nelle Forze armate, nella Guardia di finanza e nei Corpi ausiliari delle Forze armate;
- c) allievi carabinieri;
- d) allievi finanzieri;
- e) allievi delle accademie militari;
- f) allievi delle scuole e dei licei militari;
- g) volontari in ferma.

2. La speciale elargizione di cui al comma 1 non spetta ai familiari di coloro che al momento dell'evento dannoso si trovavano in licenza, in permesso o fuori dal presidio senza autorizzazione.

#### Art. 1896. - Speciale elargizione ai superstiti del personale deceduto a causa di servizio

1. Ai superstiti dei soggetti deceduti in attivita' di servizio per diretto effetto di ferite o lesioni causate da eventi di natura violenta, riportate nell'adempimento del servizio, appartenenti a una delle seguenti categorie di personale, e' corrisposta una speciale elargizione pari al 50 per cento del beneficio previsto dagli articoli 6 della legge 13 agosto 1980, n. 466, 4 della legge 20 ottobre 1990, n. 302 e 5, comma 5, della legge 3 agosto 2004, n. 206, aumentata di un ulteriore 30 per cento, quando il dante causa ha familiari fiscalmente a carico:

- a) militari in servizio permanente e di complemento;
- b) personale delle Forze di polizia a ordinamento militare;
- c) militari in servizio di leva;
- d) richiamati nelle Forze armate, nella Guardia di finanza e nei Corpi ausiliari delle Forze armate;
- e) allievi carabinieri;
- f) allievi finanzieri;
- g) allievi delle accademie militari;
- h) allievi delle scuole e dei licei militari;
- i) volontari in ferma.

2. L'importo della speciale elargizione di cui al comma 1 e' soggetto a rivalutazione annuale automatica in misura pari al tasso di inflazione accertato per l'anno precedente, sulla base dei dati ufficiali ISTAT.

#### Art. 1897. - Speciale trattamento pensionistico di reversibilita'

1. La pensione privilegiata spettante al coniuge superstite e agli orfani degli ufficiali, dei sottufficiali e dei graduati delle Forze armate e delle Forze di polizia a ordinamento militare, caduti vittime del dovere, in servizio di ordine pubblico o di vigilanza a infrastrutture civili e militari, ovvero in operazioni di soccorso, ovvero deceduti successivamente per la stessa causa, e' stabilita in misura pari al trattamento complessivo di attivita' percepito dal congiunto all'epoca del decesso o, se piu' favorevole, in misura pari al trattamento complessivo di attivita' del grado immediatamente superiore a quello rivestito dal congiunto all'epoca del decesso, ivi compresi gli emolumenti pensionabili, con esclusione degli assegni per il nucleo familiare e dell'indennita' integrativa speciale che sono corrisposte nella misura stabilita per i pensionati.

2. Per il coniuge superstite e gli orfani dei militari di truppa, caduti vittime del dovere in servizio di ordine pubblico o di vigilanza a infrastrutture civili e militari, ovvero in operazioni di soccorso, la pensione privilegiata ordinaria e' liquidata a norma dell'articolo 67, comma 5, del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092.

3. E' fatto salvo quanto disposto dall'articolo 2 della legge 24 maggio 1970, n. 336, e, se piu' favorevole, il trattamento privilegiato ordinario nella misura e alle condizioni previste dalle disposizioni in materia di pensioni di guerra. Ai titolari di pensione cosi' determinata, va attribuito, se piu' favorevole, il trattamento previsto dal presente articolo.

4. La pensione spettante, in mancanza del coniuge superstite o degli orfani, ai genitori e ai collaterali dei militari indicati ai commi da 1 a 3 e' liquidata applicando le percentuali previste dalle norme in vigore.

5. Il trattamento speciale di pensione di cui al presente articolo sara' riliquidato in relazione alle variazioni della composizione del nucleo familiare e ai miglioramenti economici attribuiti ai militari in attivita' di servizio di grado corrispondente a quello posto a base del trattamento pensionistico.

### SEZIONE II - INDENNIZZO PRIVILEGIATO AERONAUTICO

#### Art. 1898. - Destinatari dell'indennizzo privilegiato aeronautico

1. L'indennizzo privilegiato aeronautico e' concesso ai militari delle Forze armate, i quali prestino servizio di volo, anche come allievi presso le scuole di pilotaggio, nonche' agli allievi delle scuole e degli istituti di istruzione dei corpi di polizia a ordinamento militare e agli allievi del primo anno dell'Accademia navale, i quali, in seguito a incidente di volo subito in servizio comandato, anche soltanto come passeggeri, sono dichiarati permanentemente inabili al servizio per infermita' ascrivibili a una delle prime tre categorie della tabella A allegata al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915.

2. Gli accertamenti relativi alle infermita' di cui al comma 1, sono effettuati con le norme stabilite per la concessione delle pensioni privilegiate.

3. Per incidente di volo deve intendersi ogni evento che ha diretta e immediata attinenza all'aeronavigazione, e che si e' verificato in danno dei militari a bordo dell'aeromobile, dal momento in cui e' iniziato il moto per spiccare il volo fino al momento della fermata dopo il volo stesso, ovvero dopo un forzato atterraggio o ammaraggio, anche quando il danno e' conseguente al lancio con paracadute da un aeromobile eseguito anche a scopo di semplice esercitazione.

4. L'indennizzo privilegiato aeronautico e' esteso al personale militare dello Stato che, essendo in servizio presso gli aeroporti, riporti invalidita' in conseguenza di incidente di volo.

5. Se dall'incidente di volo e' derivata la morte del militare, l'indennizzo e' liquidato alle famiglie, nel seguente ordine di priorita':

- a) coniuge superstite, anche se separato, purche' senza addebito, per l'intero ammontare oppure in concorso con gli orfani in ragione del 75, 60, 50 e 45 per cento del relativo importo, secondo che i figli stessi siano, rispettivamente, rappresentati in numero di 1, 2, 3, 4 e piu', mentre la rimanente quota va ripartita tra i figli o i loro discendenti;
- b) figli legittimi, legittimati, adottivi e naturali riconosciuti, in mancanza del coniuge superstite;
- c) genitori, in mancanza di coniuge superstite e figli;
- d) fratelli e sorelle, in mancanza di coniuge superstite, figli e genitori.

#### Art. 1899. - Misura dell'indennizzo privilegiato aeronautico

1. L'indennizzo privilegiato aeronautico, in caso di decesso di un dipendente militare, e' determinato nei seguenti importi, maggiorati di euro 619,75 per ciascun figlio fiscalmente a carico:

- a) ufficiali generali: 1) euro 7.746,85 ai soggetti di cui alle lettere a) e
- b) dell'articolo 1898; 2) euro 1.936,71 ai soggetti di cui alle lettere c) e d) dell'articolo 1898; b) ufficiali superiori: 1) euro 6.197,48 ai soggetti di cui alle lettere a) e b) dell'articolo 1898; 2) euro 1.549,37 ai soggetti di cui alle lettere c) e d) dell'articolo 1898;
- c) ufficiali inferiori: 1) euro 4.648,11 ai soggetti di cui alle lettere a) e b) dell'articolo 1898; 2) euro 1.208,51 ai soggetti di cui alle lettere c) e
- d) dell'articolo 1898; d) sottufficiali: 1) euro 3.873,43 ai soggetti di cui alle lettere a) e b) dell'articolo 1898; 2) euro 991,60 ai soggetti di cui alle lettere c) e d) dell'articolo 1898;
- e) graduati e militari di truppa: 1) euro 3.098,74 ai soggetti di cui alle lettere a) e b) dell'articolo 1898; 2) euro 774,69 ai soggetti di cui alle lettere c) e d) dell'articolo 1898.

2. L'indennizzo privilegiato aeronautico, in caso di infermita' di un dipendente militare, e' determinato nei seguenti importi, maggiorati di euro 619,75 per ciascun figlio fiscalmente a carico, per patologie ascrivibili alla 1^ e alla 2^ categoria della tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e di euro 309,87, per infermita' ascrivibili alla 3^ categoria della tabella A:

- a) ufficiali generali: euro 7.746,85 per infermita' ascrivibile alla 1^ categoria, euro 6.972,17 per la 2^ categoria ed euro 1.936,71 per la 3^ categoria;
- b) ufficiali superiori: euro 6.197,48 per infermita' ascrivibile alla 1^ categoria, euro 5.577,73 per la 2^ categoria ed euro 1.549,37 per la 3^ categoria;
- c) ufficiali inferiori: euro 4.648,11 per infermita' ascrivibile alla 1^ categoria, euro 4.338,24 per la 2^ categoria ed euro 1.208,51 per la 3^ categoria;
- d) sottufficiali: euro 3.873,43 per infermita' ascrivibile alla 1^ categoria, euro 3.563,55 per la 2^ categoria ed euro 991,60 per la 3^ categoria;
- e) graduati e militari di truppa: euro 3.098,74 per infermita' ascrivibile alla 1^ categoria, euro 2.788,87 per la 2^ categoria ed euro 774,69 per la 3^ categoria.

3. Le misure di cui ai commi 1 e 2 sono aumentate di tanti dodicesimi delle somme stesse quanti sono gli anni di servizio di volo effettivamente prestati dal militare.

4. Se nell'insieme del servizio di volo prestato, ai fini della disposizione di cui al comma 3, risulta una frazione di anno, il periodo che eccede i sei mesi si calcola come un anno intero, mentre il periodo uguale o inferiore ai sei mesi si trascura.

5. Per i militari in congedo, che compiono esercitazioni di allenamento e addestramento, l'aumento e' pari a tanti dodicesimi quanti sono gli anni nei quali i militari stessi sono stati richiamati per allenamento o addestramento, indipendentemente dalla durata del servizio prestato per ciascuno degli anni stessi.

6. Nei casi in cui l'indennizzo privilegiato aeronautico risulti di importo inferiore all'assicurazione obbligatoria prevista dall'articolo 941 del codice della navigazione, l'ammontare di esso e' elevato fino alla concorrenza della predetta assicurazione.

7. In ogni caso, l'indennizzo non e' cumulabile con l'assicurazione obbligatoria prevista dall'articolo 941 del codice della navigazione. Se quest'ultima e' di importo inferiore, l'indennizzo e' corrisposto per la differenza.

#### Art. 1900. - Indennizzo privilegiato aeronautico integrativo

1. A ciascun figlio minore del dipendente militare, deceduto per incidente di volo come qualificato dall'articolo 1898 e' concesso, in aggiunta all'indennizzo privilegiato aeronautico, un indennizzo integrativo dell'importo di euro 2.685,58.

2. L'indennizzo integrativo compete anche ai figli maggiorenni che risultano permanentemente inabili a proficuo lavoro alla data di morte del genitore.

#### Art. 1901. - Anticipo dell'indennizzo privilegiato aeronautico

1. Ai superstiti aventi diritto all'indennizzo privilegiato aeronautico nella misura corrispondente alla 1^ categoria della tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e' concesso d'ufficio un anticipo nella misura pari ai nove decimi dell'ammontare globale del beneficio stesso, avuto riguardo alla misura in vigore al verificarsi dell'evento lesivo.

2. L'anticipo e' concesso sul fondo scorta dell'ente che amministra il personale che ha subito l'incidente, non appena il competente organo medico legale giudica che la morte e' connessa al servizio di volo. Il predetto anticipo e' reintegrato in sede di liquidazione definitiva dell'indennizzo.

#### Art. 1902. - Cause di esclusione dell'indennizzo privilegiato aeronautico

1. L'indennizzo privilegiato aeronautico non spetta a coloro che sono incorsi in condanna definitiva, che ha avuto per effetto l'interdizione perpetua dai pubblici uffici.

2. L'indennizzo non spetta per gli incidenti di volo che si verificano durante lo stato di guerra dal momento dell'inizio dell'ostilita' fino a quello della loro cessazione.

#### Art. 1903. - Termini di decadenza della domanda di indennizzo privilegiato aeronautico

1. La domanda per la concessione dell'indennizzo privilegiato aeronautico deve essere presentata all'Amministrazione militare, a pena di decadenza, entro il termine di cinque anni dalla morte del militare.

2. Avverso il provvedimento e' ammesso il ricorso alla Corte dei conti.

### SEZIONE III - PROVVIDENZE ALLE VITTIME DEL TERRORISMO, DELLA CRIMINALITA' E DEL DOVERE

#### Art. 1904. - Vittime del terrorismo, della criminalita' e del dovere

1. Al personale militare spettano le provvidenze in favore delle vittime del terrorismo, della criminalita' e del dovere, previste dalle seguenti disposizioni:

- a) legge 13 agosto 1980, n. 466;
- b) legge 20 ottobre 1990, n. 302;
- c) legge 23 novembre 1998, n. 407;
- d) legge 3 agosto 2004, n. 206;
- e) legge 10 ottobre 2005, n. 207.

### SEZIONE IV - PROVVIDENZE AI SOGGETTI ESPOSTI A SPECIFICI FATTORI DI RISCHIO

#### Art. 1905. - Provvidenze alle vittime di incidenti causati da attivita' istituzionali delle Forze armate

1. Ai superstiti delle vittime di incidenti verificatisi nel corso o in conseguenza di attivita' operative e addestrative svolte dalle Forze armate sul territorio nazionale nell'adempimento di compiti assegnati, e' concessa un'elargizione nella misura di 51.645,69 euro, che spetta solo se la vittima o i suoi aventi causa non hanno in alcun modo concorso all'incidente con dolo o colpa grave. L'elargizione, che non esclude il risarcimento del maggior danno eventualmente dovuto, e' esente da imposte e non e' cumulabile con altre provvidenze corrisposte allo stesso titolo.

2. L'elargizione e' corrisposta ai superstiti fiscalmente a carico nell'ordine di priorita':

- a) coniuge e figli;
- b) figli, in mancanza del coniuge;
- c) genitori;
- d) fratelli e sorelle, se conviventi. Fermo restando il predetto ordine, nell'ambito di ciascuna categoria, si applicano le disposizioni sulle successioni legittime stabilite dal codice civile.

3. Se a causa degli incidenti indicati nel comma 1 deriva un'invalidita' permanente, al danneggiato spetta un'anticipazione sulle somme delle quali l'Amministrazione della difesa risultera' debitrice. La misura dell'anticipazione e' stabilita in ragione del grado di invalidita' e del costo delle cure mediche, gia' effettuate o da effettuare, necessarie a limitare il danno.

4. Agli invalidi, al coniuge superstite e ai figli delle vittime degli incidenti di cui al comma 1, se in possesso della cittadinanza italiana, si applicano le disposizioni della legge 12 marzo 1999, n. 68.

5. Le modalita' di attuazione delle norme previste dal presente articolo sono stabilite nel regolamento.

#### Art. 1906. - Provvidenze a favore delle vittime di ordigni bellici in tempo di pace

1. Ai cittadini italiani divenuti invalidi a seguito di scoppio di armi e ordigni esplosivi lasciati incustoditi o abbandonati dalle Forze armate in tempo di pace in occasione di esercitazioni combinate o isolate, e ai loro familiari, in caso di decesso, e' attribuito il trattamento di quiescenza di cui all'articolo 1886.

2. Per il trattamento di pensione di cui al comma 1 trova applicazione la normativa prevista per i mutilati e gli invalidi per servizio.

3. Il trattamento di pensione di cui al comma 1 e' esente dall'imposta sul reddito.

#### Art. 1907. - (( (Personale esposto a particolari fattori di rischio) 1. I termini e le modalita' per il riconoscimento della causa di servizio e per la corresponsione di adeguati indennizzi per il personale che a causa dell'esposizione a particolari fattori di rischio ha contratto infermita' o patologie tumorali sono disciplinati dall'articolo 603, che detta altresi' il relativo limite massimo di spesa, e dal regolamento))

## TITOLO IV TRATTAMENTO DI FINE SERVIZIO

### Art. 1908. - Trattamento di fine servizio

1. Il trattamento di fine servizio, e' corrisposto al personale militare secondo le disposizioni stabilite per i dipendenti dello Stato, in quanto compatibili con le norme del presente codice.

### Art. 1909. - Computo del servizio comunque prestato

1. Il servizio militare comunque prestato, ivi compresi i periodi pre-ruolo, e' riscattabile ai sensi dell'articolo 5, commi 4 e 6, del decreto legislativo 30 aprile 1997, n. 165.

### Art. 1910. - Effetti degli emolumenti pensionabili ai fini del trattamento di fine servizio

1. La base contributiva del trattamento di fine servizio e' determinata ai sensi dell'articolo 38 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1032.

### Art. 1911. - Attribuzione dei sei aumenti periodici di stipendio ai fini del trattamento di fine servizio

1. In alternativa alla promozione alla vigilia disciplinata dall'articolo 1082, gli ufficiali in servizio permanente possono chiedere l'attribuzione, ai fini della liquidazione del trattamento di fine servizio, di sei aumenti periodici di stipendio, in aggiunta a qualsiasi altro beneficio spettante.

2. Il beneficio dei sei aumenti periodici di stipendio, di cui al comma 1, si applica anche al personale militare che ha conseguito la promozione ai sensi degli articoli 1076 ((, comma 1,)) e 1077, nonche' agli ufficiali cessati dal servizio per limiti di eta' con il grado di generale di corpo d'armata e gradi equiparati e a quelli che hanno conseguito una promozione nella posizione di <<a disposizione>>.

3. Al personale delle Forze di polizia a ordinamento militare continua ad applicarsi l'articolo 6-bis, del decreto legge 21 settembre 1987, n. 387, convertito, con modificazioni, dalla legge 20 novembre 1987, n. 472.

### Art. 1912. - Ufficiali dirigenti cessati dall'aspettativa per riduzione dei quadri

1. Agli ufficiali dirigenti che cessano a domanda dalla posizione di aspettativa per riduzione di quadri compete l'indennita' di fine servizio che sarebbe loro spettata qualora fossero rimasti in servizio fino al limite di eta', comprensiva degli aumenti periodici e dei passaggi di classe di stipendio commisurati al trattamento percepito all'atto della cessazione.

## TITOLO V TRATTAMENTO PREVIDENZIALE INTEGRATIVO

### Art. 1913. - Fondi previdenziali integrativi

1. Fermo restando quanto previsto per i dipendenti pubblici dal ((decreto legislativo 5 dicembre 2005, n. 252)), in materia di previdenza complementare, ((gli ufficiali, i sottufficiali, i graduati, i sovrintendenti, gli appuntati in servizio permanente e i carabinieri)) sono iscritti d'ufficio ai seguenti fondi previdenziali integrativi, tra loro indipendenti e a gestione separata, amministrati dalla Cassa di previdenza delle Forze armate di cui all'articolo 74 del regolamento:

- a) fondo di previdenza ufficiali dell'Esercito italiano e dell'Arma dei carabinieri;
- b) fondo di previdenza ufficiali della Marina militare;
- c) fondo di previdenza ufficiali dell'Aeronautica militare;
- d) fondo di previdenza sottufficiali dell'Esercito italiano e dell'Arma dei carabinieri;
- e) fondo di previdenza ((sovrintendenti,)) appuntati e carabinieri;
- f) fondo di previdenza sottufficiali della Marina militare;
- g) fondo di previdenza sottufficiali dell'Aeronautica militare.

((1-bis. E' iscritto d'ufficio ai pertinenti fondi di cui al comma 1 anche il personale militare richiamato in servizio ai sensi dell'articolo 806. Il computo degli anni di iscrizione al fondo decorre dalla data di avvenuto richiamo in servizio))

((99))

2. L'Ordinario militare, gli ispettori e i cappellani militari in servizio permanente sono iscritti d'ufficio al fondo di previdenza ufficiali dell'Esercito italiano e dell'Arma dei carabinieri.

3. L'iscrizione del personale militare ai fondi viene meno all'atto della cessazione dal servizio permanente, anche in caso di trattenimento o di richiamo in servizio ((, salvo quanto previsto dal comma 1-bis)).((99))

((3-bis. L'iscrizione d'ufficio non si attua nei confronti del personale che, in ragione degli anni residui di servizio effettivo, non ha la possibilita' di maturare il diritto all'indennita' supplementare di cui all'articolo 1914, comma 1.))

((3-ter. Il personale militare impiegato a tempo indeterminato, ai sensi della legge 3 agosto 2007, n. 124, che rientra nel ruolo di provenienza e' iscritto al relativo fondo di previdenza se, in ragione degli anni di servizio residui, puo' maturare il diritto all'indennita' supplementare ai sensi dell'articolo 1914 del presente codice. Il computo degli anni di iscrizione al fondo decorre dalla data di reiscrizione nei ruoli di provenienza))

((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 652) che "La costituzione del fondo previdenziale di cui alla lettera g-bis) del comma 1 dell'articolo 1913 del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, introdotta dal comma 651 del presente articolo, decorre dal 1° gennaio 2023". Ha inoltre disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1914. - Indennita' supplementare

((1. Al personale militare iscritto da almeno sei anni ai fondi previdenziali di cui all'articolo 1913, che cessa dal servizio, e' dovuta un'indennita' supplementare)) ((99)) ((2. Per i periodi di contribuzione antecedenti al 31 dicembre 2022, l'indennita' di cui al comma 1 e' liquidata in base all'aliquota del 2 per cento dell'ultimo stipendio annuo lordo, comprensivo della tredicesima mensilita', considerato in ragione dell'80 per cento, moltiplicato per gli anni di iscrizione al fondo maturati a tale data.)) ((2-bis. Per i periodi di contribuzione successivi al 31 dicembre 2022, l'indennita' di cui al comma 1 e' liquidata in base alle aliquote percentuali di seguito riportate dell'ultimo stipendio annuo lordo, comprensivo della tredicesima mensilita', considerato in ragione dell'80 per cento, moltiplicate per gli anni di iscrizione al fondo maturati a decorrere dal 1° gennaio 2023: a) 2 per cento per gli iscritti ai fondi previdenziali di cui all'articolo 1913, comma 1, lettere a), c), g) e g-bis); b) 2,5 per cento per gli iscritti ai fondi previdenziali di cui all'articolo 1913, comma 1, lettere b), d) e f); c) 3 per cento per gli iscritti al fondo previdenziale di cui all'articolo 1913, comma 1, lettera e).)) ((2-ter. Ai fini di cui ai commi 2 e 2-bis, le frazioni di anno sono calcolate in mesi e le frazioni di mesi con numero di giorni non inferiore a quindici sono arrotondate per eccesso. Conseguentemente, le aliquote percentuali di cui ai commi 2 e 2-bis sono ridotte in dodicesimi)) ((99))

3. Ai fini della liquidazione dell'indennita' supplementare non sono valutabili i periodi nei quali non vi e' stato versamento del contributo.

((4. L'indennita' di cui al comma 1 e' ordinariamente corrisposta all'atto della cessazione dal servizio. Con decreto del Ministro della difesa, su proposta motivata del consiglio di amministrazione della Cassa di previdenza delle Forze armate, sentito il Capo di stato maggiore della difesa, il termine di corresponsione di cui al precedente periodo puo' essere differito fino a ventiquattro mesi))

((99))

5. L'indennita' supplementare e' reversibile in favore dei superstiti. In mancanza del coniuge o di figli minorenni, l'indennita' e' corrisposta, nell'ordine, ai figli maggiorenni, ai genitori, ai fratelli e sorelle.

6. Nell'ipotesi prevista dal comma 5, il consiglio di amministrazione della Cassa di previdenza delle Forze armate provvede al recupero, nei confronti dei superstiti, dei debiti eventualmente lasciati dall'iscritto, oppure procede alla radiazione delle partite di credito senza promuovere alcun addebito, secondo i casi e le direttive del Ministro della difesa.

7. L'indennita' supplementare e' soggetta alle disposizioni degli articoli 17, comma 1, lettera a), e 19, comma 2 - bis, ultimo periodo, del decreto del Presidente della Repubblica 22 dicembre 1986, n. 917. ((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 653) che "Il diritto alle prestazioni di cui agli articoli 1914, 1917 e 1917-bis del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, decorre dalla data di entrata in vigore del medesimo codice". Ha inoltre disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1915. - Assegno speciale

1. Agli ufficiali dell'Esercito italiano e dell'Arma dei carabinieri, collocati nella riserva o in congedo assoluto, e' corrisposto, al raggiungimento del sessantacinquesimo anno di eta', oltre all'indennita' supplementare di cui all'articolo 1914, un assegno speciale in relazione al grado rivestito all'atto del collocamento nella riserva o in congedo assoluto.

2. L'assegno speciale:

- a) e' soppresso in tutti i casi che comportano la perdita del grado o della pensione;
- b) e' ridotto a meta' durante il periodo di sospensione dal grado;
- c) non e' reversibile.

((2-bis. L'assegno speciale non spetta agli ufficiali iscritti al relativo fondo previdenziale in data successiva al 1° gennaio 2023))

((99))

3. Le misure annue lorde dell'assegno speciale sono stabilite con decreto del Ministro della difesa, su proposta del consiglio di amministrazione della Cassa di previdenza delle Forze armate, in relazione alle disponibilita' finanziarie della pertinente gestione.

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1916. - Contributi obbligatori degli iscritti

(( 1. Il personale di cui all'articolo 1913, comma 1, contribuisce obbligatoriamente ai fondi previdenziali ivi previsti in ragione delle percentuali di seguito stabilite, calcolate sull'80 per cento dello stipendio annuo lordo effettivamente percepito, comprensivo della tredicesima mensilita': a) 3 per cento, per i fondi previdenziali di cui all'articolo 1913, comma 1, lettere a), b), c), d), f) e g); b) 2 per cento, per i fondi previdenziali di cui all'articolo 1913, comma 1, lettere e) e g-bis) )) ((99))

2. ((COMMA ABROGATO DALLA L. 29 DICEMBRE 2022, N. 197)). ((99))

3. L'importo dei contributi dovuti dagli iscritti di cui all'articolo 1913, comma 2, e' versato mensilmente al fondo di previdenza ufficiali dell'Esercito italiano e dell'Arma dei carabinieri a cura dell'Amministrazione obbligata a corrispondere loro il trattamento economico di attivita' ai sensi dell'articolo 587.

4. I contributi dovuti dal personale militare i cui assegni sono a carico di altre amministrazioni, sono versati al pertinente fondo secondo criteri e modalita' concordati con le singole amministrazioni interessate.

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1917. - (( (Restituzione dei contributi obbligatori) ))

((1. Agli iscritti che cessano dal servizio senza avere maturato il diritto all'indennita' supplementare sono restituiti i contributi obbligatori versati ai fondi previdenziali di cui all'articolo 1913, rivalutati in misura corrispondente alla variazione dell'indice annuo dei prezzi al consumo per le famiglie di operai e impiegati, al netto dei tabacchi, calcolato dall'Istituto nazionale di statistica, tra ciascun anno solare cui i contributi si riferiscono e l'anno precedente alla restituzione. Le somme liquidate secondo le modalita' di cui al precedente periodo sono reversibili)) ((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 653) che "Il diritto alle prestazioni di cui agli articoli 1914, 1917 e 1917-bis del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, decorre dalla data di entrata in vigore del medesimo codice". Ha inoltre disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1917-bis. - (( (Trattamento previdenziale a seguito del passaggio tra ruoli) ))

((

1. Il personale militare di cui all'articolo 1913 che transita tra ruoli e' iscritto al nuovo fondo di previdenza.

2. Il diritto alla liquidazione dell'indennita' supplementare e' riconosciuto alla data di cessazione dal servizio computando il numero di anni complessivi di contribuzione al pertinente fondo nei diversi ruoli.

3. L'importo dell'indennita' supplementare e' a carico di ciascun fondo in quota proporzionale ai periodi di contribuzione))

((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 653) che "Il diritto alle prestazioni di cui agli articoli 1914, 1917 e 1917-bis del codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, decorre dalla data di entrata in vigore del medesimo codice". Ha inoltre disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1918. - Gestione finanziaria della Cassa di previdenza delle Forze armate

1. I proventi dei contributi di cui all'articolo 1916 e ogni altra attivita' di gestione finanziaria, eccedenti la quota necessaria al pagamento dell'indennita' supplementare e dell'assegno speciale di cui agli articoli 1914 e 1915, sono impiegati in acquisto di titoli del debito pubblico o in altri investimenti espressamente autorizzati dal Ministro della difesa su proposta del consiglio di amministrazione della Cassa di previdenza delle Forze armate di cui agli articoli 74, 75 e 76 del regolamento, nel rispetto delle previsioni di cui all'articolo 65 della legge 30 aprile 1969, n. 153.

2. I proventi di cui al comma 1 possono, altresi', essere impiegati, secondo le disposizioni approvate dal Ministro della difesa su proposta del consiglio di amministrazione in prestiti da concedere agli iscritti.

((2-bis. I proventi di cui al comma 1 possono essere impiegati, nell'ambito della somma globale annua fissata al principio di ogni esercizio dal Ministro della difesa in relazione alle disponibilita' e ai risultati dei bilanci, per concedere sussidi da erogare a favore dei militari iscritti ai fondi previdenziali di cui all'articolo 1913 al verificarsi di gravi e documentate esigenze))

((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1919.

((ARTICOLO ABROGATO DALLA L. 29 DICEMBRE 2022, N. 197)) ((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### Art. 1920. - Disposizioni applicative

1. Con decreto del Ministro della difesa, di natura non regolamentare, sono emanate le istruzioni tecniche per l'attuazione degli istituti e dei procedimenti previsti dal presente titolo.

### Art. 1920-bis. - (( (Fondo per la sostenibilita' della Cassa di previdenza delle Forze armate) ))

((1. Per garantire la sostenibilita' finanziaria della Cassa di previdenza delle Forze armate e' istituito nello stato di previsione del Ministero della difesa un fondo alimentato dalle risorse di cui all'articolo 619 del presente codice, in relazione alla riduzione dei contributi versati alla predetta Cassa in applicazione della legge 31 dicembre 2012, n. 244)) ((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

## TITOLO VI DECORATI DELL'ORDINE MILITARE D'ITALIA E RICOMPENSE AL VALOR MILITARE CAPO I BENEFICI PREVIDENZIALI PER GLI APPARTENENTI ALL'ORDINE MILITARE D'ITALIA

### Art. 1921. - Pensione straordinaria

1. Alle decorazioni dell'Ordine Militare d'Italia e' annessa la pensione straordinaria stabilita dall'articolo 1922. Tale pensione e' cumulabile con gli assegni annessi alle medaglie al valor militare.

2. Il decorato dell'Ordine Militare d'Italia al quale e' concessa una decorazione dello stesso Ordine di classe piu' elevata percepisce la sola pensione straordinaria relativa a quest'ultima.

3. Alle Bandiere decorate di piu' croci di cavaliere competono tutte le corrispondenti pensioni straordinarie.

### Art. 1922. - Entita' della pensione straordinaria

1. La pensione straordinaria di cui all'articolo 1921 e' stabilita nelle seguenti misure annue, con decorrenza 1° gennaio 1985:

- a) per il grado di cavaliere di gran croce, euro 1549,37;
- b) per il grado di grand'ufficiale, euro 464,81;
- c) per il grado di commendatore, euro 413,16;
- d) per il grado di ufficiale, euro 361,51;
- e) per il grado di cavaliere, euro 309,87.

### Art. 1923. - Limiti alle pensioni straordinarie

1. Le pensioni straordinarie ai decorati dell'Ordine Militare d'Italia non possono essere concesse, per le singole classi, in numero superiore a:

- a) 12, per la classe di cavaliere di gran croce;
- b) 25, per la classe di grande ufficiale;
- c) 56, per la classe di commendatore;
- d) 140, per la classe di ufficiale;
- e) 700, per la classe di cavaliere.

2. Nei limiti di cui al comma 1, sono comprese le pensioni di reversibilita' e sono escluse le pensioni annesse alle decorazioni concesse alle Bandiere delle armi, corpi e reparti militari.

3. Al verificarsi delle vacanze nelle classi superiori dell'Ordine, possono essere concesse pensioni in soprannumero nei gradi inferiori, nel limite numerico delle vacanze stesse.

### Art. 1924. - Estensione della pensione straordinaria

1. La pensione straordinaria di cui all'articolo 1923 e' estesa, nella misura ridotta del 50 per cento e alle medesime condizioni, a favore dei congiunti dei decorati alla memoria o deceduti successivamente al conferimento della ricompensa o della decorazione.

2. Resta fermo il disposto del decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, per quanto concerne il diritto, nella misura del 50 per cento di cui al comma 1, a favore dei genitori, collaterali e assimilati.

3. Se si tratta di concessioni fatte alla memoria di persona defunta, la pensione straordinaria e' concessa direttamente a quello dei congiunti a favore del quale e' ammessa la reversibilita'.

4. La pensione straordinaria non e' cedibile ne' sequestrabile.

## CAPO II - RICOMPENSE AL VALOR MILITARE

### SEZIONE I - CONCESSIONE DI RICOMPENSE AL VALOR MILITARE

#### Art. 1925. - Assegno straordinario

1. A ciascuna medaglia al valor militare e' annesso un assegno straordinario annuo il cui ammontare e' fissato nelle seguenti misure, con decorrenza 1° luglio 1991: a)medaglia d'oro, euro 2.324,05; b) medaglia d'argento, euro 413,16; c) medaglia di bronzo, euro 129,11; d) croce di guerra, euro 77,46.

2. Gli assegni di cui al comma 1 sono esenti da ogni imposizione fiscale.

#### Art. 1926. - Estensione degli assegni straordinari

1. Gli assegni straordinari di cui all'articolo 1925 sono devoluti nella stessa misura e alle medesime condizioni a favore dei congiunti, aventi titolo al trattamento di reversibilita', dei decorati alla memoria o deceduti successivamente al conferimento della ricompensa, fermo restando il diritto a favore dei genitori, collaterali e assimilati ai sensi del decreto del Presidente della Repubblica 23 dicembre 1978, n. 915.

2. Se si tratta di concessioni fatte alla memoria di persona defunta, l'assegno annuo e' concesso direttamente a quello dei congiunti a favore del quale e' ammessa la reversibilita'.

3. L'assegno annuo annesso alle medaglie al valor militare non e' cedibile ne' sequestrabile.

### SEZIONE II - PERDITA DELLE RICOMPENSE AL VALOR MILITARE

#### Art. 1927. - Reversibilita' dei benefici economici

1. E' ammessa, a domanda, la reversibilita' del beneficio economico annesso alle medaglie al valor militare perdute, o delle quali e' stata sospesa la facolta' di fregiarsi, a favore delle stesse persone di famiglia per le quali la reversibilita' stessa e' consentita dalle disposizioni vigenti in caso di decesso del decorato, salvo quanto previsto dall'articolo 1422.

## LIBRO OTTAVO SERVIZIO MILITARE E SERVIZIO DEGLI OBIETTORI DI COSCIENZA IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE TITOLO I DISPOSIZIONI GENERALI CAPO I OBBLIGHI DI LEVA, SOSPENSIONE DELLE CHIAMATE, E CASI DI RIPRISTINO

### Art. 1928. - Obblighi di leva e di servizio militare e riflessi nelle ammissioni a pubblici uffici e lavori privati

1. In attuazione dell'articolo 52 della Costituzione, il servizio militare e' obbligatorio nei casi e con le modalita' stabilite dal presente codice.

2. Nessun cittadino italiano soggetto agli obblighi della leva puo' essere ammesso a pubblico ufficio se non provi di essere in posizione regolare nei riguardi degli obblighi di leva e nei riguardi degli obblighi del servizio militare.

3. Per l'ammissione ai concorsi nelle pubbliche amministrazioni e per le assunzioni in impieghi, servizi e attivita' in uffici pubblici e privati, non deve essere imposta la condizione di aver soddisfatto gli obblighi militari di leva o di esserne esente.

4. L'interessato e' comunque tenuto a comprovare di essere in posizione regolare nei riguardi degli obblighi di leva e nei riguardi degli obblighi del servizio militare.

### Art. 1929. - Sospensione del servizio obbligatorio di leva e ipotesi di ripristino

1. Le chiamate per lo svolgimento del servizio obbligatorio di leva sono sospese a decorrere dal 1° gennaio 2005.

2. Il servizio di leva e' ripristinato con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei Ministri, se il personale volontario in servizio e' insufficiente e non e' possibile colmare le vacanze di organico, in funzione delle predisposizioni di mobilitazione, mediante il richiamo in servizio di personale militare volontario cessato dal servizio da non piu' di cinque anni, nei seguenti casi:

- a) se e' deliberato lo stato di guerra ai sensi dell'articolo 78 della Costituzione;
- b) se una grave crisi internazionale nella quale l'Italia e' coinvolta direttamente o in ragione della sua appartenenza ad una organizzazione internazionale giustifica un aumento della consistenza numerica delle Forze armate.

3. Nei casi di cui al comma 2, al fine di colmare le vacanze di organico, non possono essere richiamati in servizio gli appartenenti alle Forze di polizia ad ordinamento civile ed al Corpo nazionale dei vigili del fuoco.

## CAPO II - ORGANI COMPETENTI

### Art. 1930. - Autorita' che sovrintende alla leva e altri organi della leva

1. Il Ministro della difesa, avvalendosi della competente ((Direzione generale della previdenza militare e della leva)), sovrintende alle operazioni concernenti:

- a) la riattivazione del servizio militare obbligatorio nei casi stabiliti dal presente codice;
- b) le residue attivita' amministrative inerenti alla leva militare sospesa.

2. Per lo svolgimento delle attivita' di cui al comma 1, lettera a), la Direzione generale di cui al comma 1 si avvale delle strutture a tale fine individuate secondo gli ordinamenti di Forza armata, in conformita' al titolo II del presente libro.

3. Per le attivita' di cui al comma 1, lettera b), la Direzione generale di cui al comma 1, tramite il comando militare per il territorio o altro organo di Forza armata indicato dall'ordinamento, esercita le funzioni di coordinamento e di vigilanza relativamente alle attivita' svolte dai comandi militari Esercito italiano, ovvero dagli altri organismi individuati dallo Stato maggiore dell'Esercito italiano. Analoghe funzioni sono esercitate nei confronti degli enti della Marina militare individuati dallo Stato maggiore della Forza armata. All'estero le residue attivita' in materia di leva sono demandate alle autorita' diplomatiche e consolari.

## CAPO III - ATTIVITA' PER L'EVENTUALE RIPRISTINO DELLA LEVA OBBLIGATORIA E PER LA LEVA OBBLIGATORIA PREGRESSA

### SEZIONE I - LISTE DI LEVA

#### Art. 1931. - Formazione, gestione e consultazione delle liste di leva

1. I comuni e le autorita' diplomatiche e consolari continuano a svolgere le attivita' per la formazione e l'aggiornamento delle liste di leva.

2. Presso i comuni le liste di leva sono gestite in modo da consentire l'accesso all'Amministrazione della difesa, senza ulteriori oneri a carico della finanza pubblica.

3. Le modalita' di tenuta delle liste da parte dei comuni e di accesso ad esse sono definite dal Ministero della difesa, di concerto con il Ministero dell'interno, acquisito il parere della Conferenza Stato-Citta' e autonomie locali.

#### Art. 1932. - Iscrizione nelle liste di leva

1. Il 1° gennaio di ogni anno il Sindaco di ciascun comune, quale ufficiale di governo ai sensi degli articoli 14 e 54 del decreto legislativo 18 agosto 2000, n. 267, con apposito manifesto, rende noto:

- a) ai giovani di sesso maschile che nell'anno stesso compiono il diciassettesimo anno di eta', il dovere di farsi inserire nella lista di leva del Comune in cui sono legalmente domiciliati;
- b) ai genitori e tutori dei giovani di cui alla lettera a), l'obbligo di curarne l'iscrizione nella lista di leva.

2. Le informazioni sugli obblighi di iscrizione nelle liste di leva possono essere diffuse dalle amministrazioni comunali, oltre che con apposito manifesto, anche attraverso altri idonei mezzi di divulgazione.

3. La divulgazione delle informazioni suddette mediante manifesto o altri idonei mezzi di divulgazione equivale ad avviso di avvio del procedimento di iscrizione nelle liste di leva.

#### Art. 1933. - Domicilio legale

1. Sono considerati legalmente domiciliati nel comune:

- a) i giovani dei quali il padre, o, in mancanza del padre, la madre o il tutore, abbia domicilio nel comune, nonostante che essi dimorino altrove, siano assenti, espatriati, emancipati, detenuti o figli di un espatriato, o di un militare in effettivo servizio o prigioniero di guerra che abbia avuto l'ultimo domicilio nel comune;
- b) i giovani coniugati, il cui padre, o, in mancanza del padre, la madre, abbia domicilio nel comune, salvo che giustifichino di aver legale domicilio in altro comune;
- c) i giovani coniugati domiciliati nel comune sebbene il padre o, in mancanza di questo, la madre, abbia domicilio altrove;
- d) i giovani nati, domiciliati o dimoranti nel comune, che siano privi di padre, madre e tutore;
- e) i giovani nati o residenti nel comune che, non trovandosi compresi in alcuno dei casi di cui alle precedenti lettere da a) a d), non giustifichino la loro iscrizione in altro comune.

2. Agli effetti dell'iscrizione sulle liste di leva e' considerato domicilio legale del giovane nato o dimorante all'estero il comune dove egli o la sua famiglia sono da ultimo domiciliati nel territorio della Repubblica; ovvero, quando cio' non sia possibile precisare, il comune designato dallo stesso giovane; ovvero, in mancanza di detta designazione, il comune di Roma. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1934. - Accertamento dell'eta'

1. I giovani domiciliati nel comune, la cui data di nascita non puo' essere accertata con documenti autentici e che sono reputati notoriamente di eta' che li rende soggetti alla leva, devono ugualmente essere iscritti nelle liste. Parimenti vi sono iscritti i giovani che, per eta' presunta, si presentano spontaneamente all'iscrizione, o vi sono dichiarati soggetti dal padre, dalla madre o dal tutore.

2. I giovani di cui al comma 1 sono cancellati dalle liste, con provvedimento del Sindaco, ed eventualmente anche dai ruoli, se, prima della loro incorporazione, risulta che hanno eta' minore di quella presunta, sulla base di copia autentica di atto di stato civile o di sentenza del tribunale, comprovante che appartengono per eta' a classe successiva a quella alla quale la lista si riferisce.

#### Art. 1935. - Lista provvisoria di leva

1. La lista provvisoria di leva e' compilata a cura del Sindaco, entro il mese di gennaio, sulla base delle segnalazioni dei soggetti obbligati e delle risultanze dei registri dello stato civile, nonche' di altri documenti o informazioni.

2. I giovani sono iscritti nelle liste di leva secondo l'ordine cronologico di nascita. A corredo della lista, le amministrazioni comunali compilano altresi' un elenco alfabetico dei giovani iscritti nella lista facendo riferimento al numero dell'iscrizione.

3. Il primo giorno del successivo mese di febbraio e' pubblicato l'elenco dei giovani iscritti nella lista, a cura del Sindaco, nell'albo comunale, mediante affissione per quindici giorni consecutivi. I comuni hanno facolta' di pubblicare l'elenco con altre modalita' idonee, anche informatiche, senza nuovi o maggiori costi.

#### Art. 1936. - Lista definitiva di leva

1. Nel corso del mese di febbraio il Sindaco registra tutte le osservazioni, le dichiarazioni e i reclami che vengono presentati per omissioni, per false indicazioni o per errori, quali che siano.

2. Nel corso del mese di marzo la lista di leva deve essere posta al corrente con le nuove iscrizioni e cancellazioni che siano necessarie e devono essere in essa introdotte tutte le modificazioni derivanti dalle osservazioni, dichiarazioni e reclami di cui al comma 1.

3. A tali operazioni sovrintende il Sindaco.

4. Non si applica l'articolo 10-bis della legge 7 agosto 1990, n. 241.

#### Art. 1937. - Trasmissione delle liste di leva e accesso a esse

((

1. Compiute le operazioni di cui all'articolo 1936, la lista di leva e' firmata dal Sindaco e, nei primi dieci giorni del mese di aprile, e' trasmessa ovvero resa accessibile al Ministero della difesa esclusivamente in modalita' telematica, in conformita' alle disposizioni di cui al decreto legislativo 7 marzo 2005, n. 82, e successive modificazioni. Si applica l'articolo 6, comma 3, del decreto-legge 9 febbraio 2012, n. 5, convertito, con modificazioni, dalla legge 4 aprile 2012, n. 35.

))

#### Art. 1938. - Aggiornamento delle liste di leva

1. Successivamente alla sottoscrizione della lista di leva, e fino al 31 dicembre dell'anno cui si riferisce la lista, il Sindaco ne cura l'aggiornamento tenendo conto delle modifiche relative alla situazione dei singoli iscritti, e di ogni altra variazione rilevante, e iscrive gli omessi che si presentino spontaneamente, o vengano scoperti o denunciati.

## CAPO IV - TUTELA AMMINISTRATIVA E GIURISDIZIONALE

### Art. 1939. - Autotutela amministrativa

1. Fermo restando quanto disposto dalla legge 7 agosto 1990, n. 241, in materia di presupposti, procedimento e termini per l'autotutela provvedimentale:

- a) l'annullamento di ufficio dei provvedimenti di cancellazione dalle liste di leva, dei provvedimenti di dispensa emessi da organi diversi dal Ministro, e dei provvedimenti di riforma determinati da reati di corruzione o procurata e simulata infermita' di cui all'articolo 2078 e' di competenza della ((Direzione generale della previdenza militare e della leva));
- b) i provvedimenti di riforma, quando ne siano cessate le cause, sono revocabili, su richiesta presentata dall'interessato entro il quarantacinquesimo anno di eta', con provvedimento della Direzione generale per il personale militare;
- c) le decisioni emesse dal Ministro su ricorsi avverso provvedimenti di dispensa possono essere annullate o revocate con atto del Ministro.

### Art. 1940. - Ricorsi amministrativi e giurisdizionali

1. Avverso i provvedimenti adottati in materia di leva e' ammesso ricorso gerarchico, ai sensi del decreto legislativo 24 novembre 1971, n. 1199, alla ((Direzione generale della previdenza militare e della leva)). E' salva la facolta' dell'interessato di adire direttamente l'autorita' giudiziaria competente ai sensi del comma 2.

2. Avverso i provvedimenti in materia di leva e contro quelli di decisione dei ricorsi gerarchici di cui al comma 1 la tutela giurisdizionale davanti al giudice amministrativo e' disciplinata dal codice del processo amministrativo.

3. Spetta al giudice ordinario in sede civile la giurisdizione quanto a:

- a) questioni di cittadinanza, di domicilio e di eta';
- b) diritti civili o di filiazione.

4. Spetta al giudice ordinario in sede penale la giurisdizione quanto agli illeciti penali che non siano espressamente attribuiti all'autorita' giudiziaria militare.

5. Contro i provvedimenti di decisione dei ricorsi gerarchici e contro i provvedimenti adottati dal Ministro della difesa in materia di leva e' anche ammesso il ricorso straordinario al Presidente della Repubblica ai sensi del decreto legislativo n. 1199 del 1971.

### Art. 1941. - Rito innanzi al giudice civile

1. Il ricorso al giudice ordinario in sede civile si propone entro il termine di dieci giorni dall'arruolamento. Entro tale termine il ricorso va notificato all'Amministrazione e depositato nella cancelleria del giudice competente.

2. La proposizione del ricorso sospende gli effetti dell'arruolamento sino all'emanazione della sentenza.

3. Se il giudizio si protrae oltre la chiusura della leva in corso, il ricorrente e' rimandato alla leva successiva in attesa dell'esito del giudizio stesso.

4. Il ricorso si propone al Tribunale nella cui circoscrizione ha sede l'organo che ha adottato l'atto contestato.

5. Il Tribunale decide in via di urgenza, in contraddittorio con l'Amministrazione.

6. La decisione del Tribunale ha immediata esecuzione agli effetti dell'arruolamento.

7. Contro la stessa e' ammesso ricorso in appello e contro la pronuncia della Corte di appello e' ammesso ricorso per cassazione.

## TITOLO II DISCIPLINA DELLA LEVA IN CASO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE CAPO I AMBITO APPLICATIVO, ORGANI, CONTINGENTE DI LEVA, NORMA GENERALE SUL PROCEDIMENTO

### Art. 1942. - Ambito applicativo.

1. Nei casi di riattivazione della leva ai sensi dell'articolo 1929, in tempo di guerra o di grave crisi internazionale, oltre alle disposizioni del titolo I, si applicano le disposizioni del presente titolo.

### Art. 1943. - Organi della leva - Profili generali

1. Fermo quanto disposto dall'articolo 1930, se viene ripristinata la leva, con decreto ministeriale:

- a) sono fissati il numero e le sedi dei Consigli di leva di mare e di terra;
- b) si provvede alla costituzione dei Consigli di cui alla lettera a);
- c) e' stabilita la loro composizione e il numero di periti selettori ad essi addetti;
- d) sono costituiti uffici di supporto.

2. Alle esigenze di cui al comma 1 si fa fronte con le dotazioni umane e strumentali del Ministero ovvero con le risorse stanziate in occasione della deliberazione dello stato di guerra o di grave crisi internazionale.

3. I Consigli di leva e gli uffici di supporto dipendono funzionalmente dalla ((Direzione generale della previdenza militare e della leva)).

4. Spettano ai Consigli di leva di terra e di mare tutte le operazioni della leva che non sono attribuite ad altri organi o uffici, rispettivamente per la leva di terra e nell'Aeronautica militare e per quella di mare.

5. Se il decreto ministeriale di cui al comma 1 nulla dispone in ordine alla composizione dei Consigli di leva, si applicano gli articoli 1944 e 1945.

### Art. 1944. - Consigli di leva per l'arruolamento nell'Esercito italiano e nell'Aeronautica militare

1. Le disposizioni del presente articolo si applicano se il decreto ministeriale di cui all'articolo 1943 non fissa una diversa composizione.

2. I Consigli per l'arruolamento nell'Esercito italiano e nell'Aeronautica militare sono composti:

- a) da un ufficiale in servizio permanente di grado non inferiore a maggiore, nel ruolo di presidente;
- b) da due ufficiali in servizio permanente, di grado non inferiore a capitano, in veste di periti selettori attitudinali, membri;
- c) dal Sindaco del comune degli iscritti che devono presentarsi o da un suo delegato, assistito dal segretario comunale;
- d) da un ufficiale con funzioni di relatore e segretario senza voto.

3. Il Consiglio di leva si avvale quale consulente di un ufficiale medico specializzato in psichiatria o di un laureato o specializzato in psicologia.

4. Il Consiglio, con l'assistenza di un gruppo di periti selettori attitudinali, accerta il grado di idoneita' somatico - funzionale e psico - attitudinale dei giovani all'impiego in incarichi del servizio militare.

5. Fanno parte del gruppo di periti di cui al comma 4, ufficiali medici ed ufficiali delle varie armi e dei servizi, nel numero determinato dal Ministro della difesa in relazione all'entita' del contingente che ogni Consiglio di leva deve annualmente esaminare.

6. Il capo nucleo medico selettore e' il perito sanitario del Consiglio di leva.

7. La qualifica di perito in materia di selezione attitudinale e' conferita dal Direttore generale della competente direzione generale agli ufficiali che abbiano superato apposito corso.

8. Il Consiglio di leva decide a maggioranza di voti. A parita' di voti prevale il voto del presidente, salvo che la decisione riguardi l'idoneita' fisica al servizio militare, nel qual caso prevale il voto conforme al parere del perito sanitario.

9. Alle sedute partecipa, con funzione consultiva, un ufficiale dei carabinieri.

### Art. 1945. - Consigli di leva per l'arruolamento nel Corpo degli equipaggi militari marittimi

1. Le disposizioni del presente articolo si applicano se il decreto ministeriale di cui all'articolo 1943 non fissi una diversa composizione.

2. I Consigli di leva per l'arruolamento nel Corpo degli equipaggi militari marittimi sono composti:

- a) da un ufficiale superiore del Corpo delle capitanerie di porto, designato dal Ministro della difesa, con l'incarico di presidente;
- b) da un ufficiale di porto del Compartimento marittimo, di grado non inferiore a tenente di vascello, con l'incarico di perito selettore attitudinale, membro;
- c) da un ufficiale dell'Esercito italiano in servizio permanente, di grado non inferiore a capitano, con l'incarico di perito selettore attitudinale, membro;
- d) da un ufficiale del Compartimento marittimo, con funzioni di relatore e segretario senza voto.

3. Il Consiglio di leva si avvale quale consulente di un ufficiale medico specializzato in psichiatria o di un laureato o specializzato in psicologia.

4. Il Consiglio di leva, assistito da un ufficiale medico della Marina militare quale perito sanitario e da un gruppo di ufficiali periti selettori della stessa Forza armata, sulla base di apposite prove ed esami preventivamente stabiliti, accerta il grado di idoneita' somatico - funzionale e psico - attitudinale degli iscritti di leva e predesigna i giovani riconosciuti idonei ed atti a prestare servizio nella Marina militare per le varie categorie, specialita' ed abilitazioni del Corpo degli equipaggi militari marittimi. I giovani riconosciuti idonei ma non atti per ragioni fisiche o professionali all'arruolamento nella predetta Forza armata, previa selezione effettuata da ufficiali periti selettori dell'Esercito italiano, sono predesignati per le varie armi, servizi e gruppi d'incarichi dell'Esercito italiano.

5. Il numero dei periti selettori e' determinato dal Ministro della difesa in relazione all'entita' del contingente che ogni Consiglio di leva deve esaminare annualmente.

6. La qualifica di perito in materia di selezione attitudinale e' conferita dal Direttore generale della competente direzione generale agli ufficiali che abbiano superato apposito corso.

7. Le decisioni del Consiglio di leva sono prese a maggioranza di voti.

### Art. 1946. - Contingente di leva

1. Il Ministro della difesa, con decreto annuale, fissa il contingente di militari chiamati ad assolvere il servizio obbligatorio di leva, tenendo conto delle esigenze derivanti dallo stato di guerra o di grave crisi internazionale. Sul decreto e' acquisito il parere delle competenti commissioni parlamentari, che si pronunciano entro trenta giorni, decorsi i quali il decreto puo' essere emanato.

2. Con separato decreto del Ministro della difesa, il contingente di cui al comma 1 e' ripartito tra l'Esercito italiano, la Marina militare, compreso il Corpo delle capitanerie di porto, e l'Aeronautica militare. Per il Corpo delle capitanerie di porto il decreto e' adottato di concerto con il Ministro delle infrastrutture e dei trasporti.

### Art. 1947. - Contingente di leva da destinare al servizio ausiliario

1. Con separato decreto del Ministro della difesa, di concerto con i Ministri dell'interno, dell'economia e finanze, e della giustizia, e' fissata, compatibilmente con le esigenze derivanti dallo stato di guerra o di grave crisi internazionale, l'entita' complessiva, nell'ambito del contingente di cui all'articolo 1946, comma 1, degli arruolati da ammettere al servizio ausiliario nelle Forze di polizia ad ordinamento militare e ad ordinamento civile e nel Corpo nazionale dei vigili del fuoco, ed e' definita la ripartizione del contingente ausiliario tra i diversi Corpi.

### Art. 1948. - Norma generale sul procedimento

1. Il procedimento di leva si articola nelle seguenti fasi:

- a) formazione delle liste di leva;
- b) chiamata alla leva: nell'ambito di detta fase rientrano i subprocedimenti di verifica e aggiornamento delle liste di leva, chiamata alla visita di leva, sottoposizione a visita, arruolamento ovvero mancato arruolamento per riforma o rivedibilita';
- c) chiamata alle armi ovvero differimento della chiamata alle armi per rinvio o ritardo, o mancata chiamata alle armi per dispensa o riforma;
- d) collocamento in congedo illimitato;
- e) richiamo;
- f) collocamento in congedo assoluto.

2. Il Ministro della difesa, con atto di natura non regolamentare, determina le istruzioni necessarie per l'applicazione delle disposizioni di cui al presente titolo e, in considerazione della situazione urgente e straordinaria, puo', in deroga al procedimento ivi previsto, stabilire misure di semplificazione e accelerazione adeguate alle circostanze.

3. Ai sensi dell'articolo 20, comma 4, della legge 7 agosto 1990, n. 241, i provvedimenti in materia di leva non si formano per silenzio - assenso.

4. In considerazione della eccezionalita' e urgenza determinate dallo stato di guerra o di grave crisi internazionale, in deroga alla legge 7 agosto 1990, n. 241:

- a) non si applicano gli articoli 7, 8, 10-bis, della legge citata, in tema di avviso di avvio del procedimento e di preavviso di rigetto;
- b) la chiamata alla leva e la chiamata alle armi sono ordini sottratti all'obbligo di motivazione; per i provvedimenti emessi su istanza di parte, in deroga all'articolo 3 della citata legge, la motivazione puo' avere forma semplificata, mediante moduli a stampa e sintetici riferimenti alle norme applicate o a direttive e circolari ministeriali, e puo' essere omessa in caso di assoluta indifferibilita' e urgenza;
- c) le istanze di partecipazione e di accesso sono accoglibili se compatibili con le esigenze di urgenza o segreto.

## CAPO II - SOGGEZIONE ALLA LEVA: REQUISITI, OBBLIGHI E LIMITAZIONI, TERMINI

### Art. 1949. - Classi di leva.

1. Ciascuna classe di leva comprende tutti i maschi nati dal primo all'ultimo giorno dell'anno cui la classe stessa si riferisce.

### Art. 1950. - Soggezione alla leva

1. Sono soggetti alla leva:

- a) i cittadini italiani di sesso maschile, anche se abbiano acquistato la cittadinanza dopo il concorso alla leva della propria classe di nascita e prima del 31 dicembre dell'anno in cui compiono il quarantacinquesimo anno di eta', salvo il disposto dell'articolo 1990, comma 1, lettera s);
- b) gli apolidi di sesso maschile che abbiano stabilito la residenza nella Repubblica anche dopo la chiamata alla leva della propria classe di nascita e prima del 31 dicembre dell'anno in cui compiono il quarantacinquesimo anno di eta'.

2. I soggetti devono essere in possesso dei requisiti di eta', idoneita' fisica e morale previsti dal presente titolo.

3. I cittadini e gli apolidi di cui ai commi 1 e 2 sono soggetti alla leva di terra, salvo che si trovino nelle condizioni di cui all'articolo 1951, nel qual caso sono soggetti alla leva di mare. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 1951. - Soggezione alla leva di mare

1. Sono soggetti alla leva per l'arruolamento nel Corpo degli equipaggi militari marittimi della Marina militare i giovani di cui all'articolo 1950 in possesso di uno o piu' dei seguenti ulteriori requisiti:

- a) siano stati o siano iscritti tra il personale marittimo e della navigazione interna in base al codice della navigazione;
- b) abbiano svolto o svolgano attivita' lavorativa nell'ambito del demanio marittimo quali titolari o dipendenti di imprese concessionarie di beni demaniali marittimi o di servizi portuali o di operazioni portuali o, comunque, soggetti alla vigilanza dei comandanti di porto - ai sensi dell'articolo 68 del codice della navigazione nell'esplicazione delle loro attivita';
- c) siano stati o siano iscritti a societa' o enti di sport nautici o di pesca subacquea;
- d) abbiano appartenuto o appartengano a personale di qualsiasi categoria in servizio negli arsenali, nei cantieri e negli stabilimenti di lavoro e negli uffici di qualsiasi genere della Marina militare;
- e) siano stati o siano dipendenti da ditte che espletano una o piu' delle seguenti attivita': 1) costruzione, allestimento, arredamento e riparazione di navi e galleggianti di qualsiasi tipo; 2) armamenti navali militari; 3) costruzione, riparazione o forniture di caldaie, macchinari e in genere di materiale per l'allestimento od arredamento delle navi e galleggianti di qualsiasi tipo;
- f) siano stati o siano dipendenti da stabilimenti meccanici o industriali compresi nelle citta' o paesi costieri la cui produzione sia di preminente interesse marinaresco;
- g) abbiano lavorato o lavorino in tonnare o altri impianti di pesca fissi a terra, ovvero siano stati o siano dipendenti da industrie che producono materiale ed attrezzature di pesca di qualsiasi tipo;
- h) siano arruolati con ferma volontaria nel Corpo degli equipaggi militari marittimi compresi gli arruolati volontari della Guardia di finanza - contingente di mare;
- i) siano stati prosciolti dall'arruolamento volontario precedentemente contratto nella Marina militare o nella Guardia di finanza - contingente di mare, salvo i casi di proscioglimento d'ufficio a seguito di condanna escludente dal servizio militare;
- l) siano diplomati aspiranti al comando di navi mercantili o aspiranti alla direzione macchine di navi mercantili, navalmeccanici, meccanici o costruttori navali;
- m) siano stati o siano iscritti a corsi di laurea in ingegneria navale e meccanica, discipline nautiche o scienze economiche e marittime oppure negli istituti tecnici nautici o nelle scuole di avviamento professionale a tipo marinaro;
- n) siano stati o siano marinaretti di navi scuole;
- o) siano stati o siano allievi di scuole marittime, pescherecce o professionali per la maestranza marittima o di scuole a carattere marinaresco;
- p) siano stati o siano iscritti a corsi professionali dell'Associazione nazionale marinai d'Italia;
- q) abbiano richiesto o richiedano di prestare servizio militare in Marina militare;
- r) siano iscritti nelle liste dei comuni costieri.

2. Le operazioni di indagine e di controllo per l'individuazione di tutti coloro che, a norma del presente articolo, sono tenuti a prestare servizio militare di leva in Marina militare sono affidate, nei rispettivi ambiti di competenza territoriale, ai comandanti di porto oppure ad ufficiali appositamente designati dal Ministero della difesa.

### Art. 1952. - Destinazione alla leva aeronautica

1. Gli idonei alla leva di terra sono destinati alla leva aeronautica nel limite del relativo contingente, in base a criteri fisio - psico - attitudinali e a titoli di interesse aeronautico.

2. Per sopperire alle necessita' dell'Aeronautica militare di elementi pratici del mare da adibirsi al servizio dei motoscafi ed ai servizi marinareschi in genere, la Marina militare fornisce all'Aeronautica militare, scegliendoli dal contingente di reclute della propria leva, un quantitativo di marinai, idonei allo scopo che sara' determinato anno per anno, in relazione alle necessita' dei servizi.

### Art. 1953. - Eta' minima e massima

1. Sono iscritti nelle liste di leva i soggetti obbligati che compiono diciassette anni di eta' nell'anno di formazione delle liste.

2. Sono chiamati alla visita di leva i soggetti obbligati che abbiano compiuto 18 anni di eta', secondo le modalita' specificate nell'articolo 1961.

3. Gli arruolati, oltre alla prestazione della leva per dieci mesi, sono soggetti agli altri obblighi derivanti dal servizio militare dal giorno dell'arruolamento sino al 31 dicembre dell'anno in cui compiono:

- a) il quarantacinquesimo anno di eta' per l'Esercito italiano;
- b) il trentanovesimo anno di eta', per la Marina militare; successivamente essi vengono trasferiti di autorita' nei ruoli della forza in congedo dell'Esercito italiano per seguire la sorte della loro classe di nascita;
- c) il quarantacinquesimo anno di eta', per l'Aeronautica militare, se trattasi di elementi nominati aiuto specialisti o aiuto specializzati. Tutti gli altri sono trasferiti nella forza in congedo dell'Esercito italiano al 31 dicembre dell'anno in cui compiono il venticinquesimo anno di eta' o dopo il compimento della ferma di leva, se trattasi di militari collocati in congedo illimitato dopo la suddetta data.

4. Fanno eccezione ai limiti di eta' massima di cui al comma 3 gli ufficiali, i sottufficiali e i militari di truppa vincolati ad obblighi speciali, per i quali si applicano le norme che particolarmente li riguardano.

### Art. 1954. - Idoneita' morale

1. Sono esclusi dal servizio militare e non possono far parte delle Forze armate coloro che, in applicazione della legge penale, sono incorsi nell'interdizione perpetua dai pubblici uffici, anche in base a sentenza penale straniera alla quale sia stato dato riconoscimento nello Stato. Gli accertamenti sono eseguiti d'ufficio mediante acquisizione, anche tramite collegamento informatico, del certificato del casellario giudiziale ai sensi dell'articolo 21 del decreto del Presidente della Repubblica 14 novembre 2002, n. 313.

### Art. 1955. - Idoneita' fisica-psichica

1. Sono arruolati nell'Esercito italiano, nella Marina militare o nell'Aeronautica militare i chiamati alla visita di leva che abbiano una statura di almeno 150 centimetri e che sono risultati idonei, per condizioni fisiche e psichiche, al servizio alle armi.

### Art. 1956. - Modalita' per il soddisfacimento degli obblighi di servizio militare

1. L'obbligo del servizio militare si soddisfa parte sotto le armi, mediante la leva e il servizio in caso di richiamo alle armi, e salvi i casi di dispensa dal compiere la ferma o le esenzioni dai richiami, e parte rimanendo a disposizione in congedo illimitato.

### Art. 1957. - Equipollenza della ferma volontaria e del servizio prestato nei Corpi di polizia e nel Corpo nazionale dei vigili del fuoco alla ferma di leva

1. Il servizio prestato nell'Esercito italiano, nella Marina militare, nell'Aeronautica militare, in ferma volontaria, per una durata pari alla ferma di leva, nonche' il servizio prestato nelle Forze di Polizia ad ordinamento militare e civile e nel Corpo nazionale dei vigili del fuoco, e' considerato valido a tutti gli effetti ai fini dell'adempimento dell'obbligo di leva. L'equipollenza sussiste alle condizioni stabilite dall'articolo 44 della legge 1 aprile 1981, n. 121 quanto al servizio prestato nella Polizia di Stato e nel Corpo forestale dello Stato e dall'articolo 8 della legge 15 dicembre 1990, n. 395 quanto a quello prestato nel Corpo della polizia penitenziaria.

2. Ove il servizio cessi, per qualunque motivo, prima del completamento del periodo minimo richiesto per l'equipollenza, l'organo che pronuncia la cessazione del servizio lo comunica al competente Consiglio di leva, ai fini dell'articolo 1965.

### Art. 1958. - Restrizioni in ordine all'espatrio dei soggetti alla leva

1. A nessuna restrizione e' soggetto l'espatrio:

- a) di coloro che espatriano anteriormente al 1° gennaio dell'anno in cui compiono il diciassettesimo di eta';
- b) di coloro che espatriano dal 1° gennaio dell'anno in cui compiono il diciassettesimo anno di eta' fino all'apertura della leva in ordine alla loro classe di nascita;
- c) di coloro che hanno compiuto la ferma di leva o sono stati dispensati dal compierla.

2. I soggetti di cui alle lettere a) e b) del comma 1, devono regolarizzare la propria posizione in ordine agli obblighi di leva ai sensi dell'articolo 1984.

3. In caso di espatrio dei soggetti di cui al comma 1, lettere b) e c), le autorita' preposte alla sorveglianza degli espatri nelle stazioni di confine, nei porti e negli aeroporti di imbarco comunicano tempestivamente, anche per via telematica, al competente comando militare dell'Esercito italiano, per gli iscritti alla leva di terra e per i militari dell'Esercito italiano, ovvero al Comando della Capitaneria di porto competente, per gli iscritti nelle note preparatorie delle liste di leva di mare e per gli iscritti nelle liste di leva di mare, nonche' per i militari della Marina militare, ovvero al competente comando di Regione aerea, se si tratta di militare dell'Aeronautica militare, le generalita' dell'espatriato, la data di partenza, e la localita' verso cui e' diretto.

4. La facolta' di espatriare, consentita ai soggetti di cui al comma 1, lettere b) e c), in circostanze eccezionali derivanti dallo stato di guerra o di grave crisi internazionale, puo' essere temporaneamente sospesa con decreto del Ministro della difesa.

5. L'espatrio degli iscritti dopo l'apertura della loro leva, ovvero dopo l'arruolamento, nonche' l'espatrio dei militari che non hanno ancora compiuto la ferma di leva, deve essere autorizzato con provvedimento del Ministro della difesa o delle autorita' dipendenti a tal fine delegate.

6. In caso di richiesta di rilascio del passaporto o di altro documento valido per l'espatrio da parte dei soggetti di cui al comma 1 lettere b) e c), le autorita' preposte al rilascio verificano che la facolta' di espatriare non sia stata sospesa ai sensi del comma 4.

7. In caso di richiesta di rilascio del passaporto o di altro documento valido per l'espatrio da parte dei soggetti di cui al comma 5, le autorita' preposte al rilascio verificano che vi sia l'autorizzazione di cui al comma 5 o la acquisiscono d'ufficio. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 1959. - Imbarco su navi battenti bandiera estera dopo l'apertura della leva

1. L'imbarco su navi battenti bandiera estera degli iscritti, dopo l'apertura della leva della loro classe, e degli arruolati che non abbiano iniziato o completato la ferma di leva, deve essere autorizzato dal Ministro della difesa, o, su delega dello stesso, dalle Capitanerie di porto.

2. Si applica l'articolo 1958 ad eccezione del comma 5. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 1960. - Imbarco di iscritti e di militari in congedo della Marina militare su navi battenti bandiera estera

1. Gli iscritti nelle note preparatorie o nelle liste della leva di mare e i militari in congedo della Marina militare, per potersi imbarcare su navi battenti bandiera estera, devono ottenere il nulla osta delle autorita' marittime.

2. Le Capitanerie di porto, in Patria, e le autorita' consolari, all'estero, possono rilasciare, per delega del Ministro della difesa, permessi d'imbarco su navi di bandiera estera.

3. I permessi di cui al comma 2 hanno la durata di due anni e sono rinnovabili.

4. Le autorita' che rilasciano o rinnovano il nulla osta comunicano alle competenti Capitanerie di porto le notizie relative al rilascio o al rinnovo del nulla osta stesso, nonche' il domicilio, la residenza o il recapito della famiglia degli interessati.

5. I militari in congedo del Corpo degli equipaggi militari marittimi che non si imbarcano entro sei mesi dalla data di concessione del permesso devono darne comunicazione all'autorita' che ha rilasciato il nulla osta.

6. A coloro che violano le disposizioni di cui al presente articolo si applicano le sanzioni previste dall'articolo 2094.

7. Si applica l'articolo 1958 ad eccezione del comma 5. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 1961. - Eta' e termini per la chiamata delle classi alla leva e termini per la chiamata degli arruolati alle armi

1. Gli iscritti di leva sono chiamati alla visita di leva, possibilmente nel trimestre in cui compiono il diciottesimo anno di eta', e comunque non prima del raggiungimento della maggiore eta'; si intende per primo trimestre il periodo gennaio-marzo, per secondo trimestre il periodo aprile-giugno, per terzo trimestre il periodo luglio-settembre, per quarto trimestre il periodo ottobre-dicembre. Il decreto del Presidente della Repubblica che dispone la riattivazione della leva puo' stabilire, fissando i relativi criteri di priorita', che siano chiamati alla visita di leva anche i cittadini italiani e gli apolidi residenti in Italia, di sesso maschile, che alla data della chiamata alla leva abbiano gia' compiuto il diciannovesimo anno di eta' e non superato il limite di eta' previsto dal presente codice per la soggezione agli obblighi del servizio militare, nonche', limitatamente al primo anno di riattivazione della leva, che abbiano compiuto il diciottesimo anno di eta' nei trimestri anteriori al trimestre in cui ha luogo la chiamata alla leva, e nel medesimo anno.

2. Coloro che sono dichiarati idonei alla visita di leva iniziano il servizio di leva entro il semestre successivo al trimestre in cui e' stata effettuata la visita e, comunque, non oltre il successivo trimestre in relazione alle esigenze funzionali delle Forze armate determinate nel quadro di una gestione unitaria delle risorse. Decorso inutilmente il termine massimo per la chiamata alle armi, gli interessati hanno diritto alla dispensa.

3. Per coloro che chiedono di prestare servizio in qualita' di ausiliari di leva, il periodo di cui al comma 2 entro il quale deve iniziare il servizio di leva degli aspiranti ausiliari non prescelti, decorre dalla data in cui viene comunicata la relativa determinazione ai competenti uffici.

4. Coloro che usufruiscono del beneficio del ritardo per motivi di studio sono chiamati alla visita di leva e assegnati agli enti secondo quanto indicato nell'articolo 1994, comma 5.

5. Le norme del presente articolo si applicano anche agli obiettori di coscienza. Il periodo di nove mesi complessivi previsto come limite massimo per l'impiego comprende anche il periodo necessario per il riconoscimento della posizione di obiettore di coscienza. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

## CAPO III - INVIO E AGGIORNAMENTO DELLE LISTE DI LEVA DA PARTE DEI COMUNI

### Art. 1962. - Invio e aggiornamento delle liste di leva da parte dei Comuni

1. Nei casi di riattivazione della leva:

- a) fermo quanto disposto dall'articolo 1937, le liste di leva sono inviate agli uffici di supporto dei competenti Consigli di leva di terra e, per i comuni costieri, anche ai competenti uffici di supporto dei Consigli di leva di mare;
- b) gli aggiornamenti di cui all'articolo 1938 sono effettuati sino al momento in cui il Consiglio di leva procede alla verifica della lista di leva del Comune.

## CAPO IV - CHIAMATA ALLA LEVA E ALLE ARMI NELL'ESERCITO ITALIANO E NELL'AERONAUTICA MILITARE

### SEZIONE I - PROFILI GENERALI

#### Art. 1963. - Sessione di leva

1. Le operazioni di leva per ogni singola classe si svolgono in un'unica sessione che ha inizio il 1° gennaio e termina il 31 dicembre di ogni anno, salvo che per ragioni straordinarie connesse alla guerra o alla grave crisi internazionale debbano avere inizio in un diverso momento.

#### Art. 1964. - Apertura della leva

1. Il Ministro della difesa con proprio decreto indice la sessione di leva e impartisce le istruzioni necessarie. Il Consiglio di leva, convocato dal Presidente, proclama l'apertura della leva, verifica e aggiorna le liste di leva ai sensi dell'articolo 1965, determina i giorni in cui gli iscritti dei vari Comuni compresi nella propria circoscrizione devono presentarsi, e adotta tutte le altre misure idonee ad assicurare il rapido svolgimento delle operazioni di leva.

#### Art. 1965. - Verifica e aggiornamento delle liste di leva a cura dei Consigli di leva di terra

1. All'inizio delle operazioni relative a ciascun Comune, il Consiglio di leva proceda alla verifica della lista di leva del Comune stesso.

2. Il Consiglio di leva aggiunge sulle liste di ciascun Comune i nomi di coloro che i Sindaci hanno ulteriormente iscritto e cancellano i nomi di coloro la cui iscrizione sia dal Consiglio ritenuta irregolare.

3. Il Consiglio di leva cancella, inoltre, gli iscritti che concorrono alla leva di mare ai sensi del capo V.

4. Sulle liste di leva in corso i Consigli di leva aggiungono:

- a) coloro che, arruolati volontariamente nelle Forze armate o in servizio nelle Forze di Polizia ad ordinamento militare e civile e nel Corpo nazionale dei vigili del Fuoco, per qualunque motivo non abbiano compiuto il periodo minimo richiesto per l'equipollenza all'assolvimento dell'obbligo di leva ai sensi dell'articolo 1957;
- b) i rimandati alla leva in corso per rivedibilita' o per legali motivi;
- c) gli omessi, appartenenti alla classe di cui e' in corso la leva o a classi precedenti, in qualunque modo sia venuta a constare la loro omissione;
- d) i renitenti presentatisi spontaneamente od arrestati;
- e) i cancellati o riformati in leve anteriori, la cui cancellazione o riforma sia stata annullata in autotutela;
- f) coloro che acquistino la cittadinanza italiana dopo la chiamata alla leva della loro classe di nascita e prima del 31 dicembre dell'anno in cui compiono il quarantacinquesimo anno di eta';
- g) gli apolidi i quali stabiliscano la residenza nel territorio della Repubblica dopo la chiamata alla leva della loro classe di nascita e prima del 31 dicembre dell'anno in cui compiono il quarantacinquesimo anno di eta'.

#### Art. 1966. - Manifesto di chiamata alla leva e precetto di chiamata alla leva

1. Il Consiglio di leva fa pubblicare in tutti i comuni compresi nella propria circoscrizione, a mezzo dell'ufficio di supporto, ed a cura dei comuni stessi, il manifesto, firmato dal presidente del Consiglio di leva, con il quale si ordina la leva e si indicano il luogo, il giorno e l'ora in cui si eseguiranno le varie operazioni.

2. Il modello di manifesto e' stabilito con decreto del Ministro della difesa di natura non regolamentare e indica i titoli di dispensa, ritardo, rinvio, e le relative modalita', nonche' le altre informazioni di cui all'articolo 1974.

3. Su disposizione del Ministro, il manifesto di chiamata alla leva puo' stabilire che i chiamati alla leva, se arruolati, verranno chiamati alle armi con cartolina-precetto consegnata in sede di visita di leva, che indichera' giorno e luogo di presentazione.

4. Le emittenti radiotelevisive e i quotidiani, nazionali e locali, sono tenuti a dare la notizia della pubblicazione dei manifesti di chiamata alla leva, senza costi a carico dello Stato.

5. Fatto salvo quanto disposto dall'articolo 1948, comma 2, gli iscritti sono convocati anche mediante precetto personale di chiamata alla leva.

#### Art. 1967. - Pubblicazione dell'elenco alfabetico degli iscritti chiamati alla leva

1. A cura del Sindaco e' pubblicato nell'albo pretorio e nel sito informatico del Comune l'elenco alfabetico degli iscritti chiamati alla leva con indicazione del giorno di chiamata.

#### Art. 1968. - Attivita' e provvedimenti del Consiglio di leva

1. Il Consiglio di leva:

- a) effettua le operazioni di cui all'articolo 1965;
- b) cancella i deceduti dalle liste di leva;
- c) pronuncia l'esclusione di coloro che si trovano nelle condizioni previste dall'articolo 1954;
- d) pronuncia la riforma senza visita di coloro che si trovino nelle condizioni di cui all'articolo 1976;
- e) pronuncia l'arruolamento provvisorio senza visita degli iscritti di leva residenti all'estero, e degli iscritti di leva che hanno presentato domanda di dispensa o domanda di ritardo per motivi di studio;
- f) riforma senza visita coloro che si trovino nelle condizioni di cui all'articolo 1977;
- g) decide sulle domande di ammissione alla dispensa dal compiere la ferma di leva, rientranti nella sua competenza, convocando per la visita di leva coloro la cui istanza venga respinta;
- h) provvede sulle domande di ritardo per motivi di studio che debbano essere respinte, convocando per la visita di leva coloro la cui istanza venga respinta;
- i) provvede sulle domande di rinvio che debbano essere respinte;
- l) trasmette alla ((Direzione generale della previdenza militare e della leva)), le domande di ritardo per motivi di studio e le domande di rinvio che siano accoglibili;
- m) procede all'esame personale di tutti coloro che non si trovino nelle condizioni di cui alle lettere da a) a l) per non essere sottoposti a visita;
- n) pronuncia la riforma o la rivedibilita' di coloro nei cui confronti risultino, a seguito di esame personale, esservene i presupposti;
- o) convoca per la visita di leva, se possibile entro la fine della sessione di leva, coloro le cui istanze di dispensa, ritardo, rinvio, siano state respinte dalla ((Direzione generale della previdenza militare e della leva)), e fissa il calendario per la convocazione dopo la fine della sessione di leva;
- p) pronuncia l'arruolamento nell'Esercito italiano di tutti coloro che risultino idonei al servizio militare;
- q) pronuncia la dichiarazione di renitenza sia per gli iscritti che non si siano presentati senza giustificato motivo, sia per coloro che, pur essendosi presentati innanzi al Consiglio di leva, rifiutano di sottoporsi all'esame personale; per questi ultimi pronuncera' altresi' il loro arruolamento senza visita;
- r) invita pubblicamente i presenti, alla fine della seduta, a dichiarare se loro consti la omissione nelle liste di giovani che debbono concorrere alla leva e, sulle osservazioni o denunce ricevute, decide in conseguenza;
- s) fornisce al comandante del competente comando militare, per gli arruolati nell'Esercito italiano, gli elementi che debbono servire alla formazione dei ruoli matricolari e dei contingenti da chiamare alle armi.

### SEZIONE II - OBBLIGO DI PRESENTAZIONE DEGLI ISCRITTI DI LEVA, ECCEZIONI,DIRITTI DEGLI ISCRITTI DI LEVA

#### Art. 1969. - Obbligo di presentazione degli iscritti ed eccezioni

1. Alle sedute dei Consigli di leva hanno l'obbligo di presentarsi, nei giorni designati, tutti gli iscritti, eccetto:

- a) coloro nei cui confronti risulti, o che documentino, che alla data di presentazione, siano gia' arruolati volontariamente nelle Forze armate, nelle Forze di Polizia ad ordinamento militare e civile e nel Corpo nazionale dei vigili del fuoco;
- b) coloro che devono essere rimandati a leva successiva ai sensi dell'articolo 1970;
- c) coloro che hanno diritto alla visita di leva a domicilio ai sensi dell'articolo 1971;
- d) coloro che risiedono all'estero, per i quali ricorrono i presupposti per l'arruolamento provvisorio senza visita ai sensi dell'articolo 1984;
- e) coloro che sono stati gia' riformati con il procedimento di definizione anticipata ai sensi dell'articolo 1976;
- f) coloro che si trovano nelle condizioni per la riforma senza esame personale ai sensi all'articolo 1977;
- g) coloro che hanno presentato domanda di dispensa o domanda di ritardo per motivi di studio, che vengono arruolati provvisoriamente senza visita;

2. I non intervenuti senza legittimo motivo sono dichiarati renitenti, ai sensi dell'articolo 2079.

#### Art. 1970. - Sospensione dell'esame degli iscritti impediti

1. Gli iscritti che, per qualsiasi legale motivo, non possono presentarsi all'esame personale prima della chiusura della leva, sono rimandati alle leve successive fino a che non sia cessato il motivo che ha dato luogo al loro rimando.

#### Art. 1971. - Visita di leva a domicilio

1. I portatori di handicap gravi, che risultino dichiarati tali dalla competente unita' sanitaria locale, hanno diritto, a richiesta, di essere sottoposti a visita medica di leva a domicilio.

#### Art. 1972. - Viaggio gratuito per gli iscritti di leva

1. Gli iscritti residenti fuori del comune ove ha sede il Consiglio di leva sono muniti, a cura dell'ufficio di supporto del Consiglio di leva, di apposito documento, se non gia' annesso al precetto di chiamata alla leva, che consente loro il viaggio gratuito di andata e ritorno su tutta la rete ferroviaria italiana, sugli autoservizi di linea, sui servizi extraurbani di navigazione interna e sulle linee marittime, sui voli nazionali, dal luogo di residenza alla sede del Consiglio di leva.

#### Art. 1973. - Somministrazione di vitto e alloggio agli iscritti di leva

1. Gli iscritti sottoposti alle operazioni di leva ricevono il vitto da parte dell'Amministrazione militare, nonche' una indennita' ragguagliata alla paga giornaliera del soldato; a quelli di essi che provengono da localita' diversa da quella dove si svolgono le operazioni di leva, e' assicurato l'alloggio a cura dell'Amministrazione militare.

#### Art. 1974. - Informazione

1. Se lo stato di guerra o di grave crisi internazionale lo consentono, il Ministero della difesa predispone un opuscolo informativo sul servizio di leva che comprende anche l'elenco dei casi di rinvio, ritardo e dispensa, da inviare ai cittadini italiani e agli apolidi residenti, di sesso maschile, nel trimestre precedente a quello in cui compiono il diciottesimo anno di eta'.

### SEZIONE III - RIFORME E RIVEDIBILITA'

#### Art. 1975. - Regola generale

1. Non sono arruolati gli iscritti che vengono riformati. Sono riformati gli iscritti che, per imperfezione od infermita', risultino non idonei in modo permanente all'impiego in incarichi del servizio militare, ovvero siano stati riconosciuti di statura inferiore al minimo richiesto.

2. L'elenco delle imperfezioni e le infermita' che sono causa di non idoneita' al servizio militare e' recato dal regolamento.

#### Art. 1976. - Procedimento di definizione anticipata per gli iscritti non idonei in modo permanente al servizio militare

1. Prima dell'apertura della leva della loro classe, i giovani iscritti i quali comprovino di essere affetti da evidenti e gravi imperfezioni o da infermita' gravi e permanenti, accertate da organi sanitari pubblici, possono ottenere in anticipo la definizione della loro posizione rispetto all'obbligo del servizio militare.

2. Al fine di cui al comma 1, i giovani iscritti presentano domanda al Consiglio di leva competente, tramite l'Amministrazione comunale, entro novanta giorni dalla data della pubblicazione delle liste di leva. La domanda e' compilata secondo le modalita' stabilite dal Ministro della difesa e corredata dei documenti prescritti.

3. Durante le operazioni di leva per comune o per gruppi di comuni, il Consiglio di leva procede anche all'esame delle domande inoltrate, ai sensi dei commi 1 e 2, dai giovani degli stessi comuni appartenenti alla successiva classe di leva, pronunciando:

- a) la riforma senza esame personale di quelli che sulla base della documentazione presentata vengono riconosciuti affetti da evidenti e gravi imperfezioni o da infermita' gravi e permanenti accertate da organi sanitari pubblici. Tali imperfezioni o infermita' sono descritte nell'elenco delle imperfezioni e infermita' che sono causa di non idoneita' al servizio militare contenuto nel regolamento;
- b) il rinvio alla chiamata alla leva della loro classe in tutti gli altri casi.

#### Art. 1977. - Riforma senza esame personale

1. Il Consiglio di leva puo' riformare senza esame personale i giovani i quali comprovino di essere affetti da deformita' che possano, senza che occorra il giudizio medico, dichiararsi evidentemente insanabili, o da infermita' gravi e permanenti, ovvero da mutilazioni, accertate da organi sanitari pubblici.

2. Le deformita' di cui al comma 1, mutilazioni od infermita' sono descritte nell'elenco delle imperfezioni e infermita' che sono causa di non idoneita' al servizio militare contenuto nel regolamento.

3. Nei casi dubbi e tutte le volte che sorga il sospetto di frode, il Consiglio di leva deve procedere all'esame personale dell'iscritto, oppure al suo invio in osservazione in un ospedale militare.

#### Art. 1978. - Rivedibilita' - Rivedibilita' in caso di tossicodipendenza o tossicofilia

1. Gli iscritti che risultino affetti da imperfezioni o infermita' presunte sanabili sono rinviati, quali rivedibili, alla successiva leva; qualora risultassero ancora inabili, sono riformati.

2. Gli iscritti rinviati alla successiva leva per infermita' non possono essere sottoposti a nuovo esame prima che siano trascorsi sei mesi da quello precedente.

3. In occasione delle operazioni di selezione per la leva, ove venga individuato un caso di tossicodipendenza o tossicofilia, l'organo che presiede alla visita di leva dispone l'invio dell'interessato all'ospedale militare per gli accertamenti del caso.

4. Gli iscritti di leva e gli arruolati di leva a cui sia riscontrato dagli ospedali militari uno stato di tossicodipendenza o di abuso di sostanze stupefacenti o psicotrope possono essere giudicati rivedibili per un massimo di tre anni, in deroga ai commi 1 e 2.

5. I soggetti di cui al comma 4 sono segnalati dalle autorita' sanitarie militari alle competenti aziende sanitarie locali al fine di facilitare il loro volontario avviamento al trattamento di recupero sociale presso il servizio pubblico per le tossicodipendenze.

6. Gli iscritti di leva e gli arruolati di leva, gia' riconosciuti tossicodipendenti dalle autorita' sanitarie civili e che hanno in corso un documentato trattamento di recupero da parte di centri civili autorizzati, possono essere giudicati rivedibili per un massimo di tre anni, previo accertamento da parte delle competenti autorita' sanitarie militari.

7. Gli iscritti di leva e gli arruolati di leva riconosciuti idonei al termine del periodo di rivedibilita' previsto per il recupero dei soggetti tossicodipendenti possono, a domanda, essere dispensati dalla chiamata alle armi, secondo l'ordine di priorita' di cui all'articolo 1990 e con il procedimento di cui all'articolo 1992.

#### Art. 1979. - Invio in osservazione degli iscritti di leva

1. Per accertare l'esistenza o l'incurabilita' di una malattia, e' in facolta' del Consiglio di leva di inviare gli iscritti in osservazione presso un ospedale militare, anche nei casi in cui l'osservazione non sia prescritta dall'elenco delle imperfezioni e infermita' che sono causa di non idoneita' al servizio militare contenuto nel regolamento.

#### Art. 1980. - Dichiarazione di riforma o di rivedibilita'

1. I Consigli di leva rilasciano, ad ogni iscritto riformato o rimandato quale rivedibile, la dichiarazione di riforma o quella di rivedibilita'.

#### Art. 1981. - Riforma e inabilita' temporanea dei militari alle armi o in congedo

1. Nei riguardi dei militari alle armi o di quelli in congedo illimitato provvisorio o in congedo illimitato o dispensati dal presentarsi alle armi quali residenti all'estero, spetta all'autorita' militare pronunciare il provvedimento di riforma.

2. Spetta alla stessa autorita' di cui al comma 1, concedere il rinvio ad una chiamata successiva, e comunque per non oltre un anno, agli arruolati i quali, prima della incorporazione, siano stati riconosciuti temporaneamente non idonei.

3. Ai fini del presente articolo, l'arruolato e' considerato incorporato: per l'Esercito italiano e l'Aeronautica militare dal momento della presentazione all'autorita' militare per essere avviato a compiere il servizio di leva, per la Marina militare dal momento in cui e' preso in forza dai centri di addestramento ai sensi dell'articolo 2022.

#### Art. 1982. - Controllo e autotutela sui provvedimenti di riforma

1. La ((Direzione generale della previdenza militare e della leva)) puo' disporre che tutti o parte dei giudizi di riforma e rivedibilita' siano sottoposti alla propria approvazione o controllo, ovvero all'approvazione o controllo di altra autorita' sanitaria periferica a tal fine delegata.

2. Fermo quanto disposto dall'articolo 1939, la ((Direzione generale della previdenza militare e della leva)) puo' annullare o revocare d'ufficio i provvedimenti di riforma, da qualunque organo pronunciati, quando, in seguito a nuova visita, sia accertato che le cause che li hanno motivati erano insussistenti, o sono cessate, nel rispetto, rispettivamente, degli articoli 21-nonies e 21-quinquies della legge 7 agosto 1990, n. 241, escluso il diritto all'indennizzo. A tal fine la Direzione generale puo' disporre controlli a campione sui provvedimenti di riforma, anche quando non dispone l'approvazione o il controllo generalizzato ai sensi del comma 1.

#### Art. 1983. - Chiamata a visita di revisione dei riformati

1. Nel caso di esigenze straordinarie, i riformati possono, con decreto del Presidente della Repubblica, essere chiamati a visita di revisione. Questa si effettua con le stesse norme stabilite per la chiamata a visita delle classi di leva.

### SEZIONE IV - NORME PER I SOGGETTI ALLA LEVA RESIDENTI ALL'ESTERO

#### Art. 1984. - Iscritti di leva residenti all'estero

1. Gli iscritti di leva residenti all'estero sono arruolati dal Consiglio di leva senza visita in base alle notifiche di cui all'articolo 1958, o in base a loro richiesta da farsi, durante la leva sulla loro classe, alle autorita' diplomatiche o consolari.

2. Gli iscritti di leva residenti all'estero hanno facolta' di farsi visitare a proprie spese, in qualunque tempo, presso le suddette autorita' diplomatiche o consolari, le quali, ove accertino la loro inabilita' al servizio militare, ne danno notizia, per il tramite del Ministero della difesa, ai Consigli di leva, ovvero al competente comando militare, secondo che si tratti di iscritti di leva o di gia' arruolati.

3. Gli iscritti di cui ai commi 1 e 2 che rimpatriano sono prosciolti dalla nota di renitenza eventualmente pronunciata sul loro conto, soltanto se si presentino agli organi di leva entro trenta giorni dal loro rimpatrio.

4. Gli iscritti di leva residenti all'estero, in caso di mobilitazione, sono obbligati a regolare la loro posizione, all'estero o in Patria, con le modalita' di cui di cui ai commi da 1 a 3, entro trenta giorni dalla indetta mobilitazione; trascorso tale termine la dichiarazione di renitenza pronunciata a loro riguardo diviene definitiva a tutti gli effetti di legge.

#### Art. 1985. - Dispensa per i cittadini residenti all'estero

1. I residenti all'estero, espatriati prima del compimento del diciottesimo anno di eta', arruolati senza visita ai sensi dell'articolo 1984, possono essere dispensati dal presentarsi alle armi.

2. Analoga dispensa di cui al comma 1, puo' essere concessa a coloro che espatriano per motivi di lavoro o familiari, entro il compimento del ventiquattresimo anno di eta'.

3. Il cittadino interessato presenta, tramite l'autorita' diplomatica o consolare italiana del luogo di residenza, apposita istanza documentata entro la data di compimento delle eta' indicate ai commi 1 e 2. L'istanza viene tempestivamente trasmessa, a cura dell'Autorita' ricevente, al Consiglio di leva nella cui circoscrizione si trova il Comune di ultima residenza in Italia del cittadino richiedente.

4. In difetto di dispensa, in caso di mobilitazione, gli arruolati di cui ai commi 1 e 2 sono obbligati a presentarsi alle armi, con quelle eccezioni che verranno stabilite, in relazione alla possibilita' che essi avranno di rimpatriare in tempo utile.

#### Art. 1986. - Rimpatrio definitivo e temporaneo dei residenti all'estero

1. I cittadini, dispensati dal presentarsi alle armi ai sensi dell'articolo 1985, rimpatriati prima del compimento del trentesimo anno di eta', sono obbligati a presentarsi alla visita di leva entro il trimestre successivo a quello in cui sono rimpatriati; i cittadini risultati idonei alla visita di leva iniziano il servizio di leva entro il semestre successivo al trimestre in cui e' stata effettuata la visita e, comunque, non oltre il trimestre successivo in relazione alle esigenze funzionali di Forza armata.

2. I cittadini, dispensati dal presentarsi alle armi ai sensi dell'articolo 1985, rimpatriati o residenti all'estero dopo il raggiungimento dell'eta' indicata al comma 1, sono collocati in congedo illimitato.

3. I cittadini, dispensati dal presentarsi alle armi ai sensi dell'articolo 1985, in possesso anche della cittadinanza di uno Stato estero, possono essere dispensati dal compiere la ferma di leva, salvo l'obbligo di rispondere alle eventuali chiamate della loro classe, se dimostrano di aver prestato nelle Forze armate dello Stato estero un periodo effettivo di servizio alle armi non inferiore a sei mesi, fatto salvo quanto diversamente stabilito da convenzioni stipulate con lo Stato.

4. Gli italiani nati all'estero, o espatriati nei termini e nelle condizioni previste dall'articolo 1958, comma 1, lettere a) e b) non perdono il titolo ad ottenere l'arruolamento provvisorio senza visita con dispensa dal presentarsi alle armi o la dispensa dopo l'arruolamento, qualora rientrino nel territorio della Repubblica:

- a) per compiere un regolare corso di studi, di qualsiasi natura e durata;
- b) per giustificati motivi, per un periodo non eccedente, rispettivamente, i dodici mesi per i provenienti dai Paesi europei o dal bacino mediterraneo, i ventiquattro mesi per i provenienti dagli altri Paesi.

5. Chi non torni all'estero al termine degli studi per i quali e' rimpatriato o prima della scadenza dei termini di cui al comma 4, lettera b), perde i benefici accordatigli per la sua qualita' di residente all'estero, salvo la possibilita' di riacquistarli, qualora un nuovo espatrio si verifichi nelle condizioni previste dall'articolo 1958, comma 1, lettere a) e b). --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1987. - Rimpatrio degli arruolati residenti all'estero

1. I militari residenti all'estero arruolati dagli organi di leva, che intendono rimpatriare o devono rimpatriare per compiere la ferma di leva, ne danno comunicazione alle autorita' diplomatiche o consolari.

2. I richiedenti che dagli accertamenti sanitari disposti dalle autorita' diplomatiche o consolari risultano abili al servizio militare sono avviati in Patria da dette autorita' al comando competente.

3. Le spese di viaggio sono anticipate dalle autorita' diplomatiche o consolari e poste a carico del bilancio del Ministero della difesa.

#### Art. 1988. - Effetti del rimpatrio in ordine alle dispense e riduzioni di servizio

1. I militari che rimpatriano rinunciano ai benefici delle dispense dal servizio alle armi e delle riduzioni di servizio, salvo quanto disposto dall'articolo 1986, comma 2.

#### Art. 1989. - Spese a carico del Ministero della difesa

1. Sono poste a carico del bilancio del Ministero della difesa, in favore dei militari residenti all'estero:

- a) le spese per gli accertamenti sanitari presso le sedi delle rappresentanze italiane all'estero dei giovani che intendono rimpatriare per compiere la ferma di leva, nonche' quelle di viaggio che i giovani stessi debbono compiere, per sottoporsi agli accertamenti anzidetti, dal luogo di residenza all'estero alle sedi delle rappresentanze italiane e viceversa; tali spese sono anticipate dalle autorita' diplomatiche o consolari;
- b) le spese di viaggio, per una sola volta nel corso della ferma, col mezzo piu' economico, per licenza da trascorrere all'estero nel Paese di residenza;
- c) le spese di viaggio per il ritorno all'estero, dopo ultimati gli obblighi di leva.

### SEZIONE V - DISPENSE

#### Art. 1990. - Titoli di dispensa dalla ferma di leva

1. Se le esigenze del contingente di leva lo consentono, possono essere dispensati dalla ferma di leva gli arruolati che si trovano in una delle seguenti condizioni soggettive in ordine di priorita' decrescente:

- a) cittadino italiano residente all'estero che si trova nelle condizioni indicate nell'articolo 1986, commi 2 e 3;
- b) soggetto recuperato dalla tossicodipendenza o tossicofilia dopo un periodi di rivedibilita', per il quale ricorrano le condizioni di cui all'articolo 1978, comma 7;
- c) profugo di cui all'articolo 1, legge 26 dicembre 1981, n. 763; chi fruisce gia' di dispensa in qualita' di residente all'estero, puo' conseguire la dispensa in qualita' di profugo, in caso di rimpatrio prima del compimento del trentesimo anno di eta'; chi rimpatria dopo tale eta' e' collocato in congedo illimitato;
- d) orfano di entrambi i genitori, con funzioni di capo famiglia, con fratelli minorenni a carico;
- e) con prole;
- f) unico figlio convivente, di genitore portatore di handicap che lo renda non autosufficiente o invalido civile affetto da mutilazione o invalidita' analoghe a quelle per le quali e' previsto l'accompagnatore ai sensi della normativa vigente;
- g) unico figlio di genitori viventi, dei quali uno affetto da infermita' permanente ed insanabile che lo renda inabile ad esplicare la sua abituale attivita' lavorativa, ovvero di padre vedovo o celibe o di madre vedova o nubile, purche', in tutti i casi, a causa della partenza alle armi dell'arruolato, la famiglia venga a perdere i necessari mezzi di sussistenza;
- h) unico fratello convivente di portatore di handicap o affetto da grave patologia, non autosufficiente;
- i) vittima del reato di sequestro di persona che, a causa di tale reato o come diretta conseguenza di esso, sia stato privato della liberta' personale o delle condizioni di normale salute fisica o psichica;
- l) fratello di militare deceduto durante la prestazione del servizio militare;
- m) difficolta' economiche o familiari ovvero particolari responsabilita' lavorative;
- n) responsabile diretto della conduzione di impresa o di attivita' economica da almeno un anno ovvero di impresa o attivita' economica avviata con il sostegno previsto da istituzioni ed enti pubblici in materia di incentivazione all'imprenditoria giovanile e al lavoro autonomo;
- o) minor indice di idoneita' somatico - funzionale o psico-attitudinale attribuito in sede di visita di leva;
- p) cittadino impegnato, con meriti particolari, sul piano nazionale o internazionale, in carriere scientifiche, artistiche, culturali;
- q) titolare di una borsa di studio o di un assegno di ricerca per laureati della durata di almeno un anno, ovvero frequenza di dottorato di ricerca, presso Universita' dell'Unione Europea legalmente riconosciute o presso istituzioni di livello universitario di altri paesi. Ai fini del conseguimento del beneficio, il cittadino deve dimostrare la frequenza dei predetti corsi e il superamento di eventuali esami stabiliti dal piano di studi o dal programma formativo;
- r) conseguimento del diploma di maturita' presso i licei militari;
- s) soggetto che ha acquistato la cittadinanza italiana dopo il concorso alla leva della propria classe, se, per compiere la leva, deve iniziare il servizio dopo il compimento del trentesimo anno di eta'.

2. Le condizioni di cui alle lettere m), n) o) e p) del comma 1 sono determinate con decreto del Ministro della difesa di natura non regolamentare.

3. In occasione della chiamata alla leva di ciascuna classe, il Ministro della difesa, sulla base dell'aggiornamento annuale dell'indice ISTAT del costo della vita, indica con proprio decreto di natura non regolamentare i livelli di reddito e gli altri elementi obiettivi di cui tener conto nel determinare l'avvenuta perdita dei necessari mezzi di sussistenza necessaria ai fini del riconoscimento dei titoli previsti dal comma 1. I livelli di reddito indicati in tale decreto devono essere computati su base familiare, considerando il reddito complessivo percepito dal nucleo familiare suddiviso per il numero dei componenti la famiglia stessa.

4. Il Ministro della difesa puo' adottare provvedimenti di invio in licenza illimitata senza assegni in attesa di congedo in favore dei giovani alle armi per situazioni, dimostrate successivamente alla loro incorporazione o non fatte valere in tempo utile, riconducibili a quelle previste al comma 1, lettere da m) a s), fermo quanto disposto dall'articolo 2067, in ordine all'anticipazione del congedo illimitato per i militari per i quali ricorrono le condizioni del comma 1, lettere da

- a) a l).

5. A parita' di condizione e' data precedenza a coloro che siano in possesso di piu' titoli. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 01/06/2010, n. 126 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1991. - Criteri per l'applicazione di talune ipotesi di dispensa

1. Ai fini dell'applicazione delle ipotesi di dispensa di cui all'articolo 1990 si osservano le disposizioni del presente articolo.

2. Devono considerarsi non esistenti in famiglia:

- a) gli affetti da imperfezioni o deformita' fisiche ascrivibili alla prima e alla seconda categoria di pensione, di cui alla legge 10 agosto 1950, n. 648;
- b) coloro che, per sopraggiunte infermita' permanenti o insanabili, abbiano dovuto abbandonare la loro abituale attivita' lavorativa e non si siano potuti dedicare ad altra proficua attivita';
- c) gli irreperibili dei quali non si siano avute notizie da almeno tre anni dopo la partenza o scomparsa dall'ultimo luogo di residenza, purche' cio' risulti debitamente comprovato da atto notorio giudiziale e da idonea dichiarazione rilasciata dall'Arma dei carabinieri, e, per i residenti all'estero, da apposita dichiarazione rilasciata dalla competente autorita' diplomatica o consolare;
- d) i religiosi che abbiano pronunciato voti per i quali non possono provvedere al mantenimento della famiglia di origine;
- e) il genitore che abbia abbandonato la residenza familiare senza piu' provvedere da almeno cinque anni al mantenimento dei propri figli, purche' cio' risulti documentato da atto notorio giudiziale e da apposita dichiarazione rilasciata dall'Arma dei carabinieri;
- f) i detenuti per espiazione di una pena detentiva non inferiore ad anni cinque, a condizione che la pena stessa non venga a scadere nel periodo di cui l'iscritto dovrebbe compiere la ferma di leva; in tal caso, l'iscritto stesso dovra' essere avviato alle armi con la prima chiamata che avra' luogo dopo che il detenuto sia stato dimesso dal carcere.

3. Ai figli legittimi sono equiparati i figli legittimati, i figli naturali riconosciuti, i figli adottivi se adottati durante la minore eta'. Per il soggetto adottato dopo la maggiore eta' i titoli relativi alla dispensa vanno riferiti alla famiglia di origine.

4. Gli arruolati con prole hanno titolo a conseguire la dispensa dalla ferma di leva, anche quando tale condizione sia maturata dopo la chiusura della sessione di leva alla quale l'iscritto concorre per ragioni di eta' o per legittimo rinvio, o durante la ferma di leva; sulla domanda di dispensa presentata durante la ferma di leva, si procede in via di urgenza e puo' essere in via provvisoria concesso l'invio in licenza illimitata senza assegni, in attesa dell'adozione del provvedimento di dispensa e del completamento della procedura per l'ammissione al congedo anticipato.

5. L'ammissione ad eventuale dispensa dal compiere la ferma di leva ai sensi dell'articolo 1990 e' consentita quando nessun fratello vivente dell'iscritto, di eta' inferiore a quaranta anni, abbia fruito di riduzione o dispensa della ferma di leva. Tale disposizione non e' applicabile nelle ipotesi di cui all'articolo 1990, comma 1, lettere e) e f) e puo' non essere applicata, per disposizione del Ministro, in uno o piu' degli altri casi di cui al comma 1 del citato articolo 1990, in caso di eccedenza del contingente. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1992. - Procedimento e competenza

1. I titoli di dispensa devono essere indicati nel manifesto di chiamata alla leva e nel manifesto di chiamata alle armi.

2. Coloro che si trovano nelle condizioni per conseguire la dispensa, salvo i residenti all'estero ai quali si applicano le norme procedurali dettate dall'articolo 1985, presentano documentata domanda esente da ogni onere fiscale all'ufficio di supporto del Consiglio di leva presso cui sono chiamati a presentarsi, ovvero provvedono ad inviarla tramite raccomandata con avviso di ricevimento, entro il trimestre in cui sono chiamati per la sottoposizione alla visita di leva; per situazioni sopravvenute all'arruolamento, presentano la domanda al competente comando militare presso cui sono chiamati alle armi, fino al giorno precedente l'incorporazione. Per i profughi, l'istanza di dispensa e' corredata dell'attestazione della qualita' di profugo rilasciata dal Prefetto, e va presentata al competente comando militare per i profughi gia' arruolati e dispensati dal presentarsi alle armi quali regolarmente residenti all'estero, che rimpatriano prima del compimento del trentesimo anno di eta'.

3. Gli uffici ed organi di cui al comma 2 curano l'istruttoria delle domande e trasmettono, anche per via telematica, la documentazione per l'adozione dei provvedimenti, comprensiva di ogni elemento utile per il rigetto o per l'accoglimento, ai Consigli di leva, in caso di domande di dispensa per uno dei motivi di cui all'articolo 1990, comma 1, lettere da

- a) a l), e alla ((Direzione generale della previdenza militare e della leva)), negli altri casi.

4. Contro i provvedimenti adottati dai Consigli di leva ai sensi del comma 3 e' ammesso ricorso gerarchico alla Direzione generale della previdenza militare, della leva e del collocamento al lavoro dei volontari. La Direzione puo' disporre controlli a campione sui provvedimenti dei Consigli di leva, al fine di intervenire su di essi in autotutela mediante annullamento o revoca, nel rispetto della legge 7 agosto 1990, n. 241 e escluso ogni indennizzo.((20))

5. Il Ministro della difesa puo' annullare o revocare in autotutela alle condizioni del comma 4 i provvedimenti in materia di dispensa adottati dalla ((Direzione generale della previdenza militare e della leva)).

6. L'elenco nominativo dei dispensati deve essere esposto annualmente, per la durata di un mese, presso i Comandi militari e le Capitanerie di porto competenti per territorio e da questi trasmesso ai comuni di residenza dei dispensati per l'affissione agli albi comunali.

7. Coloro la cui domanda di dispensa non sia stata accolta, gia' arruolati senza visita, sono sottoposti a visita di leva, ove possibile, entro la sessione di leva a cui erano stati originariamente chiamati, ovvero entro il termine di chiamata alle armi, nella data indicata nella cartolina - precetto, fissata secondo il calendario all'uopo fissato dal Consiglio di leva competente.

--------------- AGGIORNAMENTO (20) Il D. Lgs. 31 dicembre 2012, n. 248 ha disposto (con l'art. 8, comma 1, lettera a)) che all'art. 1992, comma 4 le parole "Direzione generale della previdenza militare, della leva e del collocamento al lavoro dei volontari congedati", ovunque ricorrono, sono sostituite dalle seguenti: "Direzione generale della previdenza militare e della leva".

### SEZIONE VI - RITARDI PER MOTIVI DI STUDIO

#### Art. 1993. - Ambito e procedimento

1. I ritardi del servizio militare previsti nella presente sezione possono essere concessi agli arruolati, se vi e' eccedenza del contingente di leva dopo l'esaurimento delle procedure relative alle dispense, secondo l'ordine di priorita' indicato all'articolo 1994.

2. Le istanze, redatte in carta semplice, sono presentate o spedite con lettera raccomandata con avviso di ricevimento, nei termini e con la documentazione di cui agli articoli 1995 e 1996, ai competenti Consigli di leva, che ne verificano l'ammissibilita' e l'accoglibilita' e che:

- a) respingono le istanze inammissibili o infondate;
- b) inviano alla ((Direzione generale della previdenza militare e della leva)) le istanze fondate.

3. La Direzione generale di cui al comma 2, respinte le istanze che ritiene inammissibili o infondate, accoglie le istanze secondo l'ordine di priorita' indicato all'articolo 1994, e, se le istanze residue che rientrano nella medesima categoria sono superiori rispetto al numero di domande ammissibili in relazione alle eccedenze del contingente, individua le domande da accogliere mediante sorteggio di cui e' redatto verbale.

#### Art. 1994. - Casi di ritardo per motivi di studio

1. Puo' essere consentito il ritardo della prestazione del servizio di leva per motivi di studio agli arruolati che si trovano nelle seguenti condizioni, nel seguente ordine di priorita':

- a) frequentano l'ultimo triennio del corso d'istruzione secondaria superiore presso istituti statali o legalmente riconosciuti, indipendentemente dalla durata del corso, purche' non abbiano compiuto il ventiduesimo anno di eta'; tale ritardo non puo' essere concesso piu' di tre volte; coloro che hanno fruito di tre ritardi non possono fruire dei ritardi di cui alle successive lettere b) e c);
- b) frequentano corsi di istruzione universitaria di diploma o di laurea presso universita' statali o legalmente riconosciute; tale ritardo va chiesto di anno in anno e puo' essere chiesto: 1) fino al compimento del venticinquesimo anno di eta', per i corsi aventi la durata di tre anni; 2) fino al compimento del ventiseiesimo anno di eta', per i corsi aventi la durata di quattro anni; 3) fino al compimento del ventisettesimo anno di eta', per i corsi aventi la durata di cinque anni; 4) fino al compimento del ventottesimo anno di eta', per i corsi aventi una durata maggiore di cinque anni;
- c) essendo gia' in possesso del diploma di laurea, sono iscritti ad un corso di specializzazione, di perfezionamento o di dottorato di ricerca, nonche' a scuole ad ordinamento speciale post-laurea, attivati od istituiti presso universita' statali o legalmente riconosciute, purche' non abbiano compiuto il ventinovesimo anno di eta'.

2. Coloro che, dopo aver conseguito il diploma universitario, accedano ad un corso di laurea sono equiparati a coloro che si trovano nella situazione di cui al comma 1, lettera b).

3. I titoli di ritardo di cui al comma 1, lettere da

- a) a c), si applicano anche agli arruolati che frequentano corsi di istruzione media superiore o universitaria nei Paesi dell'Unione europea o che frequentano, al di fuori di questi, corsi i cui titoli di studio finali sono considerati equipollenti dallo Stato italiano.

4. I cittadini che intendano frequentare o che frequentano al di fuori dell'Unione europea corsi al termine dei quali non e' rilasciato un titolo di studio, aventi il requisito di cui al comma 3, devono chiedere al competente Consiglio di leva l'autorizzazione a soggiornare all'estero per motivi di studio.

5. Coloro la cui domanda sia stata accolta, gia' arruolati senza visita:

- a) sono sottoposti alla visita di leva nel trimestre successivo a quello in cui e' terminato il beneficio del ritardo; gli idonei iniziano il servizio di leva entro il semestre successivo al trimestre in cui e' stata effettuata la visita e, comunque, non oltre il successivo trimestre in relazione alle esigenze funzionali di Forza armata;
- b) possono chiedere, contestualmente alla domanda di ritardo, di essere chiamati a sostenere la visita di leva nel corso del primo trimestre dell'anno solare in cui termina il beneficio del ritardo e di iniziare il servizio di leva nel corso dell'ultimo trimestre dello stesso anno, ferma la possibilita' di chiedere ulteriori ritardi a cui si abbia titolo.

6. Il beneficio del ritardo cessa, oltre che per lo scadere del termine indicato nel provvedimento che lo accorda e per il raggiungimento dell'eta' massima, anche per abbandono definitivo degli studi. Chi, fruendo del beneficio del ritardo, abbandona definitivamente gli studi, deve darne comunicazione al competente Consiglio di leva.

7. Coloro la cui domanda non sia stata accolta, gia' arruolati provvisoriamente senza visita, sono sottoposti a visita di leva, ove possibile, entro la sessione di leva a cui erano stati originariamente chiamati, ovvero entro il termine di chiamata alle armi, nella data indicata nella cartolina - precetto, fissata secondo il calendario all'uopo fissato dal Consiglio di leva competente. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1995. - Norme ulteriori per il ritardo per motivi di studio d'istruzione secondaria superiore

1. La domanda di ritardo di cui all'articolo 1994, comma 1, lettera a), deve essere:

- a) corredata di certificato di iscrizione rilasciato dalla scuola o certificazione sostitutiva per i privatisti iscritti a sostenere l'esame di idoneita' o di Stato conclusivi dei corsi di scuola secondaria superiore o di abilitazione presso gli istituti di cui al citato comma 1, lettera a);
- b) presentata entro il 30 settembre dell'anno scolastico per il quale si richiede il beneficio, fatti salvi i nati nell'ultimo trimestre dell'anno i quali possono presentare domanda anche in sede di chiamata alla leva.

2. Il ritardo, se concesso, ha decorrenza immediata e fino al 30 settembre dell'anno successivo. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 1996. - Norme ulteriori per il ritardo per motivi di studio universitario e post universitario

1. I limiti di eta' ed i requisiti da possedere per ottenere il beneficio di cui all'articolo 1994, comma 1, lettere b) e c), possono essere modificati, con decreto del Ministro della difesa di natura non regolamentare di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca, a seguito dell'entrata in vigore dei decreti concernenti i criteri generali degli ordinamenti degli studi universitari di cui all'articolo 17, commi 95 e 96, della legge 15 maggio 1997, n. 127.

2. Per ottenere il ritardo di cui all'articolo 1994, comma 1, lettera b), l'arruolato deve dimostrare:

- a) per la prima richiesta di ritardo, di essere iscritto a un corso di istruzione universitaria di diploma e di laurea presso universita' statali o legalmente riconosciute;
- b) per la seconda richiesta, di aver sostenuto con esito positivo quattro esami previsti dal piano di studi;
- c) per la terza richiesta, di aver sostenuto con esito positivo otto esami previsti dal piano di studi;
- d) per la quarta richiesta e le successive, di aver sostenuto ulteriori quattro esami previsti dal piano di studi per anno rispetto alla terza richiesta e alle successive.

3. Ai fini della concessione del ritardo di cui all'articolo 1994, comma 1, lett. c), occorre dimostrare la frequenza ai predetti corsi ed il superamento di eventuali esami stabiliti dal piano di studio o dal programma formativo.

4. Le domande di ritardo per i motivi di cui all'articolo 1994, comma 1, lettere b) e c), sono presentate:

- a) non oltre il 30 settembre dell'anno precedente a quello per il quale si intende usufruire del ritardo, dagli studenti iscritti al primo anno, corredate dal certificato di iscrizione ovvero da dichiarazione temporaneamente sostitutiva di essere in attesa di iscrizione con esibizione, entro il 31 dicembre successivo, del certificato di iscrizione;
- b) non oltre il 31 dicembre dell'anno precedente a quello per il quale si intende usufruire del ritardo, dagli studenti iscritti agli anni successivi, essere corredate dal certificato comprovante gli esami sostenuti rilasciato dall'universita' o da una dichiarazione temporaneamente sostitutiva cui dovra' seguire, entro il 31 gennaio successivo, la certificazione dovuta.

5. Agli studenti universitari che hanno titolo a presentare richiesta di ritardo, esclusa la prima, e non la presentano, o ai quali il ritardo non e' accordato, possono essere concessi, al di fuori dei periodi di addestramento, quattro periodi di assenza dal servizio per la durata di otto giorni, al fine di completare la preparazione e sostenere gli esami. Per le prove di esame non superate, detti periodi non sono computati ai fini del compimento del servizio.

6. Gli studenti universitari che non hanno piu' titolo al ritardo e che devono sostenere non piu' di quattro esami di profitto e l'esame di laurea o di diploma per completare gli studi universitari, possono essere avviati al servizio, su loro richiesta, e compatibilmente con le esigenze delle Forze armate, presso un ente ubicato nel comune ove ha sede l'universita' o in un comune limitrofo. Agli stessi studenti possono essere concessi quattro periodi di assenza dal servizio della durata di otto giorni per sostenere gli esami di profitto, nonche' due giorni per sostenere l'esame di laurea o di diploma universitario, che non sono computati ai fini del compimento del servizio qualora tali prove di esame abbiano esito negativo.

#### Art. 1997. - Rinuncia al beneficio del ritardo per motivi di studio

1. Coloro che hanno ottenuto il beneficio del ritardo per motivi di studio possono, in qualunque momento, rinunciare a detto beneficio presentando apposita dichiarazione; essi sono chiamati alla visita di leva nel trimestre successivo a quello in cui hanno presentato domanda di rinuncia e se risultati idonei iniziano il servizio di leva entro il semestre successivo al trimestre in cui e' stata effettuata la visita e, comunque, non oltre il trimestre successivo in relazione alle esigenze funzionali di Forza armata. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### SEZIONE VII - ALTRI RINVII

#### Art. 1998. - Ambito e procedimento

1. I rinvii del servizio militare previsti dagli articoli 1999, 2000 e 2001 possono essere concessi agli arruolati, se vi e' eccedenza del contingente di leva dopo l'esaurimento delle procedure relative a dispense, nonche' relative a ritardi per motivi di studio. Il rinvio di cui all'articolo 2002 puo' essere concesso, se vi e' eccedenza del contingente di leva, dopo la concessione delle dispense di cui all'articolo 1990, comma 1, lettere da

- a) a l).

2. Le istanze sono presentate ai competenti Consigli di leva che ne verificano l'ammissibilita' e l'accoglibilita' e che:

- a) respingono le istanze inammissibili o infondate;
- b) inviano alla ((Direzione generale della previdenza militare e della leva)) le istanze fondate.

3. La Direzione generale, respinte le istanze che ritiene inammissibili o infondate, se le istanze residue sono superiori rispetto al numero di domande ammissibili in relazione alle eccedenze del contingente, individua le domande da accogliere mediante sorteggio di cui e' redatto verbale.

#### Art. 1999. - Rinvio della prestazione del servizio militare degli addetti al governo di aziende agricole industriali e commerciali

1. Puo' essere concesso il rinvio di anno in anno, e per un massimo di due anni, della prestazione del servizio militare agli arruolati indispensabili al governo di una azienda o stabilimento agricolo, industriale o commerciale al quale attendono per conto proprio o della famiglia.

#### Art. 2000. - Rinvio della prestazione del servizio militare degli arruolati che hanno un fratello alle armi

1. Gli arruolati che, all'atto della chiamata alle armi, abbiano un fratello in servizio di leva o volontario possono ottenere il rinvio della prestazione del servizio fino al termine della ferma di leva, nel primo caso, e finche' il fratello si trova alle armi con la propria classe, nell'altro caso.

#### Art. 2001. - Rinvio della prestazione del servizio militare dei fratelli che devono presentarsi contemporaneamente alle armi

1. Qualora due fratelli debbano presentarsi contemporaneamente alle armi, uno di essi, su sua richiesta e con l'assenso dell'altro fratello, puo' ottenere il rinvio della prestazione del servizio fino al termine della ferma di leva dell'altro.

#### Art. 2002. - Rinvio e dispensa per i volontari in servizio civile in Paesi in via di sviluppo

1. I volontari in servizio civile, che prestino la loro opera, ai sensi dell'articolo 31 della legge 26 febbraio 1987, n. 49, in Paesi in via di sviluppo possono chiedere il rinvio del servizio di leva, che puo' esser concesso per la durata del servizio civile all'estero, a condizione che il richiedente sia sottoposto a visita medica ed arruolato.

2. Al termine di un biennio di effettivo e continuativo servizio nei Paesi suindicati, i volontari che abbiano ottenuto il rinvio del servizio militare possono conseguire la dispensa.

3. Nel caso in cui un volontario, pur avendo tempestivamente iniziato il servizio all'estero cui si e' impegnato, non raggiunga il compimento di un biennio di servizio, perde il titolo a conseguire la dispensa. Tuttavia, se l'interruzione avviene per i motivi di cui al comma 4 dell'articolo 34 della legge n. 49 del 1987, o per documentati motivi di salute o di forza maggiore, il tempo trascorso in posizione di rinvio nel Paese di destinazione e' proporzionalmente computato ai fini della ferma militare obbligatoria.

### SEZIONE VIII - NORME COMUNI A DISPENSE, RITARDI E RINVII

#### Art. 2003. - Rinvio ad altre fonti normative

1. I ritardi, i rinvii, le dispense dalla leva e le modalita' alternative di prestazione del servizio di leva sono disciplinati dal presente codice.

2. E' fatto salvo quanto disposto dal Concordato tra l'Italia e la Santa Sede nonche' dalle vigenti leggi di ratifica delle Intese tra lo Stato italiano e le confessioni religiose diverse dalla cattolica, e, in particolare, a titolo esemplificativo, dalle seguenti disposizioni:

- a) legge 25 marzo 1985, n. 121 (articolo 4 e punto 2 del protocollo addizionale) (ratifica dell'accordo modificativo del Concordato tra Italia e Santa Sede);
- b) legge 11 agosto 1984, n. 449 (articolo 5) (legge previa intesa tra l'Italia e le Chiese rappresentate dalla Tavola valdese);
- c) legge 22 novembre 1988, n. 516 (articoli 6 e 7) (legge previa intesa tra l'Italia e l'Unione italiana delle Chiese cristiane avventiste del 7° giorno);
- d) legge 22 novembre 1988, n. 517 (articoli 3 e 10) (legge previa intesa tra l'Italia e le Assemblee di Dio in Italia);
- e) legge 8 marzo 1989, n. 101 (articolo 3) (legge previa intesa tra l'Italia e l'Unione delle Comunita' ebraiche in Italia);
- f) legge 29 novembre 1995, n. 520 (articolo 5) (legge previa intesa tra l'Italia e la Chiesa Evangelica Luterana in Italia).

3. Per i cittadini italiani residenti all'estero e per i cittadini italiani che hanno anche la cittadinanza di uno Stato estero, e' fatto salvo quanto diversamente disposto da convenzioni internazionali ratificate dall'Italia, e, a titolo esemplificativo, dai seguenti atti normativi:

- a) regio decreto legge 11 novembre 1938, n. 1822 (Italia - Argentina);
- b) legge 6 giugno 1939, n. 1320 (articolo 39-bis, aggiunto dall'articolo 2, l. 10 luglio 1982, n. 488) (Italia - San Marino);
- c) legge 18 giugno 1949, n. 385 (articolo XIII), (Italia - U.S.A.);
- d) legge 13 marzo 1958, n. 239, Italia - Cile);
- e) legge 4 agosto 1960, n. 924 (Italia - Brasile);
- f) legge 9 marzo 1961, n. 436 (art. 5 e art. 2 del Protocollo Italia - Germania);
- g) legge 12 luglio 1962, n. 1111 (Italia - Paesi Bassi);
- h) legge 4 ottobre 1966, n. 876 (articoli 5 e 6) (Convenzione multilaterale Austria, Belgio, Cipro, Danimarca, Francia, Germania, Grecia, Irlanda, Islanda, Italia, Lussemburgo, Olanda, Norvegia, Svezia, Turchia, Regno Unito di Gran Bretagna e Irlanda del Nord);
- i) decreto del Presidente della Repubblica 9 dicembre 1970, n. 1430 (articolo 33) (Italia - Australia);
- l) legge 18 maggio 1973, n. 282 (articolo 3) ( Italia - Argentina);
- m) legge 5 maggio 1976, n. 401 (Italia - Francia);
- n) legge 12 marzo 1977, n. 168 (Italia - Spagna);
- o) legge 10 luglio 1982, n. 560 (Italia - Belgio).

#### Art. 2004. - Forma dei provvedimenti di rigetto delle istanze di rinvio, ritardo, dispensa

1. I provvedimenti di rigetto delle istanze di dispensa, ritardo, rinvio, indicano, mediante l'utilizzo di moduli prestampati, se la reiezione dipende da:

- a) difetto di requisiti e documenti;
- b) insufficienza del contingente di leva, pur essendo l'istanza in astratto accoglibile.

#### Art. 2005. - Durata della leva per gli aventi titoli a dispense, ritardi, rinvii la cui istanza non ha trovato accoglimento

1. La proroga della leva oltre il termine di dieci mesi, di cui all'articolo 2026 non si applica, se le esigenze del contingente lo consentono, a coloro la cui domanda di conseguire una dispensa, un ritardo o un rinvio, non sia stata accolta, pur sussistendone i requisiti, per insufficienza del contingente.

#### Art. 2006. - Sospensione dei titoli di dispensa, ritardo rinvio - Titoli di dispensa, ritardo, rinvio fissati con regolamento

1. In caso di urgenza, il Ministro, anche dopo la pubblicazione del manifesto di chiamata alla leva, con decreto reso noto con i mezzi di informazione consentiti dalle circostanze, puo' disporre che sono sospesi tutti o parte dei titoli di dispensa, ritardo, rinvio, nel rispetto dell'ordine di priorita' fissato dal presente codice, ovvero che l'esame ne e' rinviato ad un momento successivo alla chiamata alle armi, e che si procede alla formazione del contingente selezionando gli idonei con migliori indici di idoneita' fisica - psichica.

2. Con decreto del Ministro della difesa di natura non regolamentare possono essere previste esenzioni o ritardi in relazione alla chiamata alle armi conseguente a mobilitazione per guerra o grave crisi internazionale, diversi o ulteriori rispetto a quelli previsti dal presente codice, in favore di coloro che ricoprano determinati impieghi o esercitino determinati mestieri o attivita' o si trovino in speciali condizioni.

### SEZIONE IX - ARRUOLAMENTO, RUOLI, E CHIAMATA ALLE ARMI

#### Art. 2007. - Congedo illimitato provvisorio

1. Gli iscritti di leva sono, dopo l'arruolamento, collocati in congedo illimitato provvisorio in attesa della chiamata alle armi; possono pero' anche essere immediatamente avviati alle armi.

2. Debbono, in ogni caso, essere avviati alle armi, subito dopo l'arruolamento, i renitenti arruolati e denunciati all'autorita' giudiziaria i quali appartengono a classe o contingente o scaglione gia' chiamato alle armi, purche' non abbiano titolo a riforma, rivedibilita', dispensa, esenzione, rinvio o ritardo della prestazione del servizio.

#### Art. 2008. - Iscrizione nei ruoli dei militari di leva

1. Gli arruolati sono iscritti nei ruoli militari della classe dell'anno in cui sono nati.

#### Art. 2009. - Iscrizione nei ruoli dell'Esercito italiano degli arruolati nella Guardia di finanza - contingente ordinario

1. Coloro che si arruolano nella Guardia di finanza - contingente ordinario, sono iscritti nei ruoli matricolari dell'Esercito italiano, previa cancellazione, ove del caso, dalla lista di leva di mare.

#### Art. 2010. - Chiamata alle armi e incorporazione

1. Il Ministro della difesa determina il tempo in cui deve aver luogo la chiamata alle armi degli arruolati, fissandone il primo e l'ultimo giorno, nel rispetto del termine massimo di cui all'articolo 1961, comma 2. Gli arruolati possono essere chiamati alle armi in totalita' oppure partitamente, in periodi di tempo successivi, secondo la data di nascita, l'arma o servizio di assegnazione, le esigenze di servizio, o altri criteri.

2. Salvo che la chiamata alle armi sia gia' stata comunicata in sede di visita di leva ai sensi dell'articolo 1966, il competente comando militare rende noti i giorni e le modalita' della presentazione alle armi con apposito manifesto, secondo il modello che viene annualmente stabilito dal Ministero difesa, e nel quale sono fissati anche i termini e le modalita' per nuovi accertamenti sanitari ai sensi dell'articolo 2012.

3. Il manifesto e' redatto in lingua italiana, e in lingua italiana e tedesca per la Provincia autonoma di Bolzano.

4. Il manifesto viene distribuito a tutti i comuni compresi nella circoscrizione del comando che lo predispone ed e', a cura dei Sindaci, pubblicato a piu' riprese, anche per via telematica, perche' rimanga esposto al pubblico per il maggior tempo possibile.

5. Dell'effettuata pubblicazione del manifesto i Sindaci danno immediata assicurazione scritta ai competenti Comandi militari.

6. I comandi militari trasmettono inoltre una copia del manifesto per conoscenza, agli uffici di supporto dei Consigli di leva, ai comandi dell'Arma dei carabinieri e della Guardia di finanza, alle Capitanerie di porto, che hanno sede nel territorio di loro circoscrizione.

7. Agli arruolati che devono presentarsi alle armi, i competenti comandi militari trasmettono per posta, qualche giorno prima di quello stabilito per la presentazione, apposita cartolina precetto, che puo' essere redatta con sistema meccanizzato e recante l'indicazione a stampa del responsabile.

8. Gli arruolati che non ricevono la cartolina precetto, o la ricevono in ritardo, devono ugualmente presentarsi nei giorni stabiliti dal manifesto, la cui pubblicazione vale per essi come precetto personale.

9. Al giungere degli arruolati, il comandante o un suo delegato verifica la loro identita' personale.

10. L'assegnazione degli arruolati alle varie armi, corpi e specialita' e' fatta dai Comandanti dei comandi militari.

11. Nell'assegnazione si tiene conto dei precedenti penali e dei carichi pendenti degli arruolati, desunti dal certificato del casellario giudiziario e dal certificato dei carichi pendenti di cui all'articolo 21 del decreto del Presidente della Repubblica 14 novembre 2002, n. 313, acquisito anche per via informatica.

#### Art. 2011. - Chiamata alle armi dei riformati, in seguito a visita di revisione

1. La chiamata alle armi dei riformati, arruolati a seguito di visita di revisione ai sensi dell'articolo 1983, e' fatta d'ordine del Ministro della difesa.

2. Essi seguono le sorti della loro classe di nascita.

#### Art. 2012. - Nuovi accertamenti sanitari e attitudinali dopo la chiamata alle armi

1. Ai fini della migliore utilizzazione del personale nei vari incarichi, il Ministro della difesa ha facolta', se richiesto dagli interessati con domanda documentata, di sottoporre a nuova visita medica e ad esami fisio - psico - attitudinali gli arruolati che abbiano ottenuto il rinvio della prestazione del servizio militare di leva per un periodo non inferiore a tre anni. La domanda deve essere presentata almeno sei mesi prima della scadenza dell'ultimo rinvio.

2. Gli arruolati nell'Esercito italiano e nell'Aeronautica militare che si ritengano affetti da malattie o lesioni tali da poter essere causa di non idoneita' al servizio militare possono chiedere di essere sottoposti a nuovi accertamenti sanitari entro i termini e con le modalita' precisate nel manifesto di chiamata alla leva ovvero nel manifesto di chiamata alle armi del proprio contingente.

3. Nuovi accertamenti sanitari sono disposti, se richiesti, in via eccezionale, anche dopo i termini fissati nel manifesto di chiamata alle armi nei casi di particolare gravita' e in cui esista seria e manifesta compromissione delle principali funzioni fisiche o psichiche, purche' sia documentata con certificazione rilasciata dagli organi sanitari pubblici. Le relative modalita' sono precisate nel manifesto di chiamata alle armi del contingente di appartenenza.

#### Art. 2013. - Manuale informativo

1. Il Ministero della difesa provvede alla pubblicazione di un manuale informativo da consegnare ai militari di leva all'atto dell'incorporazione, che contiene la Costituzione, la legge recante norme sui principi della disciplina militare, i regolamenti sulla rappresentanza militare e di disciplina militare nonche' le principali disposizioni che regolano la vita del militare, comprese quelle relative ai servizi e alle licenze.

## CAPO V - CHIAMATA ALLA LEVA E ALLE ARMI NEL CORPO DEGLI EQUIPAGGI MILITARI MARITTIMI

### SEZIONE I - PROCEDIMENTO ORDINARIO

#### Art. 2014. - Norme applicabili

1.Alla chiamata alla leva e alla chiamata alle armi nel Corpo degli equipaggi militari marittimi e alle attivita' dei Consigli di leva di mare e degli uffici di supporto si applicano: a) le disposizioni contenute nel capo IV, esclusi gli articoli: 1965, 1968, comma 1, lettere a), b), o), r); e 2009; b) le disposizioni del presente capo. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2015. - Annotazione nelle liste di leva dei soggetti alla leva nel Corpo degli equipaggi militari marittimi

1. Nelle liste di leva e' apposta apposita annotazione dei giovani che, in possesso dei prescritti requisiti, sono soggetti alla leva per l'arruolamento nel Corpo degli equipaggi militari marittimi. Tali giovani sono iscritti nelle note definitive.

#### Art. 2016. - Note preparatorie

1. Nel mese di febbraio di ciascun anno gli uffici di supporto dei Consigli di leva di mare iniziano la compilazione delle note preparatorie dei giovani soggetti alla leva di mare, domiciliati nei comuni rientranti nella propria sfera di competenza territoriale, che nello stesso anno compiono il diciassettesimo anno di eta'.

#### Art. 2017. - Note definitive

1. A partire dal mese di maggio dell'anno in cui i giovani compiono il diciassettesimo anno di eta', gli uffici di supporto dei Consigli di leva di mare chiedono agli uffici di supporto dei Consigli di leva di terra che nelle liste di leva, a fianco ai nominativi dei giovani iscritti nelle note preparatorie, sia apposta l'annotazione indicante la soggezione degli stessi alla leva per l'arruolamento nel Corpo degli equipaggi militari marittimi.

2. Effettuata la annotazione di cui al comma 1, gli uffici di supporto dei Consigli di leva di terra trasmettono agli uffici di supporto dei Consigli di leva di mare la documentazione personale degli iscritti di cui al comma 1.

3. Gli uffici di supporto dei Consigli di leva di mare, ricevuta la documentazione di cui al comma 2, compilano in ordine alfabetico, su disposizione dell'autorita' centrale, le note definitive dei giovani soggetti alla leva per l'arruolamento nel Corpo degli equipaggi militari marittimi, includendovi tutti i giovani iscritti nelle note preparatorie, per ciascuno dei quali sia stata riportata l'annotazione di cui al comma 1 da parte degli uffici di supporto dei Consigli di leva di terra.

4. Nelle note definitive sono aggiunti tutti gli omessi ed i gia' rimandati, per qualsiasi motivo, alla prossima leva.

#### Art. 2018. - Obbligo di presentazione degli iscritti nelle note definitive

1. Fermo quanto disposto dall'articolo 1969, gli iscritti nelle note definitive hanno l'obbligo di presentarsi alla data e al Consiglio di leva indicati nel precetto personale di chiamata alla leva.

2. Gli iscritti che sono imbarcati su navi all'estero che fanno periodicamente ritorno nella Repubblica hanno l'obbligo di sbarcare al primo approdo nello Stato e di presentarsi al Consiglio di leva per l'arruolamento nel Corpo degli equipaggi militari marittimi piu' vicino al predetto approdo, nel termine di venti giorni dalla data di arrivo della nave.

3. Le autorita' diplomatiche o consolari all'estero possono impedire il passaggio da una nave all'altra di iscritti chiamati alla leva.

4. I pescatori imbarcati su navi spedite e partite per campagne di pesca periodica possono ritardare la loro presentazione fino al termine della campagna stessa.

5. Gli iscritti che non si presentano per giustificati motivi nel termine stabilito hanno l'obbligo di darne subito notizia all'ufficio competente della capitaneria di porto e di regolare la propria posizione entro la data di chiusura della sessione di leva.

#### Art. 2019. - Dilazioni da accordarsi agli iscritti marittimi

1. Nel caso di legittimo impedimento a comprovare il diritto di passaggio alla leva di terra, i Consigli di leva di mare possono concedere agli iscritti dilazioni estensibili fino al termine della sessione di leva.

#### Art. 2020. - Attivita' e provvedimenti del Consiglio di leva per l'arruolamento nel Corpo degli equipaggi militari marittimi

1. Il Consiglio di leva per l'arruolamento nel Corpo degli equipaggi militari marittimi, dopo aver verificato e chiuso le note definitive, prende in esame la posizione di ogni iscritto e adotta, oltre ai i provvedimenti di cui all'articolo 1968, comma 1, con esclusione di quelli di cui alle lettere a), b), o) e r) , i seguenti:

- a) la cancellazione dei deceduti dalle note definitive, dandone comunicazione al competente ufficio della capitaneria di porto, per i successivi adempimenti;
- b) la cancellazione dalle note definitive, con conseguente annullamento della relativa annotazione nelle liste di leva, dei seguenti iscritti: 1) gia' arruolati volontariamente nelle Forze armate, nelle Forze di Polizia ad ordinamento militare e civile e nel Corpo nazionale dei vigili del fuoco; 2) specialisti della montagna o soci della Federazione italiana sport invernali, del Club alpino italiano, dell'Alpenverein tesserati da almeno un anno, sempre che sia gli uni che gli altri abbiano svolto specifica attivita' agonistica o professionale nel settore della montagna, comprovata da idonea documentazione, e facciano domanda prima dell'arruolamento al competente ufficio delle Capitanerie di porto di prestare servizio nelle truppe alpine e ne siano riconosciuti idonei; 3) in possesso dei titoli preferenziali per l'assegnazione ai contingenti aeronautici di cui all'articolo 1952, previo esame di documentata domanda; 4) che, all'atto della chiamata alla leva, siano riformati; 5) per i quali sia dimostrato il difetto di requisito per l'assoggettamento alla leva per l'arruolamento nel Corpo degli equipaggi militari marittimi, o che comunque non siano ritenuti atti, per ragioni fisiche o professionali, a prestare servizio nella Marina militare; 6) per i quali, per motivi di carattere eccezionale, il Ministro della difesa determini la cancellazione dalle note definitive;
- c) l'arruolamento nel Corpo degli equipaggi militari marittimi degli idonei ed atti per la Marina militare ovvero l'arruolamento dei restanti idonei nell'Esercito italiano.

2. Il presidente del Consiglio di leva, sulla base dei documenti in suo possesso, dispone la compilazione del documento matricolare dell'arruolato nel Corpo degli equipaggi militari marittimi da parte del competente ufficio della capitaneria di porto e fornisce al competente comando militare, per gli arruolati nell'Esercito italiano, gli elementi necessari alla formazione dei ruoli matricolari e dei contingenti da chiamare alle armi. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2021. - Ruoli del Corpo degli equipaggi militari marittimi

1. Sono compresi nei ruoli del Corpo degli equipaggi militari marittimi:

- a) gli arruolati volontariamente nel Corpo stesso, prima dell'apertura della leva della loro classe di nascita, compresi gli arruolati volontari nella Guardia di finanza - contingente di mare;
- b) gli arruolati di leva nel Corpo degli equipaggi militari marittimi.

2. Sono cancellati dai ruoli dell'Esercito italiano e trasferiti nei ruoli del Corpo degli equipaggi militari marittimi:

- a) gli iscritti ai corsi di laurea ed i laureati in ingegneria navale e meccanica; i reiscritti ai corsi di laurea in ingegneria navale e meccanica provenienti da altri corsi di laurea; gli iscritti ai corsi di laurea ed i laureati in discipline nautiche o scienze economiche e marittime presso l'Istituto superiore navale di Napoli, che risultino gia' arruolati di leva senza avere ancora prestato servizio di leva alle armi. I rettori delle universita' e il direttore dell'istituto predetto debbono fornire, sessione per sessione, alla Marina militare, su richiesta delle Capitanerie di porto, i nomi e le generalita' dei giovani iscritti ai corsi delle facolta' sopraindicate;
- b) coloro i quali, dopo il concorso alla leva per l'arruolamento nell'Esercito italiano o nell'Aeronautica militare, ottengono di prestare servizio nella Marina militare o nella Guardia di finanza - contingente di mare, ovvero siano stati o siano iscritti tra il personale marittimo e della navigazione interna in base al codice della navigazione.

3. Sono cancellati dai ruoli del Corpo degli equipaggi militari marittimi e trasferiti nei ruoli delle Forze armate dello Stato:

- a) gli arruolati di leva che, pur essendo riconosciuti idonei, non sono ritenuti atti, per ragioni fisiche o professionali, a prestare servizio nella Marina militare; essi sono trasferiti nei ruoli dell'Esercito italiano;
- b) i militari di leva del Corpo degli equipaggi militari marittimi i quali ottengono, ai sensi delle norme previste dall'ordinamento del Corpo degli equipaggi militari marittimi e dello stato giuridico dei sottufficiali, il trasferimento nelle altre Forze armate per intraprendervi una carriera;
- c) i militari di leva del Corpo degli equipaggi militari marittimi i quali siano riformati, dopo aver prestato servizio per un periodo inferiore a tre mesi; essi sono trasferiti nei ruoli dell'Esercito italiano;
- d) gli arruolati di leva e i militari in congedo illimitato, eccedenti ai fabbisogni della Marina militare; essi sono trasferiti nei ruoli dell'Esercito italiano;
- e) i militari in congedo, forniti di brevetto di pilota civile di secondo e terzo grado, i quali siano trasferiti previo nulla osta del Ministero, nella forza in congedo dell'Aeronautica militare;
- f) i militari in servizio nella Guardia di finanza - contingente di mare, che ottengono il passaggio del contingente ordinario del Corpo; essi sono trasferiti nei ruoli dell'Esercito italiano;
- g) i militari in congedo illimitato i quali cessino di avere obbligo di servizio militare marittimo per limite di eta'.

4. Puo' essere concesso ai militari in congedo del Corpo degli equipaggi militari marittimi il nulla osta per il temporaneo arruolamento in altre Forze armate o Forze di polizia dello Stato.

5. I militari di cui al comma 1 restano iscritti nei ruoli del Corpo degli equipaggi militari marittimi, a disposizione della Marina militare, fino al compimento del trentaduesimo anno di eta', se arruolati nella Polizia di Stato o nella Polizia penitenziaria; fino al compimento del trentanovesimo anno di eta', se arruolati nelle Forze armate.

6. Puo' essere concesso ai militari in congedo del Corpo degli equipaggi militari marittimi, gia' appartenenti alla Guardia di finanza - contingente di mare, il nulla osta per l'arruolamento nel Corpo della Guardia di finanza - contingente di mare o ordinario.

7. Quelli che ottengono il nulla osta per l'arruolamento nella Guardia di finanza - contingente di mare, restano iscritti nei ruoli del Corpo degli equipaggi militari marittimi; quelli invece che ottengono il nulla osta per l'arruolamento nel contingente ordinario di detto Corpo sono trasferiti nei ruoli dell'Esercito italiano.

8. Ai militari in congedo che aspirano a conseguire il grado di ufficiale di complemento in altre Forze armate dello Stato, oppure ad intraprendere la carriera in altra Forza armata o nelle Forze di polizia dello Stato, puo' essere concesso il nulla osta per la presentazione delle relative domande. Detti militari, qualora ottengano la nomina ad ufficiale o l'ammissione in carriera, sono trasferiti nei ruoli delle rispettive Forze armate o Forze di polizia.

#### Art. 2022. - Chiamata alle armi degli arruolati nel Corpo degli equipaggi militari marittimi

1. La data dell'avviamento alle armi degli arruolati nel Corpo degli equipaggi militari marittimi e' determinata dal Ministro della difesa in relazione alle esigenze della Marina militare.

2. Alla chiamata, nel rispetto del termine massimo di cui all'articolo 1961, comma 2 e all'avviamento alle armi provvedono i competenti uffici delle Capitanerie di porto.

3. Gli arruolati, alla data fissata, vengono presi in forza dai centri addestramento reclute della Marina militare.

### SEZIONE II - ARRUOLAMENTO ECCEZIONALE ALL'ESTERO NELLA MARINA MILITARE

#### Art. 2023. - Arruolamenti eccezionali all'estero

1. Possono essere effettuati dai comandanti di navi militari arruolamenti eccezionali tra i componenti l'equipaggio di navi mercantili nazionali in porti esteri, quando l'assoluta carenza del proprio equipaggio comprometta la missione loro affidata.

2. Sono soggetti all'arruolamento di cui al comma 1, fino alla concorrenza di un quarto dei componenti l'equipaggio di ogni nave, gli appartenenti alla gente di mare di prima categoria.

3. Nei porti ove ha sede un ufficio diplomatico o consolare dello Stato, gli arruolamenti eccezionali debbono essere effettuati tramite il rappresentante diplomatico o consolare prepostovi, il quale emana gli ordini in base alle richieste dei comandanti delle navi militari.

4. Il quarto dell'equipaggio delle navi mercantili e' calcolato, ai fini degli arruolamenti eccezionali, escludendo dal totale dell'equipaggio il personale marittimo graduato, quello non appartenente alla gente di mare di prima categoria ed i mozzi.

5. Gli arruolamenti sono effettuati in relazione alle categorie necessarie per l'equipaggio della nave militare secondo il seguente ordine di precedenza:

- a) sottufficiali, graduati e militari del Corpo degli equipaggi militari marittimi in congedo, a cominciare dalla classe piu' giovane;
- b) sottufficiali, graduati e militari in congedo delle altre Forze armate dello Stato, a cominciare dalla classe piu' giovane;
- c) personale di bordo, di eta' superiore ai diciotto anni, che non ha assolto, per qualsiasi motivo, gli obblighi di leva o di servizio alle armi.

#### Art. 2024. - Congedo dei marinai arruolati eccezionalmente. Indennita' e rimborsi

1. Il personale arruolato in base all'articolo 2023 viene congedato al ritorno della nave militare in un porto della Repubblica o prima, se sono giunti a bordo militari del Corpo degli equipaggi militari marittimi destinati a coprire le carenze organiche.

2. Al personale di cui al comma 1 vengono forniti, a spese dell'Amministrazione militare, i mezzi per far ritorno nel luogo di domicilio.

3. Le maggiori spese eventualmente incontrate dagli armatori per la sostituzione sulle loro navi del personale arruolato a norma dell'articolo 2023 sono a carico dell'Amministrazione militare.

## CAPO VI - FERMA DI LEVA

### SEZIONE I - DISPOSIZIONI GENERALI

#### Art. 2025. - Nozione

1. La ferma di leva e' quella parte dell'obbligo del servizio militare che si compie sotto le armi per chiamata d'autorita', allo scopo di acquisire la necessaria istruzione militare.

#### Art. 2026. - Durata della ferma di leva

1. La durata della ferma di leva e del servizio civile sostitutivo per gli obiettori di coscienza e' di dieci mesi, prolungabili con decreto del Ministro della difesa se si renda necessario in considerazione delle esigenze dello stato di guerra o di grave crisi internazionale.

#### Art. 2027. - Decorrenza della ferma di leva

1. La ferma di leva decorre dal giorno in cui ha inizio la prestazione del servizio alle armi.

#### Art. 2028. - Tempo computabile e non computabile nella ferma di leva

1. Gli allievi delle accademie, delle scuole formative degli ufficiali e delle scuole allievi ufficiali, che abbiano seguito da arruolati i rispettivi corsi per almeno ventiquattro mesi, sono esonerati dal compiere il servizio militare di leva.

2. Per gli allievi non sottoposti a vincoli di ferma volontaria e per i militari che siano stati prosciolti dalla ferma volontariamente contratta presso le Forze armate o Forze di polizia dello Stato, salvo che il proscioglimento sia stato determinato da lesioni o infermita' dipendenti da causa di servizio, non e' computabile nella ferma di leva il tempo trascorso presso istituti, accademie e scuole delle Forze armate o Forze di polizia dello Stato.

3. Non e' computabile nella ferma di leva il tempo trascorso dai militari in stato di diserzione o di allontanamento illecito o scontando una pena loro inflitta dai tribunali militari o ordinari, ne' quello trascorso in custodia cautelare in carcere in attesa del processo, se questo si conclude con condanna.

4. Nei casi di interruzione di servizio di cui al comma 3, i militari debbono compiere alle armi tanto tempo in piu' quanto ne occorra per completare la ferma di leva cui sono obbligati.

5. Il periodo trascorso dal personale di leva in licenza di convalescenza per malattie od infermita' non dovute a causa di servizio, non e' computabile ai fini dell'assolvimento degli obblighi di leva, tranne i primi quindici giorni complessivi.

6. Non e' computabile ai fini dell'assolvimento degli obblighi di leva, il periodo trascorso presso luoghi di cura per infermita' o malattie non dipendenti da causa di servizio, tranne i primi quarantacinque giorni complessivi.

7. I limiti di quindici e di quarantacinque giorni di cui ai commi 5 e 6 possono essere aumentati solo con esplicita e motivata decisione della competente autorita' sanitaria militare a domanda degli interessati.

8. E' computabile nella ferma di leva la licenza di convalescenza accordata ai militari di leva riconosciuti tossicodipendenti dagli ospedali militari.

9. Non e' computabile, ai fini dell'assolvimento degli obblighi di leva, il periodo trascorso in licenza speciale per campagna elettorale dai militari di leva candidati ad elezioni politiche e amministrative.

#### Art. 2029. - Luogo di prestazione della ferma di leva

1. Purche' non sia incompatibile con le direttive strategiche e le esigenze logistiche delle Forze armate, e con lo stato di guerra o di grave crisi internazionale, il militare di leva e' assegnato ad unita' o reparti aventi sede nel luogo piu' vicino al comune di residenza, possibilmente distanti non oltre 100 chilometri da essa. Per i militari che siano destinati a prestare servizio di leva presso unita' o reparti aventi sede oltre i 100 chilometri dalla localita' di residenza, o all'estero, sono previste, con decreto del Ministro della difesa, agevolazioni di carattere non economico volte a favorirne il rientro periodico alla localita' di residenza, compatibilmente con le esigenze di servizio. Tali agevolazioni sono proporzionali alla distanza tra la sede di servizio e il comune di residenza.

### SEZIONE II - COMPITI DEI MILITARI IN FERMA DI LEVA

#### Art. 2030. - Contenuto della ferma di leva

1. La ferma di leva comprende un periodo di addestramento pratico ed uno di attivita' operativa.

#### Art. 2031. - Obbligo di volo per i militari dell'Aeronautica militare

1. I militari dell'Aeronautica militare hanno obbligo di volo, ognuno nell'ambito del proprio impiego e delle proprie attribuzioni, secondo le norme particolari di detta Forza armata.

#### Art. 2032. - Impiego dei militari di leva

1. I militari di leva sono impiegati esclusivamente per le esigenze connesse con le attivita' operative, logistiche, addestrative, e riguardanti il benessere del personale militare ed i servizi generali di caserma.

2. La durata dell'impiego di militari di leva per le esigenze di benessere del personale militare e dei servizi generali in caserma non puo' superare il periodo di sei mesi.

3. Fermi restando i compiti prioritari della difesa della Patria e di partecipazione alle missioni necessitate dallo stato di grave crisi internazionale, e' consentito, nelle zone del territorio nazionale colpite da pubbliche calamita' durante lo stato di guerra o di grave crisi internazionale, l'impiego dei militari di leva per concorrere nella fase di prima emergenza oltre che al soccorso immediato delle popolazioni colpite, al ripristino di infrastrutture pubbliche, alla tutela del patrimonio storico, artistico e culturale, nonche' alla salvaguardia dell'ambiente naturale. A tale scopo il Ministro della difesa dispone i possibili interventi d'intesa con le amministrazioni statali e regionali interessate.

4. E' vietato impiegare i militari di leva per esigenze diverse da quelle indicate nel presente titolo, fatta eccezione per gli impieghi previsti dall'articolo 3 della legge 2 maggio 1984, n. 111, che sono autorizzati con decreto del Ministro della difesa, se compatibili con le esigenza di impiego dei militari nella guerra o nella grave crisi internazionale, ovvero sospesi finche' durano tali esigenze.

### SEZIONE III - FORMAZIONE DEI MILITARI DI LEVA

#### Art. 2033. - Elevazione culturale e formazione civica

1. Lo Stato promuove l'elevazione culturale e la formazione civica dei militari di leva avvalendosi anche della capacita' professionale e dello spirito di iniziativa dei singoli per il proficuo svolgimento delle attivita' di servizio.

2. Parte integrante della formazione del militare di leva e' la preparazione civica da svolgere presso i comandi, i reparti e gli enti delle Forze armate, secondo un programma fissato dal Ministro della difesa, sentito il Ministro dell'istruzione, dell'universita' e della ricerca.

3. Il programma di cui al comma 2 comprende nozioni sull'ordinamento costituzionale dello Stato e sulla storia moderna e contemporanea, con specifico riferimento al processo unitario nazionale, alla fondazione della Repubblica, alla Costituzione e alle sue norme di attuazione, all'ordinamento delle Forze armate e alle norme del diritto penale militare.

4. I parlamentari componenti delle Commissioni Difesa della Camera dei deputati e del Senato della Repubblica hanno diritto ad assistere alle attivita' di cui al comma 2, previa comunicazione al Comandante del reparto o dell'ente militare preposto allo svolgimento del programma relativo alla preparazione civica.

5. Nelle occasioni ritenute piu' significative, i comandi di corpo invitano le autorita' civili e i presidenti delle associazioni combattentistiche e partigiane a presenziare alle attivita' di cui al comma 2.

6. Le attivita' di cui al comma 2 possono essere sospese o ridotte secondo le direttive impartite dal Ministro della difesa se lo stato di guerra o di grave crisi internazionale ne impediscono il regolare svolgimento.

#### Art. 2034. - Formazione professionale

1. Le Forze armate, nella definizione dei programmi di addestramento relativi ai propri compiti istituzionali, tendono all'elevazione delle capacita' professionali dei giovani alle armi, contribuendo in tal modo alle esigenze produttive e civili della nazione.

2. Il piano dei corsi di ciascuna Forza armata per la formazione di specialisti ed aiuto specialisti, cui sono ammessi i militari di leva, e' comunicato al Ministro del lavoro e delle politiche sociali e al Ministro dell'istruzione, dell'universita' e della ricerca, nonche' ai Presidenti delle giunte regionali.

3. I corsi di qualificazione e di specializzazione, previsti per i militari ammessi alla commutazione della ferma di leva ai sensi dell'articolo 2038, sono resi noti ai militari alle armi.

#### Art. 2035. - Formazione sportiva

1. L'attivita' sportiva, condotta da istruttori qualificati, e' parte integrante della formazione del militare di leva.

2. I programmi di istruzione devono comprendere appositi periodi destinati alla anzidetta attivita'.

### SEZIONE IV - DISCIPLINA MILITARE

#### Art. 2036. - Disciplina militare - Rinvio

1. I militari in servizio di leva sono tenuti all'osservanza delle norme di disciplina militare, e sono sottoposti alle relative sanzioni disciplinari, secondo le disposizioni dettate nel titolo VIII del libro IV, e nelle pertinenti norme regolamentari.

### SEZIONE V - CARRIERA MILITARE

#### Art. 2037. - Avanzamento

1. I militari in servizio di leva possono conseguire, previo giudizio di idoneita', i gradi e le qualifiche di caporale, comune di prima classe, aviere scelto, al compimento del terzo mese dalla data di incorporazione.

#### Art. 2038. - Ferma di leva prolungata su base volontaria

1. In relazione alle esigenze derivanti dalla durata dello stato di guerra o di grave crisi internazionale, i militari ed i graduati in servizio di leva possono essere ammessi, a domanda, alla commutazione della ferma di leva in ferma di leva prolungata, biennale o triennale, secondo le esigenze numeriche delle Forze armate fissate annualmente nella legge di bilancio, in una percentuale non superiore a quella dei militari di leva rispetto ai militari volontari.

2. Ai fini del comma 1 il Ministro della difesa ha facolta' di indire bandi per la commutazione, a domanda, della ferma di leva in ferma prolungata biennale o triennale, per i militari che non abbiano superato il ventiduesimo anno di eta'.

3. Il Ministro della difesa ha, inoltre, facolta', qualora il numero dei richiedenti la commutazione di leva risulti insufficiente a soddisfare le esigenze organiche, di indire arruolamenti riservati ai giovani che non abbiano ancora assolto l'obbligo di leva ed abbiano compiuto il diciottesimo anno di eta' e non superato il ventiduesimo.

4. I militari ammessi alla ferma di leva prolungata sono inclusi nei corsi di qualificazione e di specializzazione effettuati dal Ministero della difesa.

5. Per l'assegnazione ai corsi di cui al comma 4 sono prese in considerazione, oltre alle richieste degli interessati, anche le qualificazioni e le specializzazioni possedute, nonche' i risultati degli esami fisio - psico - attitudinali effettuati in sede di visita di leva.

6. I giovani ammessi alla ferma di leva prolungata possono rassegnare le dimissioni, senza ulteriori obblighi, entro i primi trenta giorni di durata del corso.

7. I militari in ferma prolungata biennale o triennale sono assegnati, tenuto conto per quanto possibile delle loro aspirazioni, alle categorie, alle specializzazioni, alle specialita' ed agli incarichi di impiego indicati nei bandi di arruolamento in base alle esigenze di ciascuna Forza armata.

8. Il periodo trascorso in ferma prolungata biennale o triennale e' valido agli effetti dell'assolvimento degli obblighi di leva.

9. Della possibilita' di cui al comma 1 e dei relativi limiti e modalita' e' data notizia mediante il manifesto di chiamata alla leva e quello, ove vi sia, di chiamata alle armi.

10. Per il proscioglimento dalla ferma volontaria contratta si applicano le corrispondenti norme di stato.

11. Le disposizioni sullo stato e l'avanzamento previste per i volontari in ferma prefissata si applicano ai militari in ferma di leva prolungata.

12. Il militare in ferma prolungata, riconosciuto tossicodipendente che dichiari la sua disponibilita' a sottoporsi a trattamenti di recupero socio-sanitario, viene posto in licenza di convalescenza straordinaria e successivamente, se del caso, in aspettativa per il periodo massimo previsto dalla normativa in vigore. Al termine del trattamento viene sottoposto a controlli sanitari intesi a stabilire la sua idoneita' al servizio militare.

### SEZIONE VI - DISCIPLINA DEI DIRITTI DURANTE LA LEVA E DEI DIRITTI INERENTI LA LEVA

#### Art. 2039. - Trattamento economico dei militari di leva e disciplina dei diritti costituzionali. Sanita' militare. Rinvio

1. Il trattamento economico e le altre provvidenze economiche a favore dei militari di leva e loro superstiti sono disciplinati dalle disposizioni del titolo II del libro VI.

2. Fatto salvo quanto disposto nella presente sezione, i diritti dei militari di leva e le relative limitazioni e modalita' di esercizio sono disciplinate dalle disposizioni del titolo IX del libro IV.

3. I diritti di cui al comma 2 sono esercitati compatibilmente con le circostanze straordinarie e urgenti del tempo di guerra o dello stato di grave crisi internazionale.

4. Ai fogli di congedo, copie di fogli matricolari e stato di servizio dei militari di leva e alle comunicazioni della inidoneita' al servizio di leva si applicano le disposizioni di cui all'articolo 1024.

5. Ai militari di leva si applicano le norme in tema di sanita' militare.

#### Art. 2040. - Licenze

1. Ai militari di leva e in ferma prolungata si applica la normativa dettata dal presente codice in materia di licenze del personale militare, fatto salvo quanto previsto nei commi da 2 a 9 del presente articolo.

2. Soddisfatte le esigenze operative, addestrative, di sicurezza e di servizio, possono essere inoltre concesse ai militari di leva, in coincidenza con il fine settimana o con le festivita', licenze brevi non superiori a trentasei ore, se compatibili con lo stato di guerra o di grave crisi internazionale.

3. I militari di leva gia' incorporati che sono riconosciuti tossicodipendenti dagli ospedali militari vengono posti in licenza di convalescenza fino al termine del congedo della classe di appartenenza. Detti militari vengono segnalati alle competenti aziende sanitarie locali al fine di facilitare il loro avvio volontario a programmi di recupero.

4. Per i militari di leva residenti in localita' distanti oltre 300 e fino a 800 chilometri dalla sede di servizio, ovvero per i quali la durata del viaggio tra tale sede e il comune di residenza sia di oltre otto e sino a sedici ore, il limite massimo previsto per le licenze brevi dalla normativa vigente puo' essere elevato a venti giorni; oltre i suddetti termini il limite massimo puo' essere elevato a venticinque giorni.

5. Ai militari di leva che si recano in licenza ordinaria compete il rimborso delle spese di viaggio dalla sede di servizio al comune di residenza e viceversa o della somma equivalente se la licenza e' fruita in localita' diversa. Analogo rimborso compete ai militari che si recano in licenza straordinaria per imminente pericolo di vita o per morte del coniuge o di un parente.

6. Ai militari di leva ai quali e' accordata la licenza breve e' concesso il rimborso delle spese di viaggio dalla sede di servizio al comune di residenza e viceversa, limitatamente a:

- a) un solo viaggio, nel periodo di dieci mesi di leva, qualora il comune di residenza sia distante dalla sede di servizio meno di trecento chilometri;
- b) cinque viaggi, nel periodo di dieci mesi di leva, qualora il comune di residenza sia distante dalla sede di servizio oltre trecento chilometri.

7. Ai militari di leva che si recano in licenza nei comuni di residenza distanti oltre seicento chilometri dalla sede di servizio sono concessi le facilitazioni di viaggio, nonche' i rimborsi previsti dal presente articolo anche per l'uso di treni rapidi.

8. Le disposizioni di cui ai commi 2, 5 e 6 del presente articolo non si applicano ai militari di leva che prestano servizio, in qualita' di ausiliari, nell'Arma dei carabinieri.

9. Il Ministro della difesa e' autorizzato a stipulare le convenzioni per l'applicazione delle facilitazioni previste nel presente articolo.

#### Art. 2041. - Militari di leva che sono amministratori locali

1. Ferme le disposizioni relative al collocamento in aspettativa dei militari di carriera eletti membri del Parlamento o investiti di cariche elettive presso gli enti autonomi territoriali, i militari di leva o richiamati, che sono amministratori locali ai sensi dell'articolo 77 del decreto legislativo 18 agosto 2000, n. 267, dovranno, compatibilmente con le esigenze di servizio, essere destinati ad una sede che consenta loro l'espletamento delle particolari funzioni cui sono stati eletti, con priorita' per la sede di espletamento del mandato amministrativo o per le sedi a questa piu' vicine.

2. Ai militari di cui al comma 1, deve essere concesso, compatibilmente con le esigenze di servizio, il tempo che si renda necessario per l'espletamento del mandato, nei limiti di cui all'articolo 79, commi 1 e 3, del citato decreto legislativo n. 267 del 2000, in funzione della carica rivestita.

3. Ai militari di leva o richiamati che rivestano la carica di sindaco, presidente di provincia, presidente delle comunita' montane, puo' essere concessa, a richiesta, una licenza illimitata in attesa di congedo per la durata del mandato.

#### Art. 2042. - Limiti allo svolgimento di attivita' sindacale

1. I militari in servizio di leva o quelli richiamati in temporaneo servizio, possono iscriversi o permanere associati ad organizzazioni sindacali di categoria, ma e' fatto loro divieto di svolgere attivita' sindacale quando si trovano in una delle seguenti condizioni:

- a) svolgono attivita' di servizio;
- b) sono in luoghi militari o comunque destinati al servizio;
- c) indossano l'uniforme;
- d) si qualificano, in relazione ai compiti di servizio, come militari o si rivolgono ad altri militari in divisa o che si qualificano come tali.

#### Art. 2043. - Presenza dei militari di leva negli organi di rappresentanza militare

1. Negli organi di base di rappresentanza di militari, i militari di leva sono rappresentati da delegati eletti nelle unita' minime compatibili con la struttura di ciascuna Forza armata e con scadenze che garantiscono la continuita' degli organi rappresentativi.

2. I rappresentanti dei militari di leva negli organi di base eleggono nel proprio ambito semestralmente loro delegati nell'organo intermedio.

3. Gli eletti che cessano anticipatamente dal mandato sono sostituiti, per il periodo residuo, dai militari che, nelle votazioni effettuate, di primo o secondo grado, seguono immediatamente nella graduatoria l'ultimo degli eletti.

4. Il Ministro della difesa riunisce una volta l'anno i militari di leva, all'uopo eletti dai rappresentanti di detta categoria negli organi intermedi, per ascoltare, in riferimento alla relazione annuale al Parlamento sullo stato della disciplina militare e dell'organizzazione delle Forze armate di cui all'articolo 10, comma 2, lettera e), pareri, proposte e richieste in merito allo stato del personale della leva.

#### Art. 2044. - Rappresentanza della leva nel Consiglio centrale di rappresentanza militare

1. I militari di leva entrano a far parte del Consiglio centrale della rappresentanza militare.

2. I delegati dei militari di leva vengono eletti semestralmente, con voto diretto, nominativo e segreto, fra i delegati dei consigli intermedi della rappresentanza militare, entro il decimo giorno successivo a quello della dichiarazione di elezione degli stessi, nella misura di tre unita' per ciascuna Forza armata o Corpo armato cosi' ripartite:

- a) due unita' in rappresentanza dei militari e graduati di truppa in servizio di leva, compresi i carabinieri ausiliari e gli allievi carabinieri ausiliari;
- b) una unita' in rappresentanza degli ufficiali di complemento in servizio di prima nomina e degli allievi ufficiali di complemento.

3. Se i problemi trattati dal Consiglio centrale della rappresentanza militare riguardano il servizio di leva, detto Consiglio deve sentire in merito i militari di leva che vengono eletti negli organi intermedi o loro delegazioni.

### SEZIONE VII - FORMAZIONE E AGEVOLAZIONI STRUMENTALI AL PASSAGGIO DALLA VITA MILITARE ALLA VITA CIVILE

#### Art. 2045. - Corsi di formazione

1. I militari di leva, compatibilmente con le esigenze di servizio, possono frequentare i corsi di formazione professionale organizzati dalle pubbliche amministrazioni, inclusi quelli promossi dall'Unione europea, che si svolgono nell'ambito territoriale dove prestano servizio.

2. Le pubbliche amministrazioni interessate inviano i programmi dei corsi ai comandi militari situati nel territorio di loro competenza.

3. I singoli comandi divulgano i programmi di cui al comma 2 presso il personale di leva e ne forniscono copia ai consigli di rappresentanza.

#### Art. 2046. - Attivita' sportiva

1. Le Forze armate, nell'ambito delle attivita' loro assegnate, e compatibilmente con lo stato di guerra o di grave crisi internazionale, facilitano la partecipazione dei militari di leva allo svolgimento di attivita' sportive.

2. I comandi responsabili, coadiuvati dagli organi di base della rappresentanza militare, nell'ambito del territorio del presidio, concordano le necessarie iniziative con le istituzioni pubbliche, le associazioni, le societa' e le istituzioni sportive e ricreative del luogo.

3. I militari di leva che risultano atleti riconosciuti di livello nazionale da una commissione, composta dai rappresentanti del Comitato olimpico nazionale italiano e delle Forze armate, sono autorizzati ad esercitare la pratica delle discipline sportive compatibilmente con gli obblighi di servizio e secondo quanto previsto dal regolamento.

4. I militari di cui al comma 3 vengono assegnati ai centri sportivi di Forza armata, tenendo conto della disciplina sportiva praticata dai singoli prima dell'incorporazione e delle esigenze della Forza armata stessa.

5. I militari di cui al comma 3 che praticano discipline sportive non previste nei centri sportivi di Forza armata o che non vengono destinati nei predetti centri, ai sensi del comma 4, possono essere assegnati a comandi, enti o reparti vicini alla societa' sportiva di appartenenza compatibilmente con le esigenze organiche o di servizio.

6. Le richieste di assegnazione di cui al comma 5 presso le sedi di origine vengono inoltrate dal Comitato olimpico nazionale italiano, almeno quattro mesi prima della partenza del contingente di appartenenza degli interessati, salvo che i presupposti per la richiesta si verifichino in un momento successivo.

#### Art. 2047. - Segnalazioni curriculari alle pubbliche amministrazioni

1. Al fine di agevolare l'inserimento dei giovani alle armi nelle attivita' produttive della Nazione, tre mesi prima del termine del servizio militare obbligatorio e della ferma di leva prolungata, il Ministro della difesa, in relazione al personale di leva delle Forze armate, comunica gli elenchi nominativi degli specialisti ed aiuto specialisti in procinto di essere congedati al Ministro del lavoro e delle politiche sociali e ai presidenti delle giunte regionali delle regioni ove risiedono gli interessati.

### SEZIONE VIII - DIRITTI INERENTI AL LAVORO CIVILE

#### Art. 2048. - Sospensione del rapporto di lavoro durante la ferma di leva e diritto alla conservazione del posto

1. La chiamata alle armi per adempiere agli obblighi di leva sospende il rapporto di lavoro per tutto il periodo della ferma e il lavoratore ha diritto alla conservazione del posto.

2. Entro trenta giorni dal congedo o dall'invio in licenza illimitata in attesa di congedo, il lavoratore deve porsi a disposizione del datore di lavoro per riprendere servizio. In mancanza, il rapporto di lavoro e' risolto.

3. La vigilanza per l'applicazione delle disposizioni di cui commi 1 e 2 e' affidata all'Ispettorato del lavoro.

4. Le violazioni delle disposizioni del presente articolo sono punite con la sanzione amministrativa da euro 103,00 a euro 516,00. Se la violazione si riferisce a piu' di cinque lavoratori si applica la sanzione amministrativa da euro 155,00 a euro 1033,00.

#### Art. 2049. - Elevazione del limite di eta' per la partecipazione ai concorsi pubblici

1. Per la partecipazione ai pubblici concorsi il limite massimo di eta' richiesto e' elevato di un periodo pari all'effettivo servizio prestato, comunque non superiore a tre anni, per i cittadini che hanno prestato servizio militare.

2. Si applica il comma 3 dell'articolo 2050.

#### Art. 2050. - Valutazione del servizio militare come titolo nei concorsi pubblici

1. I periodi di effettivo servizio militare, prestati presso le Forze armate sono valutati nei pubblici concorsi con lo stesso punteggio che le commissioni esaminatrici attribuiscono per i servizi prestati negli impieghi civili presso enti pubblici.

2. Ai fini dell'ammissibilita' e della valutazione dei titoli nei concorsi banditi dalle pubbliche amministrazioni e' da considerarsi a tutti gli effetti il periodo di tempo trascorso come militare di leva o richiamato, in pendenza di rapporto di lavoro.

3. Le norme del presente articolo sono applicabili ai concorsi banditi dalle amministrazioni dello Stato, comprese le aziende autonome, e dagli altri enti pubblici, regionali, provinciali e comunali per l'assunzione e l'immissione di personale esterno in tutte le qualifiche, carriere, fasce o categorie funzionali previste dai rispettivi ordinamenti organici.

#### Art. 2051. - Valutazione delle qualifiche professionali e specializzazioni acquisiti durante il servizio militare come titolo nei concorsi pubblici

1. Le qualifiche professionali e le specializzazioni acquisite durante il servizio militare, attestate con diploma rilasciato dall'ente militare competente, costituiscono titolo da valutare nei concorsi per titoli ed esami per l'accesso alle qualifiche funzionali e relativi profili professionali della pubblica amministrazione.

2. Parimenti le effettive prestazioni disimpegnate dagli ufficiali di complemento di 1^ nomina e le qualifiche professionali acquisite, comprovate con attestati rilasciati dall'ente militare competente, costituiscono titoli da valutare per l'accesso alle qualifiche funzionali e relativi profili professionali della pubblica amministrazione.

3. La valutazione dei titoli di cui ai comma 1 e 2 e' riferita ai casi in cui la qualifica professionale o la specializzazione acquisita ha una diretta corrispondenza con il profilo della qualifica cui si riferisce il concorso o l'assunzione diretta. In ogni caso, pur in mancanza di diretta corrispondenza tra la specializzazione acquisita e il profilo della qualifica cui si riferisce il concorso o l'assunzione diretta, l'aver assolto effettivamente all'obbligo di leva costituisce titolo da valutare.

4. Con decreto del Ministro della difesa, adottato di concerto con i Ministri per la pubblica amministrazione e l'innovazione, dell'economia e delle finanze, del lavoro e delle politiche sociali, e dell'istruzione, dell'universita' e della ricerca, e' stabilita la corrispondenza delle qualifiche e specializzazioni di cui ai commi 1 e 2 con le qualifiche funzionali e relativi profili professionali previsti ai fini dell'avviamento al lavoro.

5. Le amministrazioni dello Stato, comprese le unita' sanitarie locali, le aziende autonome e gli altri enti pubblici regionali, provinciali e comunali, nei bandi di concorso per l'immissione di personale esterno, devono indicare la valutazione da attribuire ai titoli di cui ai commi 1, 2 e 3.

#### Art. 2052. - Riconoscimento del servizio militare per l'inquadramento economico e il trattamento previdenziale nel pubblico impiego

1. Il periodo di servizio militare e' valido a tutti gli effetti per l'inquadramento economico e per la determinazione della anzianita' lavorativa ai fini del trattamento previdenziale del settore pubblico.

2. Il servizio militare valutabile ai sensi del comma 1 e' esclusivamente quello in corso alla data di entrata in vigore della legge 24 dicembre 1986, n. 958, nonche' quello prestato successivamente. Rimane fermo il computo ai fini del trattamento di quiescenza dei periodi previsti dall'articolo 1, comma 1, della legge 8 agosto 1991, n. 274, con onere a carico dell'INPDAP, indipendentemente dall'epoca nella quale siano stati prestati. Gli eventuali maggiori trattamenti comunque in godimento, conseguenti ad interpretazioni difformi da quelle recate dal presente comma, cessano di essere corrisposti; le somme gia' erogate sono riassorbite con i futuri miglioramenti dovuti sul trattamento di attivita' o di quiescenza.

### SEZIONE IX - FERMA DI LEVA MEDIANTE SERVIZIO AUSILIARIO

#### Art. 2053. - Ferma di leva mediante servizio ausiliario nelle Forze di polizia a ordinamento militar e a ordinamento civile e nel Corpo nazionale dei vigili del fuoco

1. Nei limiti del contingente complessivo di cui all'articolo 1947, e della sua ripartizione, e nei limiti delle vacanze esistenti nei ruoli delle Forze di polizia ad ordinamento militare e ad ordinamento civile e del Corpo nazionale dei vigili del fuoco, il Ministro competente puo' reclutare in detti Corpi giovani iscritti nelle liste di leva, nell'anno in cui ne facciano domanda, che abbiano ottenuto il nulla osta delle competenti autorita' militari, e che siano in possesso dei requisiti prescritti per il reclutamento nel Corpo per cui hanno fatto domanda.

2. Gli interessati devono presentare domanda alla competente autorita' militare, indicata nel manifesto di chiamata alle armi. Detto manifesto indica anche la consistenza numerica del contingente ausiliario e della sua ripartizione, nonche' i requisiti ed i criteri per l'ammissione al servizio ausiliario.

3. Il servizio ausiliario prestato nei Corpi di cui al comma 1 e' equiparato a tutti gli effetti al servizio militare di leva e ha la stessa durata.

4. I militari reclutati ai sensi del comma 1 assumono il grado o la qualifica prevista dall'ordinamento del Corpo in cui sono ammessi; sono assegnati agli istituti di istruzione, comunque denominati, del Corpo di assegnazione per un addestramento militare e tecnico - professionale della durata prevista dall'ordinamento del Corpo cui sono assegnati. Nel successivo impiego si tiene conto del loro particolare grado di addestramento.

5. I militari reclutati ai sensi del comma 1 sono soggetti alle norme sullo stato giuridico e alle norme di servizio previste per il personale del Corpo di assegnazione.

6. Con decorrenza dal termine del corso di addestramento per essi rispettivamente previsto, ai militari in servizio ausiliario e' attribuito il trattamento economico previsto per i carabinieri ausiliari.

7. Il Ministero competente per ciascuno dei Corpi di cui al comma 1 puo', in qualsiasi momento, durante la ferma di leva, esonerare i militari dal servizio ausiliario, con provvedimento motivato. I militari esonerati dal servizio ausiliario sono posti a disposizione della competente autorita' militare per il completamento della ferma di leva.

8. I militari in servizio ausiliario sono collocati in congedo illimitato al termine del periodo di servizio e nei loro riguardi si applicano, per il richiamo in servizio, le norme dettate dall'ordinamento di ciascun Corpo, per il richiamo in servizio dei militari di leva, ovvero, in caso di Corpi non militari, le norme dettate per il richiamo in servizio dei militari di leva dell'Esercito italiano, della Marina militare e dell'Aeronautica militare.

## CAPO VII - CONGEDI

### SEZIONE I - CONGEDO ILLIMITATO

#### Art. 2054. - Congedo illimitato

1. Il congedo illimitato spetta ai militari di qualunque ferma che, all'atto in cui cessano dal servizio alle armi o ne sono dispensati, conservano l'obbligo del servizio militare.

#### Art. 2055. - Ritardo del congedo ai militari che scontano sanzioni disciplinari di corpo

1. Il militare di leva cui spetterebbe il congedo illimitato, il quale stia scontando una sanzione disciplinare di corpo di consegna o di consegna di rigore, non puo' essere congedato se non dopo scontata la sanzione.

2. Il congedo del militare di leva, ove il militare sia stato punito con consegna o con consegna di rigore, puo' essere ritardato per un numero di giorni non superiore a quelli complessivamente trascorsi in tale punizione durante la seconda meta' del servizio prestato.

3. Il militare di leva, il quale si sia a suo tempo presentato alle armi con ritardo, salvo che il ritardo sia giustificato da uno dei presupposti che, se verificatosi durante la leva, darebbe luogo ad una sospensione del servizio computabile nella ferma di leva ai sensi dell'articolo 2028, e' trattenuto alle armi, dopo il termine del suo servizio, per un numero di giorni pari a quelli del ritardo.

#### Art. 2056. - Ritardo del congedo a militari in navigazione o in servizio all'estero

1. I militari imbarcati sulle navi dello Stato in navigazione possono essere congedati anche dopo aver compiuto la loro ferma ed all'arrivo della nave nel primo porto della Repubblica.

2. I militari in servizio all'estero o su navi stazionarie all'estero possono essere congedati anche dopo aver compiuto la loro ferma, qualora per esigenze di servizio il rimpatrio abbia dovuto subire ritardo.

#### Art. 2057. - Sospensione dell'invio in congedo illimitato in caso di prolungamento della leva a seguito di dichiarazione dello stato di guerra o di grave crisi internazionale

1. In caso di prolungamento della ferma di leva in tempo di guerra o di grave crisi internazionale ai sensi dell'articolo 2026, l'invio in congedo illimitato e' sospeso.

#### Art. 2058. - Obblighi di sottufficiali e militari di truppa in congedo illimitato di notificare i cambiamenti di residenza e gli espatri

1. I sottufficiali e i militari di truppa inviati in congedo illimitato devono presentarsi, entro otto giorni dall'arrivo nel comune di residenza, se appartenenti all'Esercito italiano e all'Aeronautica militare, al Sindaco, e, se appartenenti alla Marina militare, alla Capitaneria di porto nella cui circoscrizione si trova il comune di residenza, o, in mancanza, al Sindaco, per far vistare il foglio di congedo e dare il proprio recapito; successivamente essi devono notificare i cambiamenti di residenza anche temporanei, entro quindici giorni dalla partenza, all'autorita' suddetta.

2. I militari in congedo illimitato che espatriano, all'atto dell'arrivo nel Paese estero, devono presentarsi all'autorita' diplomatica o consolare per comunicare la loro residenza. Qualora nella localita' manchi il rappresentante diplomatico o consolare, devono comunicare la loro residenza al consolato piu' vicino, oppure direttamente all'organo militare nella cui forza in congedo sono iscritti.

3. I militari in congedo illimitato che rimpatriano definitivamente devono presentarsi per dichiarare la loro residenza:

- a) se appartenenti all'Esercito italiano e all'Aeronautica militare, al Sindaco;
- b) se appartenenti alla Marina militare, alla Capitaneria di porto di iscrizione o, in mancanza, al Sindaco.

4. I Sindaci e le autorita' diplomatiche o consolari notificano ai competenti organi militari, nel termine di quindici giorni dalla data della dichiarazione, le denunce ricevute dai militari in congedo illimitato, nonche' tutte le notizie e le variazioni ad essi relative.

#### Art. 2059. - Richiamo in servizio dei militari di truppa in congedo illimitato

1. I militari di truppa dell'Esercito italiano, della Marina militare e dell'Aeronautica militare in congedo illimitato possono essere richiamati in servizio in totalita', ovvero in parte, per classi, per aliquote di classi, per Arma di provenienza, per Corpo, per specializzazione, per incarico, per Comando militare, o per Compartimento marittimo o per Regione aerea.

2. I richiami di cui al comma 1 avvengono con decreto del Presidente della Repubblica, ma i militari, se invitati a presentarsi con precetto personale, hanno l'obbligo di rispondere nel termine loro assegnato, anche se non sia intervenuta ancora la pubblicazione del decreto presidenziale di richiamo.

3. Col consenso degli interessati possono essere richiamati dal congedo anche singoli militari di truppa, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

#### Art. 2060. - Diritti dei militari richiamati in ordine al rapporto di lavoro e alla partecipazione a concorsi pubblici

1. In ordine alla conservazione del posto di lavoro, alla partecipazione a pubblici concorsi, ai titoli valutabili e al computo del servizio militare nell'anzianita' di servizio si applicano, ai richiamati alle armi, gli articoli 2048, commi 1, 3, e 4, 2049, 2050, 2051 e 2052.

2. Alla fine del richiamo il lavoratore deve porsi a disposizione del datore di lavoro per riprendere la sua occupazione, entro il termine di cinque giorni se il richiamo ha avuto durata non superiore a un mese, di otto giorni se ha avuto durata superiore a un mese ma non a sei mesi, di quindici giorni se ha avuto durata superiore a sei mesi, di trenta giorni se ha avuto durata superiore a dieci mesi. In mancanza il rapporto di lavoro e' risolto.

3. Il lavoratore, salvo il caso di recesso per giusta causa di cui all'articolo 2119 del codice civile, non puo' essere licenziato prima che siano trascorsi tre mesi dalla ripresa della occupazione.

4. Rimangono salve le condizioni piu' favorevoli ai lavoratori contenute nei contratti di lavoro.

5. Per i rapporti di lavoro alle dipendenze di pubbliche amministrazioni il tempo trascorso in servizio militare da richiamato e fino alla presentazione per riprendere il posto di lavoro e' computato agli effetti dell'anzianita' di servizio.

6. Per i rapporti di lavoro dei prestatori d'opera i quali, all'atto del richiamo alle armi per qualunque esigenza delle Forze armate, sono alle dipendenze di un privato datore di lavoro si applica la disposizione del secondo comma dell'articolo 2111 del codice civile, in relazione al primo e terzo comma dell'articolo 2110 dello stesso codice.

#### Art. 2061. - Militari di truppa che hanno prestato servizio nelle Forze di polizia dello Stato

1. I militari di truppa in congedo illimitato iscritti nei ruoli dell'Esercito italiano che durante il servizio di leva hanno prestato servizio come ausiliari nelle Forze di Polizia ad ordinamento militare o civile o nel Corpo nazionale dei vigili del fuoco, in caso di richiamo alle armi per qualsiasi motivo, possono essere destinati a prestare servizio nei predetti Corpi. Resta fermo il divieto di richiamo di coloro che sono, alla data del richiamo, appartenenti alle Forze di polizia ad ordinamento civile e al Corpo nazionale dei vigili del fuoco, ai sensi dell'articolo 1929.

#### Art. 2062. - Esclusione dal richiamo dei militari in particolari condizioni di famiglia

1. Il Ministro della difesa puo' escludere dall'obbligo di rispondere al richiamo alle armi i militari delle classi piu' anziane, che abbiano figli in servizio alle armi o morti in servizio militare e quelli che abbiano non meno di quattro figli conviventi ed a carico.

#### Art. 2063. - Esenzioni o ritardi dal richiamo

1. Il Ministro della difesa ha facolta' di concedere esenzioni o ritardi in caso di richiamo per mobilitazione a coloro per i quali ricorrano presupposti che secondo il presente codice costituiscono titolo per dispense, ritardi, rinvii, o che si trovino in altre speciali condizioni fissate dal regolamento in occasione della guerra o di grave crisi internazionale.

#### Art. 2064. - Ritardi nella presentazione alle armi di militari imbarcati

1. I militari in congedo illimitato imbarcati su navi nazionali in navigazione all'estero o su navi spedite o partite per campagne di pesca periodica, in caso di richiamo in servizio, possono ritardare la presentazione alla competente autorita' fino al loro arrivo in porto o rada dello Stato.

#### Art. 2065. - Chiamata di controllo della forza in congedo

1. Il Ministro della difesa puo' ordinare, con manifesto o con precetto personale, speciali chiamate, normalmente in giorno festivo, dei militari di truppa in congedo illimitato per il controllo della forza in congedo.

2. I militari di cui al comma 1 sono obbligati a rispondere a tali chiamate, attenendosi alle modalita' indicate nel manifesto o nel precetto personale. Essi non hanno diritto ad alcun assegno o indennita', sono rilasciati in liberta' nello stesso giorno di presentazione e sono considerati, ad ogni altro effetto diverso dall'applicazione della legge penale militare, come militari in servizio.

3. Se la chiamata di cui al comma 1 comporta la presentazione in una localita' diversa da quella di residenza, il militare ha diritto al viaggio gratuito, su esibizione del precetto personale.

### SEZIONE II - ANTICIPAZIONE DEL CONGEDO ILLIMITATO E RIDUZIONI DEL SERVIZIO DI LEVA

#### Art. 2066. - Anticipazione del congedo illimitato d'ufficio

1. Il Ministro della difesa ha facolta' di anticipare l'invio in congedo illimitato, con provvedimento di carattere generale, dei militari alle armi quando, per diminuite esigenze, la forza alle armi risulti esuberante.

2. Il congedo anticipato puo' essere totale o parziale e, ove sia parziale, puo' essere disposto per contingenti o scaglioni di classe, oppure per Armi, Corpi, servizi, specialita', categorie e specializzazioni.

#### Art. 2067. - Anticipazione del congedo illimitato a domanda per la sussistenza di titoli di dispensa

1. Il Ministro della difesa ha facolta' di anticipare l'invio in congedo illimitato dei militari in servizio alle armi che, per sopravvenute modificazioni nelle situazioni di famiglia non determinate dalla volonta' degli interessati, vengano a trovarsi in una delle condizioni dell'articolo 1990, comma 1, lettere da

- a) a l).

2. L'ammissione all'eventuale congedo anticipato e' pronunciata dai Consigli di leva.

#### Art. 2068. - Riduzione di servizio agli ufficiali e agli aspiranti in servizio di leva

1. Il Ministro della difesa puo', in relazione alle esigenze di ciascuna Forza armata, concedere una riduzione del servizio alle armi agli ufficiali ed agli aspiranti del servizio permanente o di complemento, con obblighi di leva.

#### Art. 2069. - Riduzione di servizio ai militari gia' allievi delle accademie militari

1. E' in facolta' del Ministro per la difesa di accordare una riduzione del servizio alle armi ai militari con obblighi di leva gia' allievi delle Accademie militari.

### SEZIONE III - CONGEDO ASSOLUTO

#### Art. 2070. - Congedo assoluto

1. Il congedo assoluto spetta ai militari alle armi o in congedo illimitato che, per eta' o per inidoneita' fisica, sono prosciolti da ogni obbligo di servizio militare.

#### Art. 2071. - Sospensione dell'invio in congedo assoluto in caso di prolungamento della leva a seguito di dichiarazione dello stato di guerra

1. In caso di prolungamento della ferma di leva in tempo di guerra o di grave crisi internazionale ai sensi dell'articolo 2026, l'invio in congedo assoluto e' sospeso.

## CAPO VIII - SANZIONI

### SEZIONE I - DISPOSIZIONI COMUNI

#### Art. 2072. - Rinvio ad altre leggi penali

1. Per quanto non previsto nel presente capo, si applicano le disposizioni del codice penale, del codice penale militare di pace, del codice penale militare di guerra, e delle altre leggi penali.

#### Art. 2073. - Esclusione dal beneficio dell'eventuale ammissione a dispensa dal compiere la ferma di leva

1. Non possono essere ammessi all'eventuale dispensa dal compiere la ferma di leva, ne' rimanere in tale posizione:

- a) gli iscritti di leva ed i militari che siano incorsi nelle sanzioni penali previste dal presente capo, salvo quanto dispone l'articolo 2082 per i renitenti;
- b) gli iscritti di leva che scientemente abbiano prodotto documenti falsi o infedeli, senza pregiudizio delle pene stabilite dalla legge qualora siano incorsi nel reato di falsita';
- c) i militari che, ai sensi del codice penale militare, siano incorsi nel reato di diserzione o di allontanamento illecito o di mancanza alla chiamata;
- d) coloro che siano stati condannati per il delitto di sottrazione alla leva, a meno che il titolo non sia sorto dopo il loro arruolamento.

### SEZIONE II - REATI RELATIVI ALLA CHIAMATA ALLA LEVA

#### Art. 2074. - Sottrazione alla leva

1. Chiunque, essendo soggetto alla leva, ed essendo stato omesso nella formazione delle liste della sua classe, non si presenta spontaneamente per concorrere alla leva della classe stessa, rimanendo in tale posizione fino alla chiusura della leva medesima, e' punito con la reclusione fino a tre anni e con la multa fino a euro 124,00.

#### Art. 2075. - Omissione o indebita cancellazione dalle liste di leva

1. Chiunque omette o cancella indebitamente un giovane dalle liste di leva, e' punito con la reclusione fino a tre anni e con la multa fino a euro 124,00.

2. Le pene di cui al comma 1 si applicano al giovane della cui omissione o cancellazione si tratta, che commette, anche a titolo di concorso, il delitto di cui al comma 1.

#### Art. 2076. - Omissione, indebita cancellazione dalle note preparatorie per la formazione delle liste di leva di mare o indebita inclusione nelle stesse

1. Chiunque, con frode o con raggiri, omette o indebitamente cancella giovani soggetti alla leva di mare, dalle note preparatorie della medesima, oppure include indebitamente nelle note stesse di giovani senza i requisiti per appartenere alla leva di mare, e' punito con la reclusione fino a sei mesi e con la multa fino a euro 31,00.

2. Le pene di cui al comma 1 si applicano al giovane della cui omissione o cancellazione si tratta, che commette, anche a titolo di concorso, il delitto di cui al comma 1.

#### Art. 2077. - Fraudolenta sostituzione di persona

1. Il delitto di fraudolenta sostituzione di persona di cui all'articolo 494 del codice penale, se commesso al fine di sottrarre se' o altro soggetto alla chiamata alla leva, alla visita di leva, all'arruolamento, e' punito con la reclusione da tre a dieci anni.

#### Art. 2078. - Reati commessi dagli iscritti di leva non ancora arruolati per sottrarsi agli obblighi del servizio militare

1. Gli iscritti di leva non ancora arruolati che, al fine di sottrarsi permanentemente o temporaneamente all'obbligo del servizio militare o ad un particolare servizio di un corpo, di un'arma o di una specialita', o comunque di menomare la loro incondizionata idoneita' al servizio militare, commettono alcuno dei reati previsti negli articoli da 157 a 163 del codice penale militare di pace e dall'articolo 115 del codice penale militare di guerra, sono puniti secondo le disposizioni di detti articoli.

#### Art. 2079. - Renitenza alla leva

1. E' considerato renitente alla leva:

- a) l'iscritto che senza legittimo motivo, nel giorno prefisso, non si presenti all'esame personale ed arruolamento o alla nuova visita disposta ai fini di cui all'articolo 1939, comma 1, lettera a) e di cui all'articolo 1982, comma 2, o che trovandosi all'estero non regoli la sua posizione di leva nei termini all'uopo fissati;
- b) l'iscritto che, pur essendosi presentato al Consiglio di leva, non adempia all'obbligo di sottoporsi all'esame personale;
- c) l'iscritto che, trovandosi in navigazione o impegnato in campagne di pesca periodica, non regoli la sua posizione di leva nei termini fissati dall'articolo 2018, comma 4;
- d) il marinaio mercantile, non militare in congedo, che si sottragga all'arruolamento eccezionale previsto dall'articolo 2023.

2. La dichiarazione di renitenza e' pronunciata dal Consiglio di leva per tutti gli iscritti alla leva.

3. Per gli arruolati eccezionalmente nella Marina militare, di cui al comma 1, lettera d), la dichiarazione di renitenza e' pronunciata, all'estero, dalle autorita' diplomatiche o consolari o dai comandanti delle navi militari.

4. Il renitente alla leva e' punito con la reclusione da uno a quattro anni.

5. I limiti minimo e massimo di cui al comma 4 sono ridotti:

- a) a due mesi e a un anno per chi si presenta spontaneamente prima della scadenza di un anno dal giorno della dichiarazione di renitenza;
- b) a sei mesi e a due anni per chi si presenta spontaneamente dopo il suddetto limite di tempo;
- c) a un mese e a due anni per colui che, fermato e tradotto davanti al Consiglio di leva, sia stato giudicato inabile al servizio militare;
- d) a un mese e a sei mesi, ovvero a un mese e a un anno per colui che, presentatosi spontaneamente entro un anno dalla dichiarazione di renitenza, ovvero dopo trascorso l'anno dalla dichiarazione stessa, sia stato giudicato inabile al servizio militare.

6. La reclusione a cui e' condannato il renitente che non ha titolo all'eventuale dispensa o all'esenzione dalla prestazione del servizio viene scontata quando il renitente e' inviato in congedo illimitato. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2080. - Liste dei renitenti

1. Subito dopo la chiusura della sessione di leva, gli uffici di supporto dei Consigli di leva di terra e di mare compilano la lista dei renitenti.

2. Dieci giorni dopo la chiusura di detta sessione, i presidenti dei Consigli di leva provvedono perche' sia pubblicata la lista medesima nell'albo pretorio dei comuni interessati.

3. I renitenti possono essere fermati e tradotti innanzi ai Consigli di leva dagli agenti della forza pubblica non appena sia avvenuta tale pubblicazione, od anche prima, per ordine scritto del presidente del Consiglio di leva, quando si tratti di renitenti la cui residenza sia nota.

4. Dalla lista di cui al comma 1 vengono successivamente cancellati i deceduti e quelli che, dopo il fermo o la spontanea presentazione, siano stati arruolati od abbiano altrimenti definito la loro posizione.

#### Art. 2081. - Esame personale, eventuale denuncia, incorporazione dei renitenti

1. I renitenti che si presentano spontaneamente, o che vengono fermati e tradotti, sono esaminati dal Consiglio di leva nella seduta eventualmente in corso o in quella successiva alla loro presentazione o fermo per essere arruolati, se riconosciuti idonei al servizio militare.

2. Per i renitenti che, pur essendosi presentati, non adempiono all'obbligo di sottoporsi all'esame personale, il Consiglio di leva procede all'arruolamento senza visita.

3. Il Consiglio di leva puo' annullare ((, se ricorrono i presupposti per l'autotutela,)) la dichiarazione di renitenza.

4. Il renitente per il quale non sia intervenuto tale annullamento, e' denunciato, dal presidente del Consiglio di leva, all'autorita' giudiziaria penale ordinaria.

5. I renitenti che sono arruolati e appartengono a classe o contingente o scaglione gia' chiamato alle armi, sono incorporati con la chiamata eventualmente in corso o con quella successiva all'arruolamento, a meno che non hanno titolo all'ammissione all'eventuale dispensa o esenzione dal compiere la ferma di leva, o al ritardo od al rinvio.

6. Essi seguono le sorti della classe, contingente o scaglione con il quale sono stati incorporati.

7. Per i renitenti residenti all'estero, valgono le disposizioni di cui all'articolo 1984.

#### Art. 2082. - Ammissione del renitente all'eventuale dispensa o esenzione dal compiere la ferma di leva

1. Il renitente per il quale sia intervenuto l'annullamento della dichiarazione di renitenza ai sensi dell'articolo 2081, comma 3, o che sia stato assolto dall'autorita' giudiziaria, e' considerato, ai fini dell'ammissione all'eventuale dispensa o esenzione dal compiere la ferma di leva, alla stessa stregua degli iscritti regolarmente presentatisi.

2. Il comma 1 si applica anche al renitente denunciato fino a che non sia intervenuta sentenza di condanna. Ove intervenga la condanna, l'eventuale dispensa o esenzione dal compiere la ferma di leva e' revocata, a meno che il titolo esistente prima dell'arruolamento sussista anche dopo la condanna.

3. Il renitente condannato puo' utilmente invocare il beneficio dell'eventuale dispensa o esenzione dal compiere la ferma di leva, purche' il titolo sia sorto dopo l'arruolamento.

#### Art. 2083. - Pene per il favoreggiatore del renitente

1. Chiunque occulta o ammette al suo servizio un renitente e' punito con la reclusione fino a sei mesi.

2. Chiunque coopera alla fuga di un renitente, ovvero con artifici o raggiri impedisce o ritarda la presentazione alla visita di leva di un iscritto di leva, e' punito con la reclusione da un mese a un anno.

3. Se i delitti di cui ai commi 1 e 2 sono commessi da un pubblico ufficiale, un agente o impiegato dello Stato, o un ministro di culto, si applicano la reclusione fino a due anni e la multa fino a euro 124,00.

#### Art. 2084. - Corruzione commessa dal perito sanitario

1. Il medico - chirurgo chiamato ad assistere i Consigli di leva in qualita' di perito sanitario, ovvero incaricato di effettuare particolari perizie, il quale riceve doni o accetta promesse per usare favori ad alcuno negli esami a lui affidati, e' punito con la reclusione da due mesi a due anni.

2. La pena si applica sia se i doni o le promesse sono stati dall'agente accettati dopo essere stato convocato per assistere il Consiglio di leva o dopo aver ricevuto l'incarico della perizia, sia se l'accettazione ha avuto luogo solo in previsione di tale convocazione.

3. La pena si applica qualunque sia il contenuto del provvedimento del Consiglio di leva per la cui adozione e' stato chiesto il parere del perito sanitario.

#### Art. 2085. - Sanzioni penali a carico dei funzionari dello Stato per azioni contrastanti col presente titolo

1. Salvo che il fatto costituisca un piu' grave delitto, e' punito con le pene previste dall'articolo 323 del codice penale per il delitto di abuso d'ufficio il pubblico ufficiale, l'agente o l'impiegato dello Stato che sotto qualsiasi pretesto, in violazione del presente titolo, pone in essere una delle seguenti condotte:

- a) autorizza o consente il passaggio dalla leva di mare alla leva di terra;
- b) effettua trasferimenti di ruoli;
- c) deliberatamente omette di attuare i provvedimenti previsti dall'articolo 2021, comma 2, lettera a);
- d) autorizza o ammette all'eventuale esenzione dal compimento della ferma di leva;
- e) consente riforme;
- f) consente esclusioni dal servizio militare;
- g) autorizza o ammette alla dispensa;
- h) autorizza o ammette all'anticipazione del congedo illimitato;
- i) autorizza o ammette alle riduzioni di servizio di cui agli articoli 2068 e 2069;
- l) da' arbitraria estensione alla durata, alle regole e condizioni della chiamata alla leva e degli arruolamenti volontari. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2086. - Punibilita' dell'iscritto e del favoreggiatore colpevole di reati, ancorche' non si trovi nel territorio della Repubblica

1. L'iscritto che, per sottrarsi all'obbligo del servizio militare, commetta in territorio estero delitti previsti dal presente titolo o dal codice penale e' punito secondo la legge italiana, ancorche' non si trovi nel territorio della Repubblica.

2. Il cittadino o lo straniero che in territorio estero concorre in qualsiasi modo, nel delitto commesso dall'iscritto e' punito secondo la legge italiana, ancorche' non si trovi nel territorio della Repubblica.

3. Se e' stato giudicato all'estero per il medesimo fatto, e' giudicato nuovamente nella Repubblica, se il Ministro della giustizia ne fa richiesta.

#### Art. 2087. - Decorrenza della prescrizione per taluni delitti

1. Per i delitti di cui agli articoli 2074, 2075 e 2076, la prescrizione inizia a decorrere dalla data in cui il renitente sarebbe stato collocato in congedo assoluto per eta'. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2088. - Giurisdizione del giudice ordinario

1. I reati di cui alla presente sezione rientrano nella giurisdizione del giudice penale ordinario.

### SEZIONE III - REATI COMMESSI DA MILITARI DI LEVA O DA MILITARI IN CONGEDO

#### Art. 2089. - Reati commessi per sottrarsi agli obblighi del servizio militare

1. I militari di leva e i militari in congedo che, al fine di sottrarsi permanentemente o temporaneamente all'obbligo del servizio militare o ad un particolare servizio di un Corpo, di un'Arma o di una specialita', o comunque di menomare la loro incondizionata idoneita' al servizio militare, commettono alcuno dei reati previsti dagli articoli dal 157 al 163 del codice penale militare di pace e dall'articolo 115 del codice penale militare di guerra, sono puniti secondo le disposizioni di detti articoli.

#### Art. 2090. - Mancanza alla chiamata

1, L'arruolato o il militare in congedo che commette i delitti di mancanza alla chiamata previsti dal codice penale militare di pace o dal codice penale militare di guerra o da altre leggi penali militari e' punito con le pene ivi stabilite.

#### Art. 2091. - Militare in congedo che si sottrae all'arruolamento eccezionale

1. Il militare in congedo che si sottrae all'arruolamento eccezionale previsto dall'articolo 2023, e' punito con la reclusione militare non inferiore a due anni.

#### Art. 2092. - Militari mancanti alla chiamata in attesa di giudizio

1. Il militare in attesa di giudizio perche' imputato di mancanza alla chiamata alle armi della sua classe, contingente o scaglione, o perche' imputato di mancanza alla chiamata per istruzione, e' assegnato ed avviato ad un Corpo.

#### Art. 2093. - Giurisdizione del giudice militare

1. I reati di cui alla presente sezione rientrano nella giurisdizione dell'autorita' giudiziaria militare.

### SEZIONE IV - SANZIONI AMMINISTRATIVE

#### Art. 2094. - Inadempienze circa le dichiarazioni di residenza o le chiamate di controllo o imbarco non autorizzato su navi di bandiera estera

1. I militari in congedo illimitato provvisorio o in congedo illimitato che omettono di notificare il cambiamento della propria residenza e abitazione, oppure non si presentano, senza giustificato motivo, alle chiamate di controllo, sono puniti, a richiesta dell'autorita' militare, con la sanzione amministrativa pecuniaria da euro 5,00 a euro 372,00.

2. Non si fa luogo alla richiesta, da parte dell'Autorita' militare, qualora il contravventore paghi, entro un mese dalla data di notificazione del processo verbale di accertamento della contravvenzione, una somma equivalente al quinto del massimo della sanzione.

3. La richiesta, in ogni caso, non puo' essere piu' proposta decorsi i tre mesi dal giorno in cui l'autorita' militare ha avuto notizia dell'omissione.

#### Art. 2095. - Sanzioni amministrative per chi ostacola o trae in inganno i Comandanti di porto e gli ufficiali designati alle operazioni di indagine e di controllo per l'inclusione nelle liste di leva di mare

1. I dirigenti di cantieri navali o di stabilimenti meccanici od industriali o di qualsiasi altro ente o societa' tenuti a segnalare i giovani soggetti alla leva di mare, che ostacolano o traggono in inganno i Comandanti di porto o gli ufficiali appositamente designati negli accertamenti di cui all'articolo 1951, comma 2, sono puniti con la sanzione amministrativa pecuniaria da euro 124,00 a euro 620,00.

#### Art. 2096. - Norme applicabili

1. Per quanto non disposto nella presente sezione, agli illeciti amministrativi ivi contemplati si applica la legge 24 novembre 1981, n. 689.

## TITOLO III SERVIZIO DEGLI OBIETTORI DI COSCIENZA E DEGLI AMMESSI A PROGRAMMA DI RECUPERO PER TOSSICODIPENDENTI IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE CAPO I SERVIZIO DEGLI OBIETTORI DI COSCIENZA

### Art. 2097. - Ambito e disciplina applicabile

1. Coloro che, per obbedienza alla coscienza, nell'esercizio del diritto alle liberta' di pensiero, coscienza e religione riconosciute dalla Dichiarazione universale dei diritti dell'uomo e dalla Convenzione internazionale sui diritti civili e politici, opponendosi all'uso delle armi, non accettano l'arruolamento nelle Forze armate e nelle Forze di polizia dello Stato, possono adempiere gli obblighi di leva, in tempo di guerra o di grave crisi internazionale, prestando, in sostituzione del servizio militare, un servizio civile, diverso per natura e autonomo dal servizio militare, ma come questo rispondente al dovere costituzionale di difesa della Patria e ordinato ai fini enunciati dai principi fondamentali della Costituzione.

2. Per quanto non disposto dal presente titolo, in ordine ai requisiti per la chiamata alla leva e alle armi, al procedimento di chiamata e arruolamento e ai titoli di dispensa, ritardo, rinvio, si applica quanto previsto dai titoli I e II.

3. Il servizio civile sostitutivo si svolge secondo le modalita' e le norme stabilite nel presente titolo. Per quanto non disposto nel presente titolo, in ordine agli enti presso cui prestare servizio civile e alle modalita' di convenzionamento ed espletamento del servizio civile, si applicano gli articoli 8 e 10 della legge 1998, n. 230, la legge 6 marzo 2001, n. 64 e il decreto legislativo 5 aprile 2002, n. 77 e successive modificazioni e integrazioni. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2098. - Preclusioni all'esercizio dell'obiezione di coscienza

1. Il diritto di obiezione di coscienza al servizio militare non e' esercitabile da parte di coloro che:

- a) risultino titolari di licenze o autorizzazioni relative alle armi indicate negli articoli 28 e 30 del testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, e successive modifiche ed integrazioni, ad eccezione delle armi e dei materiali esplodenti privi di attitudine a recare offesa alle persone ovvero non dotati di significativa capacita' offensiva, individuati con decreto del Ministro dell'interno, sentita la commissione consultiva centrale per il controllo delle armi di cui all'articolo 6 della legge 18 aprile 1975, n. 110. A coloro che sono soggetti agli obblighi di leva che facciano richiesta di rilascio del porto d'armi per fucile da caccia, il questore, prima di concederlo, fa presente che il conseguimento del rilascio comporta rinunzia ad esercitare il diritto di obiezione di coscienza;
- b) abbiano presentato domanda da meno di due anni per la prestazione del servizio militare nelle Forze armate, nel Corpo della Guardia di finanza, nella Polizia di Stato, nel Corpo di Polizia penitenziaria e nel Corpo forestale dello Stato, o per qualunque altro impiego che comporti l'uso delle armi;
- c) siano stati condannati con sentenza di primo grado per detenzione, uso, porto, trasporto, importazione o esportazione abusivi di armi e materiali esplodenti;
- d) siano stati condannati con sentenza di primo grado per delitti non colposi commessi mediante violenza contro persone o per delitti riguardanti l'appartenenza a gruppi eversivi o di criminalita' organizzata. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2099. - Pubblicita'

1. Nel manifesto di chiamata alla leva di cui all'articolo 1966 e' fatta esplicita menzione dei diritti e dei doveri concernenti l'esercizio dell'obiezione di coscienza.

### Art. 2100. - Istanza

1. Gli obiettori di coscienza presentano domanda per la prestazione del servizio civile al competente organo di leva entro quindici giorni dalla data di arruolamento. La domanda non puo' essere sottoposta a condizioni e contiene espressa menzione dei motivi di cui all'articolo 2097 nonche' l'attestazione, sotto la propria personale responsabilita', con le forme della dichiarazione sostitutiva di atto notorio, circa l'insussistenza delle cause ostative di cui all'articolo 2098.

2. Con la domanda, l'obiettore puo' indicare le proprie scelte in ordine all'area vocazionale e al settore d'impiego, ivi compresa l'eventuale preferenza per il servizio gestito da enti del settore pubblico o del settore privato, designando fino a dieci enti nell'ambito di una regione prescelta. A tal fine la dichiarazione puo' essere corredata da qualsiasi documento attestante eventuali esperienze o titoli di studio o professionali utili.

3. Gli abili ed arruolati ammessi al ritardo ed al rinvio del servizio militare, nel caso che non abbiano presentato la domanda nei termini stabiliti al comma 1, possono produrla al predetto organo di leva entro il 31 dicembre dell'anno precedente la chiamata alle armi. La presentazione della domanda di ammissione al servizio civile non pregiudica l'ammissione al ritardo o al rinvio del servizio militare.

### Art. 2101. - Liste degli obiettori di coscienza e liste di leva

1. Il Ministro della difesa trasmette tempestivamente all'Ufficio nazionale per il servizio civile l'elenco di tutti gli obiettori. Ove, occorra, le modalita' di redazione e trasmissione dell'elenco sono specificate con il regolamento.

2. I nominativi degli obiettori vengono inseriti nella lista del servizio civile nazionale; tale inserimento viene contestualmente annotato nelle liste originarie per l'arruolamento di terra o di mare.

3. La lista degli obiettori di coscienza puo' prevedere piu' contingenti annui per la chiamata al servizio.

### Art. 2102. - Dispense e invii in missioni umanitarie

1. Ferme restando le cause di dispensa dal servizio militare indicate nel titolo II del presente libro, qualora ricorrano eccedenze di obiettori da avviare al servizio rispetto alle disponibilita' finanziarie del Fondo nazionale per il servizio civile e fino alla eliminazione di tali eccedenze, possono essere dispensati o collocati in licenza illimitata senza assegni, in attesa di congedo, gli obiettori che si trovino, in ordine di importanza decrescente, in almeno una delle seguenti condizioni:

- a) difficolta' economiche o familiari ovvero responsabilita' lavorative o di conduzione d'impresa o assistenziali;
- b) svolgimento di attivita' scientifica, artistica, culturale, con acquisizione di particolari meriti in campo nazionale o internazionale;
- c) minore indice di idoneita' somatico - funzionale o psico - attitudinale attribuito in sede di visita di leva, anche tenuto conto dell'area vocazionale e del settore di impiego, qualora costituisca impedimento all'espletamento del servizio o ne pregiudichi la funzionalita';
- d) indisponibilita' all'impiego degli obiettori di coscienza da parte degli enti convenzionati nell'ambito della regione di residenza o in quella indicata nella domanda, entro il termine di chiamata alle armi.

2. In ogni caso, e' fatto obbligo all'Ufficio nazionale per il servizio civile di ridurre le eccedenze di cui al comma 1 anche qualora nessun obiettore versi in alcuna delle condizioni indicate, fino a concorrenza delle risorse disponibili. Relativamente alle condizioni previste dalle lettere c) e d) del comma 1, lo stesso Ufficio puo' adottare i provvedimenti di competenza anche d'ufficio.

3. Con decreto del Presidente del Consiglio dei Ministri sono determinati l'entita' della consistenza massima degli obiettori in servizio, nei limiti delle disponibilita' finanziarie del Fondo nazionale per il servizio civile, gli aspetti applicativi delle condizioni di cui al comma 1, nonche' le forme di collocamento in licenza illimitata senza assegni in attesa di congedo.

4. Gli obiettori di coscienza in servizio o in attesa di chiamata possono essere collocati, a domanda ovvero d'ufficio, in licenza illimitata senza assegni in attesa di congedo o dispensati dal servizio, secondo quanto previsto dai commi 1, 2 e 3. Le domande di dispensa e di invio in licenza illimitata senza assegni in attesa di congedo possono essere presentate rispettivamente entro e non oltre il giorno che precede l'assunzione del servizio e nel corso dell'espletamento del servizio medesimo.

5. L'assegnazione dell'obiettore al servizio civile avviene, fatte salve le esigenze del servizio e compatibilmente con le possibilita' di impiego, entro l'area vocazionale ed il settore di impiego da lui indicati, nell'ambito della regione di residenza o di quella indicata nella domanda e tenendo conto delle richieste degli enti e delle organizzazioni presso cui il servizio civile va prestato.

6. Il servizio civile ha una durata pari a quella del servizio militare di leva e comprende un periodo di formazione e un periodo di attivita' operativa. Il periodo di formazione dovra' prevedere un periodo di formazione civica e di addestramento generale al servizio civile differenziato secondo il tipo d'impiego, destinato a tutti gli obiettori ammessi a quel servizio. Per l'espletamento del servizio in determinati settori ove si ravvisino specifiche esigenze di formazione, le convenzioni disciplinano i casi nei quali puo' essere previsto un periodo di addestramento aggiuntivo presso l'ente o l'organizzazione in cui verra' prestata l'attivita' operativa.

7. L'obiettore puo' essere destinato al servizio civile in un altro Paese, su sua domanda o, ove necessario, di ufficio, secondo le norme ivi vigenti, salvo che per la durata, sulla base di apposite intese bilaterali. L'Ufficio nazionale per il servizio civile determina annualmente il contingente di servizio civile da svolgere all'estero.

8. Il servizio civile puo' essere svolto anche secondo le modalita' previste, per i volontari in servizio civile, dagli articoli da 31 a 35 della legge 26 febbraio 1987, n. 49, per la cooperazione allo sviluppo.

9. L'obiettore che ne faccia richiesta puo' essere inviato fuori dal territorio nazionale dall'ente presso cui presta servizio, per un periodo concordato con l'ente stesso, per partecipare a missioni umanitarie direttamente gestite dall'ente medesimo.

10. E' facolta' dell'Ufficio nazionale per il servizio civile disporre l'impiego di obiettori di coscienza in missioni umanitarie nelle quali sia impegnato personale italiano, d'ufficio o su domanda dell'obiettore. A tale fine gli obiettori di coscienza, selezionati in base alle loro attitudini vocazionali, vengono trasferiti alle dipendenze dell'ente o organizzazione che gestisce la missione.

11. Nel presentare domanda per partecipare alle missioni umanitarie fuori dal territorio nazionale di cui ai commi 9 e 10, l'obiettore indica la specifica missione umanitaria richiesta, nonche' l'ente, ovvero la organizzazione non governativa, ovvero l'Agenzia delle Nazioni Unite che ne sono responsabili. L'accoglimento ovvero la reiezione della domanda sono comunicati all'obiettore, con relativa motivazione, entro un mese. La mancata risposta entro tale termine comporta accoglimento della domanda.

12. Nei casi di cui ai commi 9 e 10, gli obiettori di coscienza devono comunque essere utilizzati per servizi non armati, non di supporto a missioni militari, e posti sotto il comando di autorita' civili.

13. L'obiettore che presta servizio civile all'estero per partecipare alle missioni umanitarie di cui ai commi 8, 9 e 10 puo' chiedere il prolungamento del servizio civile per un periodo massimo di un anno.

### Art. 2103. - Assistenza sanitaria, tutela previdenziale e del lavoro

1. Coloro che prestano servizio civile godono degli stessi diritti, anche ai fini previdenziali e amministrativi, di coloro che prestano il servizio militare di leva in tempo di guerra o grave crisi internazionale. Essi hanno diritto al medesimo trattamento economico dei militari di leva con esclusione dei benefici volti a compensare la condizione militare.

2. Il periodo di servizio civile e' riconosciuto valido, a tutti gli effetti, per l'inquadramento economico e per la determinazione dell'anzianita' lavorativa ai fini del trattamento previdenziale del settore pubblico e privato, nei limiti e con le modalita' con le quali la legislazione vigente riconosce il servizio di leva.

3. Il periodo di servizio civile effettivamente prestato e' valutato nei pubblici concorsi con lo stesso punteggio che le commissioni esaminatrici attribuiscono per i servizi prestati negli impieghi civili presso enti pubblici. Ai fini dell'ammissibilita' e della valutazione dei titoli nei concorsi banditi dalle pubbliche amministrazioni e' da considerarsi a tutti gli effetti il periodo di tempo trascorso nel servizio civile in pendenza di rapporto di lavoro.

4. L'assistenza sanitaria e' assicurata dal Servizio sanitario nazionale. In caso di servizio civile nell'ambito di missioni umanitarie all'estero, qualora la missione preveda l'impiego di reparti delle Forze armate, l'assistenza sanitaria e' assicurata dal Servizio di sanita' militare. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2104. - Congedo illimitato

1. L'Ufficio nazionale per il servizio civile comunica immediatamente al Ministero della difesa l'avvenuto espletamento del servizio da parte dell'obiettore di coscienza.

2. I competenti organi di leva provvedono a porre l'interessato in congedo illimitato, dandogliene tempestivamente comunicazione.

### Art. 2105. - Richiamo

1. Gli obiettori che abbiano prestato servizio civile ai sensi del presente titolo, sono soggetti, sino all'eta' prevista per i cittadini che hanno prestato servizio militare, al richiamo in caso di pubblica calamita'.

2. L'Ufficio nazionale per il servizio civile tiene apposito elenco di coloro soggetti a richiamo ai sensi del comma 1.

3. Nel periodo di richiamo si applicano integralmente le norme penali e disciplinari previste per gli ammessi al servizio civile.

4. In caso di guerra o di mobilitazione generale, gli obiettori di coscienza che prestano il servizio civile o che, avendolo svolto, siano richiamati in servizio, e per i quali non siano sopravvenute le condizioni ostative di cui all'articolo 2098, sono assegnati alla Protezione civile o alla Croce rossa. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2106. - Incompatibilita'

1. L'obiettore che presta servizio civile non puo' assumere impieghi pubblici e privati, iniziare attivita' professionali, ne' iscriversi a corsi o a tirocini propedeutici ad attivita' professionali che impediscano il normale espletamento del servizio.

2. Colui che viola il divieto di cui al comma 1 e' trasferito in altra sede presso altra regione geograficamente non contigua, anche nell'espletamento di altri compiti. In caso di recidiva, si applicano le sanzioni di cui all'articolo 2110, comma 1.

3. A colui che si trova gia' nell'esercizio delle attivita' e delle funzioni di cui al comma 1, si applicano le disposizioni valevoli per coloro che sono chiamati al servizio militare. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2107. - Sanzioni disciplinari

1. All'obiettore che si renda responsabile di comportamenti reprensibili o incompatibili con la natura e la funzionalita' del servizio possono essere comminate le seguenti sanzioni:

- a) la diffida per iscritto;
- b) la multa in detrazione della paga;
- c) la sospensione di permessi e licenze;
- d) il trasferimento ad incarico affine, anche presso altro ente, in altra regione, oppure a diverso incarico nell'ambito della stessa o di altra regione;
- e) la sospensione dal servizio fino ad un massimo di tre mesi, senza paga e con conseguente recupero dei periodi di servizio non prestato.

2. Il regolamento generale di disciplina previsto dall'articolo 8, comma 2, lettera i), della legge 8 luglio 1998, n. 230, stabilisce i criteri di applicazione delle sanzioni in relazione alle infrazioni commesse.

3. Le sanzioni di cui al comma 1, lettere a), b) e c), sono irrogate dal legale rappresentante dell'ente o dell'organizzazione interessati e vengono comunicate all'Ufficio nazionale per il servizio civile.

4. L'Ufficio nazionale per il servizio civile adotta le altre sanzioni e, sulla base dei provvedimenti notificatigli dagli enti o dalle organizzazioni, puo' decidere l'irrogazione di sanzioni piu' gravi in luogo di quelle gia' adottate.

5. Quando il comportamento dell'obiettore sia tale da equivalere ad un vero e proprio rifiuto di prestare il servizio, si applicano le norme di cui all'articolo 2110.

### Art. 2108. - Requisiti degli enti e organizzazioni che concorrono al servizio civile

1. Gli enti e le organizzazioni pubblici e privati che intendano concorrere all'attuazione del servizio civile mediante l'attivita' degli obiettori di coscienza, per essere ammessi alla convenzione con l'Ufficio nazionale per il servizio civile, devono possedere i seguenti requisiti:

- a) assenza di scopo di lucro; >b) corrispondenza tra le proprie finalita' istituzionali e quelle di cui all'articolo 8, comma 2, lettera b), della legge 8 luglio 1998, n.230; c) capacita' organizzativa e possibilita' di impiego in rapporto al servizio civile; d) aver svolto attivita' continuativa da non meno di tre anni.

2. Gli enti e le organizzazioni di cui al comma 1 inoltrano domanda di ammissione alla convenzione all'Ufficio nazionale per il servizio civile. Nella domanda di ammissione alla convenzione essi devono indicare i settori di intervento di propria competenza, le sedi e i centri operativi per l'impiego degli obiettori, il numero totale dei medesimi che puo' essere impiegato e la loro distribuzione nei vari luoghi di servizio.

3. Gli enti e le organizzazioni di cui al comma 1 debbono inoltre indicare la loro disponibilita' a fornire agli obiettori in servizio civile vitto e alloggio nei casi in cui cio' sia dagli stessi enti ed organizzazioni ritenuto necessario per la qualita' del servizio civile o qualora i medesimi enti e organizzazioni intendano utilizzare obiettori non residenti nel comune della sede di servizio. All'ente o all'organizzazione tenuti a fornire vitto e alloggio agli obiettori sono rimborsate le spese sostenute, con le modalita' previste dall'Ufficio nazionale per il servizio civile, sentita la Consulta nazionale per il servizio civile di cui all'articolo 10 della legge 8 luglio 1998, n. 230.

4. In nessun caso l'obiettore puo' essere utilizzato in sostituzione di personale assunto o da assumere per obblighi di legge o per norme statutarie organiche dell'organismo presso cui presta servizio civile.

5. Ogni convenzione viene stipulata sulla base della presentazione di un preciso progetto di impiego in rapporto alle finalita' dell'ente e nel rispetto delle norme che tutelano l'integrita' fisica e morale dell'obiettore.

6. E' condizione per la stipulazione della convenzione la dimostrazione, da parte dell'ente, della idoneita' organizzativa a provvedere all'addestramento al servizio civile.

7. L'Ufficio nazionale per il servizio civile accerta la sussistenza dei requisiti dichiarati dagli enti e dalle organizzazioni che hanno inoltrato la domanda di ammissione alla convenzione.

8. Sulle controversie aventi per oggetto le convenzioni previste dal presente articolo, decide il tribunale amministrativo regionale territorialmente competente con riferimento alla sede dell'ente o dell'organizzazione, quale indicata nella convenzione.

9. All'atto della stipula della convenzione gli enti si impegnano a non corrispondere agli obiettori alcuna somma a titolo di controvalore e simili, pena la risoluzione automatica della convenzione.

10. Insorto lo stato di guerra o di grave crisi internazionale, il Presidente del Consiglio dei Ministri emana le norme di attuazione e predispone il testo delle convenzioni tipo, dopo aver acquisito i pareri delle competenti Commissioni del Senato della Repubblica e della Camera dei deputati. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2109. - Sanzioni a carico degli enti o organizzazioni convenzionati

1. Gli enti e le organizzazioni convenzionati che contravvengono a norme di legge o alle disposizioni della convenzione, ferme restando le eventuali responsabilita' penali individuali, sono soggetti a risoluzione della convenzione o a sospensione dell'assegnazione degli obiettori con provvedimento motivato dell'Ufficio nazionale per il servizio civile.

2. In caso di risoluzione della convenzione con un ente o con una organizzazione, l'Ufficio nazionale per il servizio civile provvede alla riassegnazione degli obiettori che prestavano servizio presso lo stesso ente o la stessa organizzazione, sino al completamento del periodo prescritto, tenendo conto delle indicazioni espresse nella domanda.

3. Contro la risoluzione della convenzione, l'ente o l'organizzazione possono proporre ricorso al tribunale amministrativo regionale territorialmente competente con riferimento alla sede dell'ente o dell'organizzazione, quale indicata nella convenzione.

### Art. 2110. - Sanzioni penali

1. L'obiettore ammesso al servizio civile che rifiuta di prestarlo e' punito con la reclusione da sei mesi a due anni.

2. Alla pena di cui al comma 1 soggiace chi, non avendo chiesto o non avendo ottenuto l'ammissione al servizio civile, rifiuta di prestare il servizio militare, prima o dopo averlo assunto, adducendo motivi di coscienza che ostano alla prestazione del servizio militare.

3. Competente a giudicare per i reati di cui ai commi 1 e 2 e' il giudice ordinario del luogo nel quale deve essere svolto il servizio civile o il servizio militare.

4. La sentenza penale di condanna per uno dei reati di cui ai commi 1 e 2 esonera dagli obblighi di leva.

5. L'imputato o il condannato puo' fare domanda per essere nuovamente assegnato o ammesso al servizio civile nei casi previsti dai commi 1 e 2, tranne nel caso in cui tale domanda sia gia' stata presentata e respinta per i motivi di cui all'articolo 2098. Nei casi previsti dal comma 2, puo' essere fatta domanda di prestare servizio nelle Forze armate.

6. Per la decisione sulle domande di cui al comma 5, il termine e' di tre mesi.

7. L'accoglimento delle domande estingue il reato. Il tempo trascorso in stato di detenzione e' computato in diminuzione della durata prescritta per il servizio militare o per il servizio civile.

### Art. 2111. - Decadenza dal servizio civile e rinuncia allo status di obiettore di coscienza

1. L'obiettore ammesso al servizio civile decade dal diritto di prestarlo o di portarlo a compimento quando sopravvengano o siano accertate le condizioni ostative indicate all'articolo 2098.

2. Nelle ipotesi di cui al comma 1, l'obiettore e' tenuto a prestare servizio militare, per la durata prevista per quest'ultimo, se la decadenza interviene prima dell'inizio del servizio civile, e per un periodo corrispondente al servizio civile non prestato, in ogni caso non superiore alla durata della leva, se la decadenza interviene durante lo svolgimento di questo.

3. La decadenza e' disposta con decreto del Presidente del Consiglio dei Ministri su accertamento e richiesta dell'Ufficio nazionale per il servizio civile.

4. In caso di richiamo per mobilitazione di coloro che abbiano prestato il servizio militare di leva, a tale richiamo sono soggetti anche coloro che abbiano prestato servizio civile quando per essi siano sopravvenute le condizioni ostative previste dall'articolo 2098 ovvero quando essi abbiano rinunziato allo status di obiettore di coscienza ai sensi dell'articolo 636, comma 3.

5. Allo stesso richiamo sono soggetti coloro che, dopo aver prestato servizio civile, abbiano fabbricato in proprio o commerciato, anche a mezzo di rappresentante, le armi e le munizioni richiamate all'articolo 2098, comma 1, lettera a), e quelli che abbiano ricoperto incarichi direttivi presso enti o organizzazioni che siano direttamente finalizzati alla progettazione e alla costruzione di armi e sistemi di armi.

6. A coloro che sono stati ammessi a prestare servizio civile e' vietato detenere ed usare le armi di cui all'articolo 2098, comma 1, lettera a), nonche' assumere ruoli imprenditoriali o direttivi nella fabbricazione e commercializzazione, anche a mezzo di rappresentanti, delle predette armi, delle munizioni e dei materiali esplodenti. I trasgressori sono puniti, qualora il fatto non costituisca piu' grave reato, con le pene previste dal testo unico delle leggi di pubblica sicurezza, approvato con regio decreto 18 giugno 1931, n. 773, per detenzione abusiva di armi e munizioni e, inoltre, decadono dai benefici previsti dal presente titolo. E' fatto divieto alle autorita' di pubblica sicurezza di rilasciare o di rinnovare ai medesimi qualsiasi autorizzazione relativa all'esercizio delle attivita' di cui al presente comma.

7. Le disposizioni di cui al comma 6 non si applicano a coloro che abbiano rinunziato allo status di obiettore di coscienza ai sensi dell'articolo 636, comma 3.

8. A coloro che sono stati ammessi a prestare servizio civile, relativamente ai concorsi per l'arruolamento e alla rinuncia allo status di obiettori di coscienza, si applica l'articolo 636. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2112. - Relazione al Parlamento

1. Il Presidente del Consiglio dei Ministri presenta ogni anno al Parlamento, entro il 30 giugno, una relazione sull'organizzazione, sulla gestione e sullo svolgimento del servizio civile degli obiettori di coscienza in tempo di guerra o di grave crisi internazionale.

## CAPO II - SERVIZIO CIVILE PER TOSSICODIPENDENTI AMMESSI A PROGRAMMI DI RECUPERO E SERVIZIO CIVILE PRESSO ASSOCIAZIONI ED ENTI DI ASSISTENZA SOCIOSANITARIA

### Art. 2113. - Servizio civile per tossicodipendenti ammessi a programmi di recupero

1. Il dipendente da sostanze stupefacenti o psicotrope che, al termine del trattamento di recupero, e' nelle condizioni di essere chiamato al servizio militare di leva puo', su propria richiesta da presentare alla competente autorita' militare, e su parere conforme della direzione della comunita' terapeutica, continuare a prestare come servizio civile la sua attivita' volontaria per in periodo pari alla durata del servizio militare.

2. Il periodo di attivita' trascorso nella comunita' terapeutica o presso il centro di accoglienza e di orientamento dell'unita' sanitaria locale e' valido a tutti gli effetti come servizio militare.

3. In caso di assenza ingiustificata, la direzione della comunita' terapeutica o il responsabile del centro di accoglienza e di orientamento dell'unita' sanitaria locale devono dare comunicazione alle competenti autorita' militari territoriali che provvedono alla chiamata dell'interessato al servizio militare di leva.

4. Le autorita' militari competenti del territorio possono, in qualsiasi momento, accertare presso le comunita' terapeutiche o presso il centro di accoglienza e di orientamento dell'unita' sanitaria locale la presenza effettiva dell'interessato.

5. Al termine del periodo di attivita' nella comunita' terapeutica o presso il centro di accoglienza e di orientamento dell'unita' sanitaria locale, l'autorita' militare rilascia all'interessato il congedo militare illimitato.

### Art. 2114. - Servizio sostitutivo civile presso associazioni ed enti di assistenza socio-sanitaria

1. Gli obiettori di coscienza possono chiedere di prestare servizio sostitutivo civile presso centri civili autorizzati e convenzionati con l'Amministrazione della difesa che provvedono all'assistenza socio - sanitaria ed alla riabilitazione dei soggetti che fanno uso di sostanze stupefacenti o psicotrope. L'istanza e' accolta compatibilmente con le esigenze del contingente.

## LIBRO NONO DISPOSIZIONI DI COORDINAMENTO, TRANSITORIE E FINALI TITOLO I DISPOSIZIONI DI COORDINAMENTO CAPO I DISPOSIZIONI GENERALI

### Art. 2115. - Clausola di corrispondenza

1. I rinvii contenuti nelle fonti normative vigenti a disposizioni o istituti riprodotti nel presente codice e nel regolamento, si intendono effettuati alle corrispondenti disposizioni e istituti dei citati codice e regolamento.

### Art. 2116. - Clausola di salvaguardia in materia di competenze

1. Le disposizioni del presente codice e del regolamento non innovano le competenze, le funzioni e le attribuzioni dell'Amministrazione della difesa, delle Forze armate, delle Forze di polizia e delle altre Amministrazioni comunque interessate, previste dalla normativa vigente alla data della loro entrata in vigore.

## CAPO II - DISPOSIZIONI PARTICOLARI

### SEZIONE I - ORGANIZZAZIONE E FUNZIONI

#### Art. 2117. - Modifiche alla legge 29 ottobre 1997, n. 374

1. Alla legge 29 ottobre 1997, n. 374, sono apportate le seguenti modificazioni:

- a) il comma 1 dell'articolo 5 e' sostituito dal seguente: <<1. Le competenze del Ministero della difesa in materia di distruzione delle scorte sono disciplinate dal codice dell'ordinamento militare.>>;
- b) il comma 2 dell'articolo 5 e' abrogato;
- c) il comma 2 dell'articolo 9 e' sostituito dal seguente: <<2. I Ministri di cui al comma 1 presentano semestralmente alle competenti commissioni parlamentari una relazione sullo stato di attuazione della presente legge. Nell'ambito di tale relazione, il Ministro della difesa riferisce secondo quanto stabilito dall'articolo 12 del codice dell'ordinamento militare.>> --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2118. - Modifiche al decreto legislativo 30 luglio 1999, n. 300

1. Al decreto legislativo 30 luglio 1999, n. 300, sono apportate le seguenti modificazioni: a) l'articolo 21, comma 2, e' sostituito dal seguente: <<Art. 21 (Ordinamento) - 2. L'articolazione del Ministero e' definita dall'articolo 16 del codice dell'ordinamento militare.>>; b) l'articolo 22 e' sostituito dal seguente: <<Art. 22 (Agenzia industrie difesa) - 1. I compiti e le funzioni dell'Agenzia industrie difesa sono definiti dall'articolo 48 del codice dell'ordinamento militare.>>

#### Art. 2119. - Modifiche alla legge 23 maggio 1980, n. 242

1. L'articolo 5 della legge 23 maggio 1980, n. 242, e' sostituito dal seguente : <<Art .5 - 1. In relazione a urgenti necessita' per la difesa nazionale, il Servizio di assistenza al volo previsto dalla presente legge puo' essere assunto dal Ministero della difesa ai sensi dell'articolo 21 del codice dell'ordinamento militare.>>

#### Art. 2120. - Modifiche alla legge 9 luglio 1990, n. 185

1. Alla legge 9 luglio 1990, n. 185, sono apportate le seguenti modificazioni: a) l'articolo 3 e' sostituito dal seguente: << Art. 3 (Registro nazionale delle imprese) - 1. Il registro nazionale delle imprese e' disciplinato dal codice dell'ordinamento militare.>>; b) l'articolo 4 e' sostituito dal seguente: << Art. 4 (Iscrizione al registro nazionale delle imprese) - 1. Il Comitato per la tenuta del registro nazionale e' disciplinato dal codice dell'ordinamento militare.>>; c) l''articolo 17 e' sostituito dal seguente: <<Art. 17 (Contributo per l'iscrizione nel registro nazionale) - 1. Il contributo per l'iscrizione nel registro nazionale e' disciplinato dal codice dell'ordinamento militare.>>

#### Art. 2121. - Modifiche al regio decreto 20 febbraio 1941, n. 303 - codice penale militare di pace

1. Al codice penale militare di pace sono apportate le seguenti modifiche: a) l'articolo 273 e' sostituito dal seguente: <<Art. 273 (Reati commessi all'estero o in corso di navigazione) - Per i reati commessi all'estero e' competente il Tribunale militare di Roma. La cognizione dei reati commessi in corso di navigazione, su navi o aeromobili militari, e' di competenza del Tribunale militare del luogo di stanza dell'unita' militare alla quale appartiene l'imputato>>; b) l'articolo 409 e' sostituito dal seguente: <<Art. 409 (Tribunale e Ufficio militare di sorveglianza) - Per le funzioni e i provvedimenti del Tribunale militare di sorveglianza, del presidente e dell'Ufficio militare di sorveglianza, si applicano le disposizioni del presente codice e, in quanto compatibili, quelle dell'ordinamento penitenziario comune. La pena della reclusione militare e' espiata negli stabilimenti militari di pena, secondo le modalita' previste dal codice dell'ordinamento militare; il magistrato militare di sorveglianza esercita la vigilanza sull'osservanza delle relative norme e sull'esecuzione della pena militare detentiva>>; c) dopo l'articolo 261-bis sono inseriti i seguenti: <<Art. 261-ter (Ricorso per Cassazione) - Contro i provvedimenti dei giudici militari e' ammesso ricorso per Cassazione secondo le norme del codice di procedura penale>>; <<Art. 261-quater (Giudizio davanti alla Corte militare di Appello) Il giudizio d'appello, compreso quello sulla riabilitazione militare, e' regolato dalle norme del codice di procedura penale; sulla impugnazione dei provvedimenti del giudice per l'udienza preliminare decide la Corte militare di appello, in camera di consiglio>>.

#### Art. 2122. - Modifiche alla legge 31 dicembre 1982, n. 979

1. L'articolo 9 della legge 31 dicembre 1982, n. 979, e' sostituito dal seguente: <<Art. 9 - 1. Il servizio di vigilanza in mare di cui alla lettera c) dell'articolo 2, e' disciplinato dall'articolo 115 del codice dell'ordinamento militare.>>

#### Art. 2123. - Uso dello spazio aereo

1. Al decreto del Presidente della Repubblica 27 luglio 1981, n. 484, sono apportate le seguenti modificazioni: a) il titolo e' sostituito dal seguente: <<Uso dello spazio aereo civile, in attuazione della delega prevista dalla legge 23 maggio 1980, n. 242>>; b) l'articolo 1 e' sostituito dal seguente: <<Art. 1. Spazio aereo. 1. Lo spazio aereo sottoposto alla sovranita' nazionale, quello posto al di sopra delle acque internazionali sulla base di accordi regionali di navigazione aerea, nonche' le parti di spazio aereo extraterritoriale attribuite all'Italia in base agli accordi internazionali si suddivide, ai fini dei servizi di assistenza al volo in generale e di quelli del traffico aereo in particolare, in spazio aereo controllato secondo le definizioni dell'Organizzazione dell'aviazione civile internazionale ed in spazio aereo non controllato. In detti spazi i servizi di assistenza al volo sono assicurati dall'Ente nazionale di assistenza al volo e dall'Aeronautica militare secondo quanto dispone il capo VI del titolo III del libro I del testo unico delle disposizioni regolamentari in materia di ordinamento militare.>>; c) l'articolo 2 e' sostituito dal seguente: <<Art. 2. Traffico aereo civile. 1. Il traffico aereo civile e il traffico aereo di cui all'articolo 228 del testo unico disposizioni regolamentari in materia di ordinamento militare prendono il nome di traffico aereo generale. 2. In materia di accordi particolari, priorita' di traffico, permeabilita' degli spazi e organismi di coordinamento si applicano rispettivamente gli articoli 230, 231, 232 e 233 del testo unico disposizioni regolamentari in materia di ordinamento militare.>>; d) l'articolo 10 e' sostituito dal seguente: <<Art. 10. Comitato consultivo per l'utilizzazione dello spazio aereo. Per l'espletamento dei poteri di coordinamento attribuiti al presidente del Consiglio dei Ministri, di cui all'art. 3, lettera a), della legge 23 maggio 1980, n. 242, e' istituito, presso la Presidenza del Consiglio dei Ministri, il comitato consultivo per l'utilizzazione dello spazio aereo. Sono membri del comitato: a) il direttore generale dell'Ente nazionale di assistenza al volo; b) il direttore generale dell'Ente nazionale per l'aviazione civile; c) i membri militari di cui all'articolo 234 del testo unico disposizioni regolamentari in materia di ordinamento militare; d) un esperto nominato dal Presidente del Consiglio dei Ministri. La presidenza del comitato e' assunta, per la durata di un anno, alternativamente, da uno dei membri appartenenti al Ministero delle infrastrutture e dei trasporti ed al Ministero della difesa. La nomina del presidente e dei membri del comitato e' conferita con decreto del Presidente del Consiglio dei Ministri. I membri possono essere assistiti da propri esperti senza diritto di voto.>>. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 30/09/2010, n. 229 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

#### Art. 2124. - Sanzioni in materia di licenza comunitaria dei controllori del traffico aereo

1. Al decreto legislativo 30 maggio 2008, n. 118 sono apportate le seguenti modificazioni:

- a) il comma 8 dell'articolo 15 e' sostituito dal seguente: <<8. Le previsioni di cui al presente articolo non si applicano all'Aeronautica militare, quale fornitore di servizio di controllo del traffico aereo, ai sensi dell'articolo 21, comma 1 del codice dell'ordinamento militare, nonche' al personale militare, che sono soggetti alle norme proprie dell'ordinamento militare.>>.

#### Art. 2125. - Norma di salvaguardia in materia di compiti d'istituto dell'Arma dei carabinieri

1. L'articolo 16 del decreto legislativo 5 ottobre 2000, n. 297, e' sostituito dal seguente: <<Art. 16. Speciali compiti d'istituto. L'Arma dei carabinieri, oltre ai compiti individuati nell'articolo 3 e ai compiti stabiliti dal codice dell'ordinamento militare, assolve, nel rispetto delle dipendenze funzionali previste dalle relative discipline di settore, anche quelli connessi con: a) i servizi di ordine pubblico e soccorso in caso di pubbliche calamita'; b) la tutela dell'ambiente; c) la tutela del patrimonio culturale; d) la tutela del lavoro; e) l'osservanza delle norme comunitarie e alimentari, ai sensi del decreto legislativo 4 giugno 1997, n. 143, e relativo regolamento; f) la repressione del falso nummario; g) le esigenze del Ministero degli affari esteri; h) le esigenze della Banca d'Italia ai sensi dell'articolo 830 del codice dell'ordinamento militare ; i) la tutela della salute; l) l'espletamento e il coordinamento delle attivita' d'indagine specialistiche, tecniche o scientifiche.>>.

#### Art. 2126. - Modifiche al decreto legislativo 20 dicembre 2007, n. 261

1. L'articolo 3 del decreto legislativo 20 dicembre 2007, n. 261, e' sostituito dal seguente: <<Art. 3 (Applicazione) - 1. Il Ministero della salute, il Centro nazionale sangue, le regioni e le province autonome di Trento e di Bolzano, nell'ambito delle rispettive competenze, e il Ministero della difesa per il servizio trasfusionale di cui all'articolo 205 del codice dell'ordinamento militare, sono le autorita' responsabili del rispetto dei requisiti di cui al presente decreto.>>

#### Art. 2126-bis. - (( (Disposizioni di coordinamento con la legge 12 gennaio 1991, n. 13).))

((

1. Gli atti di nomina agli incarichi comunque denominati, di comandante territoriale, logistico, ovvero della formazione dell'Esercito italiano, della Marina e dell'Aeronautica militare, ove non altrimenti previsto dal codice, sono adottati nella forma del decreto del Ministro della difesa.

))

### SEZIONE II - BENI E AMMINISTRAZIONE

#### Art. 2127.

Modifiche ai decreti del Presidente della Repubblica 6 giugno 2001, nn. 379 e 380 e al decreto legislativo 1° agosto 2003, n. 259

1. All'articolo 5, comma 4, lettera b) del decreto del Presidente della Repubblica 6 giugno 2001, n. 380, e nell'articolo 5, comma 4, lettera b) del decreto del Presidente della Repubblica 6 giugno 2001, n. 379 le parole <<di cui all'articolo 16 della legge 24 dicembre 1976, n. 898>> sono sostituite dalle seguenti: <<di cui all'articolo 333 del codice dell'ordinamento militare>>.

2. All'articolo 86, comma 4 del decreto legislativo 1° agosto 2003, n. 259, le parole <<di cui alla legge 24 dicembre 1976, n. 898>> sono sostituite dalle seguenti: <<di cui al titolo VI, del libro II, del codice dell'ordinamento militare>>.

#### Art. 2128. - Modifica al decreto legislativo 30 aprile 1992, n. 285

1. Dopo il comma 10 dell'articolo 2 del decreto legislativo 30 aprile 1992, n. 285, e' aggiunto il seguente: <<10-bis. Resta ferma, per le strade e veicoli militari, la disciplina specificamente prevista dal codice dell'ordinamento militare>>.

#### Art. 2129. - Modifiche alla legge 18 aprile 1975, n. 110, e alla legge 23 dicembre 1994, n. 724

1. All'articolo 31, primo comma della legge 18 aprile 1975, n. 110, le parole <<Ferme restando le disposizioni di cui al decreto-legge 16 dicembre 1935, n. 2430, convertito nella legge 4 giugno 1936, n. 1143 sul Tiro a segno nazionale e successive modificazioni>>, sono sostituite dalle seguenti: <<Ferme restando le disposizioni sul Tiro a segno nazionale contenute nel codice dell'ordinamento militare e nel testo unico delle disposizioni regolamentari in materia di ordinamento militare>>.

2. L'articolo 43, comma 4, secondo periodo, della legge 23 dicembre 1994, n. 724, e' cosi' sostituito: <<Entro tre mesi dalla data di entrata in vigore della presente legge, il Ministro dell'economia e delle finanze, sentite le competenti commissioni parlamentari, emana, con proprio decreto, il regolamento di gestione e utilizzo del fondo casa, sentito il parere delle sezioni del Consiglio centrale di rappresentanza interessate>>.

#### Art. 2130. - Modifiche alla legge 23 dicembre 2009, n. 191

1. Nella legge 23 dicembre 2009, n. 191 sono apportate le seguenti modificazioni:

- a) l'articolo 2, comma 28, e' cosi' sostituito: <<28. Il Corpo della Guardia di finanza ha il diritto all'uso esclusivo delle proprie denominazioni, dei propri stemmi, degli emblemi e di ogni altro segno distintivo. Il Corpo della guardia di finanza, anche avvalendosi dell'apposito ente, puo' consentire l'uso anche temporaneo delle denominazioni, degli stemmi, degli emblemi e dei segni distintivi di cui al presente comma, in via convenzionale ai sensi dell'articolo 26 del codice dei contratti pubblici relativi a lavori, servizi e forniture, di cui al decreto legislativo 12 aprile 2006, n. 163, nel rispetto delle finalita' istituzionali e dell'immagine del Corpo della Guardia di finanza. Si applicano le disposizioni contenute negli articoli 124, 125 e 126 del codice della proprieta' industriale di cui al decreto legislativo 10 febbraio 2005, n. 30, e successive modificazioni.>>;
- b) nell'articolo 2, comma 195: b.1) le parole "comma 190" sono sostituite dalle parole: "comma 2 dell'articolo 314 del codice dell'ordinamento militare"; b.2) le parole "comma 189" sono sostituite dalle parole: "comma 1 dell'articolo 314 del codice dell'ordinamento militare";
- c) nell'articolo 2, comma 196, le parole "comma 190" sono sostituite dalle parole "comma 2 dell'articolo 314 del codice dell'ordinamento militare".

#### Art. 2131. - Norma di coordinamento in materia di energia

1. Nella rubrica dell'articolo 39 della legge 23 luglio 2009, n. 99, sono soppresse le parole <<militari e>>.

#### Art. 2132. - Cessioni di beni mobili a titolo gratuito nell'ambito delle missioni internazionali da parte del Corpo della Guardia di finanza

1. I mezzi e materiali, escluso il materiale d'armamento di cui alla legge 9 luglio 1990, n. 185, utilizzati a supporto dell'attivita' operativa del personale del Corpo della Guardia di finanza impiegato nelle missioni internazionali, per i quali non risulta conveniente il rimpatrio in relazione ai ((relativi costi)) o dismessi alla data di entrata in vigore dell'atto che autorizza la missione internazionale, su disposizione del Comando generale del medesimo Corpo possono essere ceduti, direttamente e a titolo gratuito nelle localita' in cui si trovano, alle Forze armate e alle Forze di polizia estere, ad autorita' locali, a organizzazioni internazionali ((anche)) non governative ovvero a organismi di volontariato e di protezione civile, prioritariamente italiani, ivi operanti. Con decreto del Ministro dell'economia e delle finanze si provvede a disciplinare le modalita' attuative.

#### Art. 2133. - Permute

1. Per il contenimento delle relative spese di potenziamento, ammodernamento, manutenzione e supporto per mezzi, materiali e strutture in dotazione, la facolta' di cui all'articolo 545, di stipulare, nei termini ivi contemplati, convenzioni e contratti aventi ad oggetto la permuta di materiali o prestazioni con soggetti pubblici e privati compete anche al Corpo della Guardia di finanza. ((A tale fine si applicano, in quanto compatibili, le disposizioni del regolamento, a norma del comma 2 dell'articolo 545.))

#### Art. 2134. - Tempestivita' dei pagamenti per forniture di materiali destinati al Corpo della Guardia di finanza

1. Al fine di garantire, attraverso la semplificazione dei correlati adempimenti amministrativi, la tempestivita' dei pagamenti per le forniture di materiali destinati al Corpo della guardia di finanza e relativi ad attivita' operative o addestrative svolte in territorio nazionale o all'estero, il Comando generale della guardia di finanza e' autorizzato a corrispondere pagamenti in conto nella misura massima del novanta per cento del valore delle forniture collaudate e accettate, per le quali il consegnatario abbia rilasciato apposita dichiarazione di ricevimento.

### SEZIONE III - ORDINAMENTO DEL PERSONALE

#### Art. 2135. - Clausola di salvaguardia in tema di adozione degli atti e dei provvedimenti relativi al personale del Corpo della Guardia di finanza

1. Per il Corpo della Guardia di finanza restano ferme le competenze del Comandante generale in materia di adozione degli atti e provvedimenti di gestione del personale, in applicazione del decreto legislativo 30 marzo 2001, n. 165.

#### Art. 2136. - Disposizioni applicabili al personale della Guardia di finanza

1. Si applicano al personale del Corpo della Guardia di finanza, in quanto compatibili, le seguenti disposizioni del libro IV del codice dell'ordinamento militare:

- a) il capo II del titolo IV , eccetto l'articolo 806;
- b) le ((sezioni III, III-bis e IV)) del capo I del titolo V e la sezione I del capo III del Titolo V, eccetto l'articolo 899;
- c) l'articolo 622;
- d) l'articolo 721;
- d-bis) l'articolo 794;
- d-ter) l'articolo 858;
- e) gli articoli 878 e 879;
- f) l'articolo 881;
- g) l'articolo 886;
- g-bis) LETTERA ABROGATA DAL D.LGS. 5 OTTOBRE 2018, N. 126;
- g-ter) LETTERA ABROGATA DAL D.LGS. 5 OTTOBRE 2018, N. 126;
- h) LETTERA ABROGATA DAL D.LGS. 5 OTTOBRE 2018, N. 126;
- i) LETTERA ABROGATA DAL D.LGS. 5 OTTOBRE 2018, N. 126;
- l) l'articolo 900;
- m) l'articolo 911 e 911-bis;
- m-bis) l'articolo 923;
- n) gli articoli 931 e 932;
- o) l'articolo 938, nonche' l'articolo 992, per la cui disposizione prevista al comma 1, il riferimento all'articolo 909, comma 4, e' da intendersi all'articolo 2145, comma 5;
- o-bis) gli articoli 946, 957 e 960;
- p) l'articolo 1008, per la cui disposizione prevista al comma 1, lettera b), il riferimento all'articolo 909, comma 4, e' da intendersi all'articolo 2145, comma 5;
- q) LETTERA ABROGATA DAL D.LGS. 29 MAGGIO 2017, N. 95;
- r) l'articolo 1091, nonche' l'articolo 1099, intendendo per numeri o contingenti massimi i volumi organici dei colonnelli previsti dal decreto legislativo 19 marzo 2001, n. 69;
- s) la sezione IV del capo III del titolo V;
- t) la sezione III del capo VII del titolo V;
- u) la sezione VIII del capo VII del titolo V;
- v) LETTERA SOPPRESSA DAL D.LGS. 26 APRILE 2016, N. 91;
- z) la sezione IV del capo IV del titolo VII;
- aa) l'articolo 1394;
- bb) la sezione I del capo XVI del titolo VII;
- cc) la sezione I del capo XVII del titolo VII;
- dd) il capo XVIII del titolo VII;
- ee) il titolo VIII;
- ee-bis) il titolo IX - capo III;
- ff) l'articolo 1493;
- ff-bis) l'articolo 1780.
- gg) LETTERA SOPPRESSA DAL D. LGS. 31 DICEMBRE 2012, N. 248.

2. Si applicano al Corpo della Guardia di finanza, in quanto compatibili, le seguenti ulteriori disposizioni del presente codice:

- a) l'articolo 192;
- b) l'articolo 558;
- c) l'articolo 2229, comma 6.

3. Per le disposizioni di cui ai commi 1 e 2, il riferimento al Ministro o al Ministero della difesa, ove previsto, e' da intendersi al Ministro, al Ministero dell'economia e delle finanze o al Comandante generale del Corpo della Guardia di finanza, ai sensi dell'articolo 2135.

#### Art. 2137. - Nomina all'impiego civile degli ispettori e sovrintendenti del Corpo della Guardia di finanza

1. L'ispettore o il sovrintendente del Corpo della Guardia di finanza che abbia compiuto dodici anni di effettivo servizio puo', entro un anno dal compimento del predetto periodo di servizio, fare domanda di impiego civile e, se riconosciuto idoneo e meritevole, acquista titolo a conseguirlo nel limite dei posti vacanti negli impieghi prescelti.

2. L'ordine di precedenza per la nomina all'impiego civile e' determinato dalla data di presentazione delle domande.

3. L'ispettore o il sovrintendente che sia cessato dal servizio permanente a domanda o d'autorita' non puo' fare domanda di impiego civile.

4. Perde titolo a conseguire l'impiego civile l'ispettore o il sovrintendente che abbia acquisito diritto a pensione vitalizia per anzianita' di servizio, che sia cessato dal servizio per una delle cause indicate al comma 3 o comunque da piu' di cinque anni o che sia incorso nella perdita del grado.

5. Gli impieghi civili che il personale del Corpo della Guardia di finanza puo' conseguire sono stabiliti dal Ministero dell'economia e delle finanze.

6. Con determinazione del Comandante generale del Corpo della Guardia di finanza sono individuati gli organi competenti ad accertare l'idoneita' e la meritevolezza dell'ispettore o del sovrintendente a conseguire l'impiego civile.

7. La nomina all'impiego civile costituisce causa di cessazione dal servizio.

#### Art. 2138. - Documentazione caratteristica per il personale della Guardia di finanza

1. Le disposizioni del Capo III, del Titolo VI, del Libro IV del presente codice si applicano al personale del Corpo della Guardia di finanza.

2. Per il personale del Corpo della Guardia di finanza i documenti caratteristici sono costituiti dalla scheda valutativa, dallo specchio valutativo, dal rapporto informativo e dal foglio di comunicazione.

3. Il modello dei documenti caratteristici, gli elementi in base ai quali compilarli, i periodi di tempo e gli altri casi in cui vanno compilati, le autorita' competenti alla compilazione e alla revisione degli stessi nonche' quant'altro occorra per la esecuzione del presente articolo, sono stabiliti in un apposito ((decreto del Ministro dell'economia e delle finanze per il Corpo della Guardia di finanza)).

#### Art. 2139. - Reclutamento volontario femminile nel Corpo della Guardia di finanza

1. Il reclutamento del personale militare femminile nel Corpo della Guardia di finanza e' effettuato su base volontaria secondo le disposizioni vigenti per il personale maschile, salvo quanto previsto per l'accertamento dell'idoneita' al servizio dalle norme contenute nel regolamento di cui al comma 3 e salve le aliquote d'ingresso eventualmente previste, in via eccezionale, con il decreto adottato ai sensi del comma 2.

((

1-bis. Le aspiranti agli arruolamenti nel Corpo della guardia di finanza che si trovano in stato di gravidanza e non possono essere sottoposte nell'ambito del concorso per il quale hanno presentato istanza di partecipazione agli accertamenti per l'idoneita' al servizio ai sensi del regolamento di cui al comma 3 e, se previste, alle prove di efficienza fisica ovvero di idoneita' al servizio nelle specializzazioni del Corpo, sono ammesse, d'ufficio, anche in deroga, per una sola volta, ai limiti di eta', a svolgere i predetti accertamenti o prove nell'ambito del primo concorso utile successivo alla cessazione di tale stato di temporaneo impedimento. Il provvedimento di rinvio puo' essere revocato su istanza di parte quando tale stato di temporaneo impedimento cessa in data compatibile con i tempi necessari per la definizione della graduatoria. Fermo restando il numero delle assunzioni annualmente autorizzate, le candidate rinviate risultate idonee e nominate vincitrici nella graduatoria finale di merito del concorso per il quale hanno presentato istanza di partecipazione, sono avviate alla frequenza del primo corso di formazione utile in aggiunta ai vincitori del concorso cui sono state rinviate.

1-ter. Le vincitrici dei concorsi rinviate ai sensi del comma 1-bis sono immesse in servizio con la medesima anzianita' assoluta, ai soli fini giuridici, dei vincitori del concorso per il quale hanno presentato istanza di partecipazione. La relativa posizione di graduatoria nell'ambito del corso originario e' determinata sulla base del punto di classificazione finale riportato al termine del periodo di formazione, fatto salvo quanto previsto all'articolo 14-bis del decreto legislativo 12 maggio 1995, n. 199. Gli effetti economici della nomina sono riconosciuti, in ogni caso, con la stessa decorrenza prevista per i militari appartenenti al corso di formazione effettivamente frequentato.

1-quater. Le vincitrici dei concorsi per la nomina a ufficiale del ruolo tecnico-logistico-amministrativo, rinviate ai sensi del comma 1-bis, sono nominate con la medesima anzianita' assoluta, ai soli fini giuridici, dei vincitori del concorso per il quale hanno presentato istanza di partecipazione e iscritte in ruolo nell'ordine della graduatoria di merito del concorso originario. Gli effetti economici della nomina decorrono, in ogni caso, dalla data di effettivo incorporamento. Una volta ultimato il corso di formazione, sono iscritte in ruolo, previa rideterminazione dell'anzianita' relativa con riferimento al corso originario, sulla base del punto di classificazione finale riportato al termine dello stesso corso.

))

2. Ferme restando le consistenze organiche complessive, il Ministro dell'economia e delle finanze puo' prevedere limitazioni all'arruolamento del personale militare femminile soltanto in presenza di motivate esigenze connesse alla funzionalita' di specifici ruoli, categorie, specialita' e specializzazioni del Corpo, qualora in ragione della natura o delle condizioni per l'esercizio di specifiche attivita' il sesso rappresenti un requisito essenziale. Il relativo decreto e' adottato su proposta del Comandante generale del Corpo della Guardia di finanza, sentito il Ministro delle pari opportunita', il quale acquisisce il parere della Commissione per le pari opportunita' tra uomo e donna.

3. Il Ministro dell'economia e delle finanze adotta con decreto, ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, il regolamento recante norme per l'accertamento dell'idoneita' al servizio militare del personale del Corpo della Guardia di finanza, sentiti, per quanto concerne il personale femminile, il Ministro per le pari opportunita' e la Commissione per le pari opportunita' tra uomo e donna.

#### Art. 2140. - Ufficiali in ferma prefissata del Corpo della Guardia di finanza

1. Il Corpo della guardia di finanza puo' arruolare ufficiali in ferma prefissata con durata della ferma di due anni e sei mesi, incluso il periodo di formazione, da reclutare tra coloro che hanno superato con esito favorevole gli appositi corsi formativi. Ai corsi si accede tramite pubblico concorso al quale possono partecipare i cittadini italiani che:

- a) siano in possesso dei requisiti di cui alle lettere a), b), c), d), e), f), g) e g-bis) dell'articolo 5, comma 1, del decreto legislativo 19 marzo 2001, n. 69;
- b) non abbiano superato il 32° anno d'eta' alla data indicata nel bando di concorso;
- c) siano riconosciuti in possesso dell'idoneita' psico-fisica e attitudinale al servizio incondizionato quale ufficiale;
- d) non siano gia' in servizio quali ufficiali ausiliari in ferma prefissata ovvero si trovino nella posizione di congedo per aver completato la ferma quali ufficiali ausiliari in ferma prefissata.

2. Con decreto del Ministro dell'economia e delle finanze sono stabiliti:

- a) i titoli di studio richiesti per l'ammissione ai singoli corsi, ed eventualmente ulteriori requisiti, le tipologie e le modalita' dei concorsi e delle eventuali prove di esame, prevedendo anche la durata dei corsi; le modalita' per lo svolgimento dei rispettivi corsi di formazione e relativi programmi sono determinati dal Comando generale del Corpo della guardia di finanza;
- b) i requisiti psico-fisici e attitudinali richiesti ai fini dell'esercizio delle mansioni previste per gli ufficiali in ferma prefissata.

3. Gli allievi che superano gli esami di fine corso sono nominati tenenti del Corpo della guardia di finanza in ferma prefissata, ausiliari del ruolo tecnico-logistico-amministrativo.

4. Fermi restando gli ulteriori requisiti prescritti dalla normativa vigente, gli ufficiali in ferma prefissata che abbiano completato diciotto mesi di servizio nel Corpo della guardia di finanza possono partecipare, esclusivamente in relazione ai posti loro riservati ai sensi dell'articolo 2143-bis, al concorso per il reclutamento degli ufficiali di cui all'articolo 9 del decreto legislativo 19 marzo 2001, n. 69, sempreche' gli ufficiali interessati non abbiano superato il ((trentasettesimo)) anno di eta'. Il servizio prestato in qualita' di ufficiale in ferma prefissata costituisce titolo ai fini della formazione della graduatoria di merito.

5. Per quanto non espressamente previsto, si applicano al Corpo della guardia di finanza, in quanto compatibili, le norme sugli ufficiali in ferma prefissata contenute nel presente codice.

#### Art. 2141. - Perdita del grado per gli appartenenti al Corpo della Guardia di finanza

1. Per gli appartenenti ai ruoli del Corpo della Guardia di finanza, la perdita del grado, qualora non consegua all'iscrizione in altro ruolo, comporta l'iscrizione d'ufficio nel ruolo dei militari di truppa dell'Esercito italiano, senza alcun grado, ((ovvero, per il comparto aeronavale e il contingente di mare, nel ruolo dei militari di truppa della Marina militare, senza alcun grado.))

#### Art. 2142. - Transito nell'impiego civile per il personale delle Forze di polizia ad ordinamento militare

1. Il personale dell'Arma dei carabinieri e del Corpo della Guardia di finanza, nei casi di cui all'articolo 930, transita - rispettivamente - nelle qualifiche funzionali del personale civile del Ministero della difesa e del Ministero dell'economia e delle finanze, secondo modalita' e procedure analoghe a quelle previste dal decreto del Presidente della Repubblica 24 aprile 1982, n. 339, da definire con decreto dei Ministri interessati, emanato di concerto con i Ministri dell'economia e delle finanze e della pubblica amministrazione e l'innovazione ((nonche' secondo le ulteriori procedure di cui al predetto articolo 930. Al personale transitato si applica il regime pensionistico e previdenziale dell'amministrazione di destinazione.))

#### Art. 2143. - Ufficiali delle forze di completamento del Corpo della Guardia di finanza

((

1. In relazione alla necessita' di disporre di adeguate forze di completamento, con specifico riferimento alle esigenze correlate con le missioni internazionali ovvero con le attivita' addestrative, operative e logistiche sia sul territorio nazionale sia all'estero, gli ufficiali di complemento o in ferma prefissata, su proposta del Comando generale del Corpo della guardia di finanza e previo consenso degli interessati, possono essere richiamati in servizio con il grado e l'anzianita' posseduta ed ammessi ad una ferma non superiore ad un anno, rinnovabile a domanda dell'interessato per non piu' di una volta, al termine della quale sono collocati in congedo.

2. Fermi restando gli ulteriori requisiti prescritti dalla normativa vigente, gli ufficiali inferiori delle forze di completamento del Corpo della guardia di finanza possono partecipare, esclusivamente in relazione ai posti loro riservati ai sensi dell'articolo 2143-bis, comma 1, ai concorsi per il reclutamento degli ufficiali di cui all'articolo 9 del decreto legislativo 19 marzo 2001, n. 69, sempreche' gli ufficiali interessati non abbiano superato il trentaquattresimo anno di eta'. Al termine dei prescritti corsi formativi i predetti ufficiali sono iscritti in ruolo, con il grado rivestito, dopo l'ultimo dei pari grado in ruolo.

3. Con decreto del Ministro dell'economia e delle finanze sono definite in relazione alle specifiche esigenze del Corpo della guardia di finanza:

- a) le modalita' per l'individuazione delle ferme e della loro eventuale estensione nell'ambito del limite massimo di cui al comma 1;
- b) i requisiti fisici e attitudinali richiesti ai fini dell'esercizio delle mansioni previste per gli ufficiali chiamati o richiamati in servizio. L'ordinamento del Corpo della guardia di finanza individua gli eventuali specifici requisiti richiesti, anche relativamente alla rispettiva articolazione interna;
- c) le procedure da seguirsi, le modalita' per l'individuazione delle professionalita' e del grado conferibile ai sensi dell'articolo 674, gli eventuali ulteriori requisiti, secondo criteri analoghi a quelli individuati dal medesimo articolo 674.

4. Per quanto non espressamente previsto per il Corpo della guardia di finanza, si applicano al medesimo Corpo, in quanto compatibili, le norme sugli ufficiali delle forze di completamento contenute nel presente codice.

))

#### Art. 2143-bis.

1. Per gli ufficiali in ferma prefissata con almeno diciotto mesi di servizio, per gli ufficiali di complemento e per gli ufficiali delle forze di completamento che abbiano prestato servizio senza demerito nel Corpo della guardia di finanza sono previste riserve di posti fino all'80 per cento dei posti annualmente disponibili per l'accesso al ruolo tecnico-logistico-amministrativo del Corpo medesimo, di cui all'articolo 9 del decreto legislativo 19 marzo 2001, n. 69.

2. ((COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95)).

#### Art. 2144. - Cessazione dell'appartenenza al complemento per gli ufficiali del Corpo della Guardia di finanza

1. L'ufficiale del Corpo della Guardia di finanza cessa di appartenere alla categoria di complemento ed e' collocato nella riserva di complemento quando raggiunge i seguenti limiti di eta': ((sottotenenti e tenenti)): 45 anni; capitani: 48 anni; ufficiali superiori: 54 anni.

#### Art. 2145. - Norme di stato giuridico e avanzamento riguardanti gli ufficiali del Corpo della Guardia di finanza).

1. Ai fini del collocamento in aspettativa per riduzione quadri di cui all'articolo 30, comma 4, del decreto legislativo 19 marzo 2001, n. 69, si applica il seguente ordine:

- a) ufficiali in possesso di un'anzianita' contributiva pari o superiore a quaranta anni che ne fanno richiesta;
- b) ufficiali che si trovano a non piu' di cinque anni dai limiti d'eta' del grado rivestito che ne fanno richiesta;
- c) ufficiali promossi nella posizione di «a disposizione»;
- d) ufficiali in servizio permanente effettivo.

2. E' escluso dal provvedimento di collocamento in aspettativa l'ufficiale che ricopra la carica di Comandante generale nonche' il colonnello del ruolo del maestro direttore della banda musicale del Corpo della guardia di finanza di cui all'articolo 7 del decreto legislativo 27 febbraio 1991, n. 79.

3. Per gli ufficiali in servizio permanente effettivo, nei gradi in cui le promozioni a scelta al grado superiore non si effettuano tutti gli anni, l'articolo 30, comma 4, del decreto legislativo 19 marzo 2001, n. 69, si applica solo negli anni in cui si forma il quadro di avanzamento. Gli ufficiali che sono stati iscritti nel predetto quadro non sono computati negli organici del grado di appartenenza fino alla promozione.

4. Gli ufficiali collocati in aspettativa per riduzione di quadri ai sensi dell'articolo 30, comma 4, del decreto legislativo 19 marzo 2001, n. 69, secondo l'ordine stabilito dal comma 1 del presente articolo, permangono in tale posizione fino al raggiungimento del limite di eta' per essi stabilito dalle vigenti norme sullo stato giuridico.

5. Gli ufficiali ((...)) collocati in aspettativa per riduzione di quadri possono chiedere di cessare dal servizio permanente a domanda.

6. Il personale collocato in aspettativa per riduzione di quadri puo' chiedere il trasferimento anticipato dall'ultima sede di servizio al domicilio eletto. Il trasferimento e' ammesso una sola volta, indipendentemente dai richiami in servizio, e non puo' piu' essere richiesto all'atto del definitivo collocamento in congedo. Si applica l'articolo 23 della legge 18 dicembre 1973, n. 836, e il termine di cui al primo comma, secondo periodo, del medesimo articolo decorre dalla data del definitivo collocamento in congedo. Nessun beneficio e' riconosciuto al personale per il raggiungimento della sede di servizio a seguito di successivi richiami.

7. Gli ufficiali nella posizione di aspettativa per riduzione di quadri sono a disposizione del Governo per essere all'occorrenza impiegati per esigenze del Ministero dell'economia e delle finanze o di altri Ministeri. A essi si applicano le norme di cui agli articoli 993 e 995.

8. Fermo restando quanto previsto dal comma 7, il Comandante generale della Guardia di finanza, in relazione a motivate esigenze di servizio del medesimo Corpo, ha facolta' di richiamare, a domanda, gli ufficiali in servizio permanente collocati in aspettativa per riduzione di quadri ai sensi del presente articolo e dell'articolo 30 del decreto legislativo 19 marzo 2001, n. 69.

9. Agli ufficiali nella posizione di aspettativa per riduzione di quadri e a quelli richiamati ai sensi del comma 8 compete il trattamento economico di cui all'articolo 1821.

10. Il comma 8 non si applica nei confronti degli ufficiali che, all'atto del collocamento in aspettativa per riduzione di quadri, rivestono il grado apicale dei ruoli normali.

11. Gli ufficiali transitati nella posizione di aspettativa per riduzione di quadri direttamente dal servizio permanente effettivo, in caso di richiamo in servizio non sono piu' valutati per l'avanzamento. In ogni caso, agli ufficiali che cessano a qualsiasi titolo dalla posizione di aspettativa per riduzione di quadri competono i benefici di cui all'articolo 1076, comma 1, sempreche' risultino valutati e giudicati idonei.

#### Art. 2146. - Reclutamento, organici e avanzamento degli ispettori e dei sovrintendenti del Corpo della Guardia di finanza

1. Alla legge 10 maggio 1983, n. 212 sono apportate le seguenti modificazioni: a) il titolo e' sostituito dal seguente: <<Norme sul reclutamento, gli organici e l'avanzamento degli ispettori e dei sovrintendenti della Guardia di finanza>>; b) l'articolo 1 e' sostituito dal seguente: <<Art. 1 - 1. Ferme restando le consistenze massime degli organici degli ispettori e dei sovrintendenti del Corpo della Guardia di Finanza, con provvedimento del Comandante Generale, di concerto con il Ministero dell'economia e delle finanze, sono annualmente determinati i contingenti massimi di ciascun ruolo in relazione alle promozioni da conferire agli ispettori e ai sovrintendenti che nell'anno maturino le condizioni previste ai fini dell'avanzamento dal decreto legislativo 12 maggio 1995, n. 199, dall'articolo 1056, commi 2, 3 e 4 del codice dell'ordinamento militare e dalla presente legge. Del decreto emanato e' data comunicazione al Parlamento entro il 31 ottobre dell'anno precedente a quello per il quale sono determinati i contingenti massimi dei ruoli ispettori e sovrintendenti. 2. Gli ispettori e i sovrintendenti di cui al comma 1 continuano a essere iscritti nei rispettivi ruoli distinti per gradi.>>; c) l'articolo 23 e' sostituito dal seguente: <<Art. 23 - 1. Per gli ispettori e i sovrintendenti del Corpo della Guardia di finanza, il Comandante generale, in relazione alle esigenze di servizio del Corpo, ha facolta' di disporre di autorita' o a domanda cambi di categoria, di specializzazione, di specialita', ovvero la perdita delle specializzazioni o degli incarichi tecnici, prevedendo altresi' le necessarie riqualificazioni.>>; d) l'articolo 31 e' sostituito dal seguente: <<Art. 31 - 1. Per la valutazione ai fini dell'avanzamento ad anzianita' e a scelta e per la compilazione dei relativi quadri, e' istituita una commissione permanente presso il Comando generale del Corpo della Guardia di finanza. 2. Per la commissione di cui al comma 1 sono nominati membri supplenti.>>; e) l'articolo 32 e' sostituito dal seguente: <<Art. 32 - 1. Per il Corpo della Guardia di finanza, la commissione permanente di avanzamento e' costituita come segue: a) presidente: un ufficiale generale; b) membri ordinari: 3 ufficiali superiori, dei quali il piu' anziano assume il ruolo di vice presidente e il meno anziano quello di segretario; un maresciallo aiutante o un brigadiere capo ovvero un appuntato scelto, rispettivamente se trattasi di valutazione di personale del ruolo ispettori, sovrintendenti ovvero <<appuntati e finanzieri>>, che possa far parte della commissione almeno per l'intero anno solare a cui si riferiscono le valutazioni da effettuare>>; f) l'articolo 33 e' sostituito dal seguente: <<Art. 33 - 1. La commissione esprime i giudizi di avanzamento sulla base degli elementi risultanti dalla documentazione personale di ciascun ispettore o sovrintendente. 2. La commissione ha facolta' d'interpellare qualunque superiore in grado, ancora in servizio, che abbia o abbia avuto alle dipendenze l'ispettore o il sovrintendente. 3. La commissione, qualora necessario, e' chiamata a pronunciarsi anche sulle ammissioni o esclusioni o ripetizioni dei corsi, degli esami e degli esperimenti e negli altri casi previsti dalla presente legge o da altre disposizioni legislative. 4. Il parere della commissione di avanzamento puo' essere sentito, altresi', in ogni altro caso in cui sia ritenuto necessario dal Ministro dell'economia e delle finanze. 5. La commissione permanente di avanzamento e' competente a pronunciarsi sulle idoneita' degli appuntati scelti, degli appuntati, dei finanzieri scelti o dei finanzieri, aspiranti al conseguimento della nomina a vice brigadiere di complemento e della riserva, ai sensi delle disposizioni di legge regolanti i rispettivi conseguimenti.>>; g) l'articolo 35 e' sostituito dal seguente: <<Art. 35 - 1. La commissione esprime i giudizi sull'avanzamento a scelta dichiarando innanzitutto se l'ispettore o il sovrintendente sia idoneo o non idoneo all'avanzamento. E' giudicato idoneo l'ispettore o il sovrintendente che riporti un numero di voti favorevoli superiore alla meta' dei votanti. 2. Successivamente la commissione valuta gli ispettori o i sovrintendenti giudicati idonei, attribuendo a ciascuno di essi un punto di merito secondo i criteri di seguito indicati. 3. Ogni componente della commissione assegna distintamente per ciascun ispettore o sovrintendente un punto da 1 a 30 per ognuno dei seguenti complessi di elementi: a) qualita' morali, di carattere e fisiche; b) benemerenze di guerra e comportamento in guerra, benemerenze di pace, qualita' professionali dimostrate durante la carriera, specialmente nel grado rivestito, con particolare riguardo al servizio prestato presso reparti o in imbarco, eventuale attivita' svolta al comando di minori unita', nonche' numero e importanza degli incarichi ricoperti e delle specializzazioni possedute; c) doti culturali e risultati di corsi, esami ed esperimenti. 4. Le somme dei punti assegnati per ciascun complesso di elementi di cui alle lettere a), b) e c), sono divise per il numero dei votanti e i relativi quozienti, calcolati al centesimo, sono sommati tra loro. Il totale cosi' ottenuto e' quindi diviso per tre, calcolando il quoziente al centesimo. Detto quoziente costituisce il punto di merito attribuito all'ispettore o al sovrintendente dalla commissione. Sulla base della graduatoria di merito risultante da tali punteggi la commissione compila il relativo quadro d'avanzamento. 5. I quadri d'avanzamento a scelta sono pubblicati nel foglio d'ordine del Comando generale del Corpo della Guardia di finanza. 6. Agli interessati e' data comunicazione, se idonei, del punteggio conseguito e, se non idonei, delle motivazioni del giudizio di non idoneita'. 7. Contro i predetti atti sono ammessi tutti i rimedi amministrativi e giurisdizionali previsti dalle norme in vigore.>>; h) l'articolo 44 e' sostituito dal seguente: <<Art. 44 - 1. Gli ispettori e sovrintendenti del Corpo della Guardia di finanza cessano dal servizio permanente al raggiungimento dei limiti di eta' e sono collocati nell'ausiliaria, nella riserva o in congedo assoluto a seconda dell'idoneita'. 2. Gli ispettori e sovrintendenti in servizio attivo, tre mesi prima del compimento dei limiti di eta', possono, a domanda, rinunciare al passaggio nella categoria dell'ausiliaria. In tal caso essi sono collocati direttamente nella categoria della riserva. 3. Gli ispettori e sovrintendenti in ausiliaria possono essere collocati nella riserva per motivi di salute, previi accertamenti sanitari>>; i) l'articolo 52 e' sostituito dal seguente: <<Art. 52 - 1. Con decreto del Ministro dell'istruzione, dell'universita' e della ricerca, d'intesa con i Ministri della difesa, dell'economia e delle finanze e del lavoro e delle politiche sociali, e' stabilita, sulla base degli insegnamenti impartiti, la equipollenza dei titoli conseguiti al termine dei corsi di formazione generale, professionale e di perfezionamento, frequentati dagli arruolati e dagli ispettori o dai sovrintendenti in applicazione della presente legge, con quelli rilasciati dagli istituti professionali ivi compresi quelli conseguibili con la frequenza dei corsi sperimentali di cui al decreto del Presidente della Repubblica 19 marzo 1970, n. 253, anche ai fini dell'ammissione agli esami di maturita' professionale. In relazione al suddetto decreto sono rilasciati agli interessati i relativi titoli.>>. 2. Per gli appartenenti al ruolo degli ispettori del Corpo della Guardia di finanza il grado iniziale viene conferito con determinazione del Comandante generale.

#### Art. 2147. - Norme sullo stato giuridico degli appartenenti ai ruoli ispettori e appuntati e finanzieri

1. Alla legge 1 febbraio 1989, n. 53 sono apportate le seguenti modificazioni: a) il titolo e' sostituito dal seguente: <<Modifiche alle norme sullo stato giuridico degli appartenenti ai ruoli ispettori e appuntati e finanzieri del Corpo della Guardia di finanza nonche' disposizioni relative alla Polizia di Stato, alla Polizia penitenziaria e al Corpo forestale dello Stato>>; b) l'articolo 1 e' sostituito dal seguente: <<Art. 1 - 1. I marescialli del Corpo della Guardia di finanza si distinguono in: a) marescialli in servizio permanente; b) marescialli in ferma volontaria; c) marescialli in congedo; d) marescialli in congedo assoluto. 2. I marescialli in congedo sono ripartiti nelle categorie dell'ausiliaria, del complemento e della riserva. 3. Ai marescialli che cessano dal servizio permanente per il raggiungimento del limite di eta' si applicano le norme di cui al titolo IV della legge 10 maggio 1983, n. 212, nonche', in quanto compatibili, l'articolo 886 e la sezione III del capo VII del titolo V del libro IV del codice dell'ordinamento militare.>>; c) l'articolo 2 e' sostituito dal seguente: <<Art. 2 - 1. I graduati e i finanzieri si distinguono in: a) appuntati scelti, appuntati, finanzieri scelti e finanzieri in servizio permanente; b) appuntati e finanzieri in ferma volontaria; c) appuntati scelti, appuntati, finanzieri scelti e finanzieri in congedo illimitato, nell'ausiliaria, nella riserva e in congedo assoluto. 2. Occupano i posti in organico i militari di cui alle lettere a) e b) del comma 1. 3. Il personale di cui al comma 1 non puo' esercitare alcuna professione, mestiere, industria o commercio, ne' comunque attendere a occupazioni o assumere incarichi incompatibili con l'adempimento dei suoi doveri. 4. L'articolo 6 della legge 3 agosto 1961, n. 833, e' abrogato. 5. In tutte le norme in vigore, le espressioni <<militare di truppa>> e <<servizio continuativo>> riferite al Corpo della guardia di finanza, sono sostituite rispettivamente con quelle di <<personale appartenente al ruolo appuntati e finanzieri>> e <<servizio permanente>>.>>; d) l'articolo 7 e' sostituito dal seguente: <<Art. 7 - 1. Il militare in servizio permanente del Corpo della Guardia di finanza subisce una detrazione di anzianita' quando sia stato detenuto per condanna a pene restrittive della liberta' personale di durata non inferiore ad un mese, o sia stato sospeso dal servizio per motivi disciplinari. 2. La detrazione di anzianita' e' pari al tempo trascorso in una delle suddette posizioni. 3. Parimenti si procede al calcolo delle riduzioni di anzianita' conseguenti a interruzioni del servizio. 4. Il militare subisce una detrazione di anzianita' anche quando sia stato in aspettativa per motivi privati. 5. L'articolo 9 della legge 3 agosto 1961, n. 833, e' abrogato.>>; e) l'articolo 8 e' sostituito dal seguente: <<Art. 8 - 1. I finanzieri in servizio permanente, i finanzieri scelti, gli appuntati e appuntati scelti del Corpo della Guardia di finanza possono essere collocati in aspettativa per infermita' e per motivi privati. Sono altresi' collocati di diritto in aspettativa per prigionia di guerra. 2. L'aspettativa non puo' superare due anni in un quinquennio, tranne che per prigionia di guerra, e termina col cessare della causa che l'ha determinata. 3. Prima del collocamento in aspettativa per infermita' ai militari di cui al comma 1 sono concessi i periodi di licenza non ancora fruiti. 4. L'aspettativa per motivi privati e' disposta a domanda; i motivi devono essere provati dall'interessato e la sua concessione e' subordinata alle esigenze di servizio. 5. Fermo il disposto del comma 2, l'aspettativa per motivi privati non puo' eccedere il periodo continuativo di un anno. L'interessato che sia gia' stato in aspettativa per motivi privati non puo' esservi ricollocato se non siano trascorsi almeno due anni dal rientro in servizio. 6. L'aspettativa e' disposta con determinazione del Comandante generale della Guardia di finanza, secondo le rispettive competenze, con facolta' di delega, e decorre dalle date fissate nella determinazione stessa. Nell'aspettativa per prigionia di guerra tale data corrisponde a quella della cattura. 7. Al militare in aspettativa per prigionia di guerra o per infermita' dipendente da causa di servizio compete l'intero trattamento economico goduto dal pari grado in attivita' di servizio. 8. Durante l'aspettativa per infermita' non dipendente da causa di servizio e corrisposto il trattamento economico di cui all'articolo 26 della legge 5 maggio 1976, n. 187. 9. Agli effetti della pensione, il tempo trascorso dal militare in aspettativa per prigionia di guerra o per infermita' proveniente o non proveniente da causa di servizio e' computato per intero. 10. I militari di cui al comma 1 in aspettativa per infermita', che debbano frequentare corsi o sostenere esami prescritti ai fini dell'avanzamento o per la nomina a ispettore o sovrintendente, se ne fanno domanda, sono sottoposti ad accertamenti sanitari e se riconosciuti idonei sono richiamati in servizio. 11. Gli stessi militari in aspettativa per motivi privati, che debbano essere valutati per lo avanzamento o che debbano sostenere esami prescritti ai fini dell'avanzamento o per la nomina a ispettore o sovrintendente, se ne fanno domanda, sono richiamati in servizio. 12. Ai medesimi militari in aspettativa per motivi privati non compete lo stipendio o altro assegno. Agli effetti del trattamento di quiescenza e della indennita' di fine servizio, il tempo trascorso in aspettativa per motivi privati non e' computato. 13. Gli articoli 11 e 12 della legge 3 agosto 1961, n. 833, sono abrogati.>>; f) l'articolo 9 e' sostituito dal seguente: <<Art. 9 - 1. Al primo comma dell'articolo 15 della legge 3 agosto 1961, n. 833, alla lettera c) le parole <<scarso rendimento>> sono sostituite dalle seguenti: <<scarso rendimento, nonche' gravi reiterate mancanze disciplinari che siano state oggetto di consegna di rigore>>. 2. Alla lettera b) dell'articolo 17 della legge 3 agosto 1961, n. 833, sono aggiunte in fine le seguenti parole: <<anche se cessi dal servizio per perdita del grado>>.>>; g) l'articolo 10, comma 2, e' sostituito dal seguente: <<Art. 10 - 2. Gli appuntati e finanzieri tre mesi prima del compimento del 60° anno di eta' possono, a domanda, rinunciare al passaggio nella categoria dell'ausiliaria. In tal caso essi sono collocati direttamente nella categoria delle riserva.>>; h) l'articolo 16 e' sostituito dal seguente: <<Art. 16 - 1. Ai marescialli in ferma volontaria del Corpo della Guardia di finanza si applicano le disposizioni di cui alla legge 3 agosto 1961, n. 833, al decreto legislativo 12 maggio 1995, n. 199 e, in quanto compatibili, al codice dell'ordinamento militare.>>.

#### Art. 2148. - Modifiche al decreto legislativo 12 maggio 1995, n. 195

1. Le denominazioni di <<Ministro delle finanze, Ministro del tesoro e Ministro del bilancio>>, ovunque compaiano nel decreto legislativo 12 maggio 1995, n. 195, sono sostituite con le parole <<Ministro dell'economia e delle finanze>>.

2. All'articolo 1, comma 1, le parole <<decreto legislativo 3 febbraio 1993, n. 29 e successive modificazioni e integrazioni>> sono sostituite dalle seguenti: <<decreto legislativo 30 marzo 2001, n. 165>>.

3. All'articolo 4, comma 2, le parole <<all'articolo 19, commi 4 e seguenti, della legge 11 luglio 1978, n. 382>> sono sostituite dalle seguenti: <<al codice dell'ordinamento militare>>.

4. All'articolo 5, comma 2, le parole <<all'articolo 19, commi 4 e seguenti, della legge 11 luglio 1978, n. 382>> sono sostituite dalle seguenti: <<al codice dell'ordinamento militare>>.

#### Art. 2149. - Disposizioni in materia di disciplina militare per il personale del Corpo della Guardia di finanza

1. Per il personale del Corpo della Guardia di finanza le sospensioni dall'impiego di cui alla sezione IV del capo III del titolo V del libro IV del presente codice sono adottate:

- a) dal Ministro dell'economia e delle finanze nei confronti ((dei generali di corpo d'armata e dei generali di divisione));
- b) dal Comandante generale nei confronti del restante personale.

2. La potesta' sanzionatoria di stato per il personale del Corpo della Guardia di finanza compete:

- a) al Ministro dell'economia e delle finanze nei confronti ((dei generali di corpo d'armata e dei generali di divisione));
- b) al Comandante generale del Corpo della Guardia di finanza nei confronti del restante personale.

3. La decisione di sottoporre un ufficiale del Corpo della Guardia di finanza ad inchiesta formale spetta alle seguenti autorita':

- a) al Ministro dell'economia e delle finanze se si tratti di ((generali di corpo d'armata e generali di divisione));
- b) al Comandante generale per i restanti ufficiali.

4. Per i militari del Corpo della Guardia di finanza diversi da quelli di cui al comma 3, la decisione spetta ai Comandanti regionali ed equiparati da cui i militari dipendono per ragioni di impiego; qualora manchi tale dipendenza l'inchiesta formale e' disposta dal Comandante regionale nella cui giurisdizione il militare risiede. Il Comandante generale del Corpo della Guardia di finanza puo' in ogni caso ordinare direttamente un'inchiesta formale nei confronti del personale di cui al presente comma.

5. In caso di corresponsabilita' tra:

- a) ufficiali e altri militari del Corpo della Guardia di finanza per fatti che configurano un illecito disciplinare, il procedimento disciplinare e' unico e si svolge secondo le norme stabilite per il procedimento a carico degli ufficiali. Fino a quando non sia convocata la Commissione di disciplina l'autorita' competente ai sensi del comma 3 puo' ordinare, per ragioni di convenienza, la separazione dei procedimenti;
- b) militari del Corpo della Guardia di finanza non appartenenti alla categoria ufficiali e dipendenti per l'impiego da Comandanti regionali o equiparati diversi o residenti in giurisdizioni diverse, l'inchiesta e' disposta dal Comandante regionale o equiparato competente a provvedere per il militare piu' elevato in grado o piu' anziano.

6. Le autorita' che hanno disposto l'inchiesta formale, in base alle risultanze della stessa:

- a) qualora ritengano che al militare debba o meno essere inflitta una delle sanzioni disciplinari indicate nell'articolo 1357, comma 1, lettere a) e b), ne fanno proposta alle autorita' indicate al comma 2;
- b) qualora ritengano che al militare possano essere inflitte le sanzioni disciplinari indicate all'articolo 1357, comma 1, lettere c) e d), ne ordinano il deferimento ad una Commissione di disciplina.

7. Le facolta' previste dall'articolo 1389, per il personale del Corpo della Guardia di finanza, si intendono riferite al Ministro dell'economia e delle finanze o al Comandante generale.

8. Fermo restando quanto previsto dall'articolo 866, per il personale del Corpo della Guardia di finanza la perdita del grado e' disposta, previo giudizio disciplinare, in caso di condanna definitiva, non condizionalmente sospesa, per reato militare o delitto non colposo che comporti la pena accessoria della interdizione temporanea dai pubblici uffici oppure una delle pene accessorie di cui all'articolo 19, primo comma, numeri 2) e 6), del codice penale.

((

8-bis. Rientrano tra gli accertamenti preliminari di cui all'articolo 1392, comma 2, anche i pareri gerarchici dei livelli superiori a quello che ha rilevato la mancanza.

8-ter. Per i militari del Corpo della guardia di finanza il procedimento disciplinare di stato e' disciplinato con decreto del Ministro dell'economia e delle finanze, ferme restando le disposizioni contenute nel presente Codice.

))

#### Art. 2150. - Clausola di salvaguardia per il personale della Polizia di Stato

1. Al personale della Polizia di Stato si applicano le disposizioni di cui all'articolo 881.

2. Al personale di cui al comma 1 si applica l'articolo 804; resta fermo quanto previsto dall'articolo 65-ter del decreto legislativo 5 ottobre 2000, n. 334.

#### Art. 2151. - Posti riservati a particolari categorie nei concorsi per il reclutamento del personale del Corpo della Guardia di finanza e delle Forze di polizia a ordinamento civile

1. Il comma 1 dell'articolo 9 del decreto-legge 1° gennaio 2010, n. 1, convertito, con modificazioni, dalla legge 5 marzo 2010, n. 30, e' cosi' sostituito: <<1. Fermi restando i benefici previsti dalle norme vigenti, fino al venticinque per cento dei posti messi a concorso:

- a) per il reclutamento degli ufficiali del Corpo della Guardia di finanza e del corrispondente personale delle Forze di polizia a ordinamento civile, e' riservato al coniuge e ai figli superstiti, ovvero ai parenti in linea collaterale di secondo grado se unici superstiti, del personale delle Forze armate e delle Forze di polizia deceduto in servizio e per causa di servizio, in possesso dei requisiti prescritti;
- b) per il reclutamento del personale dei ruoli degli ispettori del Corpo della Guardia di finanza e delle Forze di polizia a ordinamento civile, e' riservato al coniuge e ai figli superstiti, ovvero ai parenti in linea collaterale di secondo grado se unici superstiti, del personale delle Forze armate e delle Forze di polizia deceduto in servizio e per causa di servizio, in possesso dei requisiti prescritti.>>.

#### Art. 2152. - Applicazione dell'articolo 17 della legge 28 luglio 1999, n. 266, nel caso di collocamento in congedo

1. Il comma 1-bis dell'articolo 2 della legge 29 marzo 2001, n. 86 e' cosi' sostituito: <<1-bis. Le disposizioni di cui al comma 1 si applicano anche al personale che elegge domicilio nel territorio nazionale a seguito di collocamento in aspettativa per riduzione dei quadri, di cui ((agli articoli 909 e 2145)) del codice dell'ordinamento militare. Il diritto del coniuge puo' essere esercitato una sola volta, anche in caso di successivi richiami in servizio previsti dalle disposizioni vigenti, e non puo' piu' essere esercitato all'atto del definitivo collocamento in congedo>>.

### SEZIONE IV - TRATTAMENTO ECONOMICO, ASSISTENZA E BENESSERE

#### Art. 2153. - Ambito soggettivo

1. Le disposizioni della presente sezione si applicano al personale delle Forze di polizia.

#### Art. 2154. - Disposizioni generali in materia di trattamento economico del personale delle Forze di polizia a ordinamento militare

1. Al personale delle Forze di polizia a ordinamento militare si applicano gli articoli 1779, 1781, 1782 e 1783.

2. Al personale di cui al comma 1, continua ad applicarsi l'articolo 2, comma 91, della legge 24 dicembre 2007, n. 244. ((Allo stesso personale si applica, altresi', l'articolo 4, comma 98, della legge 12 novembre 2011, n. 183.))

#### Art. 2155. - Retribuzione del personale di leva delle Forze di polizia a ordinamento militare

1. In caso di ripristino della coscrizione obbligatoria, al personale che adempie gli obblighi di leva nelle Forze di polizia a ordinamento militare si applicano, in quanto compatibili, le disposizioni recate dal libro VI, titolo II.

#### Art. 2156.

Retribuzione ((stipendiale)) e premio di fine ferma agli ufficiali in ferma prefissata delle Forze di polizia a ordinamento militare

1. Agli ufficiali in ferma prefissata delle Forze di polizia a ordinamento militare si applicano gli articoli 1795 e 1796.

#### Art. 2157. - Retribuzione degli allievi di scuole e accademie delle Forze di polizia a ordinamento militare

1. Agli allievi delle scuole e delle accademie delle Forze di polizia a ordinamento militare sono attribuite le paghe nette giornaliere di cui all'articolo 1798((, secondo le modalita' ivi previste)).

#### Art. 2158. - Retribuzione delle forze di completamento per le Forze di polizia a ordinamento militare

1. Alle Forze di polizia a ordinamento militare si applicano le disposizioni di cui all'articolo 1799, in materia di retribuzione delle forze di completamento.

#### Art. 2159. - Scatti per invalidita' di servizio per le Forze di polizia a ordinamento civile e militare

1. All'articolo 70 del decreto legge 25 giugno 2008, n. 112, convertito con modificazioni, dalla legge 6 agosto 2008, n. 133, il comma 1-bis e' sostituito dal seguente: <<1-bis - In deroga alle disposizioni del presente articolo, al personale delle Forze di polizia a ordinamento civile e militare si applica l'articolo 1801 del codice dell'ordinamento militare>>.

#### Art. 2160. - Omogeneizzazione stipendiale per le Forze di polizia a ordinamento militare

1.Agli ufficiali ((...)) delle Forze di polizia a ordinamento militare si applicano le disposizioni di cui agli articoli 43, commi 16, 22 e 23, e 43-ter, comma 1, della legge 1° aprile 1981, n. 121.

#### Art. 2161. - Incentivi agli ufficiali piloti in servizio permanente del Corpo della Guardia di finanza

1. COMMA ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190.

2. COMMA ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190.

((

3. Gli ufficiali in servizio permanente del Corpo della guardia di finanza ammessi ai corsi di pilotaggio per il conseguimento del brevetto di pilota militare devono contrarre, all'atto della nomina a ufficiale, una ferma volontaria, decorrente dalla menzionata data di nomina, di durata pari a sedici anni. L'ufficiale che non porta a termine o non supera il corso di pilotaggio e' prosciolto dalla ferma, salvo l'obbligo di completare le ferme contratte ai sensi dell'articolo 11 del decreto legislativo 19 marzo 2001, n. 69.

))

((

4. Gli ufficiali in servizio permanente del Corpo della guardia di finanza in possesso del brevetto di pilota militare, che hanno ultimato, alternativamente:

- a) la ferma obbligatoria di cui al comma 3;
- b) una delle ferme gia' previste dall'articolo 3 della legge 28 febbraio 2000, n. 42, sono ammessi a una ferma volontaria di durata biennale, rinnovabile per non piu' di quattro volte, entro il quarantacinquesimo anno di eta'.

4-bis. Agli ufficiali in servizio permanente del Corpo della guardia di finanza, in possesso del brevetto di pilota militare, ammessi a contrarre le ferme volontarie biennali di cui al comma 4, sono corrisposti, per ciascun periodo di ferma volontaria contratta, i premi di cui all'articolo 1803.))

--------------- AGGIORNAMENTO (30) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 260) che "Gli importi dei premi previsti dagli articoli 1803, comma 1, lettere da a) ad e), 1804, comma 1, lettere da a) ad e), e 2161, comma 4, del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, sono ridotti alla meta'".

#### Art. 2162. - Modifiche al d.P.R. 22 dicembre 1986, n. 917

1. All'articolo 51, comma 6 del decreto del Presidente della Repubblica 22 dicembre 1986, n. 917, dopo le parole <<le indennita' di navigazione e di volo previste dalla legge o dal contratto collettivo,>> sono inserite le seguenti:<<i premi agli ufficiali piloti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare di cui all'articolo 1803 del codice dell'ordinamento militare, i premi agli ufficiali piloti del Corpo della Guardia di finanza di cui all'art. 3 della legge 28 febbraio 2000, n. 42>>.

#### Art. 2163. - Estensione dell'indennita' di missione all'estero al personale delle Forze di polizia

1. Le disposizioni di cui all'articolo 1807 si applicano anche al personale delle Forze di polizia.

#### Art. 2164. - Estensione dell'indennita' di lungo servizio all'estero

1. Le disposizioni di cui all'articolo 1808 si applicano anche agli appartenenti alla Polizia di Stato e alle Forze di polizia a ordinamento militare. ((62))

-------------- AGGIORNAMENTO (62) Il D.Lgs 29 maggio 2017, n. 95, come modificato dal D.Lgs 27 dicembre 2019, n. 172, ha disposto (con l'art. 44, comma 14-sexies) che "Le disposizioni di cui agli articoli 2164 e 1808 del decreto legislativo 15 marzo 2010, n. 66 si applicano anche agli appartenenti al Corpo di polizia penitenziaria".

#### Art. 2165. - Estensione dell'indennita' di servizio all'estero presso rappresentanze diplomatiche

1. Le disposizioni di cui all'articolo 1809 si applicano anche al personale dell'Arma dei carabinieri.

#### Art. 2166. - Accesso alla dirigenza e trattamenti retributivi per il personale delle Forze di polizia a ordinamento militare

1. Al personale delle Forze di polizia a ordinamento militare si applicano gli articoli 1810, 1811 e 1821.

#### Art. 2167. - Indennita' pensionabile per le Forze di polizia a ordinamento militare

1. Agli ufficiali dirigenti delle Forze di polizia a ordinamento militare si applicano le disposizioni di cui all'articolo 43, comma 3, della legge 1° aprile 1981, n. 121.

#### Art. 2168. - Speciale indennita' pensionabile al Comandante generale dell'Arma dei carabinieri e della Guardia di finanza

1. Al Comandante generale dell'Arma dei carabinieri e del Corpo della Guardia di finanza e' attribuita la speciale indennita' pensionabile ai sensi dell'articolo 5, comma 3, della legge 1° aprile 1981, n. 121.

#### Art. 2169. - Indennita' di impiego operativo al personale dirigente delle Forze di polizia a ordinamento militare

1. Ove previsto da specifiche disposizioni di legge, al personale dirigente delle Forze di polizia a ordinamento militare si applicano le indennita' operative e relative indennita' supplementari, previste per l'Esercito italiano, la Marina militare e l'Aeronautica militare.

#### Art. 2170. - Compenso per lavoro straordinario al personale dirigente delle Forze di polizia a ordinamento militare

1. Il compenso per lavoro straordinario al personale dirigente delle Forze di polizia a ordinamento militare e' disciplinato dall'articolo 43, commi 13 e 14, della legge 1° aprile 1981, n. 121.

#### Art. 2171. - Ulteriori istituti economici per il personale dirigente delle Forze di polizia a ordinamento militare

1. Al personale dirigente delle Forze di polizia a ordinamento militare sono attribuiti gli ulteriori emolumenti accessori previsti da specifiche disposizioni di legge.

#### Art. 2172. - Competenza statale per gli interventi di protezione sociale

1. Ai sensi dell'art. 24, comma 1, n. 3, del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, rientrano nella competenza dello Stato gli interventi di protezione sociale prestati ad appartenenti alle Forze di polizia a ordinamento militare e ai loro familiari, da enti e organismi appositamente istituiti.

#### Art. 2173. - Organismi di protezione sociale per le Forze di polizia a ordinamento militare

1. Al fine di assicurare gli interventi di protezione sociale, di cui all'articolo 5, commi 3 e 4, della legge 23 dicembre 1993, n. 559, a favore del personale delle Forze di polizia a ordinamento militare e dei loro familiari, sono concessi in uso alle organizzazioni costituite tra il personale dipendente, ai sensi dell'articolo 1475, oppure a enti e terzi, i locali demaniali, i mezzi, le strutture, i servizi e gli impianti necessari per i predetti interventi.

#### Art. 2174. - Promozione del benessere, formazione ed elevazione culturale delle Forze di polizia a ordinamento militare

1. Alle Forze di polizia a ordinamento militare si applica la disposizione di cui all'articolo 1832. Inoltre, le predette Forze di polizia promuovono il benessere del personale e della sua famiglia mediante: a ) contributi e sovvenzioni in favore degli organismi di protezione sociale di cui all'articolo 2173; b) borse di studio, conferite mediante concorso pubblico, in favore dei figli del personale dipendente o in quiescenza, nonche' degli orfani del personale medesimo; c) contributi per il rimborso delle spese sostenute dal dipendente per le rette degli asili nido pubblici o privati; d) altri interventi di protezione sociale, anche diretti a promuovere, mediante la frequenza di corsi interni ed esterni, l'elevazione culturale e la preparazione professionale del personale.

#### Art. 2175. - Rimborso spese sostenute per rette di asili nido per le Forze di polizia a ordinamento militare

1. Nell'ambito delle attivita' assistenziali nei confronti del personale delle Forze di polizia a ordinamento militare e nei limiti degli stanziamenti di bilancio, le Amministrazioni interessate, in luogo della istituzione di asili nido, possono concedere il rimborso, anche parziale, delle rette relative alle spese sostenute dai dipendenti per i figli a carico.

#### Art. 2176. - Borse di studio per le Forze di polizia a ordinamento militare

1. Nei confronti del personale per le Forze di polizia a ordinamento militare trovano applicazione le disposizioni in materia di borse di studio riservate alle vittime del terrorismo e della criminalita' organizzata, nonche' agli orfani e ai figli delle medesime, ai sensi dell'articolo 4, comma 1, della legge 23 novembre 1998, n. 407.

2. Restano ferme le disposizioni in materia di borse di studio universitarie previste per i dipendenti pubblici.

### SEZIONE V - TRATTAMENTO PREVIDENZIALE E PER LE INVALIDITA' DI SERVIZIO

#### Art. 2177. - Ambito soggettivo

1. Le disposizioni della presente sezione si applicano al personale delle Forze di polizia ad ordinamento civile e al Corpo nazionale dei Vigili del fuoco.

#### Art. 2178. - Estensione delle norme sul computo del servizio effettivo e sul trattamento economico di ausiliaria al personale dei disciolti Corpi delle Guardie di Pubblica sicurezza e degli Agenti di custodia

1. Al personale dei disciolti Corpi delle Guardie di Pubblica sicurezza e degli Agenti di custodia, si applicano le disposizioni in materia di computo del servizio effettivo di cui all'articolo 1847 e quelle sul trattamento economico di ausiliaria di cui agli articoli 1864, 1870, 1871, 1872, 1874 e 1875.

#### Art. 2179. - Effetti pensionistici delle indennita' di impiego operativo percepite dalle Forze di polizia a ordinamento civile

1. Al personale delle Forze di polizia a ordinamento civile, percettore delle indennita' di impiego operativo previste dalla legge 23 marzo 1983, n. 78, si applicano le disposizioni di cui agli articoli 1868, 1869 e 1888.

#### Art. 2180. - Lesioni traumatiche da causa violenta subite dal personale delle Forze di polizia a ordinamento civile e del Corpo nazionale dei Vigili del fuoco

1. Al personale delle Forze di polizia a ordinamento civile e del Corpo nazionale del Vigili del fuoco si applicano, in materia di accertamento della dipendenza in caso di lesioni traumatiche da causa violenta, le disposizioni di cui all'articolo 1880.

#### Art. 2181. - Speciale elargizione ai superstiti degli allievi delle Forze di polizia a ordinamento civile deceduti durante il servizio ed equo indennizzo

1. Ai superstiti degli allievi delle Forze di polizia ad ordinamento civile si applicano le disposizioni di cui all'articolo 1895.

2. Agli allievi delle Forze di polizia ad ordinamento civile si applicano le disposizioni di cui all'articolo 1882.

#### Art. 2182. - Speciale elargizione ai superstiti del personale e degli allievi delle Forze di polizia a ordinamento civile deceduti a causa di servizio

1. Ai superstiti del personale e degli allievi delle Forze di polizia a ordinamento civile, si applicano le disposizioni di cui all'articolo 1896.

#### Art. 2183. - Speciale trattamento pensionistico di reversibilita' ai superstiti del personale delle Forze di polizia a ordinamento civile e militare

1. Ai superstiti del personale delle Forze di polizia a ordinamento civile si applicano le disposizioni di cui all'articolo 1897, anche in caso di decesso in attivita' di servizio per diretto effetto di ferite o lesioni riportate in conseguenza di azioni terroristiche o criminose o in servizio di ordine pubblico.

#### Art. 2184. - Indennizzo privilegiato aeronautico ai dipendenti civili

1. L'indennizzo privilegiato aeronautico, di cui al libro VII, titolo III, capo IV, sezione II , ivi comprese le norme sull'indennizzo integrativo, e' concesso al personale delle Forze di polizia a ordinamento civile ed e' esteso ai dipendenti civili dello Stato, alle condizioni di cui al comma 4 dell'articolo 1898.

2. L'indennizzo privilegiato aeronautico, in caso di decesso di un dipendente civile, e' determinato nei seguenti importi, maggiorati di euro 619,75 per ciascun figlio fiscalmente a carico:

- a) dirigenza: 1) euro 7.746,85 al coniuge superstite, anche se separato, purche' senza addebito, per l'intero ammontare oppure in concorso con gli orfani in ragione del 75, 60, 50 e 45 per cento del relativo importo, secondo che, rispettivamente, i figli stessi siano rappresentati in numero di 1, 2, 3, 4 e piu', mentre la rimanente quota va ripartita tra i figli o i loro discendenti, ovvero ai figli legittimi, legittimati, adottivi e naturali riconosciuti, in mancanza del coniuge superstite; 2) euro 1.936,71 ai genitori, in mancanza di coniuge superstite e figli, ovvero ai fratelli e alle sorelle, in mancanza di coniuge superstite, figli e genitori;
- b) area terza: 1) euro 6.197,48 ai soggetti di cui al numero 1) della lettera a); 2) euro 1.549,37 ai soggetti di cui al numero 2) della lettera a);
- c) area seconda: 1) euro 4.648,11 ai soggetti di cui al numero 1) della lettera a); 2) euro 1.208,51 ai soggetti di cui al numero 2) della lettera a);
- d) area prima: 1) euro 3.873,43 ai soggetti di cui al numero 1) della lettera a); 2) euro 991,60 ai soggetti di cui al numero 2) della lettera a);
- e) personale non dirigente con contratto a tempo determinato: 1) euro 3.098,74 ai soggetti di cui al numero 1) della lettera a); 2) euro 774,69 ai soggetti di cui al numero 2) della lettera a).

3. L'indennizzo privilegiato aeronautico, in caso di infermita' di un dipendente civile, e' determinato nei seguenti importi, maggiorati di euro 619,75 per ciascun figlio fiscalmente a carico, per patologie ascrivibili alla 1^ ed alla 2^ categoria della tabella A annessa al decreto del Presidente della Repubblica 23 dicembre 1978, n. 915, e di euro 309,87, per infermita' ascrivibili alla 3^ categoria della tabella A:

- a) dirigenza: euro 7.746,85 per infermita' ascrivibile alla 1^ categoria, euro 6.972,17 per la 2^ categoria ed euro 1.936,71 per la 3^ categoria;
- b) area terza: euro 6.197,48 per infermita' ascrivibile alla 1^ categoria, euro 5.577,73 per la 2^ categoria ed euro 1.549,37 per la 3^ categoria;
- c) area seconda: euro 4.648,11 per infermita' ascrivibile alla 1^ categoria, euro 4.338,24 per la 2^ categoria ed euro 1.208,51 per la 3^ categoria;
- d) area prima: euro 3.873,43 per infermita' ascrivibile alla 1^ categoria, euro 3.563,55 per la 2^ categoria ed euro 991,60 per la 3^ categoria;
- e) personale non dirigente con contratti a tempo determinato: euro 3.098,74 per infermita' ascrivibile alla 1^ categoria, euro 2.788,87 per la 2^ categoria ed euro 774,69 per la 3^ categoria.

#### Art. 2185. - Personale civile e cittadini italiani esposti all'uranio impoverito e ad altro materiale bellico

1. La speciale elargizione di cui all'articolo 1907, e' corrisposta, con le stesse modalita', alle seguenti categorie di personale e loro superstiti:

- a) al personale civile italiano impiegato nelle missioni internazionali svolte al di fuori del territorio nazionale, autorizzate dall'autorita' gerarchicamente o funzionalmente sopra ordinata al dipendente;
- b) al personale civile italiano impiegato nei poligoni di tiro e nei siti in cui vengono stoccati munizionamenti;
- c) al personale civile italiano impiegato nei teatri di conflitto e nelle aree di cui alle lettere a) e b);
- d) ai cittadini italiani operanti nei settori della cooperazione ovvero impiegati da organizzazioni non governative nell'ambito di programmi aventi luogo nei teatri di conflitto e nelle aree di cui alle lettere a) e b);
- e) ai cittadini italiani residenti nelle zone adiacenti alle basi militari sul territorio nazionale presso le quali e' conservato munizionamento pesante o esplosivo e nelle aree di cui alla lettera b).

2. I termini e le modalita' per il riconoscimento della causa di servizio e per la corresponsione di adeguati indennizzi in favore dei soggetti indicati nel comma 1, entro il limite massimo di spesa stabilito nell'articolo 603, sono disciplinati dal regolamento.

## TITOLO II DISPOSIZIONI TRANSITORIE CAPO I DISPOSIZIONI GENERALI

### Art. 2186. - Validita' ed efficacia degli atti emanati. Salvaguardia dei diritti quesiti

1. Alla data di entrata in vigore del presente codice e del regolamento:

- a) restano validi gli atti e i provvedimenti emanati;
- b) sono fatti salvi i diritti acquisiti sulla base della normativa antecedente;
- c) le disposizioni del presente codice e quelle del regolamento, in relazione al trattamento economico e previdenziale del personale del comparto sicurezza e difesa, non possono produrre effetti peggiorativi ovvero disallineamenti rispetto a quanto previsto dalla normativa vigente alla data della loro entrata in vigore.

2. I decreti ministeriali non regolamentari, le direttive, le istruzioni, le circolari, le determinazioni generali del Ministero della difesa, dello Stato maggiore della difesa, del Segretariato generale della difesa, ((della Direzione nazionale degli armamenti,)) degli Stati maggiori di Forza armata, del Comando generale dell'Arma dei carabinieri e del Comando generale del Corpo della Guardia di finanza, emanati in attuazione della precedente normativa abrogata, continuano a trovare applicazione, in quanto compatibili con il presente codice ed il regolamento, fino alla loro sostituzione. (14) (20)

------------- AGGIORNAMENTO (14) Il D.Lgs. 24 febbraio 2012, n. 20 ha disposto (con l'art. 10, comma 1, lettera 1)) che sono "fatti salvi gli effetti giuridici, nonche' i provvedimenti adottati in attuazione dell'articolo 2186 del decreto legislativo 15 marzo 2010, n. 66". ----------------- AGGIORNAMENTO (20) Il D.Lgs. 31 dicembre 2012, n. 248, ha disposto (con l'art. 10, comma 11) che "In relazione a quanto disposto dagli articoli 4, comma 1, lettera ll), 9, comma 1, lettera s), numeri 3), 4) e 7), e lettera u), numero 1.1), nonche' dal comma 7 del presente articolo, sono comunque fatti salvi gli effetti giuridici e i provvedimenti adottati in attuazione dell'articolo 2186 del decreto legislativo 15 marzo 2010, n. 66."

### Art. 2187. - Procedimenti in corso

1. I procedimenti in corso alla data di entrata in vigore del presente codice e del regolamento rimangono disciplinati dalla previgente normativa.

## CAPO II - DISPOSIZIONI PARTICOLARI

### SEZIONE I - ORGANIZZAZIONE E FUNZIONI

#### Art. 2188. - Ristrutturazione di ruoli e corpi dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. Fermi restando il volume organico complessivo, gli organici complessivi dei ruoli degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare e il numero massimo delle promozioni annuali, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, da emanare ai sensi dell'articolo 17 della legge 23 agosto 1988, n. 400, non appena attuate le disposizioni previste nei decreti legislativi di ristrutturazione dell'organizzazione della Difesa previsti dall'abrogata legge 28 dicembre 1995, n. 549, possono essere modificate le disposizioni del presente codice relative a:

- a) l'unificazione dei corpi sanitari delle Forze armate;
- b) l'unificazione di ruoli omologhi preposti a funzioni similari delle Forze armate;
- c) il trasferimento di funzioni da un ruolo ad un altro anche di Forza armata diversa;
- d) l'unificazione dei corpi di una Forza armata.

2. Le dotazioni organiche dei singoli ruoli di Forza armata, risultate in eccedenza al termine dell'unificazione o del trasferimento di funzioni, possono essere ripartite tra i ruoli delle Forze armate o riassegnate secondo necessita', con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, emanato, senza oneri aggiuntivi, ai sensi dell'articolo 17 della legge 23 agosto 1988, n. 400.

#### Art. 2188-bis. - Disposizioni transitorie in materia di provvedimenti di soppressione e di riconfigurazione di comandi, enti e altre strutture ordinative dell'Esercito italiano

1. Ai fini del conseguimento, in concorso con i provvedimenti ordinativi di cui agli articoli 2188-ter e 2188-quater, della contrazione strutturale complessiva non inferiore al 30% imposta dall'articolo 2, comma 1, lettera b), della legge 31 dicembre 2012, n. 244, nonche' per il raggiungimento degli assetti ordinamentali dell'Esercito italiano di cui agli articoli dal 100 al 109, sono adottati ai sensi dell'articolo 10, comma 3, sentite, per le materie di competenza, le organizzazioni sindacali rappresentative, i provvedimenti di soppressione, ovvero di riconfigurazione, di comandi, enti e altre strutture ordinative di Forza armata, rispettivamente specificati nelle lettere a) e b), secondo la tempistica affianco di ciascuno di essi indicata:

- a) provvedimenti di soppressione: 1) Comando militare Esercito Toscana, entro il 31 marzo 2014; 2) Centro documentale di Genova, entro il 31 marzo 2014; 3) Centro documentale di Bari, entro il 31 marzo 2014; 4) Centro documentale di Catanzaro, entro il 31 marzo 2014; 5) Centro documentale di Firenze, entro il 31 marzo 2014; 6) Centro documentale di Padova, entro il 31 marzo 2014; 7) Centro documentale di Perugia, entro il 31 marzo 2014; 8) Centro documentale di Trento, entro il 31 marzo 2014; 9) Centro documentale di Bologna, entro il 31 dicembre 2014; 10) Centro documentale di Napoli, entro il 31 dicembre 2014; 11) Comando 2° FOD di entro il 31 maggio 2016; 12) Ispettorato delle Infrastrutture dell'Esercito, entro il 31 dicembre 2014; 13) Raggruppamento Unita' Addestrative (RUA), entro il 31 dicembre 2014; 14) Comando Logistico NORD, entro il 31 dicembre 2014; 15) Comando Logistico SUD, entro il 31 dicembre 2014; 16) NUMERO SOPPRESSO DAL D.LGS. 26 APRILE 2016, N. 91; 17) Comando Infrastrutture Centro, entro il 31 dicembre 2016; 18) Comando Infrastrutture Nord, entro il 31 dicembre 2016; 19) Comando Infrastrutture Sud, entro il 31 dicembre 2016; 20) Centro documentale di Ancona, entro il ((31 dicembre 2019)); 21) Centro documentale di Brescia, entro il ((31 dicembre 2019)); 22) Centro documentale di Cagliari, entro il ((31 dicembre 2019)); 23) Centro documentale di Caserta, entro il ((31 dicembre 2019)); 24) Centro documentale di Catania, entro il ((31 dicembre 2019)); 25) Centro documentale di Chieti, entro il ((31 dicembre 2019)); 26) Centro documentale di Como, entro il ((31 dicembre 2019)); 27) Centro documentale di Lecce, entro il ((31 dicembre 2019)); 28) Centro documentale di Milano, entro il ((31 dicembre 2019)); 29) Centro documentale di Palermo, entro il ((31 dicembre 2019)); 30) Centro documentale di Salerno, entro il ((31 dicembre 2019)); 31) Centro documentale di Udine, entro il ((31 dicembre 2019)); 32) Centro documentale di Verona, entro il ((31 dicembre 2019)); 33) Centro documentale di Roma, entro il ((31 dicembre 2019)); 34) Comando militare esercito Molise, entro il ((31 dicembre 2019)); 34-bis) Comando militare esercito Trentino Alto-Adige, entro il 31 maggio 2016; 34-ter) Centro studi e ricerche di sanita' e veterinaria dell'Esercito italiano, entro il 31 maggio 2016;
- b) provvedimenti di riconfigurazione: 1) il Centro Ospedaliero militare di Milano, entro il 31 marzo 2014, e' riconfigurato in Dipartimento militare di medicina legale posto alle dipendenze del Comando Sanita' e Veterinaria; 2) il Comando Militare Esercito Abruzzo, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 3) il Comando Militare Esercito Basilicata, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione dell'Ufficio Documentale di Potenza; 4) il Comando Militare Esercito Calabria, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Catanzaro; 5) il Comando Militare Esercito Puglia, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Bari; 6) il Comando Militare Esercito Trentino Alto Adige, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle attribuzioni conseguenti alla soppressione del Centro Documentale di Trento; 7) il Comando Militare Esercito Umbria, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Perugia; 8) il Comando Militare Esercito Liguria, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Genova; 9) il Comando logistico dell'Esercito, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione complessiva delle relative attribuzioni, funzionali al nuovo assetto ordinamentale; 10) il Polo Mantenimento dei mezzi di Telecomunicazione, Elettronici ed Optoelettronici di Roma, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni anche conseguenti all'assunzione alle proprie dipendenze degli Enti di sostegno TLC; 11) il Polo Mantenimento Armi Leggere di Terni, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 12) il Comando Militare Esercito Campania, entro il 31 dicembre 2014 e' riconfigurato in Comando Forze di Difesa Interregionale SUD in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro documentale di Napoli; 13) il Comando Divisione "Acqui", entro il 31 maggio 2016, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni; 14) NUMERO SOPPRESSO DAL D.LGS. 26 APRILE 2016, N. 91; 15) il Polo di Mantenimento Pesante Nord, entro il 31 dicembre 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale ; 16) il Polo di Mantenimento Pesante Sud, entro il 31 dicembre 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 17) il Comando Regione Militare SUD, entro il 31 dicembre 2014, e' riconfigurato in Comando Militare Autonomo della Sicilia; 18) il Comando Divisione "Tridentina", entro il : 31 maggio 2016, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale dell'Area operativa dell'Esercito in sistema con la riorganizzazione del Comando Truppe Alpine, di cui al numero 29-ter); 19) il Centro Documentale di Torino entro il 31 dicembre 2014, e' riconfigurato in Centro Gestione Archivi in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione dei Centri documentali dell'Esercito; 20) il Comando militare Esercito Emilia Romagna, entro il 31 dicembre 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Bologna; 21) il Comando Regione Militare NORD, entro il 31 maggio 2016, e' riconfigurato e ridenominato in ragione della rideterminazione delle relative attribuzioni; 22) il Comando Forze Operative Terrestri, attualmente dislocato a Verona, entro il ((31 dicembre 2019)), e' riconfigurato nella sede di Roma in Comando forze operative terrestri e Comando operativo esercito; 23) il Comando militare Esercito Abruzzo, entro il ((31 dicembre 2019)), e' riconfigurato e ridenominato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alle soppressioni del Comando Militare Esercito Molise e del Centro Documentale di Chieti; 24) il Comando militare Esercito Friuli Venezia Giulia, entro il ((31 dicembre 2019)), e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Udine; 25) il Comando militare Esercito Lombardia con sede a Milano, entro il ((31 dicembre 2019)), e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Milano; 26) il Comando militare Esercito Marche, entro il ((31 dicembre 2019)), e' riconfigurato e ridenominato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Centro Documentale di Ancona; 27) il Comando militare della Capitale, entro il 31 maggio 2016, e' riconfigurato in ragione dei compiti e funzioni da assolvere ed entro il ((31 dicembre 2019)) acquisisce le relative attribuzioni conseguenti alla soppressione del Centro Documentale di Roma; 28) il Comando militare autonomo della Sardegna, entro il 31 maggio 2016, e' riconfigurato e ridenominato in ragione dei compiti/funzioni da assolvere ed entro il ((31 dicembre 2019)) acquisisce le funzioni del soppresso Centro Documentale di Cagliari; 29) il Comando militare autonomo della Sicilia, entro il 31 maggio 2016, e' riconfigurato e ridenominato in ragione dei compiti/funzioni da assolvere ed entro il ((31 dicembre 2019)) acquisisce le funzioni del soppresso Centro Documentale di Palermo; 29-bis) il Comando forze di difesa interregionale Nord, entro il 31 maggio 2016, e' ridenominato e riconfigurato come struttura di comando a valenza interregionale e multifunzione, in ragione della rideterminazione e razionalizzazione delle attribuzioni e della riarticolazione delle relative componenti ordinative; 29-ter) il Comando delle truppe alpine, entro il 31 maggio 2016, e' ridenominato e riconfigurato come struttura di comando a valenza interregionale e multifunzione, in ragione della rideterminazione e razionalizzazione delle attribuzioni e della riarticolazione delle relative componenti ordinative; 29-quater) il Comando forze di difesa interregionale Sud, entro il 31 maggio 2016, e' ridenominato e riconfigurato come struttura di comando a valenza interregionale e multifunzione, in ragione della rideterminazione e razionalizzazione delle attribuzioni e della riarticolazione delle relative componenti ordinative anche conseguenti alla soppressione del 2° FOD; 29-quinquies) il Comando supporti in Verona, entro il ((31 dicembre 2019)), e' riconfigurato in Comando delle forze operative terrestri di supporto, in ragione della rideterminazione e razionalizzazione delle relative attribuzioni; 29-sexies) l'Istituto geografico militare, entro il 31 maggio 2016, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle proprie attribuzioni nel settore territoriale.

2. Gli ulteriori provvedimenti ordinativi di soppressione o riconfigurazione di strutture di Forza armata non direttamente disciplinate nel codice o nel regolamento, nonche' le altre soppressioni o riconfigurazioni consequenziali all'attuazione dei provvedimenti di cui al comma 1, lettere a) e b), sono adottati, per quanto di rispettiva competenza e nell'esercizio della propria ordinaria potesta' ordinativa, previa informativa, per le materie di competenza, alle organizzazioni sindacali rappresentative, dal Capo di stato maggiore dell'Esercito italiano, nell'ambito delle direttive del Capo di Stato maggiore della difesa e concorrono, unitamente a quelli di cui al comma 1, al conseguimento della contrazione strutturale complessiva non inferiore al 30%.

#### Art. 2188-ter. - ((Disposizioni transitorie in materia di provvedimenti di soppressione e di riconfigurazione di comandi, enti e altre strutture ordinative della Marina militare ))

((

1. Ai fini del conseguimento, in concorso con i provvedimenti ordinativi di cui agli articoli 2188-bis e 2188-quater, della contrazione strutturale complessiva non inferiore al 30% imposta dall'articolo 2, comma 1, lettera b), della legge 31 dicembre 2012, n. 244, nonche' per il raggiungimento degli assetti ordinamentali della Marina militare di cui agli articoli dal 110 al 131, sono adottati ai sensi dell'articolo 10, comma 3, sentite, per le materie di competenza, le organizzazioni sindacali rappresentative, i provvedimenti di soppressione, ovvero di riconfigurazione, di comandi, enti e altre strutture ordinative di Forza armata, rispettivamente specificati nelle lettere a) e b), secondo la tempistica affianco di ciascuno di essi indicata:

- a) provvedimenti di soppressione: 1) Comando militare marittimo autonomo in Sardegna, entro il 31 marzo 2014; 2) Comando servizi base/COMAR con sede a Brindisi, entro il 31 marzo 2014; 3) Sezione di commissariato militare marittimo di Cagliari, entro il 31 dicembre 2014;
- b) provvedimenti di riconfigurazione: 1) la Brigata San Marco-Comando forza da sbarco, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Comando servizi base/COMAR con sede a Brindisi; 2) il Comando in capo del dipartimento militare marittimo dell'alto Tirreno, entro il 31 marzo 2014, e' riconfigurato in Comando marittimo Nord, in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti alla soppressione del Comando militare marittimo autonomo in Sardegna; 3) il Comando in capo del dipartimento militare marittimo dello Ionio e del Canale d'Otranto, entro il 31 marzo 2014, e' riconfigurato in Comando marittimo Sud in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 4) il Comando militare marittimo autonomo in Sicilia, entro il 31 marzo 2014, e' riconfigurato in Comando marittimo Sicilia; 5) il Comando militare marittimo autonomo della Capitale, entro il 31 marzo 2014, e' riconfigurato in Comando marittimo Capitale; 6) il Comando servizi base di Taranto, entro il 31 marzo 2014, e' riconfigurato in Comando stazione navale Taranto, in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti all'accorpamento e all'assorbimento delle funzioni della Direzione del supporto diretto dell'Arsenale militare marittimo di Taranto; 7) il Comando servizi base di Augusta (SR), entro il 31 marzo 2014, e' riconfigurato in Comando stazione navale Augusta, in ragione della rideterminazione e razionalizzazione delle relative attribuzioni conseguenti all'accorpamento e all'assorbimento delle funzioni della Direzione del supporto diretto dell'Arsenale militare marittimo di Augusta; 8) il Servizio Sanitario del Comando servizi base di La Spezia, entro il 31 marzo 2014, e' riconfigurato in Infermeria presidiaria di La Spezia in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 9) il Sezione Sanitaria del Comando servizi base di Taranto, entro il 31 marzo 2014, e' riconfigurato in Infermeria presidiaria di Taranto in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 10) il Servizio Sanitario del Comando servizi base di Augusta (SR), entro il 31 marzo 2014, e' riconfigurato in Infermeria presidiaria Augusta in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 11) il Servizio Sanitario del Distaccamento Marina militare di Roma, entro il 31 marzo 2014, e' riconfigurato in Infermeria presidiaria di Roma in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 12) il Comando supporto logistico, entro il 31 marzo 2014, assume le funzioni di supporto logistico della base di Cagliari precedentemente svolte dal soppresso Comando militare marittimo autonomo in Sardegna; 13) la Sezione Fari di Napoli del Comando Zona Fari di Taranto, entro il 31 marzo 2014, e' riconfigurata in Comando Zona Fari di Napoli; 14) il Distaccamento della Marina militare di Napoli, entro il 31 marzo 2014, e' riconfigurato in Quartier generale Marina Napoli in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 15) il Distaccamento della Marina militare di Messina, entro il 31 marzo 2014, e' riconfigurato in Nucleo supporto logistico Messina in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 16) l'Ufficio allestimento e collaudo nuove navi, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 17) la Brigata San Marco-Comando forza da sbarco, entro il 31 dicembre 2015, e' riconfigurato in ragione del transito delle funzioni e delle strutture della Sezione staccata di supporto diretto di Brindisi che conseguentemente cambia dipendenza; 18) l'Arsenale Militare Marittimo di Taranto, entro il 31 dicembre 2015, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle attribuzioni funzionali al nuovo assetto ordinamentale; 19) l'Arsenale Militare Marittimo di La Spezia, entro il 31 dicembre 2015, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 20) l'Arsenale Militare Marittimo di Augusta (SR), entro il 31 dicembre 2015, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 21) il Centro di supporto e sperimentazione navale, entro il 31 dicembre 2015, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 22) il Centro interforze studi per le applicazioni militari, entro il 31 dicembre 2015, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 23) il Centro interforze munizionamento avanzato, entro il 31 dicembre 2015, e' riconfigurato in ragione in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale.

2. Gli ulteriori provvedimenti ordinativi di soppressione o riconfigurazione di strutture di Forza armata non direttamente disciplinate nel codice o nel regolamento, nonche' le altre soppressioni o riconfigurazioni consequenziali all'attuazione dei provvedimenti di cui al comma 1, lettere a) e b), sono adottati, per quanto di rispettiva competenza e nell'esercizio della propria ordinaria potesta' ordinativa, previa informativa, per le materie di competenza, alle organizzazioni sindacali rappresentative, dal Capo di stato maggiore della Marina militare, nell'ambito delle direttive del Capo di Stato maggiore della difesa, e concorrono, unitamente a quelli di cui al comma 1, al conseguimento della contrazione strutturale complessiva non inferiore al 30%.

))

#### Art. 2188-quater. - Disposizioni transitorie in materia di provvedimenti di soppressione e di riconfigurazione di comandi, enti e altre strutture ordinative dell'Aeronautica militare

1. Ai fini del conseguimento, in concorso con i provvedimenti ordinativi di cui agli articoli 2188-bis e 2188-ter, della contrazione strutturale complessiva non inferiore al 30% imposta dall'articolo 2, comma 1, lettera b), della legge 31 dicembre 2012, n. 244, nonche' per il raggiungimento degli assetti ordinamentali dell'Aeronautica militare di cui agli articoli dal 139 al 154, sono adottati ai sensi dell'articolo 10, comma 3, sentite, per le materie di competenza, le organizzazioni sindacali rappresentative, i provvedimenti di soppressione, ovvero di riconfigurazione, di comandi, enti e altre strutture ordinative di Forza armata, rispettivamente specificati nelle lettere a) e b), secondo la tempistica affianco di ciascuno di essi indicata:

- a) provvedimenti di soppressione: 1) 50° Stormo con sede a Piacenza, entro il 31 dicembre ((2016)); 2) Distaccamento Aeroportuale con sede a Elmas (CA), entro il 31 dicembre 2015;
- b) provvedimenti di riconfigurazione: 1) il Comando logistico, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 2) l'Ispettorato per la sicurezza del volo con sede a Roma, entro il 31 marzo 2014, e' riconfigurato in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; 3) il 41° Stormo con sede a Sigonella (CT), entro il 31 marzo 2014, e' riconfigurato in ragione dei compiti / funzioni da assolvere in area operativa; 4) il Distaccamento Aeroportuale con sede a Pantelleria (TP), entro il 31 marzo 2014, e' riconfigurato e' razionalizzato nelle strutture e relativi organici; 5) il Distaccamento Aeroportuale di Brindisi, entro il 31 marzo 2014, e' riconfigurato in ragione dei compiti / funzioni da assolvere; 6) il 9° Stormo con sede a Grazzanise (CE), entro il 31 dicembre 2014, e' riconfigurato per assumere le funzioni aggiuntive di Quartier Generale Interforze a favore degli assetti NATO co ubicati; 7) la Direzione di Amministrazione con sede a Bari, entro il 31 dicembre 2015, e' riconfigurata in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale, ed e' ricollocata a Roma; 8) Scuola Volontari di truppa dell'Aeronautica militare con sede a Taranto, entro il 31 dicembre 2015, e' riconfigurata in ragione della rideterminazione e razionalizzazione delle relative attribuzioni funzionali al nuovo assetto ordinamentale; ((8-bis) Poligono interforze di Salto di Quirra (Ogliastra), entro il 31 maggio 2016 e' riconfigurato e razionalizzato in riduzione nelle strutture e relativi organici.))

2. Gli ulteriori provvedimenti ordinativi di soppressione o riconfigurazione di strutture di Forza armata non direttamente disciplinate nel codice o nel regolamento, nonche' le altre soppressioni o riconfigurazioni consequenziali all'attuazione dei provvedimenti di cui al comma 1, lettere a) e b), sono adottati, per quanto di rispettiva competenza e nell'esercizio della propria ordinaria potesta' ordinativa, previa informativa, per le materie di competenza, alle organizzazioni sindacali rappresentative, dal Capo di stato maggiore dell'Aeronautica militare, nell'ambito delle direttive del Capo di Stato maggiore della difesa, e concorrono, unitamente a quelli di cui al comma 1, al conseguimento della contrazione strutturale complessiva non inferiore al 30%.

#### Art. 2188-quinquies. - Disposizioni transitorie attuative dei programmi di revisione dello strumento militare nazionale

1. Il Ministro della difesa nei tre mesi precedenti l'adozione dei provvedimenti di soppressione, ovvero di riconfigurazione previsti dagli articoli 2188-bis, 2188-ter e 2188-quater, promuove incontri con le organizzazioni sindacali rappresentative per i casi di reimpiego del personale civile ivi in servizio, secondo i criteri e le procedure fissati dal vigente contratto collettivo nazionale di lavoro del personale del comparto Ministeri, e favorisce, nei limiti degli ordinari stanziamenti di bilancio, l'attivazione di programmi di riconversione professionale.

2. I reimpieghi di cui al comma 1 avvengono senza nuovi o maggiori oneri per la finanza pubblica.

3. Senza nuovi maggiori oneri per la finanza pubblica, attraverso le strutture e il personale esistenti, lo Stato maggiore della difesa svolge le funzioni di direzione e monitoraggio del processo di attuazione dei provvedimenti di soppressione e di riconfigurazioni previsti dagli articoli 2188-bis), 2188-ter) e 2188-quater) nonche', in caso di comprovate e sopravvenute necessita', quelle connesse all'individuazione e all'attuazione di eventuali provvedimenti correttivi al programma di contrazione strutturale in modo da assicurare, in ogni caso, gli obiettivi di riduzione fissati dall'articolo 2, comma 1, lettera b), della legge 31 dicembre 2012, n. 244.

4. Nell'ambito della relazione annuale al Parlamento prevista dall'articolo 12, comma 2, sullo stato di avanzamento del programma di soppressioni e riorganizzazioni delle strutture militari di vertice, operative, logistiche, territoriali, formative e infrastrutturali, di cui agli articoli 2188-bis, 2188-ter e 2188-quater, il Ministro della difesa da' evidenza, a consuntivo, tenuti presente anche i provvedimenti ordinativi adottati negli anni precedenti, degli effettivi risultati conseguiti sul piano delle riduzioni della spesa, fermo restando quanto previsto dall'articolo 4, comma 1, della legge 31 dicembre 2012, n. 244.

5. Con cadenza annuale, presso il Ministero della difesa, sono svolti incontri, per le materie di competenza, con ((le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)) e le organizzazioni sindacali rappresentative sullo stato di attuazione del programma di revisione dello strumento militare nazionale.

#### Art. 2189. - Competenze residuali della Direzione generale per il personale militare

1. La Direzione generale per il personale militare provvede, quanto ai volontari in ferma breve, alle residuali competenze che risultassero ancora pendenti alla data di entrata in vigore del presente codice, in ordine all'assegnazione di questi ultimi alle Forze armate e la loro predesignazione per l'immissione nelle Forze di polizia a ordinamento militare e civile e nelle amministrazioni, nonche' al loro impiego.

#### Art. 2190. - Unita' produttive e industriali dell'Agenzia industrie difesa

1. I contributi a favore dell'Agenzia industrie difesa, di cui all'articolo 559, sono determinati per gli importi, rispettivamente, di euro 5.500.000 nell'anno 2012, euro 3.800.000 nell'anno 2013 e euro 3.000.000 nell'anno 2014; a decorrere dall'anno 2015 i suddetti contributi sono soppressi. PERIODO SOPPRESSO DAL D.L. 20 GIUGNO 2017, N. 91, CONVERTITO CON MODIFICAZIONI DALLA L. 3 AGOSTO 2017, N. 123. (29) (43)

1-bis. Allo scopo di conseguire il processo di risanamento del sistema costituito dalle unita' produttive di cui all'articolo 48, comma 1, l'Agenzia predispone, entro il 31 dicembre 2017, un piano industriale triennale, da approvare con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze, che individui le progressive misure volte a realizzare sinergie gestionali nell'ambito della propria attivita' anche attraverso il conseguimento della complessiva capacita' di operare dell'Agenzia medesima secondo criteri di economica gestione. Al termine del predetto triennio, il Ministro della difesa, d'intesa con il Ministro dell'economia e delle finanze, opera una verifica della sostenibilita' del sistema industriale dell'Agenzia e, in sede di approvazione del nuovo piano industriale triennale, individua le unita' produttive i cui risultati compromettono la stabilita' del sistema ed il conseguimento dell'economica gestione dell'Agenzia e per le quali il Ministero della difesa procede alla liquidazione coatta amministrativa.

2. L'articolo 144 del regolamento cessa di avere efficacia a decorrere dalla data di eventuale chiusura ovvero di trasferimento all'Agenzia dell'ultimo degli enti dipendenti ((dalla Direzione nazionale degli armamenti)) di cui al medesimo articolo.

3. L'Agenzia industrie difesa e' autorizzata a prorogare i contratti di cui all'articolo 143, comma 3, del regolamento, comunque non oltre la scadenza del 31 dicembre 2014 e, in ogni caso, entro i limiti della spesa gia' sostenuta nell'anno 2011 per tale tipologia di contratti, ridotta per gli anni 2012, 2013 e 2014, rispettivamente, del dieci per cento, del venti per cento e del trenta per cento. (29) (33) (43)

3-bis. Ai fini del conseguimento dell'obiettivo della sostenibilita' finanziaria attraverso lo sviluppo del piano industriale di cui al comma 1-bis, l'Agenzia e' autorizzata a prorogare, fino al 31 dicembre 2018, i contratti di cui all'articolo 143, comma 3, del testo unico di cui al decreto del Presidente della Repubblica 15 marzo 2010, n. 90, entro il limite stabilito ai sensi dell'articolo 1, comma 379, della legge 23 dicembre 2014, n. 190. Agli oneri derivanti dall'attuazione del presente comma, pari a 540.000 euro per l'anno 2018, si provvede mediante corrispondente riduzione delle risorse del fondo di cui all'articolo 616 del presente codice.

--------------- AGGIORNAMENTO (29) La L. 23 dicembre 2014, n. 190 ha disposto (con l'art. 1, comma 379) che "Anche ai fini della valorizzazione degli investimenti effettuati e della salvaguardia dei livelli occupazionali, il termine di cui all'articolo 2190, comma 1, del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, e' prorogato al bilancio 2016, assicurando una riduzione delle spese per il personale con contratto a tempo determinato dell'Agenzia industrie difesa non inferiore al 60 per cento rispetto alla spesa sostenuta nell'anno 2014. Conseguentemente, l'ulteriore termine di cui al comma 3 del citato articolo 2190 del codice di cui al decreto legislativo n. 66 del 2010, e successive modificazioni, e' prorogato al 31 dicembre 2015 per non oltre un terzo dei contratti stipulati ai sensi dell'articolo 143, comma 3, del testo unico di cui al decreto del Presidente della Repubblica 15 marzo 2010, n. 90". --------------- AGGIORNAMENTO (33) La L. 23 dicembre 2014, n. 190, come modificata dal D.L. 30 dicembre 2015, n. 210, convertito con modificazioni dalla L. 25 febbraio 2016, n. 21, ha disposto (con l'art. 1, comm 379) che "Anche ai fini della valorizzazione degli investimenti effettuati e della salvaguardia dei livelli occupazionali, il termine di cui all'articolo 2190, comma 1, del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, e' prorogato al bilancio 2016, assicurando una riduzione delle spese per il personale con contratto a tempo determinato dell'Agenzia industrie difesa non inferiore al 60 per cento rispetto alla spesa sostenuta nell'anno 2014. Conseguentemente, l'ulteriore termine di cui al comma 3 del citato articolo 2190 del codice di cui al decreto legislativo n. 66 del 2010, e successive modificazioni, e' prorogato al 31 dicembre 2016 per non oltre un terzo dei contratti stipulati ai sensi dell'articolo 143, comma 3, del testo unico di cui al decreto del Presidente della Repubblica 15 marzo 2010, n. 90. Gli uffici dirigenziali di livello non generale dell'Agenzia industrie difesa previsti dal decreto del Presidente del Consiglio dei ministri 13 gennaio 2014, pubblicato nella Gazzetta Ufficiale n. 94 del 23 aprile 2014, sono rideterminati in 12 unita'". ------------ AGGIORNAMENTO (43) La L. 23 dicembre 2014, n. 190, come modificata dal D.L. 30 dicembre 2016, n. 244, convertito con modificazioni dalla L. 27 febbraio 2017, n. 19, ha disposto (con l'art. 1, comma 379) che "Anche ai fini della valorizzazione degli investimenti effettuati e della salvaguardia dei livelli occupazionali, il termine di cui all'articolo 2190, comma 1, del codice di cui al decreto legislativo 15 marzo 2010, n. 66, e successive modificazioni, e' prorogato al bilancio 2017, assicurando una riduzione delle spese per il personale con contratto a tempo determinato dell'Agenzia industrie difesa non inferiore al 60 per cento rispetto alla spesa sostenuta nell'anno 2014. Conseguentemente, l'ulteriore termine di cui al comma 3 del citato articolo 2190 del codice di cui al decreto legislativo n. 66 del 2010, e successive modificazioni, e' prorogato al 31 dicembre 2017 per non oltre un terzo dei contratti stipulati ai sensi dell'articolo 143, comma 3, del testo unico di cui al decreto del Presidente della Repubblica 15 marzo 2010, n. 90. Gli uffici dirigenziali di livello non generale dell'Agenzia industrie difesa previsti dal decreto del Presidente del Consiglio dei ministri 13 gennaio 2014, pubblicato nella Gazzetta Ufficiale n. 94 del 23 aprile 2014, sono rideterminati in 12 unita'".

#### Art. 2191. - Magistrati militari in posizione di fuori ruolo

1. I magistrati militari che risultavano collocati in posizione di fuori ruolo alla data del 28 settembre 2007 e che, alla data di entrata in vigore del presente codice, risultano ancora collocati nella medesima posizione, sono considerati in soprannumero riassorbibile nello stesso ruolo della magistratura militare.

2. I magistrati di cui al comma 1 all'atto del rientro in ruolo hanno facolta' di esercitare interpello per il transito in magistratura ordinaria secondo le seguenti modalita':

- a) hanno diritto a essere assegnati, anche in soprannumero riassorbibile, a un ufficio giudiziario della stessa sede di servizio, ovvero a altro ufficio giudiziario ubicato in una delle citta' sede di corte d'appello con conservazione dell'anzianita' e della qualifica maturata, a funzioni corrispondenti a quelle svolte in precedenza con esclusione di quelle direttive e semidirettive eventualmente ricoperte;
- b) i trasferimenti sono disposti con decreto interministeriale del Ministro della difesa e del Ministro della giustizia, previa conforme deliberazione del Consiglio della magistratura militare e del Consiglio superiore della magistratura.

3. Se i magistrati militari di cui al comma 1 non esercitano il diritto all'interpello di cui al comma 2, vengono assegnati allo stesso ufficio giudiziario militare in precedenza ricoperto o, a domanda, a ufficio di altra sede di servizio, anche in soprannumero.

4. Ai trasferimenti disposti in applicazione del presente articolo non si applica l'articolo 194 dell'ordinamento giudiziario, di cui al regio decreto 30 gennaio 1941, n. 12.

5. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con proprio decreto, le variazioni necessarie in diminuzione sugli stanziamenti del Ministero della difesa, in relazione al decremento eventuale degli organici dei magistrati militari e in aumento sui corrispondenti stanziamenti del Ministero della giustizia, in relazione al corrispondente eventuale incremento degli organici dei magistrati ordinari.

#### Art. 2192. - Determinazione della dotazione organica dell'ufficio di segreteria del Consiglio della magistratura militare

1. Con decreto del Presidente della Repubblica e' rideterminata la dotazione organica dell'ufficio di segreteria del Consiglio della magistratura militare, in riduzione rispetto a quella vigente.

### SEZIONE II - BENI

#### Art. 2193. - Porti militari

1. In via transitoria, fino alla pubblicazione del decreto previsto dall'articolo 238, comma 2, sono porti o specifiche aree portuali destinati unicamente o principalmente alla difesa militare quelli gia' in consegna al Ministero della difesa alla data di entrata in vigore del presente codice, e il cui elenco e' recato dall'articolo 1120 del regolamento.

#### Art. 2194. - Disciplina transitoria in materia di acquisti a seguito di confisca

1. Le disposizioni di cui all'articolo 319 si applicano anche alle armi, alle munizioni, agli esplosivi e agli altri materiali di interesse militare per i quali, anteriormente alla data di entrata in vigore della legge 3 agosto 2009, n. 108, e' stata disposta ma non ancora eseguita la distruzione.

### SEZIONE III - AMMINISTRAZIONE E CONTABILITA'

#### Art. 2195. - (( (Contributi a favore di Associazioni combattentistiche).))

((

1. Al fine di sostenere le finalita' istituzionali e le attivita' di promozione sociale e di tutela degli associati delle Associazioni combattentistiche, sottoposte alla vigilanza del Ministero della difesa, di cui alla legge 31 gennaio 1994, n. 93, e' autorizzata la spesa di 1 milione di euro per ciascuno degli anni 2017, 2018 e 2019.

))

#### Art. 2195-bis. - (( Finanziamento dello sviluppo tecnologico nel settore aeronautico) ))

((

1. Per la prosecuzione degli interventi di cui all'articolo 5 del decreto-legge 17 giugno 1996, n. 321, convertito, con modificazioni, dalla legge 8 agosto 1996, n. 421, e' autorizzato un contributo di 25 milioni di euro per ciascuno degli anni dal 2012 al 2016 e di 125 milioni di euro per ciascuno degli anni 2017 e 2018. Al relativo onere si provvede mediante corrispondente riduzione dell'autorizzazione di spesa di cui all'articolo 2, comma 180, della legge 24 dicembre 2007, n. 244.

))

#### Art. 2195-ter. - (( (Sperimentazione di misure di flessibilita' gestionale della spesa). ))

((

1. In attuazione dell'articolo 4, comma 1, lettera e), della legge 24 dicembre 2012, n. 244, nelle more del completamento della riforma di cui all'articolo 40, comma 2, lettera p), della legge 31 dicembre 2009, n. 196, e tenuto conto di quanto previsto dall'articolo 15, comma 8, della legge 24 dicembre 2012, n. 243, il Ministero della difesa puo' continuare a utilizzare le correnti modalita' di gestione delle risorse necessarie per il funzionamento delle strutture periferiche.

2. Ai fini dell'accertamento dei risparmi di spesa di cui all'articolo 4, comma 1, lettera c), della legge n. 244 del 2012, il Ministro della difesa predispone annualmente un piano di attuazione pluriennale delle misure da adottare, che contiene in apposita relazione tecnica la quantificazione dei possibili risparmi derivanti dalle misure e da destinare al riequilibrio dei settori di spesa del Dicastero nel corso dell'esercizio finanziario.

3. L'effettivo conseguimento dei risparmi derivanti dalla realizzazione del piano di cui al comma 2 e' sottoposto alla verifica del Ministero dell'economia e delle finanze-Dipartimento della Ragioneria generale dello Stato, anche al fine di garantire l'invarianza sui saldi di finanza pubblica. I risparmi accertati sono destinati all'incremento dei fondi di cui all'articolo 619, anche mediante versamento all'entrata per la quota relativa al primo anno del piano di attuazione.

))

#### Art. 2195-quater. - (( (Contabilita' speciale unica della Difesa). ))

((

1. Per la gestione della contabilita' speciale unica del Ministero della difesa istituita ai sensi dell'articolo 11-bis del decreto legislativo 12 maggio 2016, n. 90, la Direzione di amministrazione interforze e' ridenominata Direzione di amministrazione generale della Difesa, e' collocata nell'ambito dello Stato maggiore della difesa e, per le funzioni connesse all'accreditamento agli enti, alla rendicontazione e al controllo, si avvale delle esistenti direzioni di amministrazione delle Forze armate.

2. In quanto compatibili, continuano ad applicarsi le disposizioni vigenti in materia di contabilita' speciali di cui agli articoli da 498 a 507, 508, commi 1, 3, 4 e 5, 509, da 511 a 514, 521, 522 e 524 del regolamento di cui al decreto del Presidente della Repubblica 15 marzo 2010, n. 90.

3. All'attuazione delle disposizioni del presente articolo l'amministrazione provvede con le risorse umane, strumentali e finanziarie disponibili a legislazione vigente, senza nuovi o maggiori oneri a carico della finanza pubblica.

))

### SEZIONE IV - PERSONALE MILITARE Parte I Reclutamento

#### Art. 2196. - Immissioni in ruolo degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. Finche' le consistenze effettive dei ruoli non siano contenute entro le dotazioni organiche fissate dal presente codice, per realizzare le economie previste dall'articolo 1, comma 97, lettera h), della legge n. 662 del 1996, i moduli complessivi di alimentazione dei ruoli degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare non devono superare la misura del 70% dei moduli complessivi previsti per ciascuna Forza armata dalle norme vigenti anteriormente alla data del 1997.

#### Art. 2196-bis. - Regime transitorio dei reclutamenti degli ufficiali dei ruoli speciali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare).

1. Sino all'anno ((2033)), per la partecipazione ai concorsi per il reclutamento degli ufficiali dei ruoli speciali, di cui all'articolo 655, riservati al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, con decreti del Ministro della difesa, di concerto con il Ministro delle infrastrutture e dei trasporti se riguardano anche il Corpo delle capitanerie di Porto, possono essere stabiliti per ciascuna Forza armata:

- a) limiti di eta', comunque non superiori a 52 anni;
- b) titoli di studio non inferiori al diploma di istruzione secondaria di secondo grado;
- c) estensione anche ai volontari in servizio permanente;
- d) permanenza minima nel ruolo di provenienza, sino a un massimo di 5 anni.

1-bis. Sino ai concorsi banditi per le immissioni dell'anno 2022, in deroga a quanto previsto dall'articolo 655-bis, il concorso per l'accesso al ruolo speciale degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare riservato ai luogotenenti in servizio e' svolto per soli titoli e con il possesso del diploma di istruzione secondaria di secondo grado.

1-ter. Le commissioni esaminatrici, istituite presso ciascuna Forza armata secondo le modalita' definite dall'articolo 668, comma 1, lettere a), b) e c), valutano:

- a) i titoli relativi alle qualita' militari e professionali;
- b) ogni altro titolo, ricompensa e benemerenza risultanti dallo stato di servizio, dal libretto personale, dalla pratica personale ovvero presentati dai concorrenti tra quelli espressamente indicati nel bando di concorso;

1-quater. Ai fini della formazione della graduatoria finale, la valutazione dei titoli di cui al comma 1-ter, che devono essere posseduti dai candidati entro la data di presentazione della domanda, comporta l'assegnazione di massimo di 45 punti, dei quali non piu' di 30 per i titoli di cui alla lettera a) e non piu' di 15 per quelli di cui alla lettera b). Ogni membro della commissione esaminatrice dispone per ciascuno dei titoli di un terzo del punteggio massimo per i medesimi stabilito. I candidati che non hanno riportato almeno 15 punti per i titoli di cui alla lettera a) sono dichiarati non idonei. 1-quinques. Il limite di eta' di cui al comma 1, lettera a):

- a) fino all'anno 2024, e' innalzato a 55 anni per il reclutamento nel ruolo speciale del Corpo sanitario dell'Esercito italiano;
- b) negli anni 2020, 2021 e 2022 non si applica ai concorrenti di cui all'articolo 655, comma 1, lettera b).

#### Art. 2196-ter. - (Disposizioni transitorie in materia di reclutamento del ruolo normale dell'Arma dei carabinieri)

1. In relazione alla graduale riduzione delle consistenze del ruolo speciale dell'Arma dei carabinieri, ferme restando le consistenze organiche di cui all'articolo 800, al fine della progressiva armonizzazione dei ruoli degli ufficiali dell'Arma dei carabinieri, le immissioni nel ruolo normale sono annualmente determinate con decreto del Ministro della difesa, in ragione dell'andamento delle consistenze effettive dei ruoli normale e speciale a esaurimento come determinatesi all'esito dei transiti di cui all'articolo 2214-quinquies.

2. Fino all'anno 2022 compreso, per la partecipazione ai concorsi di cui all'articolo 651-bis, comma 1, lettera b), sono necessari i seguenti requisiti:

- a) grado di luogotenente in servizio permanente, senza alcun limite d'eta';
- b) diploma di scuola secondaria di 2° grado o equipollente;
- c) qualifica finale non inferiore a «eccellente» nell'ultimo quinquennio.

3. Fino all'anno 2022 compreso, per la partecipazione ai concorsi di cui all'articolo 651-bis, comma 1, lettera c), sono necessari i seguenti requisiti:

- a) avere almeno cinque anni di servizio e non aver superato il quarantacinquesimo anno di eta';
- b) possesso di laurea triennale ((...)) definita con determinazione del Comandante generale dell'Arma dei carabinieri;
- c) qualifica finale non inferiore a «eccellente» nell'ultimo biennio.

4. Dall'anno 2028 compreso, le previsioni contenute nell'articolo 651-bis, inerenti ai ruoli degli ispettori, dei sovrintendenti e degli appuntati e carabinieri, si applicano anche ai corrispondenti ruoli forestali dell'Arma dei carabinieri.

#### Art. 2196-quater. - (Disposizioni transitorie in materia di reclutamento del ruolo forestale dell'Arma dei carabinieri)

1. Fino all'anno 2022 compreso, per i militari in servizio permanente dell'Arma dei carabinieri dei ruoli forestali ((degli ispettori, dei sovrintendenti, degli appuntati e carabinieri, dei periti, dei revisori e degli operatori e collaboratori,)), il limite di eta' di cui all'articolo 664-bis, comma 1, lettera b), e' fissato in cinquanta anni.

#### Art. 2196-quinquies. - (Disposizioni transitorie in materia di reclutamento dell'Arma dei carabinieri)

1. Fino all'anno 2021 compreso:

- a) nel limite delle vacanze organiche registrate nel ruolo ispettori alla data del 31 dicembre dell'anno precedente, i posti disponibili per il corso previsto dall'articolo 685 possono essere incrementati fino al 50 per cento dei limiti fissati dall'articolo 679, comma 2-bis, lettere b) e c);
- b) la durata dei corsi di cui agli articoli 685, 775 e 776 puo' essere ridotta fino alla meta';
- c) per il personale che ha maturato almeno 8 anni di permanenza nel ruolo sovrintendenti, promosso al termine del corso di cui all'articolo 685, non si applica l'articolo 979;
- d) non si applica quanto previsto dall'articolo 683, comma 5, lettera a);
- e) in deroga al requisito richiesto dall'articolo 683, comma 5, lettera b), per la partecipazione al concorso interno previsto dall'articolo 679, comma 2-bis, lettera c), il titolo di studio richiesto e' il diploma di istruzione secondaria di secondo grado.

2. Gli incrementi di cui al comma 1, lettera a), con solo riferimento al concorso bandito per l'anno 2017, possono essere portati fino alla copertura del 50 per cento delle vacanze organiche registrate nel ruolo ispettori al 1° gennaio 2017 con riferimento alle dotazioni organiche previste dal presente codice per il predetto personale.

3. I posti del concorso di cui al comma 2 sono riservati per:

- a) l'ottantacinque per cento, al ruolo sovrintendenti;
- b) il quindici per cento, al ruolo iniziale.

3-bis. Gli appuntati scelti possono partecipare a uno dei due concorsi di cui all'articolo 692 banditi fino all'anno 2021. ((I brigadieri capo possono partecipare a uno dei due concorsi di cui all'articolo 679, comma 2-bis, lettera b), banditi fino all'anno 2021.))

3-ter. Nei concorsi di cui al comma 3-bis, tra i titoli di merito assume particolare rilevanza, per quanto concerne l'attribuzione del relativo punteggio, essere risultati idonei ma non vincitori in un concorso analogo.

3-quater. ((COMMA SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)).

((

3-quinquies. Il ruolo dei sovrintendenti dell'Arma dei carabinieri, in deroga a quanto previsto dall'articolo 690, comma 4, e' incrementato, con le modalita' di cui all'articolo 692, per 3.500 unita' soprannumerarie complessive, suddivise in:

- a) 500 unita' per l'anno 2020, di cui 450 tratte dagli appartenenti ai ruoli iniziali in servizio permanente che ricoprano il grado apicale e 50 da quelli che ricoprano gli altri gradi;
- b) 600 unita' per ciascuno degli anni 2021 e 2022, di cui 550 tratte dagli appartenenti ai ruoli iniziali in servizio permanente che ricoprano il grado apicale e 50 da quelli che ricoprano gli altri gradi;
- c) 900 unita' per ciascuno degli anni 2023 e 2024, di cui 850 tratte dagli appartenenti ai ruoli iniziali in servizio permanente che ricoprano il grado apicale e 50 da quelli che ricoprano gli altri gradi.

))

((

3-sexies. Al fine del completo riassorbimento delle unita' soprannumerarie di cui al precedente comma, il numero massimo delle stesse e' fissato:

- a) al 31 dicembre 2025, in 2.900 unita';
- b) al 31 dicembre 2026, in 2.300 unita';
- c) al 31 dicembre 2027, in 1.700 unita';
- d) al 31 dicembre 2028, in 1.100 unita';
- e) al 31 dicembre 2029, in 500 unita';
- f) al 31 dicembre 2030, in 0 unita'. Fino al 31 dicembre 2024, la durata dei corsi di cui agli articoli 775 e 776 puo' essere ridotta fino alla meta'.

))

#### Art. 2197. - Regime transitorio del reclutamento nel ruolo marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. Sino all'anno ((2033)), fatti salvi i concorsi gia' banditi o in via di espletamento, il reclutamento nel ruolo marescialli avviene, in deroga alle disposizioni di cui all'articolo 679, comma 1, in misura:

- a) non superiore al 70 per cento dei posti disponibili in organico mediante concorso pubblico;
- b) non inferiore al 30 per cento dei posti disponibili in organico mediante concorso interno, riservato agli appartenenti al ruolo dei sergenti e al ruolo dei volontari in servizio permanente, secondo quanto previsto dall'articolo 682, comma 5.

1-bis. Sino all'anno ((2033)), il limite di eta' per la partecipazione al concorso di cui al comma 1, lettera b), e' elevato a 52 anni.

2. I posti di cui al comma 1, lettera a) rimasti scoperti possono essere devoluti in aumento al numero dei posti di cui alla lettera b) e viceversa.

2-bis. COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173.

2-ter. COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173.

2-quater. Le norme per lo svolgimento dei concorsi di cui al presente articolo , comprese la definizione degli eventuali ulteriori requisiti, dei titoli e delle prove, la loro valutazione, la nomina delle commissioni e la formazione delle graduatorie sono stabilite con decreto del Ministro della difesa, di concerto col Ministro delle infrastrutture e dei trasporti per la parte riferita al Corpo delle capitanerie di porto.

3. COMMA ABROGATO DAL D.LGS. 26 APRILE 2016, N. 91.

#### Art. 2197-bis. - (Regime transitorio della valutazione delle consistenze organiche ai fini delle immissioni in alcuni ruoli delle Forze armate)

1. Sino all'anno ((2033)), per le immissioni annuali nei ruoli dei marescialli, dei sergenti e dei volontari in servizio permanente si tiene conto delle vacanze complessive esistenti nei predetti ruoli rispetto alle dotazioni organiche transitorie complessive nei medesimi ruoli previste per ciascuna Forza armata.

#### Art. 2197-ter. - (Concorso straordinario per il ruolo dei Marescialli)

1. In deroga a quanto previsto dall'articolo 682, per il solo anno 2018 e' bandito un concorso straordinario per titoli ed esami per il reclutamento nei ruoli dei Marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare.

2. Il concorso di cui al comma 1 e' riservato al solo personale appartenente ai ruoli sergenti e volontari in servizio permanente arruolato ai sensi della legge 24 dicembre 1986, n. 958, e successive modificazioni, e transitato in servizio permanente ai sensi degli articoli 35, comma 2, e 36, del decreto legislativo 12 maggio 1995, n. 196, anche in deroga ai vigenti limiti di eta', in servizio alla data del 31 dicembre 2016 e in possesso dei seguenti requisiti:

- a) diploma di istruzione secondaria di primo grado;
- b) non aver riportato nell'ultimo biennio sanzioni disciplinari piu' gravi della consegna.

3. Con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, e' stabilito il numero dei posti a concorso ripartiti per ruoli di provenienza e per Forza armata di appartenenza.

4. In relazione alla natura straordinaria del concorso:

- a) i vincitori sono immessi nel ruolo dei marescialli con il grado di maresciallo e corrispondenti con le seguenti decorrenze: 1) se provenienti dal ruolo dei sergenti: 1° gennaio 2018; 2) se provenienti dal ruolo dei volontari in servizio permanente: 1° luglio 2018;
- b) i vincitori del concorso sono tenuti a frequentare un corso di formazione della durata massima di tre mesi, qualora ritenuto indispensabile dalla Forza armata di appartenenza nel grado di maresciallo;
- c) ai vincitori del concorso e' assicurata la permanenza, almeno biennale, nella propria sede di servizio ((; se impiegati in ambito internazionale, all'estero e in Italia, e' assicurata la permanenza nella sede fino al termine del mandato)).

#### Art. 2197-ter.1. - (Reclutamento straordinario per il ruolo dei marescialli)

1. In deroga a quanto previsto dagli articoli 682 e 760 e nell'ambito delle consistenze del personale di ciascuna Forza armata, come determinate per l'anno 2020 ai sensi dell'articolo 2207, e' autorizzato, per il solo anno 2020, il reclutamento, a nomina diretta con il grado di maresciallo o grado corrispondente, mediante concorso per titoli, di n. 60 marescialli in servizio permanente, di cui n. 30 dell'Esercito italiano, n. 15 della Marina militare e n. 15 dell'Aeronautica militare.

2. Il concorso di cui al comma 1 e' riservato al personale in servizio appartenente ai ruoli dei sergenti e dei volontari in servizio permanente, anche in deroga ai vigenti limiti di eta', in possesso dei seguenti requisiti:

- a) laurea per le professioni sanitarie di cui all'articolo 212, comma 1, e relativa abilitazione professionale;
- b) non aver riportato nell'ultimo biennio sanzioni disciplinari piu' gravi della consegna.

3. Le modalita' di svolgimento del concorso, compresi la tipologia e i criteri di valutazione dei titoli di merito ai fini della formazione della graduatoria, sono stabiliti dal bando di concorso.

3-bis. Per i posti eventualmente non coperti con il concorso di cui al comma 1, nell'anno 2021 puo' essere bandito un ulteriore concorso per titoli riservato al medesimo personale di cui al comma 2 e secondo le modalita' di cui al comma 3. Con determinazione del Capo di stato maggiore della difesa, i posti di cui al primo periodo sono ripartiti per Forza armata, nell'ambito delle relative consistenze di personale, come determinate per l'anno 2021 ai sensi dell'articolo 2207.

3-ter. ((Per i posti non coperti con il concorso di cui al comma 3-bis, nell'anno 2024 puo' essere bandito un ulteriore concorso per titoli riservato al medesimo personale di cui al comma 2 e secondo le modalita' di cui al comma 3. Con determinazione del Capo di stato maggiore della difesa, i posti di cui al primo periodo sono ripartiti per Forza armata, nell'ambito delle relative consistenze di personale, come determinate per l'anno 2024 ai sensi dell'articolo 2207)).

#### Art. 2197-quater. - (Concorso straordinario per il ruolo dei marescialli)

1. In deroga a quanto previsto dall'articolo 682, per gli anni dal 2021 al 2023 sono banditi concorsi straordinari per titoli ed esami per un numero complessivo di trecento posti, per il reclutamento nei ruoli dei marescialli dell'Esercito italiano, della Marina militare, compreso il Corpo delle capitanerie di porto, e dell'Aeronautica militare.

2. I concorsi di cui al comma 1 sono riservati ai ((sergenti maggiori aiutanti e qualifiche)) corrispondenti, in possesso dei seguenti requisiti:

- a) la laurea.
- b) aver riportato nell'ultimo triennio in servizio permanente la qualifica di almeno "superiore alla media" o giudizio corrispondente e non aver ricevuto, nel medesimo periodo, sanzioni disciplinari piu' gravi della consegna.

3. Con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, e' stabilita la ripartizione annuale dei posti per Forza armata.

4. I vincitori dei concorsi di cui al comma 1 sono immessi nel ruolo dei marescialli con il grado di maresciallo e, con il medesimo grado, ove ritenuto indispensabile dalla Forza armata di appartenenza, sono tenuti a frequentare un corso di formazione della durata massima di sei mesi.

#### Art. 2197-quinquies. - (( (Disciplina transitoria relativa allo stato giuridico degli allievi marescialli e dei frequentatori). ))

((

1. A decorrere dal 1° gennaio 2020 il personale vincitore dei concorsi di cui all'articolo 679, comma 1, lettera b), appartenente ai ruoli dei sergenti e dei volontari in servizio permanente, gia' ammesso a frequentare i corsi formativi previsti, ne prosegue la frequenza con il grado precedentemente rivestito.

2. Al personale di cui al comma 1, si applicano le disposizioni sullo stato giuridico del rispettivo ruolo di provenienza.

3. I periodi di tempo trascorsi presso le scuole sono computati ai fini dell'anzianita' di servizio.

))

#### Art. 2197-sexies. - (Concorso straordinario per il ruolo dei sergenti)

1. In deroga a quanto previsto dall'articolo 690, per gli anni dal 2021 al 2023 sono banditi concorsi straordinari per titoli ed esami per un numero complessivo di mille posti, per il reclutamento nei ruoli dei Sergenti dell'Esercito italiano, della Marina militare, compreso il Corpo delle Capitanerie di porto e dell'Aeronautica militare.

2. I concorsi di cui al comma 1 sono riservati ai ((graduati aiutanti e qualifiche)) corrispondenti, in possesso dei seguenti requisiti:

- a) diploma quinquennale di istruzione secondaria di secondo grado;
- b) non aver riportato nell'ultimo quadriennio una valutazione inferiore a «superiore alla media» o giudizio corrispondente;
- c) non aver riportato nell'ultimo biennio sanzioni disciplinari piu' gravi della consegna.

3. Con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, e' stabilita la ripartizione annuale dei posti per Forza armata.

4. I vincitori dei concorsi di cui al comma 1 sono immessi nel ruolo dei sergenti con il grado di sergente e, con il medesimo grado, ove ritenuto indispensabile dalla Forza armata di appartenenza, sono tenuti a frequentare un corso di formazione della durata massima di tre mesi.

#### Art. 2198. - (( (Regime transitorio dei concorsi per il reclutamento nei ruoli dei marescialli, dei sergenti e dei volontari in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). ))

((

1. I concorsi banditi prima del 1° gennaio 2017 per il reclutamento di personale in servizio permanente sono espletati e i vincitori conseguono la nomina secondo la normativa vigente prima della stessa data.

))

#### Art. 2198-bis. - (( (Disposizioni transitorie in materia di reclutamento e stato giuridico dei volontari in ferma prefissata di un anno o in rafferma). ))

((

1. I bandi per il reclutamento dei volontari in ferma prefissata di un anno possono essere emanati fino al 31 dicembre 2022.

2. I partecipanti ai reclutamenti di cui al comma 1 debbono possedere i requisiti di cui all'articolo 697.

3. Le modalita' di reclutamento dei volontari in ferma prefissata di un anno sono disciplinate dal decreto del Ministro della difesa 23 aprile 2015, recante disposizioni relative alle procedure per l'arruolamento dei volontari in ferma prefissata di 1 anno (VFP1) dell'Esercito Italiano, della Marina Militare, compreso il Corpo delle Capitanerie di Porto, e dell'Aeronautica Militare, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 12 del 30 aprile 2015. Si applica l'articolo 702 del presente codice.

4. I volontari sono ammessi alla ferma prefissata di un anno in qualita' di soldato, per l'Esercito italiano, comune di 2ª classe, per la Marina militare, o aviere, per l'Aeronautica militare.

5. I volontari in ferma prefissata di un anno reclutati ai sensi del comma 1 possono essere ammessi, a domanda, a un successivo periodo di rafferma della durata di un anno.

6. I criteri e le modalita' di ammissione alla rafferma di cui al comma 5 sono disciplinati dal decreto del Ministro della difesa 28 aprile 2014, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 13 del 10 maggio 2014, come modificato dal decreto del Ministro della difesa 13 luglio 2017, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 22 del 10 agosto 2017.

7. La durata della ferma e della rafferma di cui al presente articolo puo' essere prolungata, con il consenso dell'interessato, per il tempo strettamente necessario al completamento dell'iter concorsuale di coloro che hanno presentato domanda per il reclutamento come volontari in ferma quadriennale.

8. Fino al 31 dicembre 2026 i volontari in ferma prefissata di un anno raffermati e in congedo possono partecipare ai concorsi per il reclutamento dei volontari in ferma prefissata triennale, di cui all'articolo 700.

9. Ai volontari di cui al presente articolo si applicano le disposizioni del presente codice riferite ai volontari in ferma prefissata senza ulteriori specificazioni, nonche':

- a) se volontari in ferma prefissata di un anno, gli articoli 703, 957, comma 1, lettera e-bis), 958, commi 3 e 3-bis, 978, 1502, comma 1, lettere a), numero 1), e b), numero 1), e 1503, comma 2, lettera a);
- b) se volontari in rafferma annuale, gli articoli 703, 1502, comma 1, lettere a), numero 1), e b), numero 1), e 1503, comma 2, lettera b).

10. I decreti di cui ai commi 3 e 6 possono essere modificati con decreto del Ministro della difesa.

))

#### Art. 2198-ter. - (( (Disposizioni transitorie in materia di reclutamento e stato giuridico dei volontari in ferma prefissata quadriennale o in rafferma). ))

((

1. I concorsi per il reclutamento dei volontari in ferma prefissata quadriennale possono essere banditi fino al 31 dicembre 2024.

2. Possono partecipare ai concorsi di cui al comma 1 i volontari in ferma prefissata di un anno, ovvero in rafferma annuale, in servizio o in congedo, in possesso dei seguenti requisiti:

- a) idoneita' fisio-psico-attitudinale per l'impiego nelle Forze armate in qualita' di volontario in servizio permanente;
- b) eta' non superiore a trent'anni compiuti.

3. Le modalita' di svolgimento dei concorsi di cui al comma 1 nonche' la possibilita' di bandire concorsi straordinari destinati ai volontari in ferma prefissata di un anno in possesso di specifici requisiti sono disciplinate dal decreto del Ministro della difesa 23 aprile 2015, recante disposizioni relative alle modalita' di svolgimento dei concorsi per il reclutamento dei volontari in ferma prefissata quadriennale (VFP4) dell'Esercito Italiano, della Marina Militare, compreso il Corpo delle Capitanerie di Porto, e dell'Aeronautica Militare, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 12 del 30 aprile 2015. Si applica l'articolo 702 del presente codice.

4. I volontari sono ammessi alla ferma prefissata quadriennale con il grado di caporale, per l'Esercito italiano, comune di 1ª classe, per la Marina militare, o aviere scelto, per l'Aeronautica militare.

5. I volontari in ferma prefissata quadriennale possono essere ammessi, a domanda:

- a) a due successivi periodi di rafferma, ciascuno della durata di due anni, se reclutati anteriormente all'anno 2017;
- b) a un solo periodo di rafferma biennale, se reclutati negli anni 2017, 2018 e 2019;
- c) a un solo periodo di rafferma annuale, se reclutati nell'anno 2020.

6. Possono presentare domanda per le rafferme di cui al comma 5 i volontari in ferma prefissata quadriennale risultati idonei ma non utilmente collocati nella graduatoria per l'immissione nei ruoli dei volontari in servizio permanente.

7. Le modalita' e i criteri di ammissione alle rafferme di cui al comma 5 sono disciplinati dal decreto del Ministro della difesa 23 aprile 2015, recante disposizioni relative alle procedure per l'ammissione dei volontari in ferma prefissata quadriennale (VFP4) dell'Esercito Italiano, della Marina Militare, compreso il Corpo delle Capitanerie di Porto, e dell'Aeronautica Militare, alle rafferme biennali, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 12 del 30 aprile 2015. I volontari in possesso dei requisiti previsti dal decreto di cui al primo periodo sono ammessi alla rafferma con riserva fino alla definizione della graduatoria di merito.

8. I volontari in rafferma conseguono il grado di graduato o corrispondente, previo giudizio di idoneita', con decorrenza dalla data di ammissione alla rafferma.

9. Al termine della ferma prefissata quadriennale ovvero di ciascun anno delle rafferme di cui al comma 5, i volontari giudicati idonei e utilmente collocati nella graduatoria annuale di merito sono immessi nei ruoli dei volontari in servizio permanente secondo le modalita' stabilite dal decreto del Ministro della difesa 23 aprile 2015, recante disposizioni relative alle modalita' di immissione dei volontari in ferma prefissata quadriennale (VFP4), ovvero in rafferma biennale, dell'Esercito Italiano, della Marina Militare, compreso il Corpo delle Capitanerie di Porto, e dell'Aeronautica Militare nei ruoli dei volontari di truppa in servizio permanente, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 12 del 30 aprile 2015. La ripartizione in misura percentuale dei posti annualmente disponibili nei ruoli dei volontari in servizio permanente tra le categorie di volontari di cui al primo periodo e' stabilita con decreto del Ministro della difesa, riservando non meno del 20 per cento dei medesimi posti al personale in ferma prefissata quadriennale.

10. I volontari in ferma prefissata quadriennale reclutati nell'anno 2021 sono ammessi alle procedure per il transito in servizio permanente al termine della ferma quadriennale secondo le modalita' stabilite dal decreto di cui al comma 9 e, se idonei, conseguono il grado di graduato o corrispondente con decorrenza dal giorno successivo alla data di completamento della ferma quadriennale.

11. I volontari in ferma prefissata quadriennale reclutati negli anni 2022, 2023 e 2024 sono ammessi alle procedure per il transito in servizio permanente al termine della ferma quadriennale secondo le modalita' stabilite all'articolo 704.

12. I volontari in ferma prefissata quadriennale ovvero in rafferma biennale o annuale, che sono stati esclusi dalle procedure di immissione nei ruoli dei volontari in servizio permanente di cui al comma 9 in quanto sottoposti a procedimento penale, nei casi in cui successivamente sia stata disposta l'archiviazione o il procedimento penale si sia concluso con sentenza irrevocabile che dichiari che il fatto non sussiste o che l'imputato non lo ha commesso o che il fatto non costituisce reato, possono presentare domanda di riammissione a tali procedure, secondo le modalita' stabilite dal decreto del Ministro della difesa 26 ottobre 2017, pubblicato nel Giornale ufficiale del Ministero della difesa, dispensa n. 31 del 10 novembre 2017, entro centottanta giorni dalla data in cui il provvedimento e' divenuto irrevocabile. Resta fermo il possesso dei requisiti previsti dalla normativa vigente per la permanenza in servizio.

13. Per i volontari in ferma prefissata quadriennale, il periodo di temporanea inidoneita' al servizio, di cui all'articolo 1503, comma 2, e' computato fino alla misura massima di diciotto mesi.

14. Per i volontari in ferma prefissata quadriennale in rafferma biennale ovvero annuale:

- a) la durata della licenza ordinaria, di cui all'articolo 1502, comma 1, e' la seguente: 1) trentadue giorni lavorativi, se l'orario settimanale di servizio e' distribuito su un periodo di sei giorni; 2) ventotto giorni lavorativi, se l'orario settimanale di servizio e' distribuito su un periodo di cinque giorni;
- b) il periodo di temporanea inidoneita' al servizio, di cui all'articolo 1503, comma 2, e' computato fino alla misura massima di dodici mesi per la rafferma biennale ovvero di sei mesi per la rafferma annuale;
- c) e' possibile fruire del congedo per la formazione di cui all'articolo 5 della legge 8 marzo 2000, n. 53, nei limiti e con le modalita' previste dai provvedimenti di concertazione, emanati ai sensi del decreto legislativo 12 maggio 1995, n. 195, in materia di licenze straordinarie e aspettative. Il personale che fruisce del congedo per la formazione e' posto in licenza straordinaria senza assegni, non compresa nel limite massimo previsto per la licenza straordinaria, e il relativo periodo non e' utile ai fini dell'avanzamento, della maturazione della licenza ordinaria e della determinazione della posizione previdenziale.

15. Ai volontari di cui al presente articolo si applicano le disposizioni del presente codice riferite ai volontari in ferma prefissata senza ulteriori specificazioni, nonche':

- a) se volontari in ferma prefissata quadriennale, gli articoli 703, 842, commi 3 e 3-ter, 1302, 1501, comma 1, terzo periodo, 1502, commi 1, lettera a), numero 2), e lettera b), numero 2), 2, 3 e 4, lettera b), e 1504;
- b) se volontari in ferma prefissata quadriennale in rafferma biennale ovvero annuale, gli articoli 842, commi 3 e 3-ter, 1501, comma 1, terzo periodo, 1502, commi 2, 3 e 4, lettera b), e 1504.

16. I decreti di cui ai commi 3, 7, 9 e 12 possono essere modificati con decreto del Ministro della difesa.

))

#### Art. 2198-quater. - (( (Disposizioni transitorie per i concorsi nelle carriere iniziali delle Forze di polizia e del Corpo nazionale dei vigili del fuoco). ))

((1. Fino al 31 dicembre 2024, i volontari di cui agli articoli 2198-bis e 2198-ter continuano a beneficiare delle riserve di posti nei concorsi nelle carriere iniziali delle Forze di polizia e del Corpo nazionale dei vigili del fuoco stabilite dall'articolo 703, comma 1, entro i limiti di eta' previsti per l'accesso alle predette carriere dai rispettivi ordinamenti vigenti il giorno precedente alla data di entrata in vigore del presente articolo. Le riserve di cui al primo periodo continuano a non operare nei confronti dei volontari in rafferma biennale))

#### Art. 2199.

((ARTICOLO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119))

#### Art. 2199-bis. - (( (Regime transitorio per l'arruolamento nel ruolo appuntati e carabinieri). ))

((

1. Il titolo di studio per l'accesso al ruolo degli appuntati e carabinieri di cui all'articolo 706 non e' richiesto per i volontari delle Forze armate reclutati ai sensi degli articoli 703 e 2199 e in servizio alla data del 31 dicembre 2020, ovvero congedati entro la stessa data.

))

#### Art. 2200.

((ARTICOLO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119))

#### Art. 2201.

((ARTICOLO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119))

#### Art. 2202.

((ARTICOLO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119))

#### Art. 2203. - Norma di salvaguardia per il reclutamento di determinate categorie

1. In relazione a quanto disposto dagli articoli 2199 e 2202, sono comunque fatte salve le disposizioni in materia di assunzione del personale di cui alle seguenti disposizioni:

- a) articolo 6, commi 5 e 6, del decreto del Presidente della Repubblica 24 aprile 1982, n. 335;
- b) articolo 5, comma 4-bis, del decreto legislativo 30 ottobre 1992, n. 443;
- c) articolo 6, commi 2 e 3, del decreto legislativo 12 maggio 1995, n. 199;
- d) articolo 4, commi 4-ter e 4-quater, del decreto legislativo 12 maggio 1995, n. 201;
- e) articolo 6, comma 4, della legge 31 marzo 2000, n. 78.

#### Art. 2203-bis. - (( (Disposizioni transitorie in materia di reclutamento del ruolo forestale dell'Arma dei Carabinieri).))

((

1. In relazione alla costituzione iniziale del ruolo forestale dell'Arma dei carabinieri, fermo restando le consistenze organiche di cui all'articolo 800, al fine della progressiva armonizzazione e fino al completo avvicendamento del personale del ruolo forestale iniziale degli ufficiali, le immissioni degli ufficiali nel ruolo forestale sono annualmente determinate, in ragione dell'andamento delle consistenze del personale in servizio degli ufficiali del ruolo forestale iniziale, con decreto del Ministro della difesa.

))

#### Art. 2203-ter.

((ARTICOLO ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 95))

#### Art. 2204. - (( (Regime transitorio del trattenimento in servizio dei concorrenti). ))

((1. Fino all'anno 2024, per i volontari in ferma prefissata di un anno o in rafferma che presentano la domanda di partecipazione ai concorsi per volontario in ferma prefissata quadriennale, e fino all'anno 2026, per i volontari in ferma prefissata quadriennale o in rafferma che partecipano alla procedura per il transito in servizio permanente, il periodo di ferma o rafferma puo' essere prolungato, con il consenso dell'interessato, per il tempo strettamente necessario al completamento dell'iter concorsuale, nei limiti delle consistenze organiche previste dal decreto di cui all'articolo 2207))

#### Art. 2204-bis. - (( (Riammissione alle procedure di immissione nei ruoli dei volontari in servizio permanente dei volontari in ferma prefissata quadriennale ovvero in rafferma biennale esclusi dalle predette procedure negli anni dal 2010 al 2016).))

1. I volontari in ferma prefissata quadriennale ovvero in rafferma biennale, che siano stati esclusi dalle procedure di immissione nei ruoli dei volontari in servizio permanente emanate negli anni dal 2010 al 2016 compreso in quanto sottoposti a procedimento penale, nei casi in cui successivamente sia stata disposta l'archiviazione o il procedimento penale si sia concluso con sentenza irrevocabile che dichiari che il fatto non sussiste o che l'imputato non lo ha commesso o che il fatto non costituisce reato, possono presentare la domanda di riammissione di cui all'articolo 704, comma 1-bis, entro centottanta giorni a decorrere dalla data di pubblicazione del relativo avviso sul sito istituzionale del Ministero della difesa, fermo restando il possesso dei requisiti previsti dalla normativa vigente per la permanenza in servizio.

#### Art. 2204-ter. - (Prolungamento della ferma dei volontari in ferma prefissata)

1. I volontari in ferma prefissata di un anno, che negli anni 2020, 2021 e 2022 terminano il periodo di rafferma ovvero di prolungamento della ferma, ((...)) possono essere ammessi, nei limiti delle consistenze organiche previste a legislazione vigente, su proposta della Forza armata di appartenenza e previo consenso degli interessati, al prolungamento della ferma per un periodo massimo di sei mesi, eventualmente rinnovabile solo per una volta.

2. ((COMMA ABROGATO DALLA L. 5 AGOSTO 2022, N. 119)).

#### Art. 2205.

((ARTICOLO ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173))

## Parte II Formazione

### Art. 2206. - Accademia dell'Arma dei carabinieri

1. Sino all'istituzione dell'Accademia dell'Arma dei carabinieri:

- a) le disposizioni del codice e del regolamento relative all'Accademia dell'Arma dei carabinieri devono intendersi riferite all'Accademia militare dell'Esercito;
- b) i corsi per la formazione di base degli ufficiali dei carabinieri del ruolo normale (( di cui all'articolo 651-bis, comma 1, lettera a) )) sono svolti presso l'Accademia militare dell'Esercito, secondo le modalita' concordate con lo Stato maggiore dell'Esercito italiano, previa selezione a cura del Centro nazionale di selezione e reclutamento dell'Arma;
- c) agli allievi ufficiali dei carabinieri si applicano le norme sullo stato degli allievi ufficiali dell'Esercito italiano frequentatori dei paritetici corsi dell'Accademia.

### Art. 2206-bis. - Riduzione delle dotazioni organiche complessive dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare).

1. L'entita' complessiva delle dotazioni organiche del personale militare dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare e' fissata:

- a) a 190.000 unita', fino al 31 dicembre 2015;
- b) a 170.000 unita', fissate dall'articolo 1 del decreto del Presidente del Consiglio dei Ministri 11 gennaio 2013, pubblicato nella Gazzetta Ufficiale n. 78 del 3 aprile 2013, a decorrere dal 1° gennaio 2016;
- c) a ((160.000 unita')), fissate dall'articolo 798, a decorrere dal 1° gennaio 2034. ((110))

------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

### Art. 2206-ter. - (Formazione dei sottufficiali dell'Arma dei carabinieri).

1. Il personale appartenente al ruolo sovrintendenti al ((31 dicembre)) 2017 puo' partecipare al concorso di cui all'articolo 679, comma 2-bis, lettera b), anche prima di aver maturato il requisito di cui all'articolo 683, comma 4, lettera a).

## Parte III Ruoli e organici

### Art. 2207. - Adeguamento degli organici

1. Sino all'anno ((2033)), le dotazioni organiche del personale ufficiali, sottufficiali, volontari in servizio permanente e volontari in ferma prefissata e in rafferma dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, sono annualmente determinate, secondo un andamento delle consistenze del personale in servizio coerente con l'evoluzione degli oneri di cui agli articoli 582, 583 e 584 e con la ripartizione degli organici complessivi di cui all'articolo 798-bis, con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze e con il Ministro per la pubblica amministrazione e l'innovazione.

### Art. 2207-bis.

((ARTICOLO ABROGATO DALLA L. 5 AGOSTO 2022, N. 119))

### Art. 2208. - Carenze organiche transitorie

1. Sino all'anno 2015, fermo restando l'organico complessivo delle Forze armate, stabilito dall'articolo 798, ed entro i limiti delle risorse finanziarie disponibili nell'anno di riferimento, le eventuali carenze organiche in uno dei ruoli del personale militare non direttivo e non dirigente delle Forze armate possono essere devolute, senza ampliare i rispettivi organici, in aumento alla consistenza di altri ruoli della medesima Forza armata e dello stesso personale militare non direttivo.

1-bis. Dall'anno 2016 e sino all'anno ((2033)), ferma restando l'entita' complessiva delle dotazioni organiche delle Forze armate, di cui all'articolo 2206-bis, la devoluzione delle eventuali carenze organiche di cui al comma 1 puo' essere effettuata anche a favore delle altre Forze armate.

### Art. 2209.

(( (Regime transitorio delle eccedenze organiche del personale non direttivo del Corpo delle capitanerie di porto) )) ((

1. Fino al 2015, per il Corpo delle capitanerie di porto sono ammesse eccedenze nell'organico dei ruoli dei marescialli dovute agli inquadramenti effettuati al momento della costituzione dei ruoli stessi. Fino al raggiungimento del volume organico previsto per i volontari di truppa in servizio permanente, sono ammesse eccedenze nell'organico del ruolo dei sergenti dovute agli inquadramenti effettuati al momento della costituzione dei ruoli stessi.

### Art. 2209-bis. - (( (Disposizioni transitorie per la graduale riduzione dell'entita' complessiva delle dotazioni organiche dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare a 170.000 unita'). ))

((

1. Ai fini del conseguimento, entro il 1° gennaio 2016, dell'entita' complessiva delle dotazioni organiche dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare fissata a 170.000 unita' dall'articolo 1 del decreto del Presidente del Consiglio dei Ministri 11 gennaio 2013, pubblicato nella Gazzetta Ufficiale n. 78 del 3 aprile 2013, e della relativa ripartizione di cui all'articolo 2 del medesimo decreto e agli articoli 668-bis e 711-bis del regolamento, continua ad applicarsi l'articolo 1125-bis del regolamento.

2. L'articolo 1126-bis, comma 1, lettera c), del regolamento continua ad applicarsi sino al 1° gennaio 2016.

))

### Art. 2209-ter.

(Disposizioni transitorie per la graduale riduzione dell'entita' complessiva delle dotazioni organiche dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare a (( 160.000 unita')) ). ((110)) 1. Ai fini del conseguimento, entro l'anno 2033, dell'entita' complessiva delle dotazioni organiche dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare fissata a ((160.000 unita')) dall'articolo 798 e della relativa ripartizione, di cui agli articoli 798-bis, 809-bis, 812-bis e 818-bis: ((110)) a) le dotazioni organiche degli ufficiali, suddivise per ruolo e grado, sono determinate per gli anni dal 2017 e seguenti, con decreto adottato dal Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze e con il Ministro per la pubblica amministrazione e la semplificazione; b) il numero delle promozioni ai gradi di colonnello e di generale, e gradi corrispondenti, e' fissato per gli anni dal 2017 e seguenti, con il decreto di cui all'articolo 2233-bis; c) fermo quanto previsto per i gradi di colonnello e di generale, e gradi corrispondenti, dagli articoli 906 e 909, con il decreto di cui all'articolo 2207, in relazione alle dotazioni organiche complessive e alle consistenze del personale determinate dal medesimo decreto sono individuate le unita' di personale eventualmente in eccedenza. 2. Le dotazioni organiche degli ufficiali determinate ai sensi del comma 1, lettera a), hanno effetto per il conferimento delle promozioni a scelta nei vari gradi di ciascun ruolo e per l'applicazione degli articoli 906 e 909 ai colonnelli e generali, e gradi corrispondenti. 3. Per i gradi in cui le promozioni non si effettuano tutti gli anni, nella determinazione dei cicli si tiene conto anche delle promozioni effettuate negli anni dal 2013 fino al termine di cui al comma 1.

------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

### Art. 2209-quater. - (Piano di programmazione triennale scorrevole).

1. Ai fini del progressivo raggiungimento delle dotazioni organiche complessive di cui all'articolo 798, comma 1, a decorrere dall'anno 2016 e sino all'anno ((2033)), con decreto del Presidente del Consiglio dei ministri, su proposta dei Ministri per la pubblica amministrazione e la semplificazione e della difesa, di concerto con il Ministro dell'economia e delle finanze, sentita la Conferenza unificata, di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e' adottato ogni anno un piano di programmazione triennale scorrevole per disciplinare le modalita' di attuazione:

- a) dei transiti del personale militare in servizio permanente non dirigente e non soggetto a obblighi di ferma, appartenente all'Esercito italiano, alla Marina militare, escluso il Corpo delle capitanerie di corpo, e all'Aeronautica militare, nei ruoli del personale civile dell'amministrazione della difesa e di altre amministrazioni pubbliche, di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, escluse le Forze di polizia, di cui all'articolo 16 della legge 1° aprile 1981, n. 121, e il Corpo nazionale dei vigili del fuoco, secondo i criteri stabiliti dall'articolo 2209-quinquies, fermo restando quanto disposto dall'articolo 30, comma 2-ter, del decreto legislativo n. 165 del 2001;
- b) delle riserve di posti di cui all'articolo 1014, estese anche al personale militare in servizio permanente.

### Art. 2209-quinquies. - (( (Transito di personale militare nei ruoli del personale civile di altre amministrazioni pubbliche). ))

((

1. Ai fini della predisposizione del piano di programmazione triennale scorrevole dei transiti di cui all'articolo 2209-quater, comma 1, lettera a), il Ministero della difesa comunica alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, nel termine da quest'ultima stabilito, i contingenti, distinti per grado e qualifica, di militari in servizio permanente in eccedenza rispetto alle dotazioni organiche, individuati, al 31 dicembre di ciascun anno, con decreto del Ministro della difesa, nonche' le categorie, i ruoli, i gradi, le specialita' e le professionalita' del personale militare in relazione ai quali il transito e' precluso. Tali contingenti vengono resi pubblici dalla Presidenza del Consiglio dei Ministri - Dipartimento della funzione pubblica, tenuto conto della tabella di equiparazione predisposta secondo le modalita' di cui all'articolo 2231-bis.

2. Ai medesimi fini di cui al comma 1, le amministrazioni pubbliche, di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni, comunicano alla Presidenza del Consiglio dei ministri - Dipartimento della funzione pubblica, nel termine da quest'ultima stabilito, il numero dei posti che intendono rendere disponibili nel triennio, in relazione al loro fabbisogno e a valere sulle relative facolta' assunzionali, indicando, per ciascuno, i requisiti richiesti, l'area funzionale e il relativo profilo professionale e, se possibile, le sedi.

3. Il piano di programmazione triennale scorrevole dei transiti individua, per ciascuna amministrazione, i posti annualmente riservati al transito del personale militare, per effetto del comma 2, assicurando comunque, a decorrere dall'anno 2017, nell'ambito delle amministrazioni statali, un numero di posti riservati pari al cinque per cento delle complessive facolta' assunzionali, salvo i posti eventualmente devoluti ai sensi dell'articolo 2259-ter, comma 3, lettera b), numero 5). L'elenco dei posti riservati e' pubblicato sul sito istituzionale del Ministero della difesa.

4. Entro 90 giorni dalla pubblicazione di cui al comma 3, il Ministero della difesa comunica alle amministrazioni interessate il personale disponibile al transito, individuato sulla base dei seguenti criteri, in ordine di priorita', tenuto conto del grado e della qualifica posseduti nonche' delle professionalita' acquisite e dando la precedenza ai transiti che favoriscono i ricongiungimenti familiari:

- a) domanda dell'interessato, con almeno dieci anni di servizio permanente, con indicazione della disponibilita' ad essere impiegato presso sedi di lavoro dislocate sia sul territorio nazionale sia all'estero;
- b) personale in servizio presso enti in chiusura, previo consenso dell'interessato, con assegnazione a una sede di lavoro situata entro trenta chilometri dall'ultima sede di impiego all'atto del transito o ad altra indicata dall'interessato, fatto salvo quanto stabilito dal decreto del Presidente della Repubblica 26 luglio 1976, n. 752, e successive modificazioni, e dal decreto del Presidente della Repubblica 15 luglio 1988, n. 574, e successive modificazioni;
- c) anzianita' anagrafica, previo consenso dell'interessato, con assegnazione a una sede di lavoro dislocata sul territorio nazionale o all'estero, fatto salvo quanto stabilito dal decreto del Presidente della Repubblica 26 luglio 1976, n. 752, e successive modificazioni, e dal decreto del Presidente della Repubblica 15 luglio 1988, n. 574, e successive modificazioni.

5. Il transito avviene, entro la data stabilita dall'amministrazione ricevente, sulla base della tabella di equiparazione predisposta secondo le modalita' di cui all'articolo 2231-bis, tenuto conto, in caso di concorrenza di domande per la medesima amministrazione e sede, della posizione nella graduatoria di cui al comma 4. E' fatto salvo quanto disposto dall'articolo 30, comma 2-ter, del decreto legislativo n. 165 del 2001. Il transito avviene con il consenso dell'amministrazione ricevente previa verifica della rispondenza tra i requisiti culturali e professionali richiesti per l'accesso al profilo da ricoprire e i requisiti posseduti dallo stesso personale da trasferire. I posti riservati al transito non ricoperti entro la data di cui al primo periodo rientrano nella disponibilita' dell'amministrazione interessata. Alla data di assunzione in servizio presso l'amministrazione di destinazione, il militare e' collocato in congedo nella posizione della riserva..

6. Al personale transitato e' dovuta, a carico del Ministero della difesa, sotto forma di assegno ad personam riassorbibile con i successivi miglioramenti economici, la differenza fra il trattamento economico percepito e quello corrisposto in relazione all'area funzionale e alla posizione economica di assegnazione individuata sulla base della tabella di equiparazione di cui al comma 5. Per il personale che transita presso le regioni e gli enti locali, le risorse finanziarie di cui al presente comma sono trasferite alle amministrazioni riceventi secondo le procedure e i tempi da stabilirsi con intesa in sede di Conferenza unificata in conformita' con la normativa contabile vigente; in ogni caso, deve essere garantita la contestualita' del trasferimento delle risorse al transito del personale.

7. Al fine di agevolare i transiti di cui al presente articolo, il Ministero della difesa, nell'ambito delle risorse finanziarie disponibili, puo' organizzare attivita' di formazione per il personale direttamente interessato, anche con le modalita' di cui all'articolo 2259-quater, comma 3, lettera c).

8. La ricongiunzione dei periodi assicurativi connessi al servizio prestato dal personale militare transitato ai sensi del presente articolo avviene d'ufficio presso la gestione previdenziale dell'ente di destinazione, ove diversa, e senza oneri a carico dei lavoratori interessati. Si applica l'articolo 6, commi 2 e 3, della legge 7 febbraio 1979, n. 29.

9. Le disposizioni di cui al presente articolo si applicano anche ai transiti riferiti ai posti eventualmente devoluti al personale militare ai sensi dell'articolo 2259-ter, comma 3, lettera b), numero 5).

))

### Art. 2209-sexies. - (( (Norme sul ricongiungimento familiare). ))

((

1. Nell'ambito del piano di programmazione di cui all'articolo 2209-quater, ferma la prioritaria necessita' di garantire il regolare svolgimento del servizio, senza nuovi o maggiori oneri a carico della finanza pubblica e nel rispetto delle tabelle organiche, sono stabilite le modalita' di attuazione della disciplina intesa a favorire l'assegnazione a domanda presso enti o reparti limitrofi di coniugi entrambi dipendenti del Ministero della difesa, compresi gli appartenenti al Corpo delle capitanerie di porto, secondo i seguenti criteri:

- a) nel caso di coniugi con figli minori, le istanze di ricongiungimento familiare in territorio nazionale sono oggetto di prioritaria istruttoria; nel caso di coniugi con figli minori fino a tre anni di eta' si applica l'articolo 42-bis del decreto legislativo 26 marzo 2001, n. 151;
- b) nel caso di coniugi entrambi militari e appartenenti a Forze armate diverse, gli organi d'impiego procedono all'esame congiunto, per individuare possibili soluzioni, anche mediante indicazione di una o piu' sedi di servizio sul territorio nazionale diverse da quelle richieste dagli interessati;
- c) nel caso di coniuge destinato in sede di servizio all'estero, l'accoglimento dell'eventuale istanza di ricongiungimento familiare dell'altro coniuge e' subordinato anche al superamento delle procedure concorsuali eventualmente previste e non incide sulla durata dei rispettivi mandati;
- d) nel caso di coniugi entrambi militari con figli minori, sono garantite particolari tutele nelle modalita' di espletamento del servizio per evitare il contestuale impiego di entrambi i genitori in attivita' operative continuative fuori dall'ordinaria sede di servizio.

))

### Art. 2209-septies. - Disposizioni transitorie intese ad estendere l'istituto dell'aspettativa per riduzione di quadri per il personale militare non dirigente dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare).

1. Sino all'anno ((2033)), il personale militare fino al grado di tenente colonnello e gradi corrispondenti dell'Esercito italiano, della Marina militare, escluso il Corpo delle capitanerie di porto, e dell'Aeronautica militare, ivi compreso quello di cui all'articolo 2210, comma 1, lettere a), b), c), d), f) e g), non altrimenti riassorbibile con le modalita' di cui all'articolo 2209-quinquies, qualora si trovi nelle condizioni di cui al comma 2 del presente articolo, e' collocato in aspettativa per riduzione di quadri, indipendentemente dal grado rivestito, dalla Forza armata, dalla categoria e dal ruolo di appartenenza.

2. Il personale di cui al comma 1 e' collocato in aspettativa per riduzione di quadri in ragione della maggiore anzianita' anagrafica, secondo il seguente ordine di priorita':

- a) a domanda al 31 dicembre di ciascun anno, per il personale che al 1° gennaio dell'anno di riferimento sia a non piu' di sette anni dal raggiungimento del limite di eta' previsto per il grado e il corpo di appartenenza;
- b) d'ufficio al 31 dicembre dell'anno di scadenza di ciascuna programmazione triennale di cui all'articolo 2209-quater, per il personale a non piu' di tre anni dal compimento dei limiti di eta' stabiliti per la cessazione dal servizio permanente e qualora abbia maturato i requisiti utili per l'accesso al trattamento pensionistico anticipato.

3. Il personale collocato in aspettativa per riduzione di quadri:

- a) LETTERA SOPPRESSA DAL D.LGS. 27 DICEMBRE 2019, N. 173;
- b) percepisce il trattamento economico di cui all'articolo 1821;
- c) e' escluso dalle procedure di avanzamento che comportano l'eventuale promozione o conferimento della qualifica di primo luogotenente ((, di sergente maggiore aiutante o di graduato aiutante, e qualifiche corrispondenti,)) con decorrenza successiva al collocamento in aspettativa per riduzione di quadri;
- d) puo' permanere in tale posizione sino al raggiungimento del limite di eta' ordinamentale, ovvero fino alla maturazione del requisito di accesso al trattamento pensionistico, senza possibilita' di riammissione in servizio e puo' essere collocato in ausiliaria esclusivamente a seguito di cessazione dal servizio per il raggiungimento dei limiti di eta' previsti per il grado rivestito o con le modalita' e nei limiti dei contingenti previsti dagli articoli 2229 e 2230.

### Art. 2209-octies. - Disposizioni transitorie per la destinazione di quota parte dei risparmi derivanti dalla progressiva riduzione del personale militare).

1. A decorrere dall'anno 2017, quota parte dei risparmi derivanti dalla progressiva riduzione del personale militare, accertati secondo quanto previsto dall'articolo 4, comma 1, lettera d), della legge 31 dicembre 2012, n. 244, e' destinata ad alimentare il fondo per l'efficienza dei servizi istituzionali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, in misura non inferiore al 4 per cento e non superiore al 10 per cento, ((informate le associazioni professionali a carattere sindacale tra militari rappresentative ai sensi dell'articolo 1478)).

### Art. 2210. - Ruoli a esaurimento degli ufficiali

1. Sono previsti i seguenti ruoli a esaurimento per gli ufficiali:

- a) ruolo a esaurimento in servizio permanente dell'Esercito italiano;
- b) ruolo tecnico-amministrativo dell'Esercito italiano;
- c) ruolo a esaurimento in servizio permanente della Marina militare;
- d) ruolo del Corpo unico degli specialisti della Marina militare;
- e) ruolo degli ufficiali specialisti del Corpo delle capitanerie di porto;
- f) ruolo a esaurimento in servizio permanente dell'Aeronautica militare;
- g) ruolo unico degli specialisti dell'Aeronautica militare;
- h) ruolo a esaurimento in servizio permanente dell'Arma dei carabinieri;
- i) ruolo tecnico-operativo dell'Arma dei carabinieri.

2. Gli ufficiali dei predetti ruoli in servizio vi permangono a esaurimento.

3. Il grado vertice per i ruoli di cui al comma 1, lettere a), c), f) e h) e', fino alla vigilia della cessazione dal servizio attivo, quello di tenente colonnello ((...)).

4. I limiti di eta' per la cessazione dal servizio permanente degli ufficiali dei ruoli di cui al comma 1, lettere b), d), e), g) e i), sono stabiliti come segue:

- a) maggiore o grado corrispondente: 63 anni;
- b) ufficiali inferiori: 61 anni.

### Art. 2210-bis. - (( (Ruolo speciale a esaurimento dell'Arma dei carabinieri).))

((

1. Gli ufficiali in servizio permanente del ruolo speciale dell'Arma dei carabinieri vi permangono a esaurimento.

2. Il grado vertice per il ruolo speciale a esaurimento dell'Arma dei carabinieri e' quello di colonnello.

3. I limiti di eta' per la cessazione dal servizio permanente degli ufficiali del ruolo speciale a esaurimento sono i seguenti:

- a) per il grado di colonnello: 61 anni;
- b) per i gradi da sottotenente a tenente colonnello: 60 anni.

))

### Art. 2211.

Consistenze organiche dei ruoli speciali e dei ruoli tecnici a esaurimento ((dell'Esercito italiano, della Marina militare e dell'Aeronautica militare))

1. Le consistenze complessive dei rispettivi ruoli speciali e a esaurimento ((dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)) non possono eccedere le dotazioni organiche dei corrispondenti ruoli speciali.

### Art. 2211-bis. - Disposizioni transitorie sulle consistenze organiche dei ruoli degli ufficiali dell'Arma dei carabinieri).

1. Fino al 31 dicembre 2020 le consistenze organiche dei ruoli degli ufficiali dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio A), quadro II (specchio A), quadro III (specchio A).

1-bis. A decorrere dal 1° gennaio 2021 e fino al 31 dicembre 2021, le consistenze organiche dei ruoli degli ufficiali dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio A-bis), quadro II (specchio A), quadro III (specchio A).

((

2. A decorrere dal 1° gennaio 2022 e fino al 31 dicembre 2026, le consistenze organiche dei ruoli degli ufficiali dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio B), quadro I (specchio B-bis), quadro II (specchio A-bis) e quadro III (specchio B).

3. A decorrere dal 1° gennaio 2027 e fino al 31 dicembre 2031, le consistenze organiche dei ruoli degli ufficiali dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio C), quadro II (specchio A-bis) e quadro III (specchio C) ))

4. A decorrere dal 1° gennaio 2032, le consistenze organiche dei ruoli degli ufficiali dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio C), quadro II (specchio B), quadro III (specchio C).

5. A decorrere dal 2032, con decreto del Ministro della difesa, adottato ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400, le dotazioni organiche complessive dei gradi di generale e di colonnello di cui all'articolo 823 sono aggiornate secondo quanto stabilito dalle tabelle di cui al comma 4.

6. Al fine di garantire l'espletamento delle funzioni di cui all'articolo 2212-ter, ferme restando le consistenze organiche complessive di cui all'articolo 800, gli ufficiali del ruolo forestale iniziale non sono computati nei contingenti massimi dei gradi di colonnello e generale stabiliti dalla tabella 4.

7. In relazione alla progressiva riduzione delle consistenze del ruolo speciale dell'Arma dei carabinieri, sino al completo esaurimento del medesimo ruolo e comunque non oltre l'anno 2050, le dotazioni organiche dei ruoli normale e speciale a esaurimento degli ufficiali in servizio permanente dell'Arma dei carabinieri, ferme restando le consistenze organiche di cui all'articolo 800, comma 1, sono annualmente determinate con decreto del Ministro della difesa. Il decreto e' adottato in ragione dell'andamento delle consistenze del personale transitato dal ruolo speciale a esaurimento nel ruolo normale e del personale in servizio nel medesimo ruolo speciale a esaurimento.

### Art. 2212. - Personale stabilizzato dell'Arma dei carabinieri

1. Il personale dell'Arma dei carabinieri, stabilizzato ai sensi dell'articolo 1, commi 519 e 526, della legge 27 dicembre 2006, n. 296, e' collocato in soprannumero rispetto all'organico dei ruoli.

2. Nell'anno 2010, per le esigenze connesse alla prevenzione e al contrasto della criminalita' e al fine di garantire la funzionalita' e l'operativita' dei comandi, degli enti e delle unita', l'Arma dei carabinieri puo' procedere all'immissione in servizio permanente, a domanda, del personale in servizio di cui all'articolo 672, comma 2, che consegue tre anni di servizio a tempo determinato entro il 31 gennaio 2010, previo espletamento di procedure concorsuali, nel limite del contingente di personale di cui all'articolo 3, comma 102, della legge 24 dicembre 2007, n. 244, ferma restando l'applicazione del comma 1, con progressivo riassorbimento delle posizioni soprannumerarie. Nelle more della conclusione delle procedure di immissione, l'Arma dei carabinieri continua ad avvalersi del personale di cui al precedente periodo nel limite del contingente stabilito dalla legge di bilancio.

### Art. 2212-bis. - (( (Ruoli forestali dell'Arma dei carabinieri).))

((

1. Per gli ufficiali dell'Arma dei Carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale iniziale degli ufficiali in servizio permanente.

2. Per gli ispettori dell'Arma dei carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale degli ispettori in servizio permanente.

3. Per i sovrintendenti dell'Arma dei carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale dei sovrintendenti in servizio permanente.

4. Per gli appuntati e carabinieri dell'Arma dei carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale degli appuntati e carabinieri in servizio permanente.

5. Per i periti dell'Arma dei carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale dei periti in servizio permanente.

6. Per i revisori dell'Arma dei carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale dei revisori in servizio permanente.

7. Per gli operatori e collaboratori dell'Arma dei carabinieri provenienti dal Corpo forestale dello Stato e' istituito il ruolo forestale degli operatori e collaboratori in servizio permanente.

))

### Art. 2212-ter. - (Consistenze organiche dei ruoli forestale e forestale iniziale degli ufficiali dell'Arma dei carabinieri)

1. Al fine di garantire l'espletamento delle funzioni in materia di tutela dell'ambiente, del territorio e delle acque, nonche' nel campo della sicurezza e dei controlli nel settore agroalimentare, ferme restando le consistenze organiche complessive di cui all'articolo 800 e fino alla completa armonizzazione dei ruoli forestali degli ufficiali dell'Arma dei carabinieri, le dotazioni organiche del ruolo forestale iniziale degli ufficiali sono progressivamente devolute nella consistenza del ruolo forestale dell'Arma dei carabinieri di cui all'art. 821, comma 1, lettera b) . ((1-bis) Dal 1° gennaio 2022 e sino al 31 dicembre 2031, la dotazione del grado di generale di divisione del ruolo forestale iniziale e' fissata in 2 unita'.))

2. L'entita' del graduale trasferimento delle dotazioni organiche di cui al comma 1 e' annualmente determinata con decreto del Ministro della difesa, di concerto con il Ministro dell'economia e delle finanze.

### Art. 2212-quater. - (Personale dei ruoli forestali dell'Arma dei carabinieri)

1. In relazione alla costituzione iniziale dei ruoli forestali dell'Arma dei carabinieri, ferme restando le consistenze organiche complessive di cui all'articolo 800, al fine del progressivo riassorbimento e fino al completo avvicendamento del personale dei ruoli forestali degli ispettori, dei periti, dei sovrintendenti, dei revisori, degli appuntati e carabinieri, degli operatori e collaboratori dell'Arma dei carabinieri ((...)) le vacanze organiche verificatesi nei predetti ruoli sono progressivamente devolute in aumento alla consistenza dei corrispondenti ed equiparati ruoli dell'Arma dei carabinieri.

((

1-bis. Fino al completo esaurimento del ruolo forestale degli ispettori di cui all'articolo 2212-bis, comma 2, la consistenza organica del ruolo ispettori dell'Arma dei carabinieri di cui all'articolo 800, comma 2, si intende comprensiva delle unita' del ruolo forestale degli ispettori.

1-ter. Fino al completo esaurimento del ruolo forestale dei sovrintendenti di cui all'articolo 2212-bis, comma 3, la consistenza organica del ruolo sovrintendenti dell'Arma dei carabinieri di cui all'articolo 800, comma 3, si intende comprensiva delle unita' del ruolo forestale dei sovrintendenti.

1-quater. Fino al completo esaurimento del ruolo forestale degli appuntati e carabinieri di cui all'articolo 2212-bis, comma 4, la consistenza organica del ruolo degli appuntati e carabinieri dell'Arma dei carabinieri di cui all'articolo 800, comma 4, si intende comprensiva delle unita' del ruolo forestale degli appuntati e carabinieri.

1-quinquies. Fino al completo esaurimento del ruolo forestale dei periti di cui all'articolo 2212-bis, comma 5, la consistenza organica del ruolo degli ispettori dell'Arma dei carabinieri di cui all'articolo 800, comma 2, si intende comprensiva delle unita' del ruolo forestale dei periti.

1-sexies. Fino al completo esaurimento del ruolo forestale dei revisori di cui all'articolo 2212-bis, comma 6, la consistenza organica del ruolo dei sovrintendenti dell'Arma dei carabinieri di cui all'articolo 800, comma 3, si intende comprensiva delle unita' del ruolo forestale dei revisori.

1-septies. Fino al completo esaurimento del ruolo forestale degli operatori e collaboratori di cui all'articolo 2212-bis, comma 7, la consistenza organica del ruolo degli appuntati e carabinieri dell'Arma dei carabinieri di cui all'articolo 800, comma 4, si intende comprensiva delle unita' del ruolo forestale degli operatori e collaboratori.

))

### Art. 2212-quinquies. - (Funzioni del personale appartenente al ruolo forestale dei periti dell'Arma dei carabinieri)

1. Il personale del ruolo forestale dei periti svolge funzioni che richiedono preparazione specialistica e conoscenza di procedure tecnico-scientifiche e amministrativo-contabili, anche complesse e collabora all'attivita' istruttoria e di studio. Svolge altresi' funzioni di ispettore fitosanitario ai sensi dell'articolo 34 del decreto legislativo 19 agosto 2005, n. 214. Ha conoscenza del funzionamento e dell'uso di apparecchiature e di procedure, anche complesse, per l'elaborazione automatica dei dati e il trattamento dei testi.

2. Nell'ambito di direttive di massima ha autonomia operativa e responsabilita' diretta connesse sia con la predisposizione e attuazione delle attivita' che con l'elaborazione degli atti relativi ai compiti affidatigli.

((

3. Nell'esercizio delle funzioni proprie del ruolo di appartenenza, puo' coordinare, con piena responsabilita', l'attivita' di piu' persone operanti in strutture organizzative che svolgono compiti riconducibili alla medesima area tecnica di riferimento. Puo' inoltre sostituire il superiore gerarchico appartenente allo stesso ruolo, in caso di impedimento o assenza.

))

4. Ai ((marescialli maggiori del ruolo forestale dei periti)), oltre ai compiti sopra specificati, sono attribuite funzioni richiedenti una qualificata preparazione professionale nel settore al quale sono adibiti, con conoscenze di elevato contenuto specialistico. Collaborano con i superiori gerarchici in studi, esperimenti e altre attivita' richiedenti qualificata preparazione professionale.

((

5. Il personale del ruolo forestale dei periti puo' svolgere, in relazione alla professionalita' posseduta, compiti di formazione e istruzione del personale.

))

5-bis. Ai ((luogotenenti del ruolo forestale dei periti)) dell'Arma dei carabinieri puo' essere attribuita la qualifica di ((carica speciale)). I ((luogotenenti con qualifica di carica speciale)) hanno rango preminente sui pari grado; fra i ((luogotenenti con qualifica di carica speciale)) si tiene conto della data di conferimento della qualifica, anche nel caso di pari grado con diversa anzianita'.

### Art. 2212-sexies. - (Mansioni del personale appartenente al ruolo forestale dei revisori dell'Arma dei carabinieri)

1. Il personale appartenente al ruolo forestale dei revisori svolge mansioni richiedenti conoscenza specialistica e particolare perizia nel settore al quale e' adibito, con capacita' di utilizzazione di mezzi e strumenti complessi e di interpretazione di disegni, grafici e dati nell'ambito delle direttive di massima ricevute. Svolge altresi' funzioni di agente fitosanitario ai sensi dell'articolo 34-bis del decreto legislativo 19 agosto 2005, n. 214.

((2. Nell'esercizio delle mansioni proprie del ruolo di appartenenza, puo' indirizzare e controllare l'attivita' di piu' persone operanti in strutture organizzative che svolgono compiti riconducibili alla medesima area tecnica di riferimento, con responsabilita' per il risultato conseguito. Puo' inoltre sostituire il superiore gerarchico appartenente al medesimo ruolo o al ruolo forestale dei periti, in caso di impedimento o assenza))

3. Al personale del grado di ((brigadiere capo del ruolo forestale dei revisori)), oltre a quanto gia' specificato, possono essere attribuiti incarichi specialistici richiedenti particolari conoscenze ed attitudini ed essere attribuiti compiti di addestramento del personale sottordinato.

((

3-bis. Ai brigadieri capo del ruolo forestale dei revisori dell'Arma dei carabinieri puo' essere attribuita la qualifica di qualifica speciale. I brigadieri capo con qualifica di qualifica speciale hanno rango preminente sui pari grado; fra i brigadieri capo con qualifica di qualifica speciale si tiene conto della data di conferimento della qualifica, anche nel caso di pari grado con diversa anzianita'.

))

### Art. 2212-septies. - (Mansioni del personale appartenente al ruolo forestale degli operatori e collaboratori)

1. Il personale appartenente al ruolo forestale degli operatori e dei collaboratori svolge mansioni esecutive anche di natura tecnico-strumentale con capacita' di utilizzazione di mezzi e strumenti e di dati nell'ambito di procedure predeterminate. Le prestazioni lavorative sono caratterizzate da margini valutativi nella esecuzione, anche con eventuale esposizione a rischi specifici.

2. ((Gli appuntati e gli appuntati scelti del ruolo forestale degli operatori e collaboratori)) possono, in relazione alla professionalita' posseduta, svolgere compiti di addestramento del personale sottordinato e avere responsabilita' di guida e di controllo di altre persone.

((

2-bis. Agli appuntati scelti del ruolo forestale degli operatori e collaboratori dell'Arma dei carabinieri puo' essere attribuita la qualifica di qualifica speciale. Gli appuntati scelti con qualifica di qualifica speciale hanno rango preminente sui pari grado; fra gli appuntati scelti con qualifica di qualifica speciale si tiene conto della data di conferimento della qualifica, anche nel caso di pari grado con diversa anzianita'.

))

### Art. 2212-octies. - (Successione e corrispondenza dei gradi nei ruoli forestali dei periti e dei revisori dell'Arma dei carabinieri)

1. La successione e la corrispondenza dei gradi dei sottufficiali dei ruoli forestali dell'Arma dei carabinieri sono cosi' determinate in ordine crescente:

- a) vice revisore: vice brigadiere;
- b) revisore: brigadiere;
- c) revisore capo: brigadiere capo;
- d) vice perito: maresciallo;
- e) perito: maresciallo ordinario;
- f) perito capo: maresciallo capo;
- g) perito superiore: ((maresciallo maggiore)).
- g-bis) perito superiore scelto: luogotenente.

2. La denominazione di ((primo perito superiore)) corrisponde ((al grado di luogotenente con qualifica di carica speciale.))

2-bis. A decorrere dal 1° gennaio 2018, i gradi dei ruoli forestali dei periti e dei revisori dell'Arma dei carabinieri assumono la denominazione di quelli previsti per i ruoli degli ispettori e dei sovrintendenti, secondo la corrispondenza di cui al comma 1;

### Art. 2212-novies.

Art. 2212-nonies Successione e corrispondenza dei gradi nei ruoli forestali degli operatori e collaboratori dell'Arma dei carabinieri. 1. La successione e la corrispondenza dei gradi dei graduati dei ruoli forestali degli operatori e collaboratori sono cosi' determinate in ordine crescente: a) operatore: carabiniere; b) operatore scelto: carabiniere scelto; c) collaboratore: appuntato; d) collaboratore capo: appuntato scelto. ((1-bis. A decorrere dal 1° gennaio 2018, i gradi dei ruoli forestali degli operatori e collaboratori dell'Arma dei carabinieri assumono la denominazione di quelli previsti per il ruolo degli appuntati e carabinieri, secondo la corrispondenza di cui al comma 1;))

### Art. 2212-decies. - (( (Trasferimento nel ruolo normale degli ufficiali in servizio permanente dell'Arma dei carabinieri).))

((

1. Gli ufficiali in servizio permanente del ruolo speciale a esaurimento dell'Arma dei carabinieri possono transitare a domanda nel ruolo normale dell'Arma dei carabinieri.

))

### Art. 2212-undecies. - (( (Rideterminazione delle anzianita' degli ufficiali del ruolo normale dell'Arma dei carabinieri).))

((

1. Per gli ufficiali gia' transitati dal ruolo speciale al ruolo normale che rivestono il grado da maggiore a tenente colonnello incluso, in possesso di un'anzianita' di nomina a ufficiale in servizio permanente uguale o successiva al 1° gennaio 1994, i gradi e le anzianita' assolute sono rideterminati in base agli anni di anzianita' minima richiesti per le promozioni stabilite nella tabella 4, quadro IV, allegata al presente codice, calcolati a partire dalla data di nomina a sottotenente del ruolo speciale in servizio permanente effettivo.

2. Per le rideterminazioni di cui al comma 1, si computano:

- a) le detrazioni di anzianita' precedentemente adottate ai sensi degli articoli 858 e 859;
- b) ai sensi all'articolo 1065, i giudizi di non idoneita' espressi in sede di precedenti valutazioni per l'avanzamento al grado superiore;
- c) le anzianita' di grado attribuite all'esito dei pregressi giudizi di avanzamento a scelta.

3. Effettuate le rideterminazioni di cui al comma 1, l'anzianita' di grado assoluta degli ufficiali transitati, e' rideterminata al giorno successivo a quella dell'ultimo dei pari grado del ruolo normale, proveniente dai corsi regolari dell'accademia militare, avente il medesimo anno di decorrenza nel grado.

4. Effettuate le rideterminazioni di cui al comma 3, gli ufficiali di cui al comma 1 conservano tra loro la pregressa anzianita' relativa posseduta.

))

### Art. 2212-duodecies. - (Rideterminazione delle anzianita' degli ufficiali del ruolo speciale dell'Arma dei carabinieri)

1. Gli ufficiali appartenenti al ruolo speciale dell'Arma dei carabinieri in servizio permanente permangono nel ruolo speciale a esaurimento secondo l'ordine di ruolo pregresso, conservando l'anzianita' relativa posseduta.

2. Per gli ufficiali di cui al comma 1, aventi il grado da sottotenente a tenente colonnello incluso, in possesso di un'anzianita' di nomina a ufficiale in servizio permanente uguale o successiva al 1° gennaio 1994, i gradi e le anzianita' assolute sono rideterminati in base agli anni di anzianita' minima richiesti per le promozioni stabilite nella tabella 4, quadro IV, allegata al presente codice, calcolati a partire dalla data di nomina a sottotenente in servizio permanente effettivo.

3. Per le rideterminazioni di cui al comma 2, si computano:

- a) le detrazioni di anzianita' precedentemente adottate ai sensi degli articoli 858 e 859;
- b) ai sensi all'articolo 1065, i giudizi di non idoneita' espressi in sede di precedenti valutazioni per l'avanzamento al grado superiore;
- c) le anzianita' di grado attribuite all'esito dei pregressi giudizi di avanzamento a scelta.

4. Agli ufficiali di cui al comma 1, gia' transitati nel ruolo speciale dal ruolo normale dell'Arma dei carabinieri, non si applicano le rideterminazioni di cui al comma 2, fatto salvo quanto previsto al comma 4 dell'articolo 2214-quinquies.

5. Agli ufficiali di cui al comma 1, gia' transitati nel ruolo speciale dell'Arma dei carabinieri dal ruolo esaurimento degli ufficiali del disciolto Corpo degli Agenti di Custodia, non si applicano le rideterminazioni di cui al comma 2 e l'anzianita' di grado e' rideterminata con l'attribuzione di un aumento di anzianita' assoluta pari a due anni((e cinque mesi)).

### Art. 2212-terdecies. - (Istituzione del ruolo straordinario a esaurimento)

1. Al fine di assicurare la massima flessibilita' ed efficacia organizzativa nella revisione della struttura ordinativa dell'Arma dei carabinieri, dall'anno 2017 e' istituito il ruolo straordinario a esaurimento.

2. Il grado massimo per il ruolo straordinario a esaurimento dell'Arma dei carabinieri e' quello di capitano.

3. Fino all'anno 2021 e' autorizzata l'immissione nel ruolo straordinario a esaurimento degli ufficiali dell'Arma dei carabinieri di massimo 800 unita' complessive suddivise ((equamente per ogni annualita')), secondo modalita' stabilite dall'articolo 2212-quaterdecies.

((

4. Le unita' da immettere, fissate annualmente con decreto del Ministro della difesa di concerto con il Ministro dell'economia e delle finanze, sono considerate a tutti gli effetti in sovrannumero rispetto all'organico complessivo degli ufficiali dell'Arma dei carabinieri di cui al comma 1 dell'articolo 800.

))

((

5. La somma delle consistenze effettive degli ispettori dell'Arma dei carabinieri e degli ufficiali del ruolo straordinario a esaurimento non puo' superare la consistenza organica fissata dal comma 2 dell'articolo 800.

))

### Art. 2212-quaterdecies. - (Modalita' di immissione nel ruolo straordinario a esaurimento)

1. Per le immissioni nel ruolo straordinario a esaurimento di cui all'articolo 2212-terdecies dall'anno 2017 all'anno 2021, gli ufficiali sono tratti con il grado di sottotenente mediante concorso per titoli dai luogotenenti dei ruoli degli Ispettori in servizio permanente dell'Arma dei carabinieri aventi anzianita' di grado uguale o antecedente al 1° gennaio 2017 e in possesso di un'eta' anagrafica non inferiore a cinquanta anni e non superiore a 59.

1-bis. Nel concorso di cui al comma 1, e' prevista una riserva non superiore a due posti per i luogotenenti del ruolo forestale degli ispettori.

2. I vincitori del concorso , previo superamento di accertamenti volti a verificare il possesso dell'idoneita' psico-fisica e attitudinale, sono:

- a) nominati sottotenenti con anzianita' relativa stabilita in base all'ordine della graduatoria di merito;
- b) ammessi a frequentare un corso ((...)) non superiore a tre mesi.

3. COMMA ABROGATO DAL D.LGS. 5 OTTOBRE 2018, N. 126.

4. I sottotenenti di cui ai commi 1 e 2 che superano il corso ((...)) per essi previsto con ritardo per motivi di servizio riconosciuti con determinazione ministeriale, ovvero per motivi di salute, sono iscritti in ruolo al posto che a essi sarebbe spettato se avessero superato il corso al loro turno.

5. I sottotenenti di cui ai commi 1 e 2 che non superano il corso ((...)) per essi previsto rientrano nella categoria di provenienza. Il periodo di durata del corso e' in tali casi computato per intero ai fini dell'anzianita' di servizio.

### Art. 2212-quindecies. - (( (Avanzamento degli ufficiali del ruolo straordinario a esaurimento dell'Arma dei carabinieri).))

((1. Gli avanzamenti sino al grado di capitano compreso degli ufficiali del ruolo straordinario a esaurimento dell'Arma dei carabinieri si effettuano ad anzianita' con le modalita' di cui all'articolo 1055. 2. Gli anni di permanenza minimi nel grado richiesti per la promozione ad anzianita' sono i seguenti: a) sottotenente: uno; b) tenente: due. 3. Agli ufficiali del ruolo straordinario a esaurimento si applica l'articolo 1084-bis.))

### Art. 2212-septiesdecies. - (( (Istituzione dei ruoli straordinari a esaurimento degli ispettori e dei periti).))

((1. Al fine di assicurare la massima flessibilita' ed efficacia organizzativa nella revisione della struttura ordinativa dell'Arma dei carabinieri, dall'anno 2020 sono istituiti i ruoli straordinari a esaurimento degli ispettori, forestale degli ispettori e forestale dei periti. 2. Il grado massimo per i ruoli di cui al comma 1 e' quello di maresciallo ordinario. 3. Per gli anni 2020 e 2021 e' autorizzata l'immissione nei ruoli di cui al comma 1 di complessive 600 unita' suddivise equamente per ogni annualita', cosi' ripartite: a) 576 per il ruolo straordinario a esaurimento degli ispettori; b) 20 per il ruolo straordinario a esaurimento forestale degli ispettori; c) 4 per il ruolo straordinario a esaurimento forestale dei periti. 4. Le unita' immesse sono considerate a tutti gli effetti in soprannumero rispetto all'organico complessivo degli ispettori dell'Arma dei carabinieri di cui al comma 2 dell'articolo 800. 5. La somma delle consistenze effettive dei sovrintendenti dell'Arma dei carabinieri e degli ispettori dei ruoli di cui al comma 1 non puo' superare la consistenza organica fissata dal comma 3 dell'articolo 800.))

### Art. 2212-octiesdecies. - (( (Modalita' di immissione nei ruoli straordinari a esaurimento degli ispettori e dei periti).))

(( 1. Per le immissioni nei ruoli straordinari a esaurimento di cui all'articolo 2212-septiesdecies dall'anno 2020 all'anno 2021, gli ispettori e i periti sono tratti con il grado di maresciallo, mediante concorso per titoli dai brigadieri capo qualifica speciale in servizio permanente dell'Arma dei carabinieri, appartenenti rispettivamente al ruolo dei sovrintendenti, al ruolo forestale dei sovrintendenti e al ruolo forestale dei revisori, aventi anzianita' di grado e qualifica uguale o antecedente al 31 dicembre 2019 e in possesso di un'eta' anagrafica non inferiore a 55 anni e non superiore a 59. 2. I vincitori del concorso, previo superamento di accertamenti volti a verificare il possesso dell'idoneita' psico-fisica e attitudinale, sono: a) ammessi a frequentare un corso, anche con modalita' telematica, di durata non superiore a 30 giorni; b) nominati maresciallo con anzianita' relativa stabilita nell'ordine determinato dalla graduatoria finale di tale corso, con decorrenza dalla data di fine corso.))

### Art. 2213. - Transito dal ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni al ruolo normale dell'Arma dei trasporti e dei materiali

1. Gli ufficiali del ruolo normale delle Armi di fanteria, cavalleria, artiglieria, genio, trasmissioni dell'Esercito, fino al 2011, possono transitare, a domanda, nel ruolo normale dell'Arma dei trasporti e dei materiali, limitatamente ai gradi da capitano a tenente colonnello compreso, nel numero e con le modalita' stabilite con decreto ministeriale una volta effettuati gli avanzamenti ordinari dell'anno di riferimento.

2. Gli ufficiali transitati conservano la posizione di stato e l'anzianita' di grado posseduta. L'ordine di iscrizione in ruolo e' stabilito in base all'articolo 797, dopo gli ufficiali dell'Arma dei trasporti e dei materiali aventi uguale anzianita' di grado.

3. Qualora il numero di domande superi gli organici dei singoli gradi per il transito nel ruolo si procede alla formazione di graduatorie distinte per gradi, sulla base dei requisiti previsti dall'articolo 1058, commi 4, 5 e 6. A parita' di merito la precedenza spetta all'ufficiale con maggiore anzianita' di grado e, a parita' di grado, al piu' anziano in ruolo. Costituisce titolo preferenziale per il transito aver ricoperto incarichi nel settore dei trasporti e dei materiali, non specificamente destinati ad ufficiali appartenenti ad altri ruoli.

### Art. 2214. - Transiti dai ruoli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare nel ruolo tecnico-logistico dell'Arma dei carabinieri

1. In relazione alle esigenze operative e funzionali da soddisfare per l'iniziale costituzione del ruolo tecnico-logistico dell'Arma dei carabinieri, con decreti del Ministro della difesa, su proposta del Capo di stato maggiore della difesa, sono autorizzati, per gli anni dal 2001 ((al 2013)), transiti in detto ruolo, nel numero complessivo di centoquarantanove unita', di ufficiali provenienti dall'Esercito italiano, dalla Marina militare e dall'Aeronautica militare, dai ruoli e dai gradi ove risultino eccedenze rispetto ai volumi organici fissati.

2. I decreti di cui al comma 1 indicano l'entita' e le modalita' dei transiti, le specifiche professionalita' richieste, nonche' gli eventuali ulteriori titoli e requisiti preferenziali. Costituisce in ogni caso titolo preferenziale l'aver prestato servizio nell'Arma dei carabinieri per almeno tre anni. Con gli stessi decreti, possono essere altresi' autorizzati transiti da tutti i ruoli e gradi in deroga a quanto previsto dal precedente comma 1, su indicazione del Capo di stato maggiore di Forza armata di appartenenza.

3. Gli ufficiali transitati ai sensi dei commi 1 e 2 sono portati in diminuzione rispetto ai contingenti massimi definiti annualmente dal decreto interministeriale di cui all'articolo 801, comma 3. Il loro trasferimento nel ruolo tecnico-logistico ha luogo, con riferimento ai ruoli dell'Arma dei carabinieri, ai sensi dell'articolo 2213, ovvero, se provenienti dai ruoli ad esaurimento in servizio permanente, ai sensi dell'articolo 2221, commi 2 e 3. L'anzianita' di servizio maturata nei ruoli degli ufficiali della Forza armata di provenienza e' utile ai fini del computo dei periodi previsti dagli articoli 43, commi 22 e 23, e 43-ter, della legge 1° aprile 1981, n. 121, per la determinazione del trattamento economico all'atto del transito ai sensi dei precedenti commi 1 e 2.

### Art. 2214-bis. - (Unificazione e riordino dei ruoli normali e speciali degli ufficiali appartenenti al Corpo del genio navale ed al Corpo delle armi navali della Marina militare)

1. Gli allievi e gli aspiranti ufficiali del Corpo del genio navale e del Corpo delle armi navali della Marina militare frequentatori del corso normale presso l'Accademia navale alla data del 1° gennaio 2017 all'atto della nomina a ufficiale sono immessi nel Corpo del genio della Marina, nelle specialita' genio navale, armi navali e infrastrutture, in relazione all'iter di studi frequentato.

2. Alla data del 1° gennaio 2017, gli ufficiali appartenenti al Corpo del genio navale e al Corpo delle armi navali della Marina militare transitano nel Corpo del genio della Marina secondo le modalita' indicate all'articolo 2214-ter.

3. Le dotazioni organiche degli ufficiali del Corpo del genio della Marina, suddivise per ruolo e grado, sono determinate con il decreto di cui all'articolo 2209-ter.

4. Alla data del 1° gennaio 2017, il numero di promozioni a scelta nei vari gradi del ruolo normale e del ruolo speciale del Corpo del genio della Marina nelle varie specialita' e' pari alla somma delle promozioni nei vari gradi dei preesistenti Corpi del genio navale e delle armi navali ed e' suddiviso nelle varie specialita' con il decreto di cui all'articolo 2233-bis, in modo che siano gradualmente ricondotte, al 31 dicembre ((2033)), ai valori di cui alla tabella 2, quadri II e VIII.

### Art. 2214-ter. - (( (Trasferimento dai ruoli del Corpo del genio navale e delle armi navali della Marina nei ruoli normale e speciale del Corpo del genio della Marina). ))

((

1. Alla data del 1° gennaio 2017, gli ufficiali del ruolo normale del corpo del genio navale e del corpo delle armi navali che frequentano i corsi applicativi presso l'Accademia navale sono trasferiti nel ruolo normale del corpo del genio della Marina, nelle specialita' genio navale, armi navali e infrastrutture, in relazione all'iter di studi frequentato.

2. Alla data del 1° gennaio 2017, gli ufficiali del ruolo speciale del corpo del genio navale e del corpo delle armi navali che frequentano i corsi applicativi presso l'Accademia navale sono trasferiti nel ruolo speciale del corpo del genio della Marina, nelle specialita' genio navale, armi navali e infrastrutture, in relazione al Corpo di provenienza, al titolo di studio posseduto ovvero alla categoria di appartenenza se provenienti dal Corpo equipaggi della Marina militare ai sensi del comma 3 dell'articolo 655.

3. Alla data del 1° gennaio 2017, gli ufficiali fino al grado di contrammiraglio appartenenti al ruolo normale e al ruolo speciale del Corpo del genio navale e del Corpo delle armi navali, sono trasferiti nei corrispondenti ruoli del Corpo del genio della Marina e nelle specialita' genio navale, armi navali e infrastrutture, in relazione:

- a) al corpo di provenienza;
- b) ai titoli di studio posseduti ovvero ai corsi effettuati;
- c) al servizio prestato nel settore infrastrutture della Marina militare o interforze, per l'inserimento nella specialita' infrastrutture.

4. I trasferimenti di cui ai commi 1, 2, e 3 avvengono mantenendo la posizione di stato, l'anzianita' assoluta e relativa, con provvedimento della Direzione generale del personale militare su indicazione dello Stato maggiore della Marina che definisce le specialita' di transito.

5. Gli ufficiali ammiragli nel grado di ispettore e ispettore capo del Corpo del genio navale e del Corpo delle armi navali sono trasferiti nel ruolo normale del Corpo del genio della Marina mantenendo la posizione di stato e l'anzianita' di grado posseduta. L'ordine di iscrizione in ruolo dei predetti ufficiali e' stabilito ai sensi del comma 3 dell'articolo 797.

))

### Art. 2214-quater. - Transito del personale appartenente al Corpo forestale dello Stato nell'Arma dei carabinieri

1. Il transito del personale del Corpo forestale dello Stato nell'Arma dei carabinieri avviene secondo la corrispondenza con i gradi militari ai sensi degli articoli 632, 2212-octies e 2212-nonies, con l'anzianita' nella qualifica posseduta e mantenendo l'ordine di ruolo acquisito nel ruolo di provenienza. La qualifica di luogotenente attribuita ai marescialli aiutanti sostituti ufficiali di pubblica sicurezza corrisponde alla denominazione di scelto attribuita agli ispettori superiori.

2. Il personale del Corpo forestale dello Stato transitato nell'Arma dei carabinieri assume lo stato giuridico di militare.

3. Fino al 31 dicembre 2020, al personale del Corpo forestale dello Stato transitato nell'Arma dei carabinieri si applicano i limiti d'eta' per la cessazione dal servizio previsti, alla data di entrata in vigore del presente decreto, per i corrispondenti ruoli e qualifiche del Corpo forestale dello Stato dagli articoli 4 del decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, e 2 del decreto legislativo 30 aprile 1997, n. 165.

3-bis. Dal 1° gennaio 2021, al personale dei ruoli forestali dell'Arma dei carabinieri che ne fa richiesta entro il 31 dicembre 2020, si applicano i limiti per la cessazione dal servizio previsti dagli articoli 924 e 928. Ai colonnelli del ruolo forestale iniziale si applica il limite fissato dall'articolo 928, comma 1, lettera d).

3-ter. Per il personale che, per effetto dell'applicazione del comma 3-bis, raggiunge il limite di eta' per la cessazione dal servizio nell'anno 2021, la domanda e' presentata entro il 31 marzo 2020.

4. Al personale del Corpo forestale dello Stato transitato nell'Arma dei carabinieri si applicano le disposizioni in materia di ausiliaria di cui all'articolo 886 e al Titolo V, Capo VII, Sezione III. In deroga all'articolo 992, il predetto personale permane in ausiliaria per un periodo non superiore a 5 anni e comunque non oltre i 65 anni di eta'.

5. Il personale appartenente al ruolo direttivo dei funzionari e al ruolo dei dirigenti del Corpo forestale dello Stato transita nel ruolo forestale iniziale degli ufficiali dell'Arma dei carabinieri di cui all'articolo 2212-bis, comma 1. Per il transito dalla qualifica di vice questore aggiunto forestale al grado di tenente colonnello e' necessario aver maturato un periodo di permanenza effettiva nella qualifica di almeno due anni.

6. Il personale appartenente al ruolo degli ispettori del Corpo forestale dello stato transita nel ruolo forestale degli ispettori dell'Arma dei carabinieri, di cui all'articolo 2212-bis, comma 2.

7. Il personale appartenente al ruolo dei sovrintendenti del Corpo forestale dello Stato transita nel ruolo forestale dei sovrintendenti dell'Arma dei carabinieri, di cui all'articolo 2212-bis, comma 3.

8. Il personale appartenente ai ruoli degli agenti e assistenti del Corpo forestale dello Stato transita nel ruolo forestale degli appuntati e carabinieri dell'Arma dei carabinieri, di cui all'articolo 2212-bis, comma 4.

9. Il personale appartenente al ruolo dei periti del Corpo forestale dello Stato transita nel ruolo forestale dei periti dell'Arma dei carabinieri, di cui all'articolo 2212-bis, comma 5.

10. Il personale appartenente al ruolo dei revisori del Corpo forestale dello Stato transita nel ruolo forestale dei revisori dell'Arma dei carabinieri, di cui all'articolo 2212-bis, comma 6.

11. Il personale appartenente ai ruoli degli operatori e collaboratori del Corpo forestale dello Stato transita nel ruolo forestale degli operatori e collaboratori dell' Arma dei carabinieri, di cui all'articolo 2212-bis, comma 7.

12. Al personale dei ruoli forestali iniziale degli ufficiali, degli ispettori, dei sovrintendenti e degli appuntati e carabinieri dell'Arma dei carabinieri sono attribuite le qualifiche di polizia giudiziaria e pubblica sicurezza previste per i corrispondenti ruoli e gradi dagli articoli 178 e 179.

13. A decorrere dal 1° gennaio 2017, al personale dei ruoli forestali dei periti e dei revisori dell'Arma dei carabinieri sono attribuite le qualifiche di ufficiale di polizia giudiziaria e agente di pubblica sicurezza.

14. A decorrere dal 1° gennaio 2017, al personale dei ruoli forestali degli operatori e collaboratori dell'Arma dei carabinieri sono attribuite le qualifiche di agente di polizia giudiziaria e agente di pubblica sicurezza.

14-bis. Le previsioni contenute negli articoli 664 e 664-bis, inerenti ai ruoli degli ispettori, dei sovrintendenti e degli appuntati e carabinieri, si applicano anche ai corrispondenti ruoli forestali dell'Arma dei carabinieri.

15. Al fine di soddisfare le esigenze in materia di sicurezza e tutela ambientale, forestale e agroalimentare, garantendo l'armonico sviluppo dei ruoli forestali dell'Arma dei carabinieri, le riserve di posti di cui agli articoli 683, comma 7, lettera b), e 692 comma 7-bis, sono ripartite tra il personale in possesso della specializzazione ed il personale dei corrispondenti ruoli forestali dell'Arma dei carabinieri dei sovrintendenti, revisori, appuntati e carabinieri e operatori e collaboratori fino al loro completo esaurimento.

16. La ripartizione dei posti di cui al comma 15 e' stabilita in misura proporzionale, nei relativi bandi, tenuto conto delle rispettive consistenze effettive registrate al 1° gennaio, garantendo in ogni caso la devoluzione di almeno un posto per ciascuna categoria riservataria.

17. Per il personale dei ruoli forestali, i requisiti richiesti per la partecipazione ai concorsi di cui al comma 16 sono i medesimi previsti per i corrispondenti ruoli dell'Arma dei carabinieri, ad eccezione di quello di cui all'articolo 692, comma 6 lettera e-bis).

18. Il personale dei ruoli forestali vincitore di concorso nei bandi di cui al comma 16 e' immesso al relativo corso dei corrispondenti ruoli dell'Arma dei carabinieri, al termine del quale:

- a) viene nominato, secondo le modalita' di cui al titolo III, nei rispettivi superiori ruoli forestali con distinta graduatoria di fine corso;
- b) avviato ad un corso integrativo specialistico, le cui modalita' di svolgimento e i relativi programmi sono stabiliti con determinazione del Comandante generale;
- c) non viene impiegato ai sensi dell'articolo 979.

19. Il personale dei ruoli forestali dei revisori e degli operatori e collaboratori, attese le mansioni svolte, partecipa ai corsi di cui al comma precedente anche con diversi programmi fissati con determinazione del Comandante generale.

20. Il personale del Corpo forestale dello Stato transitato nell'Arma dei carabinieri:

- a) frequenta uno specifico corso di formazione militare, definito con determinazione del Comandante generale dell'Arma dei carabinieri;
- b) all'atto del transito, compatibilmente con il nuovo assetto organizzativo, viene confermato nella stessa sede di servizio, in relazione alle esigenze di mantenimento della specialita' e dell'unitarieta' delle funzioni di presidio dell'ambiente, del territorio e delle acque e della sicurezza agroalimentare.

21. ((COMMA ABROGATO DAL D.LGS. 24 NOVEMBRE 2023, N. 192)).

22. ((COMMA ABROGATO DAL D.LGS. 24 NOVEMBRE 2023, N. 192)).

23. ((COMMA ABROGATO DAL D.LGS. 24 NOVEMBRE 2023, N. 192)).

24. Per l'anno 2019, il personale dei ruoli forestali dei periti, dei revisori e degli operatori e collaboratori dell'Arma dei carabinieri puo' transitare nei corrispondenti ruoli forestali degli ispettori, dei sovrintendenti e degli appuntati e carabinieri, a domanda e secondo le modalita' stabilite con decreto del Ministro della difesa.

24-bis. Il personale transitato ai sensi del comma 24:

- a) e' iscritto nel rispettivo ruolo di destinazione al giorno successivo dell'ultimo dei parigrado gia' presente in ruolo e avente il medesimo anno di decorrenza nel grado, secondo l'ordine di ruolo di provenienza, mantenendo l'anzianita' relativa pregressa;
- b) frequenta un apposito corso secondo modalita' stabilite con determinazione del Comandante Generale, il cui mancato superamento comporta la restituzione al ruolo di provenienza;
- c) al termine del corso e' assegnato secondo i vigenti profili di impiego del ruolo di destinazione.

### Art. 2214-quinquies. - (( Transito dal ruolo speciale a esaurimento al ruolo normale dell'Arma dei carabinieri).))

((

1. In sede di prima applicazione, sino al 30 ottobre 2017, gli ufficiali in servizio permanente del ruolo speciale a esaurimento dell'Arma dei carabinieri, aventi anzianita' di spallina uguale o successiva al 1° gennaio 1994, che rivestono il grado da sottotenente a tenente colonnello incluso, in possesso di laurea magistrale o titolo equipollente stabilita con determinazione del Comandante generale dell'Arma dei carabinieri, sono ammessi al transito di cui all'articolo 2212-decies, secondo modalita' stabilite con determinazione ministeriale.

2. Gli ufficiali del ruolo speciale a esaurimento transitati nel ruolo normale ai sensi del comma 1, sono iscritti nel ruolo normale secondo l'ordine del ruolo di provenienza, conservando l'anzianita' relativa pregressa.

3. Effettuate le iscrizioni in ruolo di cui al comma 2, l'anzianita' di grado assoluta degli ufficiali transitati, e' rideterminata al giorno successivo a quella dell'ultimo dei pari grado del ruolo normale, proveniente dai corsi regolari dell'accademia militare ovvero gia' transitato dal ruolo speciale al ruolo normale, avente il medesimo anno di decorrenza nel grado.

4. Agli ufficiali di cui al comma 1, gia' transitati nel ruolo speciale dal ruolo normale dell'Arma dei carabinieri, si applicano le rideterminazioni di cui ai commi 2 e 3 nonche' quelle dei commi 2 e 3 dell'articolo 2212-duodecies.

5. Sino all'anno 2023 compreso, l'Amministrazione della difesa ha facolta' di bandire concorsi per titoli per il transito nel ruolo normale degli ufficiali del ruolo speciale a esaurimento, ad eccezione di quelli transitati nel ruolo speciale da altro ruolo degli ufficiali dell'Arma dei carabinieri, in possesso, alla data del 30 ottobre dell'anno in cui e' bandito il concorso, dei seguenti requisiti:

- a) anzianita' di nomina a ufficiale in servizio permanente uguale o successiva al 1° gennaio 1994;
- b) possesso di laurea magistrale o titolo equipollente stabilita con determinazione del Comandante generale dell'Arma dei carabinieri;
- c) classificati «eccellente» negli ultimi tre anni.

6. Il numero massimo dei posti da mettere a concorso ai sensi del comma 5, non puo' eccedere, per ciascuna anzianita' di grado, la differenza esistente tra 88 unita' e il numero di ufficiali aventi le medesime anzianita' di grado all'esito dei transiti e dei trasferimenti di cui al comma 1 e all'articolo 2212-decies.

7. I vincitori dei concorsi di cui al comma 5 sono trasferiti nel ruolo normale secondo l'ordine del ruolo di provenienza, conservando tra loro le anzianita' di grado e relativa pregressa.

8. Per i trasferimenti nel ruolo normale di cui al comma 7:

- a) l'anzianita' di grado assoluta degli ufficiali vincitori di concorso, e' rideterminata al giorno successivo a quella dell'ultimo dei pari grado del ruolo normale, proveniente dai corsi regolari dell'accademia militare ovvero gia' transitato dal ruolo speciale al ruolo normale, ovvero transitato dal ruolo speciale a esaurimento ai sensi del comma 1, avente il medesimo anno di decorrenza nel grado;
- b) ai fini del posizionamento in ruolo, una volta effettuate le rideterminazioni di anzianita' di cui alla lettera a), l'ufficiale vincitore di concorso e' comunque collocato in posizione immediatamente successiva a quella conseguita dal parigrado, se presente in ruolo, transitato a norma del comma 7 dal ruolo speciale a esaurimento al ruolo normale, che lo precedeva nel medesimo ruolo.

9. Non possono partecipare ai concorsi di cui al comma 5:

- a) per l'anno 2019, con procedura da bandire entro il 1° luglio 2018, gli ufficiali aventi anzianita' di nomina a sottotenente del ruolo speciale in servizio permanente effettivo uguale o antecedente al 31 dicembre 1994;
- b) per l'anno 2020, con procedura da bandire entro il 1° luglio 2019, gli ufficiali aventi anzianita' di nomina a sottotenente del ruolo speciale in servizio permanente effettivo uguale o antecedente al 31 dicembre 1995;
- c) per l'anno 2021, con procedura da bandire entro il 1° luglio 2020, gli ufficiali aventi anzianita' di nomina a sottotenente del ruolo speciale in servizio permanente effettivo uguale o antecedente al 31 dicembre 1996;
- d) per l'anno 2022, con procedura da bandire entro il 1° luglio 2021, gli ufficiali aventi anzianita' di nomina a sottotenente del ruolo speciale in servizio permanente effettivo uguale o antecedente al 31 dicembre 1997;
- e) per l'anno 2023 con procedura da bandire entro il 1° luglio 2022, gli ufficiali aventi anzianita' di nomina a sottotenente del ruolo speciale in servizio permanente effettivo uguale o antecedente al 31 dicembre 1998.

))

### Art. 2215.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 2216. - Contingente di inquadramento dei volontari in ferma prefissata di un anno

1. Al fine di inquadrare, formare e addestrare i volontari in ferma prefissata di un anno, necessari per raggiungere la consistenza totale stabilita' dall'articolo ((798-bis)) e fino al 31 dicembre 2020, in aggiunta alle consistenze stabilite, dal decreto del Ministro della difesa, adottato di concerto con i Ministri dell'economia e delle finanze e per la pubblica amministrazione e l'innovazione, previsto dall'articolo ((2207)), e' computato un contingente di personale militare determinato annualmente nelle misure di seguito indicate: 90 ufficiali, 150 marescialli, 150 sergenti e 747 volontari in servizio permanente.

2. Al fine di compensare il personale in formazione non impiegabile in attivita' operative, fino al 31 dicembre 2020, in aggiunta alle consistenze stabilite dal decreto del Ministro della difesa, adottato di concerto con i Ministri dell'economia e delle finanze e per la pubblica amministrazione e l'innovazione, previsto dall' articolo ((2207)), e' computato un contingente di volontari in ferma prefissata di un anno determinato annualmente nelle misure progressivamente decrescenti di seguito indicate:

- a) 478 unita', in ciascuno degli anni dal 2006 al 2011;
- b) 406 unita', in ciascuno degli anni dal 2012 al 2020.

### Art. 2217. - Consistenze organiche dei volontari del Corpo delle Capitanerie di porto

1. Fino al 31 dicembre 2015, ferme restando le dotazioni organiche complessive di cui all'articolo 815, le consistenze di ciascuna categoria di volontari di truppa del Corpo delle capitanerie di porto sono annualmente determinate con decreto del Ministro della difesa, di concerto con i Ministri delle infrastrutture e dei trasporti, dell'economia e delle finanze e per la pubblica amministrazione e l'innovazione, secondo un andamento coerente con l'evoluzione degli oneri previsti, per l'anno di riferimento, dall'articolo 585.

2. Le eventuali carenze in una delle categorie di volontari possono essere devolute, senza ampliare i rispettivi organici, in aumento delle consistenze delle altre categorie del medesimo Corpo, entro i limiti delle risorse finanziarie previste dall'articolo 585 per l'anno di riferimento.

((2-bis. Le disposizioni di cui ai commi 1 e 2 si applicano nuovamente dal 1° gennaio 2024 al 31 dicembre 2028))

### Art. 2218. - Compensazioni organiche per il Corpo delle Capitanerie di porto

1. Al fine di compensare il personale in formazione non impiegabile in attivita' operative, fino al 31 dicembre 2015, in aggiunta alle consistenze stabilite dal decreto di cui all'articolo 2217, e' computato un contingente di volontari in ferma prefissata in un anno del Corpo delle capitanerie di porto, nella misura di 5 unita' in ciascuno degli anni dal 2008 al 2015.

### Art. 2219. - Transito dai ruoli tecnici a esaurimento ai ruoli speciali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

1. Finche' non siano raggiunte nei gradi di capitano e di maggiore dei ruoli speciali i volumi organici fissati dal presente codice, e' consentito il transito, per concorso per titoli ed esami, nei ruoli speciali con il grado di capitano e di maggiore degli ufficiali diplomati appartenenti ai ruoli tecnico-amministrativo dell'Esercito italiano, del Corpo unico degli specialisti della Marina militare e unico degli specialisti dell'Aeronautica militare, nonche' del ruolo degli ufficiali specialisti del Corpo delle capitanerie di porto. Per la partecipazione ai concorsi e' richiesto il possesso di una anzianita' minima di grado rispettivamente di tre anni per i capitani e di quattro anni per i maggiori.

2. Gli ufficiali transitati nei ruoli speciali ai sensi del comma 1 non possono conseguire nei nuovi ruoli promozioni con decorrenza anteriore a quella del transito.

3. All'atto del transito nei ruoli speciali, ai vincitori dei concorsi e' applicata una detrazione di anzianita' di tre anni per i capitani e di quattro anni per i maggiori, senza effetto sul trattamento economico percepito. Effettuati gli avanzamenti ordinari dell'anno di riferimento, i vincitori dei concorsi vengono iscritti in ruolo, con l'anzianita' di grado rideterminata e, a parita' di anzianita', secondo l'ordine della graduatoria concorsuale, dopo i pari grado dei ruoli speciali aventi uguale o maggiore anzianita' di servizio da ufficiale.

4. Gli ufficiali che partecipano ai concorsi di cui al comma 1 non devono aver superato i limiti di eta' per la cessazione dal servizio permanente previsti per i gradi di capitano e di maggiore dei ruoli speciali.

### Art. 2220. - Transito dal ruolo tecnico-operativo al ruolo speciale dell'Arma dei carabinieri

1. Finche' non siano raggiunti i volumi organici fissati nel presente codice per il grado di maggiore del ruolo speciale, e' consentito il transito in detto ruolo, per concorso per titoli e per esami, di maggiori diplomati appartenenti al ruolo tecnico-operativo. Per la partecipazione ai concorsi e' richiesto il possesso di una anzianita' minima di grado di quattro anni.

2. All'atto del transito nel ruolo speciale, ai vincitori dei concorsi e' applicata una detrazione d'anzianita' di quattro anni, senza effetto sul trattamento economico percepito. Effettuati gli avanzamenti ordinari dell'anno di riferimento, i vincitori dei concorsi vengono iscritti in ruolo, con l'anzianita' di grado rideterminata e, a parita' di anzianita', secondo l'ordine della graduatoria concorsuale, dopo i pari grado del ruolo speciale aventi uguale o maggiore anzianita' di servizio da ufficiale.

3. Gli ufficiali che partecipano ai concorsi di cui al comma 1 non devono aver superato i limiti d'eta' per la cessazione dal servizio permanente previsti per i gradi di capitano e maggiore del ruolo speciale.

### Art. 2221. - Transito dai ruoli a esaurimento in servizio permanente nei ruoli speciali

1. Finche' non siano raggiunti nei gradi di maggiore e di tenente colonnello dei ruoli speciali i volumi organici fissati dal presente codice, e' consentito il transito, per concorso per titoli ed esami, nei corrispondenti ruoli speciali, con il grado di maggiore, ai maggiori, di cui all'articolo 2210, comma 1, lettere a), c), f) e h), aventi una anzianita' di grado non inferiore a tre anni. E' parimenti consentito il transito, per concorso per titoli ed esami, nei corrispondenti ruoli speciali, con il grado di tenente colonnello, ai tenenti colonnelli di cui all'articolo 2210, comma 1, lettere a), c), f) e h), aventi una anzianita' di grado non inferiore a tre anni e non meno di ventidue anni di anzianita' di servizio.

2. All'atto del transito nei ruoli speciali, ai vincitori dei concorsi e' applicata una detrazione di anzianita' di tre anni senza effetto sul trattamento economico percepito. Effettuati gli avanzamenti ordinari dell'anno di riferimento, i vincitori dei concorsi vengono iscritti in ruolo, con l'anzianita' di grado rideterminata per effetto della predetta detrazione di anzianita' e, a parita' di anzianita' di grado, secondo l'ordine della graduatoria concorsuale, dopo i pari grado dei ruoli speciali aventi uguale o maggiore anzianita' di servizio.

3. Gli ufficiali transitati nei ruoli speciali ai sensi del comma 1 non possono conseguire nei nuovi ruoli promozioni con decorrenza anteriore a quella del trasferimento.

### Art. 2221-bis. - (Aspettativa per riduzione quadri)

1. A decorrere dal 1° gennaio 2017 e fino al 31 dicembre ((2033)), agli ufficiali del Corpo del genio della Marina:

- a) fino al grado di contrammiraglio, si applica quanto previsto dall'articolo 906, con riferimento all'organico della specialita' di assegnazione;
- b) nei gradi di ammiraglio ispettore ed ammiraglio ispettore capo, si applica quanto previsto dall'articolo 906 con riferimento all'organico del rispettivo grado del Corpo del genio della Marina.

2. Con i decreti di cui all'articolo 2209-ter, durante il predetto periodo transitorio verranno stabilite le dotazioni organiche distinte per il Corpo del genio della Marina e le singole specialita'.

### Art. 2221-ter. - (( (Categorie in congedo del Corpo del genio navale e del Corpo delle armi navali).))

((

1. Dal 1° gennaio 2017 gli ufficiali dell'ausiliaria, della riserva e della riserva di complemento del Corpo del genio navale e del Corpo delle armi navali sono iscritti nelle corrispondenti posizioni di stato dei ruoli del congedo del Corpo del genio della Marina.

2. Il trasferimento degli ufficiali di cui al comma 1 viene effettuato ai sensi dell'articolo 797.

))

### Art. 2222.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

## Parte IV Stato giuridico

### Art. 2223. - Regime transitorio per il collocamento in aspettativa per riduzione di quadri).

1. Fino all'anno 2015, se si determinano nei ruoli eccedenze non riassorbibili nei gradi di generale o corrispondenti, e' collocato in aspettativa per riduzione di quadri l'ufficiale generale o corrispondente piu' anziano in grado e, a parita' di anzianita', l'ufficiale anagraficamente piu' anziano.

2. ((Fino all'anno 2016)), se il conferimento delle promozioni annuali determina, nei gradi di colonnello o di generale dei ruoli speciale e tecnico-logistico dell'Arma dei carabinieri, eccedenze rispetto alle dotazioni organiche previste dalla tabella 4, quadri II e III, allegata al presente codice, il collocamento in aspettativa per riduzione quadri e' effettuato se le eccedenze non possono essere assorbite nelle dotazioni complessive di ciascun grado fissate per i ruoli dell'Arma dei carabinieri.

### Art. 2223-bis. - (( (Regime transitorio per gli ufficiali del ruolo forestale iniziale dell'Arma dei carabinieri).))

((

1. Fino all'anno 2037 compreso, in relazione alla progressiva devoluzione delle dotazioni organiche del ruolo forestale iniziale degli ufficiali dell'Arma dei carabinieri e al fine del progressivo assestamento del ruolo forestale, le disposizioni di cui agli articoli 900 e 1099 non si applicano ai tenenti colonnelli in servizio permanente effettivo del ruolo forestale iniziale dell'Arma dei carabinieri.

))

### Art. 2224. - Rafferme dei volontari di truppa

1. L'ammissione alla rafferme ((...)) e' subordinata al rispetto dei limiti delle risorse finanziarie disponibili e delle consistenze organiche previste:

- a) fino al ((2033)), dal decreto del Ministro della difesa, adottato di concerto con i Ministri dell'economia e delle finanze e per la pubblica amministrazione e l'innovazione, previsto dall'articolo 2207, secondo un andamento coerente con l'evoluzione degli oneri complessivamente previsti per l'anno di riferimento dagli articoli 582 e 583;
- b) a decorrere dal 1° gennaio ((2034)), dall'articolo 798-bis.

2. I criteri e le modalita' di ammissione alle rafferme sono disciplinati con decreto del Ministro della difesa.

### Art. 2225. - Ferma obbligatoria per gli ufficiali piloti in servizio permanente

1. Gli ufficiali in servizio permanente delle Forze armate in possesso del brevetto di pilota militare, reclutati in data precedente a quella dell'entrata in vigore della legge n. 42 del 2000, sono vincolati agli obblighi di servizio previsti dalle precedenti disposizioni di legge.

### Art. 2226. - Requisiti per ricoprire gli incarichi relativi al servizio di stato maggiore

1. Ai fini del possesso dei requisiti per svolgere le funzioni di stato maggiore e ricoprire gli incarichi di particolare rilievo negli stati maggiori dei comandi e negli enti centrali e periferici, di cui all'articolo 679 del regolamento, al corso superiore di stato maggiore interforze e' equivalente il Corso superiore di Stato maggiore della Scuola di applicazione e Istituto di studi militari dell'Esercito, di cui all'articolo 1, comma 1, lettera c), della legge 28 aprile 1976, n. 192.

### Art. 2227. - Ufficiali dell'arma dei trasporti e dei materiali e dei corpi tecnico-logistici

1. Possono ricoprire gli incarichi di cui all'articolo 2226 gli ufficiali superiori dei ruoli normali dell'arma dei trasporti e dei materiali e dei corpi tecnico-logistici dell'Esercito italiano che, alla data del 10 giugno 2003, hanno completato il percorso formativo superiore previsto dall'ordinamento di Forza armata e hanno assolto gli obblighi stabiliti per l'avanzamento al grado superiore, riportando la qualifica di eccellente.

### Art. 2228. - Regime transitorio dei richiami in servizio nelle forze di completamento

1. I provvedimenti di richiamo in servizio di cui all'articolo 988 del presente codice sono adottati nei limiti dei contingenti annuali a tale fine determinati con decreto del Ministro della difesa di cui all'articolo 2207 e nel rispetto dei vincoli previsti dalla normativa vigente in materia di assunzione del personale.

### Art. 2229. - Regime transitorio del collocamento in ausiliaria

1. Fino al ((31 dicembre 2025)), ai fini del progressivo conseguimento dei volumi organici stabiliti dall'articolo 2206-bis, il Ministro della difesa ha facolta' di disporre il collocamento in ausiliaria degli ufficiali e dei sottufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare che ne facciano domanda e che si trovino a non piu' di cinque anni dal limite di eta'.

2. La facolta' di cui al comma 1 puo' essere esercitata entro i limiti del contingente annuo massimo di personale di ciascuna categoria indicata dall'articolo 2230 e comunque nel limite delle risorse disponibili nell'ambito dell'autorizzazione di spesa di cui agli articoli 582 e 583. Se nell'ambito di una categoria di personale il numero delle domande e' inferiore al contingente annuo massimo di cui all'articolo 2230, le residue posizioni possono essere portate in aumento nell'altra, nei limiti dell'autorizzazione di spesa prevista dal periodo precedente.

3. Il collocamento in ausiliaria di cui al comma 1 e' equiparato a tutti gli effetti a quello per il raggiungimento dei limiti di eta'. Al predetto personale compete, in aggiunta a qualsiasi altro istituto spettante, il trattamento pensionistico e l'indennita' di buonuscita che allo stesso sarebbe spettato qualora fosse rimasto in servizio fino al limite di eta', compresi gli eventuali aumenti periodici e i passaggi di classe di stipendio. Al medesimo personale si applicano le disposizioni di cui agli articoli precedenti, per il reimpiego nell'ambito del comune o della provincia di residenza presso l'amministrazione di appartenenza o altra amministrazione.

4. Le domande di cessazione dal servizio ai sensi del comma 1 devono essere presentate all'amministrazione di appartenenza, da parte del personale interessato, entro il 1 marzo di ciascun anno, e hanno validita' solo per l'anno in corso. In caso di accoglimento della domanda, il personale e' collocato in ausiliaria a partire dalla data del 1° luglio ed entro il 31 dicembre dello stesso anno. Il personale, la cui domanda non sia stata accolta entro l'anno, puo' ripresentarla, con le stesse modalita', negli anni successivi.

5. Se, nell'ambito di ciascuna categoria di personale, il numero di domande e' superiore al contingente di cui al comma 2, viene collocato in ausiliaria l'ufficiale o il sottufficiale anagraficamente piu' anziano e, a parita' di eta', l'ufficiale o il sottufficiale piu' anziano in grado.

6. Fino all'anno 2033, il collocamento in ausiliaria puo' avvenire, altresi', a domanda dell'interessato che abbia prestato non meno di 40 anni di servizio effettivo. Il periodo di permanenza in tale posizione e' di 5 anni.

### Art. 2230. - Unita' di personale da collocare in ausiliaria

1. Le unita' di personale da collocare in ausiliaria in relazione a quanto disposto dall'articolo 2229, sono cosi' determinate per l'anno di riferimento:

- a) 2010: ufficiali: 18; marescialli: 350; totale: 368;
- b) 2011: ufficiali: 33; marescialli: 550; totale: 583;
- c) 2012: ufficiali: 35; marescialli: 595; totale: 630;
- d) 2013: ufficiali: 35; marescialli: 595; totale: 630;
- e) 2014: ufficiali: 38; marescialli: 650; totale: 688;
- f) 2015: ufficiali: 35; marescialli: 595; totale; 630;
- g) 2016: ufficiali: 65; marescialli: 643; totale: 708;
- h) 2017: ufficiali: 65; marescialli: 830: totale: 895;
- i) 2018: ufficiali: 60; marescialli: 251; totale: 311;
- l) 2019: ufficiali: 55; marescialli: 297; totale: 352;
- m) 2020: ufficiali: 29; marescialli: 226; totale: 255.
- m-bis) 2021: ufficiali: 40; marescialli: 200; totale 240;
- m-ter) 2022: ufficiali: 50; marescialli: 206; totale 256;
- m-quater) 2023: ufficiali: 61; marescialli: 265; totale 326;
- m-quinquies) 2024: ufficiali: 60; marescialli: 284; totale 344;
- m-sexies) 2025: ufficiali: 32; marescialli: 75; totale 107.

1-bis. Il cinquanta per cento delle unita' di ufficiali di cui al comma 1, lettere da m) a (( m-sexies) )), e' riservato ai tenenti colonnelli. Se il numero dei tenenti colonnelli e' inferiore alla quota riservata, le posizioni residue sono devolute a ufficiali aventi grado diverso.

### Art. 2231. - Risoluzione del rapporto d'impiego

1. Al personale militare si applica la norma sancita dall'articolo 72, commi 1, 2, 3, 4, 5, 6, e 11, decreto legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, come sostituito dall'articolo 17, comma 35-novies, del decreto-legge 1° luglio 2009, n. 78, convertito, con modificazioni, dalla legge 3 agosto 2009, n. 102.

### Art. 2231-bis. - (Trasferimento presso altre pubbliche amministrazioni)

1. ((Sino all'anno 2019)), gli ufficiali fino al grado di tenente colonnello compreso e gradi corrispondenti e i sottufficiali dell'Esercito, della Marina e dell'Aeronautica possono presentare domanda di trasferimento presso altre pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni. Il trasferimento e' condizionato al preventivo parere favorevole del Ministero della difesa e all'accettazione da parte dell'amministrazione di destinazione ed e' autorizzato secondo le modalita' e nei limiti delle facolta' assunzionali annuali della medesima amministrazione, previsti dalle disposizioni vigenti. Al personale trasferito, che viene inquadrato nell'area funzionale del personale non dirigenziale individuata dall'amministrazione di destinazione sulla base di apposite tabelle di equiparazione approvate con decreto del Presidente del Consiglio dei Ministri, su proposta del Ministro per la pubblica amministrazione e l'innovazione, di concerto con il Ministro dell'economia e delle finanze, si applica il trattamento giuridico ed economico, compreso quello accessorio, previsto nei contratti collettivi per il personale non dirigente vigenti nel comparto dell'amministrazione di destinazione. Alla data di assunzione in servizio presso l'amministrazione di destinazione, il militare e' collocato in congedo nella posizione della riserva.

### Art. 2231-ter. - (( (Disposizione transitoria per il transito nell'impiego civile degli ufficiali con i gradi di maggiore e di tenente colonnello e gradi corrispondenti).))

((

1. L'articolo 930, comma 1-sexies, si applica agli ufficiali con i gradi di maggiore e di tenente colonnello e gradi corrispondenti delle Forze armate e delle Forze di polizia a ordinamento militare a decorrere dal 1° gennaio 2018.

))

## Parte V Documentazione personale

### Art. 2232. - Indicazione di malattia o cause inabilitanti nel congedo militare

1. I fogli di congedo, le copie di fogli matricolari e di stato di servizio e ogni altro documento rilasciati dall'amministrazione militare in data anteriore al 1978, sono sostituiti, a richiesta dell'interessato, da corrispondenti documenti redatti secondo quanto previsto dall'articolo 1024.

## Parte VI Avanzamento

### Art. 2232-bis. - (( (Formazione dei quadri di avanzamento degli ufficiali. Regime transitorio). ))

((

1. Fino all'anno 2015, in deroga a quanto stabilito dall'articolo 1067, comma 1, lettera b), il quadro di avanzamento e' formato iscrivendovi:

- a) per l'avanzamento a scelta degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare ai gradi di generale o corrispondenti, gli ufficiali idonei, in ordine di ruolo, compresi nel numero dei posti corrispondente a quello delle promozioni da effettuare;
- b) per l'avanzamento a scelta degli ufficiali dell'Arma dei carabinieri: 1) ai gradi di colonnello e generale di brigata, gli ufficiali idonei, nell'ordine di graduatoria di merito, compresi nel numero dei posti corrispondente a quello delle promozioni da effettuare; 2) ai gradi di generale di divisione e di generale di corpo d'armata, gli ufficiali idonei, in ordine di ruolo, compresi nel numero dei posti corrispondente a quello delle promozioni da effettuare.

))

### Art. 2233.

Regime transitorio dell'avanzamento degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare ((sino alla formazione delle aliquote per le promozioni nell'anno 2016)) 1. Fermo restando le dotazioni organiche dei gradi di colonnello e di generale, nonche' il numero di promozioni annuali nei vari gradi di ciascun ruolo di ogni Forza armata, stabiliti dal presente codice, sino al 2015, con decreto ministeriale: a) il numero complessivo di promozioni da conferire ai vari gradi dei ruoli unificati potra' essere ripartito tra i ruoli di provenienza in relazione alla composizione delle aliquote di valutazione e alle distinte graduatorie di merito; b) in fase transitoria le aliquote di valutazione dovranno comprendere ufficiali con anzianita' di grado, crescenti o decrescenti a seconda dei ruoli o dei gradi, in modo da consentire dal 2016 l'inserimento nelle aliquote di valutazione degli ufficiali aventi le permanenze minime nei gradi previste dal presente codice. ((PERIODO SOPPRESSO DAL D.LGS. 28 GENNAIO 2014, N. 8)); c) ((LETTERA SOPPRESSA DAL D.LGS. 28 GENNAIO 2014, N. 8)). 2. COMMA ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29. (22)

--------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 2233-bis. - Regime transitorio dell'avanzamento degli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare a decorrere dall'anno 2016).

1. Dal 1° gennaio 2016 e sino all'anno ((2033)), in relazione alla determinazione delle dotazioni organiche di cui all'articolo 2209-ter, il numero complessivo di promozioni a scelta al grado superiore per ogni grado dei ruoli del servizio permanente e' annualmente fissato, con decreto del Ministro della difesa, secondo i seguenti criteri: ((110))

- a) qualora il numero di promozioni annuali stabilito dalle tabelle 1, 2, e 3 allegate al presente codice sia superiore a quello fissato dalle tabelle 1, 2 e 3 allegate al regolamento, puo' essere conferito il numero di promozioni previsto dalle citate tabelle allegate al regolamento, fino al conseguimento delle dotazioni organiche previste dal presente codice per ciascuna Forza Armata;
- b) qualora il numero di promozioni annuali stabilito dalle tabelle 1, 2, e 3 allegate al presente codice sia inferiore a quello fissato dalle tabelle 1, 2 e 3 allegate al regolamento, il numero di promozioni puo' essere aumentato nel limite massimo previsto dalle citate tabelle allegate al regolamento, fino al conseguimento delle dotazioni organiche previste dal presente codice per ciascuna Forza Armata;
- c) il numero complessivo di promozioni da conferire ai vari gradi dei ruoli unificati potra' essere ripartito tra i ruoli di provenienza in relazione alla composizione delle aliquote di valutazione e alle distinte graduatorie di merito;
- c-bis) per gli anni 2017 e 2018, in relazione a specifiche esigenze di ciascuna Forza armata, in deroga ai criteri di cui al comma 1, lettere a) e b), il decreto che fissa il numero delle promozioni a scelta puo' prevedere una riduzione del numero delle promozioni annuali al grado di colonnello o grado corrispondente stabilite dalle tabelle 1, 2 e 3 allegate al presente codice, nel limite massimo del 30 per cento con arrotondamento all'unita' per difetto. Il numero di promozioni non conferite non puo' essere riportato in aumento per l'anno successivo.

------------- AGGIORNAMENTO (110) Il D.Lgs. 23 novembre 2023, n. 185 ha disposto (con l'art. 4, comma 2) che "Le modificazioni apportate dalle disposizioni del presente decreto al codice dell'ordinamento militare, di cui al decreto legislativo 15 marzo 2010, n. 66, hanno effetto a decorrere dal 1° gennaio 2024".

### Art. 2233-ter. - (( (Regime transitorio dell'avanzamento dei colonnelli del ruolo normale del Corpo degli ingegneri). ))

((

1. Fermi restando le dotazioni organiche dei gradi di colonnello e di generale e il numero di promozioni annuali nei vari gradi, stabiliti dal presente codice, sino al 31 dicembre 2015, in deroga a quanto previsto dalla tabella 1, quadro III, allegata al presente codice, il numero delle promozioni annuali al grado di colonnello del ruolo normale del Corpo degli ingegneri dell'Esercito italiano e' pari al 3 per cento dell'organico del grado di tenente colonnello del medesimo ruolo, ridotto all'unita'.

))

### Art. 2233-quater. - (Regime transitorio per la formazione delle aliquote degli ufficiali)

1. A decorrere dal 1° gennaio 2017 e fino al 31 ottobre 2019, per l'avanzamento ai gradi di capitano e di maggiore, e gradi corrispondenti, le aliquote di valutazione per l'avanzamento al grado superiore sono stabilite con decreto del Ministro della difesa e sono determinate comprendendo ufficiali con anzianita' di grado, crescenti o decrescenti a seconda dei ruoli o dei gradi, in modo da consentire, a decorrere dal 2020, l'inserimento nelle aliquote di valutazione degli ufficiali aventi le permanenze minime nei gradi previste dalle tabelle 1, 2 e 3, di cui agli articoli 1099-bis, 1136-bis e 1185-bis, allegate al presente codice.

2. Per l'avanzamento ai gradi di tenente colonnello, colonnello, e gradi corrispondenti:

- a) agli ufficiali che, nell'anno 2017, rivestono il grado di maggiore, tenente colonnello e gradi corrispondenti, nonche' ai capitani inseriti in aliquota di avanzamento al 31 ottobre 2017 per aver maturato i periodi di permanenza minima nel grado previsti dalle tabelle 1, 2 e 3 vigenti al 31 dicembre 2016, continuano ad applicarsi i periodi di permanenza nei gradi previsti dalle tabelle 1, 2 e 3, di cui agli articoli 1099-bis, 1136-bis e 1185-bis, vigenti al 31 dicembre 2016;
- b) agli ufficiali che per effetto delle disposizioni di cui al comma 1 hanno beneficiato di una riduzione dei periodi di permanenza nel grado di tenente e capitano e corrispondenti rispetto a quelli previsti dalle tabelle 1, 2 e 3, di cui agli articoli 1099-bis, 1136-bis e 1185-bis, vigenti al 31 dicembre 2016, si applica l'incremento degli anni di permanenza nei gradi di maggiore e corrispondenti, nel limite massimo di un anno, e di tenente colonnello e corrispondenti, per la parte residuale, in misura complessivamente pari alla riduzione della permanenza richiesta per l'avanzamento al grado di capitano e di maggiore, o gradi corrispondenti, di cui hanno beneficiato.

3. I tenenti, e gradi corrispondenti, inseriti nelle aliquote di valutazione formate ai sensi delle disposizioni di cui al comma 1 e promossi al grado di capitano, e gradi corrispondenti, assumono, agli effetti giuridici ed economici, un'anzianita' assoluta nel grado di tenente, e gradi corrispondenti, ridotta nei limiti strettamente necessari ad evitare l'eventuale scavalcamento in ruolo da parte di ufficiali con anzianita' di grado inferiore.

3-bis. Fino all'avanzamento al grado di colonnello e gradi corrispondenti degli ufficiali di cui ai commi 1 e 2, lettera b), le aliquote di valutazione sono stabilite con decreto del Ministro della difesa. Per l'avanzamento al grado di maggiore e gradi corrispondenti, possono essere previste distinte aliquote sulla base delle diverse anzianita' possedute al 31 dicembre 2016.

3-ter. Per gli anni 2021 e 2022, le aliquote di valutazione degli ufficiali sono formate alla data del 15 ottobre.

3-quater. Per gli anni 2021, 2022 e 2023 i periodi minimi di comando, di attribuzioni specifiche, di servizio e di imbarco, previsti dal presente codice ai fini dell'inserimento degli ufficiali nelle aliquote di valutazione per l'avanzamento, sono ridotti di trenta giorni.

3-quinquies. ((Le disposizioni di cui al comma 3-quater si applicano anche al triennio 2024-2026)).

### Art. 2234.

((ARTICOLO ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29)) ((22)) ---------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 2235. - (( (Regime transitorio dell'avanzamento degli ufficiali dei ruoli speciali dell'Esercito italiano della Marina militare e dell'Aeronautica militare). ))

((

1. Fino al 2015, per tutti i ruoli speciali degli ufficiali in servizio permanente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, il periodo di permanenza minima nel grado di maggiore o grado corrispondente, ai fini dell'avanzamento al grado superiore, e' di 4 anni.

))

### Art. 2236. - Regime transitorio dell'avanzamento dei capitani dell'Esercito italiano

1. In deroga al numero di promozioni annuali nel grado di maggiore dell'Esercito italiano di ciascun ruolo, previsto dal presente codice, sino al 2015, il numero annuale di promozioni al grado di maggiore di tutti i ruoli normali e speciali e' fissato in tante unita' quanti sono i capitani inseriti nell'aliquota di valutazione e giudicati idonei all'avanzamento. ((Le disposizioni di cui all'articolo 1100 si applicano a partire dagli ufficiali che hanno terminato il corso di applicazione, successivo al biennio accademico, nel corso del 1998.))

2. Sino al 2015, per la formazione delle aliquote di valutazione dei capitani di tutti i ruoli dell'Esercito italiano non si applica la limitazione del 30% di cui all'articolo 2233, comma 1, lettera b).

### Art. 2236-bis. - Regime transitorio dell'avanzamento degli ufficiali del ruolo normale della Marina

1. Fino all'inserimento in aliquota di valutazione per la promozione al grado di tenente di vascello dei sottotenenti di vascello del ruolo normale del Corpo di stato maggiore con anzianita' 2014, i periodi minimi di imbarco e i titoli richiesti sono i seguenti: 3 anni di imbarco, anche se svolto, nel limite massimo di un anno, nel grado immediatamente inferiore; aver conseguito la laurea specialistica.

1-bis. Per i sottotenenti di vascello del ruolo normale del Corpo di stato maggiore con anzianita' 2015, 2016 e 2017, ai fini dell'inserimento in aliquota di valutazione per la promozione al grado di tenente di vascello del ruolo normale del Corpo di stato maggiore, e' richiesto il seguente periodo minimo di imbarco: due anni di imbarco, anche se svolto, nel limite massimo di un anno, nel grado immediatamente inferiore.

1-ter. Per gli ufficiali di cui al comma 1-bis promossi al grado di tenente di vascello, ai fini dell'inserimento in aliquota di valutazione per la promozione al grado di capitano di corvetta del ruolo normale del Corpo di stato maggiore, i periodi minimi di imbarco ed i titoli richiesti sono i seguenti: un anno di comando di unita' navale o incarico equipollente, tre anni di imbarco compreso il periodo di comando od attribuzioni specifiche, aver conseguito la laurea magistrale.

1-quater. Fino all'inserimento in aliquota di valutazione per l'avanzamento al grado di capitano di corvetta degli ufficiali che hanno maturato il periodo di permanenza minima nel grado previsto dalla tabella 2, di cui all'articolo 1136-bis, vigente al 31 dicembre 2016, e comunque non oltre il ((2033)), i tenenti di vascello che, per effetto delle nuove permanenze nei gradi previste dalla tabella 2, di cui all'articolo 1136-bis, allegata al presente codice, non hanno compiuto, per motivi di servizio, i periodi minimi di comando o attribuzioni entro l'anno di inserimento in aliquota, sono valutati al raggiungimento delle predette condizioni e, comunque, non oltre la formazione della graduatoria dell'anno successivo. Gli ufficiali sono promossi con la decorrenza giuridica ed economica che sarebbe loro spettata se la promozione avesse avuto luogo al raggiungimento della permanenza minima nel grado prevista dal presente codice.

### Art. 2237. - Regime transitorio dell'avanzamento degli ufficiali della Marina militare

1. Sino al 2015, per il ruolo normale del Corpo sanitario il numero di promozioni annue, stabilito dal presente codice, da conferire a scelta sino al grado di capitano di vascello e' ripartito tra i ruoli in esso confluiti, secondo le proporzioni esistenti nei ruoli e nei gradi di provenienza.

### Art. 2238. - Regime transitorio dell'avanzamento dei capitani di corvetta

1. In deroga al numero di promozioni annuali nel grado di capitano di corvetta di ciascun ruolo, previsto dal presente codice, sino al 2015, il numero annuale di promozioni al grado di capitano di corvetta dei ruoli normali e speciali di tutti i corpi della Marina militare e' fissato in tante unita' quanti sono i tenenti di vascello inseriti nell'aliquota di valutazione e giudicati idonei all'avanzamento.

### Art. 2238-bis. - (( (Commissione superiore d'avanzamento della Marina Militare). ))

((

1. Sino al 31 dicembre 2016, continuano a far parte della commissione di cui all'articolo 1038 gli ammiragli di squadra che sono o sono stati preposti al comando in capo di dipartimento militare marittimo.

))

### Art. 2238-ter. - (Regime transitorio per i generali di divisione, ammiragli di divisione e generali di divisione aerea)

1. In relazione all'andamento dei ruoli, sino all'anno ((2033)), la permanenza minima nel grado di generale di divisione e gradi corrispondenti per la promozione al grado di generale di corpo d'armata e gradi corrispondenti e' fissata con decreto del Ministro della difesa in modo da includere, oltre agli ufficiali gia' valutati l'anno precedente e giudicati idonei e non iscritti in quadro, i generali di divisione e gradi corrispondenti non ancora valutati che abbiano anzianita' di grado anche inferiore a quelle stabilite dalle tabelle 1, 2, 3 e 4, di cui agli articoli 1099-bis, 1136-bis, 1185-bis e 1226-bis, allegate al presente codice e comunque non inferiore a due anni.

### Art. 2239. - Regime transitorio dell'avanzamento degli ufficiali dell'Aeronautica militare

1. Fermo restando le dotazioni organiche dei gradi di colonnello e di generale, nonche' il numero di promozioni annuali nei vari gradi, stabiliti dal presente codice:

- a) sino all'anno 2015, per l'avanzamento a colonnello del ruolo speciale delle armi dell'Arma aeronautica sono inclusi i tenenti colonnelli gia' valutati, giudicati idonei e non iscritti in quadro e i tenenti colonnelli aventi un'anzianita' di grado pari o superiore a 6 anni;
- b) sino all'anno 2015, per il ruolo normale del Corpo del genio aeronautico il numero di promozioni annue a scelta e' ripartito tra i ruoli in esso confluiti, secondo le proporzioni esistenti nei ruoli e nei gradi di provenienza.

2. COMMA ABROGATO DAL D.P.R. 15 MARZO 2010, N. 90, COME MODIFICATO DAL D.P.R. 12 FEBBRAIO 2013, N. 29. (22)

3. In deroga al numero di promozioni annuali nel grado di maggiore, sino al 2015, il numero annuale delle promozioni al grado di maggiore, per ciascun ruolo degli ufficiali in servizio permanente dell'Aeronautica militare, e' fissato in tante unita' quanti sono i capitani inseriti in aliquota di avanzamento.

3-bis. Fino all'adozione di una nuova disciplina ai sensi dell'articolo 1096, comma 1, lettera b), restano validi ai fini dell'avanzamento gli esami e i corsi di cui alle vigenti disposizioni, ad esclusione della frequenza del corso superiore della scuola di guerra aerea per gli ufficiali del ruolo naviganti normale.

3-ter. Il requisito del conseguimento della laurea specialistica previsto nella tabella 3, quadro I e quadro II, e' richiesto a partire dall'inserimento in aliquota per l'avanzamento al grado superiore dei capitani aventi anzianita' di grado 2010.

3-quater. ((COMMA ABROGATO DAL D.LGS. 23 NOVEMBRE 2023, N. 185)).

--------------- AGGIORNAMENTO (22) Il D.P.R. 15 marzo 2010, n. 90, come modificato dal D.P.R. 12 febbraio 2013, n. 29, ha disposto (con l'art. 1126-bis, comma 1, lettera c)) che "i rinvii alle disposizioni soppresse, di cui alla lettera a), alle disposizioni abrogate, di cui alla lettera b), o alle materie dalle stesse disciplinate, contenuti nel codice, debbono intendersi riferiti alle disposizioni del presente regolamento ovvero del decreto del Presidente del Consiglio dei Ministri in data 11 gennaio 2013, adottato in attuazione dell'articolo 2, comma 3, primo periodo, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, che disciplinano la medesima materia".

### Art. 2240. - Regime transitorio dell'avanzamento dei capitani del ruolo speciale delle armi dell'Aeronautica militare

1. Il capitano del ruolo speciale delle armi dell'Aeronautica militare, sino al 2015, e' incluso in aliquota di avanzamento allorquando e' parimenti incluso in aliquota il pari grado del ruolo normale che lo seguiva nel ruolo di provenienza, purche' abbia maturato una pari o superiore anzianita' nel grado. --------------- Nota redazionale Il testo del presente articolo e' gia' integrato con le correzioni apportate dall'avviso di rettifica pubblicato in G.U. 07/09/2010, n. 209 durante il periodo di "vacatio legis". E' possibile visualizzare il testo originario accedendo alla versione pdf della relativa Gazzetta di pubblicazione.

### Art. 2241. - Avanzamento degli ufficiali dei ruoli tecnici a esaurimento

1. L'avanzamento degli ufficiali del ruolo tecnico-amministrativo dell'Esercito italiano del ruolo del Corpo unico degli specialisti della Marina militare e il ruolo unico degli specialisti dell'Aeronautica militare, avviene in base alle norme del presente articolo.

2. L'avanzamento al grado di capitano e al grado di maggiore ha luogo ad anzianita'. Nelle aliquote di valutazione sono inclusi gli ufficiali aventi rispettivamente cinque anni di anzianita' di grado da tenente e sette anni di anzianita' di grado da capitano. Ferme restando le dotazioni complessive di ciascun grado di ogni Forza armata, sono altresi' inseriti nell'aliquota di avanzamento al grado di maggiore i capitani che abbiano maturato complessivamente dodici anni di anzianita' di servizio dalla nomina a tenente.

3. Le aliquote di valutazione per l'avanzamento ai gradi di capitano e di maggiore comprendono gli ufficiali appartenenti ai predetti ruoli aventi le anzianita' di grado di cui al comma 2.

### Art. 2242. - Avanzamento degli ufficiali appartenenti ai ruoli a esaurimento in servizio permanente

1. Nelle aliquote di valutazione per la promozione a maggiore degli ufficiali dei ruoli a esaurimento transitati in servizio permanente sono inclusi gli ufficiali che abbiano compiuto undici anni di permanenza nel grado di capitano, a condizione che abbiano diciotto anni di anzianita' di servizio.

2. I maggiori e gradi corrispondenti dei ruoli di cui al comma 1 sono promossi, se idonei al grado superiore dopo cinque anni di permanenza nel grado, a condizione che abbiano ventidue anni di anzianita' di servizio.

### Art. 2242-bis. - (( (Ulteriori disposizioni transitorie per gli ufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). ))

((

1. Agli ufficiali dell'Esercito italiano e dell'Aeronautica militare si applicano, in quanto compatibili, le disposizioni di cui all'articolo 2236-bis, comma 1-quater, qualora sussistono analoghe condizioni.

))

### Art. 2243. - (( (Regime transitorio per le aliquote di valutazione dei tenenti colonnelli del ruolo normale dell'Arma dei carabinieri). ))

((

1. Fino all'inserimento in aliquota di valutazione dei tenenti colonnelli del ruolo normale dell'Arma dei carabinieri aventi anzianita' di nomina a ufficiale uguale o anteriore al 30 agosto 1994, le aliquote di valutazione per la promozione al grado di colonnello sono fissate annualmente con decreto del Ministro della difesa in modo da includere, oltre agli ufficiali gia' valutati l'anno precedente e giudicati idonei e non iscritti in quadro, i tenenti colonnelli non ancora valutati che abbiano anzianita' di grado anche inferiore a quella stabilita dalla tabella 4, quadro I, allegata al presente codice.

))

### Art. 2243-bis. - Regime transitorio per la frequenza del corso d'istituto per gli ufficiali dell'Arma dei carabinieri).

1. Sino all'anno 2023 compreso, sono ammessi a frequentare il corso d'istituto di cui all'articolo 755 anche gli ufficiali del ruolo normale dell'Arma dei carabinieri aventi il grado di tenente colonnello.

2. Per gli ufficiali del ruolo normale transitati dal ruolo speciale a esaurimento aventi anzianita' di nomina a ufficiale in servizio permanente nell'Arma dei carabinieri uguale o antecedente al 31 dicembre 2004 il corso d'istituto di cui all'articolo 755 e' considerato assolto.

3. Per gli ufficiali del ruolo tecnico aventi anzianita' di nomina a ufficiale in servizio permanente nell'Arma dei carabinieri uguale o antecedente al 31 dicembre ((2010)) il corso d'istituto di cui all'articolo 755 e' considerato assolto.

4. Gli ufficiali dei ruoli forestale iniziale e speciale a esaurimento non frequentano il corso d'istituto di cui all'articolo 755.

### Art. 2243-ter. - Regime transitorio per la frequenza del corso superiore di stato maggiore interforze per gli ufficiali dell'Arma dei carabinieri).

1. Gli ufficiali del ruolo normale transitati dal ruolo speciale a esaurimento aventi anzianita' di nomina a ufficiale in servizio permanente nell'Arma dei carabinieri uguale o antecedente al 31 dicembre 2004 non sono ammessi alle selezioni per la frequenza del corso superiore di stato maggiore interforze di cui all'articolo 751.

2. Gli ufficiali del ruolo tecnico aventi anzianita' di nomina a ufficiale in servizio permanente nell'Arma dei carabinieri uguale o antecedente al 31 dicembre ((2010)) non sono ammessi alle selezioni per la frequenza del corso superiore di stato maggiore interforze di cui all'articolo 751.

### Art. 2243-quater. - Regime transitorio dei periodi minimi di comando richiesti per la valutazione ai fini dell'avanzamento degli ufficiali del ruolo normale dell'Arma dei carabinieri).

1. Sino all'anno 2027 compreso, per gli ufficiali del ruolo normale transitati dal ruolo speciale a esaurimento, permangono gli obblighi di comando ((per l'avanzamento al grado di colonnello)) previsti nel ruolo di provenienza e i medesimi periodi di comando sono considerati validi ai fini dell'avanzamento anche se espletati, in tutto o in parte, nel ruolo di provenienza.

2. A partire dall'anno 2028, agli ufficiali del ruolo normale transitati dal ruolo speciale a esaurimento si applicano gli obblighi di comando ((per l'avanzamento al grado di colonnello)) previsti dal presente codice e gli eventuali periodi espletati, in tutto o in parte nel ruolo di provenienza, sono computati ai fini dell'avanzamento.

### Art. 2243-quinquies. - (( (Regime transitorio delle progressioni di carriera e delle autorita' competenti a esprimere giudizi sull'avanzamento degli ufficiali del ruolo speciale a esaurimento dell'Arma dei carabinieri).))

((

1. Le progressioni di carriera degli ufficiali in servizio permanente del ruolo speciale a esaurimento dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro IV, allegata al presente codice.

2. Sino al completo esaurimento del ruolo di cui al comma 1 e comunque non oltre l'anno 2050, per esprimere i giudizi sull'avanzamento degli ufficiali del ruolo speciale a esaurimento dell'Arma dei carabinieri, la commissione ordinaria di cui all'articolo 1045 e' integrata da un colonnello del ruolo speciale a esaurimento, se presente in ruolo.

))

### Art. 2243-sexies. - (Regime transitorio dell'avanzamento dei tenenti colonnelli dei ruoli normale e speciale a esaurimento dell'Arma dei carabinieri)

1. Sino all'anno 2032, il numero annuale delle promozioni al grado di colonnello per gli ufficiali in servizio permanente del ruolo speciale a esaurimento e' fissato con decreto annuale del Ministro della difesa, su proposta del Comandante generale dell'Arma dei carabinieri, in misura pari a 7 unita' anche in eccedenza al numero delle promozioni a colonnello del ruolo normale stabilito dal presente codice.

2. In relazione alle variazioni delle consistenze complessive dei ruoli normale e speciale a esaurimento e delle aliquote di valutazione come determinate all'esito dei transiti di cui all'articolo 2214-quinquies nonche' alle esigenze di mantenimento di adeguati tassi di avanzamento, le promozioni di cui al comma 1 con il medesimo decreto possono essere devolute ai tenenti colonnelli del ruolo normale in misura comunque non superiore a 5 unita'.

3. Le eventuali eccedenze rispetto ai contingenti massimi dei gradi di colonnello ((...)) stabiliti dalla tabella 4 che si determinano con il conferimento delle promozioni di cui ai commi 1 e 2 sono considerate in soprannumero nei cinque anni successivi alla decorrenza delle stesse, in misura comunque non superiore alle trentacinque unita' e sono progressivamente assorbite entro il 2032.

4. A decorrere dall'anno 2033 e sino al completo esaurimento del ruolo di cui all'articolo 2210-bis, ferma restando la dotazione organica complessiva del grado di colonnello del ruolo normale e il numero di promozioni annue da attribuire ai tenenti colonnelli del medesimo ruolo stabilite dal presente codice, il numero annuale delle promozioni al grado di colonnello per gli ufficiali in servizio permanente del ruolo speciale a esaurimento e' fissato con decreto annuale del Ministro della difesa, su proposta del Comandante generale dell'Arma dei carabinieri, in relazione alle variazioni delle consistenze complessive dei citati ruoli e delle aliquote di valutazione nonche' alle esigenze di mantenimento di adeguati tassi di avanzamento, e comunque in misura non superiore a 7 unita'.

### Art. 2244.

((ARTICOLO ABROGATO DAL D.LGS. 28 GENNAIO 2014, N. 8))

### Art. 2245.

Modalita' per colmare ulteriori vacanze organiche ((dei ruoli)) degli ufficiali ((...)) dell'Arma dei carabinieri

1. Agli ufficiali del ruolo normale dell'Arma dei carabinieri l'articolo 1079 si applica dal 2012.

((

1-bis. Agli ufficiali del ruolo speciale a esaurimento non si applica l'articolo 1079.

))

### Art. 2246. - Ufficiali del ruolo speciale provenienti dai ruoli a esaurimento dell'Arma dei carabinieri

1. Per gli ufficiali gia' appartenenti al ruolo a esaurimento in servizio permanente e al ruolo tecnico-operativo transitati nel ruolo speciale in applicazione delle disposizioni del presente codice, si prescinde, ai fini dell'inclusione in aliquota di valutazione per l'avanzamento al grado superiore, dall'effettuazione del previsto periodo di comando.

### Art. 2247. - Ufficiali del ruolo speciale dell'Arma dei carabinieri provenienti dalla Polizia di Stato

1. Per gli ufficiali immessi nel ruolo speciale in applicazione delle disposizioni di cui all'articolo 5, comma 3 della legge 31 marzo 2000, n. 78, si prescinde, ai fini dell'inclusione in aliquota di valutazione per l'avanzamento al grado superiore, dall'effettuazione del previsto periodo di comando.

### Art. 2247-bis. - (Avanzamento del personale del Corpo forestale dello Stato transitato nei ruoli forestali dell'Arma dei carabinieri)

1. Le dotazioni organiche iniziali e le progressioni di carriera del personale transitato nel ruolo forestale iniziale degli ufficiali dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro V, allegata al presente codice.

2. Fino all'anno 2037 compreso, per esprimere i giudizi sull'avanzamento degli ufficiali del ruolo forestale iniziale e del ruolo forestale dell'Arma dei carabinieri:

- a) la Commissione superiore d'avanzamento dell'Arma dei carabinieri di cui all'articolo 1040, e' integrata ((dall'ufficiale generale piu' elevato in grado o piu' anziano)) del ruolo forestale iniziale dell'Arma dei carabinieri;
- b) la Commissione ordinaria d'avanzamento dell'Arma dei carabinieri di cui all'articolo 1045, e' integrata da un generale di brigata del ruolo forestale iniziale dell'Arma dei carabinieri.

3. Per i gradi degli ufficiali del ruolo forestale iniziale nei quali le promozioni a scelta si effettuano a vacanza, il Ministro della difesa, per gli anni in cui non sono previste promozioni, approva egualmente la graduatoria, ma il Direttore generale della Direzione generale per il personale militare forma il quadro di avanzamento solo se nel corso dell'anno si verificano una o piu' vacanze nei gradi rispettivamente superiori.

4. Per l'avanzamento degli ufficiali del ruolo forestale iniziale dell'Arma dei carabinieri non si applicano le disposizioni di cui agli articoli 2242 e 2250.

5. Le progressioni di carriera degli ispettori transitati nel ruolo forestale degli ispettori dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro VI, allegata al presente codice.

6. Le progressioni di carriera dei sovrintendenti transitati nel ruolo forestale dei sovrintendenti dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro VII, allegata al presente codice.

7. Le progressioni di carriera degli appuntati e carabinieri transitati nel ruolo forestale degli appuntati e carabinieri dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro VIII, allegata al presente codice.

8. Le progressioni di carriera dei periti transitati nel ruolo forestale dei periti dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro IX, allegata al presente codice.

8-bis. La qualifica di carica speciale e' attribuita, previa verifica del possesso dei requisiti da parte dalla commissione di cui all'articolo 1047, ai luogotenenti del ruolo forestale dei periti dell'Arma dei carabinieri che:

- a) hanno maturato 4 anni di anzianita' di grado;
- b) non si trovano nelle condizioni di cui all'articolo 1051;
- c) nel triennio precedente hanno ottenuto, in sede di valutazione caratteristica, la qualifica di almeno «eccellente» o giudizio equivalente;
- d) nell'ultimo biennio non abbiano riportato alcuna sanzione disciplinare piu' grave del "rimprovero";
- d-bis) nell'ultimo triennio non abbiano riportato una condanna definitiva per delitto non colposo.

8-ter. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al precedente comma.

9. Le progressioni di carriera dei revisori transitati nel ruolo forestale dei revisori dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro X, allegata al presente codice.

9-bis. La qualifica di qualifica speciale e' attribuita, previa verifica del possesso dei requisiti da parte dalla commissione di cui all'articolo 1047, ai brigadieri capo del ruolo forestale dei revisori dell'Arma dei carabinieri che:

- a) hanno maturato 6 anni di anzianita' di grado;
- b) non si trovano nelle condizioni di cui all'articolo 1051;
- c) nel triennio precedente hanno ottenuto, in sede di valutazione caratteristica, la qualifica di almeno "superiore alla media" o giudizio equivalente;
- d) nell'ultimo biennio non abbiano riportato alcuna sanzione disciplinare piu' grave del "rimprovero";
- d-bis) nell'ultimo triennio non abbiano riportato una condanna definitiva per delitto non colposo.

9-ter. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al precedente comma.

10. Le progressioni di carriera degli operatori e collaboratori transitati nel ruolo forestale degli operatori e collaboratori dell'Arma dei carabinieri sono stabilite nella tabella 4, quadro XI, allegata al presente codice.

10-bis. La qualifica di qualifica speciale e' attribuita, previa verifica del possesso dei requisiti da parte dalla commissione di cui all'articolo 1047, agli appuntati scelti del ruolo forestale degli operatori e collaboratori dell'Arma dei carabinieri che:

- a) hanno maturato 5 anni di anzianita' di grado;
- b) non si trovano nelle condizioni di cui all'articolo 1051;
- c) nel triennio precedente hanno ottenuto, in sede di valutazione caratteristica, la qualifica di almeno "superiore alla media" o giudizio equivalente;
- d) nell'ultimo biennio non abbiano riportato alcuna sanzione disciplinare piu' grave del "rimprovero";
- d-bis) nell'ultimo triennio non abbiano riportato una condanna definitiva per delitto non colposo.

10-ter. La qualifica e' conferita dal giorno successivo a quello del compimento del periodo minimo di anzianita' di grado di permanenza previsto al precedente comma.

11. Per esprimere i giudizi sull'avanzamento del personale dei ruoli forestali degli ispettori, dei sovrintendenti, degli appuntati e carabinieri, dei periti, dei revisori e degli operatori e collaboratori dell'Arma dei carabinieri, i membri della commissione di avanzamento dell'Arma dei carabinieri di cui al comma 4, lettera b), dell'articolo 1047, sono:

- a) un generale di brigata del ruolo forestale iniziale dell'Arma dei carabinieri, che assume il ruolo di vice presidente;
- b) quattro colonnelli del ruolo normale dell'Arma dei carabinieri;
- c) tre colonnelli del ruolo forestale iniziale dell'Arma dei carabinieri, di cui il meno anziano assume il ruolo di segretario;
- d) due luogotenenti del ruolo ispettori dell'Arma dei carabinieri, se si tratta di valutazione di personale del ruolo forestale degli ispettori dell'Arma dei carabinieri;
- e) due luogotenenti del ruolo forestale degli ispettori dell'Arma dei carabinieri, se si tratta di valutazione di personale del ruolo forestale degli ispettori dell'Arma dei carabinieri;
- f) un brigadiere capo del ruolo dei sovrintendenti dell'Arma dei carabinieri, se si tratta di valutazione di personale del ruolo forestale dei sovrintendenti dell'Arma dei carabinieri;
- g) un brigadiere capo del ruolo forestale dei sovrintendenti dell'Arma dei carabinieri, se si tratta di valutazione di personale del ruolo forestale dei sovrintendenti dell'Arma dei carabinieri;
- h) un appuntato scelto del ruolo degli appuntati e carabinieri dell'Arma dei carabinieri, se si tratta di valutazione di personale del ruolo forestale degli appuntati e carabinieri dell'Arma dei carabinieri;
- i) un appuntato scelto del ruolo forestale degli appuntati e carabinieri dell'Arma dei carabinieri, se si tratta di valutazione di personale del ruolo forestale degli appuntati e carabinieri dell'Arma dei carabinieri;
- l) un luogotenente o un brigadiere capo o un appuntato scelto dei ruoli forestali dei periti, dei revisori o degli operatori e collaboratori dell'Arma dei carabinieri se si tratta di valutazione di personale dei rispettivi ruoli.

12. Per l'avanzamento del personale del Corpo forestale dello Stato transitato nei ruoli forestali dell'Arma dei carabinieri si applicano, se non diversamente stabilito, le disposizioni di cui al libro quarto, titolo VII, riferite a corrispondenti ruoli e categorie.

### Art. 2247-ter. - (Elementi di giudizio per l'avanzamento del personale dei ruoli forestali dell'Arma dei carabinieri)

1. Nelle valutazioni del personale dei ruoli forestali dell'Arma dei carabinieri le autorita' competenti esprimono i giudizi sull'avanzamento sulla base degli elementi di cui all'articolo 1032, e fondandosi sulle risultanze emerse dai fascicoli personali e dalle note informative, dai rapporti informativi e dalle schede di valutazione dell'attivita' svolta per i dirigenti riferiti al servizio antecedente al transito, prestato nel Corpo forestale dello Stato.

((

1-bis. Per l'anno 2016, i documenti per valutare il rendimento in servizio del personale appartenente al ruolo direttivo dei funzionari e al ruolo dei dirigenti del Corpo forestale dello Stato transitato nel ruolo forestale iniziale degli ufficiali in servizio permanente effettivo dell'Arma dei carabinieri, sono sostituiti da una dichiarazione di mancata redazione della documentazione caratteristica compilata, alla data del 1° gennaio 2017, dal comando di cui alla lettera a) del comma 1 dell'articolo 174-bis e finalizzata a documentare gli incarichi assolti e il relativo periodo di tempo.

1-ter. Per l'anno 2016, le disposizioni di cui al comma 1-bis si applicano anche al personale appartenente ai ruoli non direttivi e non dirigenti del Corpo forestale dello Stato transitato nei corrispondenti ruoli dell'Arma dei carabinieri, nei casi previsti dall'articolo 53 del decreto del Presidente della Repubblica 10 gennaio 1957, n. 3.

))

### Art. 2247-quater. - (( (Nomina del Vice Comandante del Comando unita' per la tutela forestale, ambientale e agroalimentare dell'Arma dei carabinieri). ))

1. All'atto del transito del personale del Corpo forestale dello Stato nell'Arma dei carabinieri, per la costituzione iniziale del ruolo forestale dell'Arma dei carabinieri e per l'istituzione del Comando unita' per la tutela forestale, ambientale e agroalimentare di cui all'articolo 174-bis, con decreto interministeriale dei Ministri della difesa e delle politiche agricole e forestali, adottato su proposta del Comandante generale dell'Arma dei carabinieri e trasmesso per il tramite del Capo di Stato maggiore della difesa, si procede alla nomina del Vice comandante del predetto Comando, scelto tra gli ufficiali in servizio permanente effettivo con grado di generale di brigata del ruolo forestale iniziale dell'Arma dei carabinieri, a cui e' conferito il grado di generale di divisione del medesimo ruolo.

### Art. 2247-quinquies. - (Regime transitorio dell'avanzamento degli ufficiali del ruolo normale dell'Arma dei carabinieri)

1. Sino all'anno 2021 le progressioni di carriera degli ufficiali del ruolo normale dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio A).

2. Sino all'anno 2026 le progressioni di carriera degli ufficiali del ruolo normale dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio B).

3. Sino all'anno 2023 gli avanzamenti sino al grado di tenente colonnello compreso si effettuano ad anzianita' con le modalita' di cui all'articolo 1055.

((3-bis. Il comma 3 si interpreta nel senso che le permanenze minime previste per l'avanzamento ad anzianita' di cui all'articolo 1055 sono stabilite in due anni nel grado di sottotenente, quattro anni nel grado di tenente, sette anni nel grado di Capitano e cinque anni nel grado di Maggiore))

4. A partire dal 1° gennaio 2027, le progressioni di carriera degli ufficiali del ruolo normale dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro I (specchio C).

### Art. 2247-sexies. - (( (Regime transitorio dell'avanzamento degli ufficiali del ruolo forestale dell'Arma dei carabinieri). ))

((

1. Sino all'anno 2031 le progressioni di carriera degli ufficiali del ruolo forestale dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro II (specchio A).

2. A partire dal 1° gennaio 2032, le progressioni di carriera degli ufficiali del ruolo forestale dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro II (specchio B).

))

### Art. 2247-septies. - (Regime transitorio dell'avanzamento degli ufficiali del ruolo tecnico dell'Arma dei carabinieri)

1. Sino all'anno 2021 le progressioni di carriera degli ufficiali del ruolo tecnico dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro III (specchio A).

2. Sino all'anno 2026 le progressioni di carriera degli ufficiali del ruolo tecnico dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro III (specchio B).

3. Sino all'anno 2023 gli avanzamenti sino al grado di tenente colonnello compreso si effettuano ad anzianita' con le modalita' di cui all'articolo 1055.

((

3-bis. Il comma 3 si interpreta nel senso che le permanenze minime previste per l'avanzamento ad anzianita' di cui all'articolo 1055 sono stabilite in due anni nel grado di tenente, sette anni nel grado di capitano e sette anni nel grado di maggiore.

))

4. A partire dal 1° gennaio 2027, le progressioni di carriera degli ufficiali del ruolo tecnico dell'Arma dei carabinieri sono stabilite dalla tabella 4, quadro III (specchio C).

5. Al fine di assicurare l'armonico sviluppo del ruolo e il graduale raggiungimento delle nuove dotazioni organiche, per l'avanzamento al grado di maggiore del ruolo tecnico per l'anno 2018, sono inseriti in aliquota di valutazione i capitani con anzianita' uguale o antecedente al 31 dicembre 2010.

6. Per gli ufficiali del ruolo tecnico dell'Arma dei carabinieri aventi anzianita' di nomina a ufficiale in servizio permanente uguale o successiva al 1° gennaio 2010 nonche' uguale o anteriore al 31 dicembre 2015, il periodo di permanenza minimo nel grado di capitano per l'avanzamento al grado superiore e' fissato in otto anni.

7. Il numero di promozioni a scelta ai gradi di seguito indicati e' fissato nelle seguenti unita':

- a) per l'anno 2018: 1) generale di divisione: nessuna promozione; 2) generale di brigata: comparto sanitario 1; 3) colonnello: comparto sanitario e psicologico 1, comparto amministrativo 2 e comparto tecnico scientifico 1;
- b) per l'anno 2019: 1) colonnello: comparto sanitario e psicologico 2; comparto amministrativo 1 e comparto tecnico scientifico 1.

### Art. 2247-octies. - (Regime transitorio dell'avanzamento degli ufficiali del ruolo speciale a esaurimento dell'Arma dei carabinieri)

1. Sino all'anno 2023 gli avanzamenti sino al grado di tenente colonnello compreso si effettuano ad anzianita' con le modalita' di cui all'articolo 1055.

((

1-bis. Il comma 1 si interpreta nel senso che le permanenze minime previste per l'avanzamento ad anzianita' di cui all'articolo 1055 sono stabilite in due anni nel grado di sottotenente, cinque anni nel grado di tenente, sette anni nel grado di Capitano e cinque anni nel grado di Maggiore.

))

2. Fermo restando quanto disposto dall'articolo 2243-sexies, il numero di promozioni a scelta al grado di colonnello e' fissato in sette unita' per l'anno 2018.

3. Per l'avanzamento degli ufficiali del ruolo speciale a esaurimento dell'Arma dei carabinieri non si applicano le disposizioni di cui agli articoli 2242 e 2250.

### Art. 2247-novies. - (( (Regime transitorio dell'avanzamento degli ufficiali del ruolo forestale iniziale dell'Arma dei carabinieri). ))

((1. Fermo restando quanto disposto dall'articolo 2247-bis, comma 1, al fine di garantire paritetici e armonici tassi di avanzamento, le aliquote di valutazione del ruolo forestale iniziale sono fissate secondo i seguenti criteri: a) per l'avanzamento al grado di generale di brigata, sono inseriti in aliquota di valutazione, per l'anno 2018, i colonnelli aventi anzianita' di grado uguale o antecedente al 31 dicembre 2013; b) per l'avanzamento al grado di colonnello sono inseriti in aliquota di valutazione, per l'anno 2018, i tenenti colonnelli con anzianita' di grado uguale o antecedente al 31 dicembre 2016; c) per l'avanzamento al grado di tenente colonnello, sono inseriti in aliquota di valutazione: 1) per l'anno 2018, i maggiori con anzianita' uguale o antecedente al 31 dicembre 2016; 2) per l'anno 2019, i maggiori con anzianita' uguale o antecedente al 31 dicembre 2017; 3) per l'anno 2020, i maggiori con anzianita' uguale o antecedente al 31 dicembre 2018; 4) per l'anno 2021, i maggiori con anzianita' uguale o antecedente al 31 dicembre 2019; d) per l'avanzamento al grado di maggiore sono inseriti in aliquota di valutazione: 1) per l'anno 2018, i capitani con anzianita' uguale o antecedente al 31 dicembre 2013; 2) per l'anno 2019, i capitani con anzianita' uguale o antecedente al 31 dicembre 2014.))

### Art. 2247-decies. - (( (Avanzamento a scelta al grado di luogotenente del ruolo forestale degli ispettori dell'Arma dei carabinieri). ))

((

1. I marescialli maggiori del ruolo forestale degli ispettori dell'Arma dei carabinieri giudicati idonei e iscritti nel quadro d'avanzamento "a scelta" sono promossi al grado superiore.

2. All'avanzamento "a scelta" al grado di luogotenente sono ammessi i marescialli maggiori che hanno maturato il periodo minimo di permanenza nel grado.

3. Il conferimento del grado decorre dal giorno successivo a quello del compimento del periodo minimo di anzianita' di permanenza previsto dalla tabella 4, quadro VI.

))

### Art. 2247-undecies.

(Avanzamento a scelta al grado di ((luogotenente del ruolo forestale dei periti dell'Arma dei carabinieri)) ).

1. I ((marescialli maggiori del ruolo forestale dei periti dell'Arma dei carabinieri)) giudicati idonei e iscritti nel quadro d'avanzamento "a scelta" sono promossi al grado superiore.

2. All'avanzamento "a scelta" al grado di ((luogotenente del ruolo forestale dei periti dell'Arma dei carabinieri)) sono ammessi i ((marescialli maggiori)) che hanno maturato il periodo minimo di permanenza nel grado.

3. Il conferimento del grado decorre dal giorno successivo a quello del compimento del periodo minimo di anzianita' di permanenza previsto dalla tabella 4, quadro IX.

### Art. 2247-duodecies.

(Avanzamento a scelta al grado di ((maresciallo maggiore del ruolo forestale dei periti dell'Arma dei carabinieri)) ).

1. Le promozioni da conferire al grado di ((maresciallo maggiore del ruolo forestale dei periti dell'Arma dei carabinieri)) sono cosi' determinate:

- a) il primo terzo dei ((marescialli)) capo iscritti nel quadro di avanzamento a scelta e' promosso al grado superiore in ordine di ruolo con decorrenza dal giorno successivo a quello di compimento del periodo minimo di permanenza previsto dal quadro IX della tabella 4 allegata al presente decreto;
- b) i restanti ((marescialli)) capo sono sottoposti a seconda valutazione per l'avanzamento all'epoca della formazione delle corrispondenti aliquote di scrutinio dell'anno successivo. Di essi: 1) la prima meta' e' promossa, in ordine di ruolo, con un anno di ritardo rispetto al periodo minimo di permanenza previsto dal quadro IX della tabella 4 allegata al presente decreto, prendendo posto nel ruolo dopo i ((marescialli)) capo da promuovere in prima valutazione nello stesso anno secondo la norma della lettera a); 2) la seconda meta', previo giudizio di idoneita', in ordine di ruolo, e' promossa con due anni di ritardo rispetto al periodo minimo di permanenza previsto dal quadro IX della tabella 4 allegata al presente decreto, prendendo posto nel ruolo dopo i ((marescialli)) capo da promuovere in seconda valutazione nello stesso anno, secondo la norma della lettera b), numero 1).

2. I ((marescialli)) capo esclusi dalle aliquote di valutazione ai sensi dell'articolo 1051, nell'avanzamento a scelta prendono posto, se idonei, a seconda del punteggio globale attribuito nella graduatoria di merito dei parigrado con i quali sarebbero stati valutati in assenza delle cause impeditive. In relazione alla posizione in graduatoria, sono promossi secondo le modalita' indicate nel comma 1.

### Art. 2248. - Norma di chiusura del regime transitorio per gli ufficiali dell'Arma dei carabinieri

1. ((Sino al completo esaurimento del ruolo di cui all'articolo 2210-bis e comunque non oltre l'anno 2027)), in relazione a eventuali variazioni nella consistenza organica dei ruoli nonche' alle esigenze di mantenimento di adeguati e paritari tassi di avanzamento e di elevazione del livello ordinativo dei comandi, il Ministro della difesa e' autorizzato annualmente a modificare, con apposito decreto, per ogni grado dei ruoli del servizio permanente, il numero complessivo di promozioni a scelta al grado superiore, nonche' la previsione relativa agli obblighi di comando, la determinazione delle relative aliquote di valutazione e le permanenze minime nei gradi in cui l'avanzamento avviene ad anzianita', fermi restando i volumi organici complessivi ((e l'invarianza di spesa. Al fine di garantire l'invarianza di spesa di personale, il decreto di cui al presente comma puo' compensare gli eventuali maggiori oneri anche mediante la riduzione temporanea o permanente delle facolta' assunzionali previste a legislazione vigente)).

2. COMMA ABROGATO DAL D. LGS. 24 FEBBRAIO 2012, N. 20.

### Art. 2248-bis. - (Regime transitorio per gli ufficiali dei ruoli forestali dell'Arma dei carabinieri)

1. Sino all'anno 2027 compreso, in relazione alle esigenze connesse con l'assorbimento del Corpo forestale dello Stato e la costituzione del ruolo forestale iniziale degli ufficiali dell'Arma dei carabinieri nonche' alle necessarie variazioni nella consistenza organica del predetto ruolo e alla contestuale determinazione delle consistenze organiche dei gradi del ruolo forestale degli ufficiali dell'Arma dei carabinieri, il Ministro della difesa e' autorizzato annualmente a modificare, con apposito decreto di concerto con il Ministro dell'economia e delle finanze, per ogni grado dei predetti ruoli forestali, il numero di promozioni a scelta al grado superiore, la determinazione delle relative aliquote di valutazione e le permanenze minime nei gradi in cui l'avanzamento avviene ad anzianita', fermi restando i volumi organici complessivi.

((

1-bis. Sino all'anno 2027 compreso, il numero delle promozioni a generale di brigata del ruolo forestale iniziale dell'Arma dei carabinieri da conferire annualmente e' pari ad una unita'.

1-ter. Le eventuali eccedenze rispetto ai contingenti massimi definiti dalla tabella 4, determinate dalle promozioni di cui al comma 1-bis, sono considerate in soprannumero nell'anno di conferimento e progressivamente riassorbite entro il 31 dicembre 2026.

))

### Art. 2248-ter. - (( (Disposizioni transitorie per il progressivo assestamento dei ruoli degli ufficiali dell'Arma dei carabinieri). ))

((

1. In relazione alle esigenze connesse con il progressivo assestamento dei ruoli degli ufficiali dell'Arma dei carabinieri nonche' al necessario adeguamento della relativa consistenza organica, fermo restando i volumi di cui all'articolo 800, fino alla data del 31 dicembre 2032, la tabella 4 puo' essere aggiornata con decreto del Ministro della difesa, adottato ai sensi dell'articolo 17, comma 3, della legge 23 agosto 1988, n. 400.

))

### Art. 2249. - Ufficiali del ruolo tecnico-operativo dell'Arma dei carabinieri

1. L'avanzamento al grado di maggiore del ruolo tecnico-operativo ha luogo ad anzianita'. Ferme restando le dotazioni complessive del grado nei vari ruoli, nell'aliquota di avanzamento sono inclusi i capitani che abbiano maturato complessivamente dodici anni di anzianita' di servizio dalla nomina a tenente.

### Art. 2250. - Promozione degli ufficiali dei ruoli a esaurimento

1. Ferma restando l'anzianita' richiesta, la promozione degli ufficiali del ruolo a esaurimento ha luogo dopo che siano stati promossi gli ufficiali in servizio permanente effettivo di pari anzianita' di grado, nell'ambito di ciascuna Arma, Corpo o specialita', purche' non siano stati dichiarati non idonei o sia stato sospeso il giudizio di avanzamento per qualsiasi causa.

### Art. 2250-bis. - (( (Periodi di permanenza minima nel grado degli ufficiali piloti di complemento della Marina militare). ))

((

1. Le anzianita' di grado minime previste per l'avanzamento al grado superiore di cui all'articolo 1243, comma 3, lettera a), si applicano agli ufficiali piloti di complemento della Marina militare a partire dagli ufficiali con anzianita' di grado da sottotenente di vascello successiva al 1° gennaio 2004.

))

### Art. 2250-ter. - Regime transitorio per la promozione dei tenenti colonnelli a disposizione).

1. Le promozioni annuali previste dall'articolo 1099, in caso di insufficiente disponibilita' di vacanze nei contingenti massimi dei colonnelli stabiliti per ciascun ruolo, sono conferite in numero pari alle seguenti percentuali degli ufficiali giudicati idonei all'avanzamento, con il riporto di eventuali frazioni di unita':

- a) per l'Esercito, la Marina militare e l'Aeronautica militare, 10 per cento per gli anni 2016, 2017 e 2018 e 5 per cento ((per l'anno 2019 e 10 per cento dal 2020 al 2031;));
- b) per l'Arma dei carabinieri e il Corpo della guardia di finanza, 30 per cento per gli anni 2016, 2017 e 2018, 20 per cento per gli anni 2019, 2020 e 2021 e 10 per cento per gli anni 2022, 2023 e 2024.

### Art. 2250-quater. - (Regime transitorio del collocamento in aspettativa per riduzione dei quadri per gli ufficiali dell'Arma dei carabinieri)

1. Sino al completo esaurimento del ruolo di cui all'articolo 2210-bis e comunque non oltre l'anno 2050, in relazione alle disposizioni di cui all'articolo 2211-bis, il collocamento in aspettativa per riduzione dei quadri degli ufficiali in servizio permanente dei ruoli normale e speciale a esaurimento di cui all'articolo 909, comma 1, lettera d), avviene secondo il seguente ordine:

- a) ufficiali del ruolo speciale a esaurimento in servizio permanente a disposizione;
- b) ufficiali del ruolo normale in servizio permanente a disposizione;
- c) ufficiali del ruolo speciale a esaurimento in servizio permanente effettivo;
- d) ufficiali del ruolo normale in servizio permanente effettivo.

2. Sino alla completa devoluzione delle dotazioni organiche dal ruolo forestale iniziale al ruolo forestale dell'Arma dei carabinieri e comunque non oltre l'anno ((2033)), le disposizioni di cui agli articoli 884, comma 2, lettera d), e comma 3, 906, 908 e 909 non si applicano ai colonnelli e generali del ruolo forestale iniziale dell'Arma dei carabinieri.

### Art. 2250-quinquies. - (( (Disposizioni transitorie per l'avanzamento nei ruoli dei marescialli dell'Aeronautica militare). ))

((

1. Le procedure di avanzamento di cui all'articolo 1273, comma 2-bis, si applicano a partire dalle promozioni decorrenti nell'anno 2020, esclusi i marescialli di 1ª classe precedentemente giudicati idonei ma non promossi.

))

### Art. 2251. - (( (Disposizioni transitorie per l'avanzamento al grado di primo maresciallo dell'Esercito italiano, della Marina militare e dell'Aeronautica militare fino al conferimento delle promozioni relative all'aliquota di avanzamento dell'anno 2016). ))

((

1. Fino al conferimento delle promozioni relative all'aliquota di avanzamento dell'anno 2016, l'avanzamento al grado di primo maresciallo avviene:

- a) a scelta, in misura non inferiore al 70 per cento dei posti disponibili al 31 dicembre di ogni anno;
- b) per concorso per titoli di servizio ed esami, nel limite massimo del 30 per cento dei posti disponibili al 31 dicembre di ogni anno.

2. Con decreto del direttore generale del personale militare, su proposta degli Stati maggiori di Forza armata, sono definite annualmente le percentuali di cui al comma 1.

3. L'avanzamento per concorso per titoli di servizio ed esami e' riservato ai marescialli capi e gradi corrispondenti in possesso del diploma di istituto secondario di secondo grado. La partecipazione al concorso e' limitata a non piu' di due volte, elevate a quattro esclusivamente per i sottufficiali che siano risultati, in tutti i precedenti concorsi cui abbiano partecipato, idonei ma non utilmente collocati nelle relative graduatorie di merito.

4. Per l'inserimento nell'aliquota di avanzamento sono richiesti i periodi di permanenza minima nel grado di maresciallo capo e gradi corrispondenti di seguito indicati:

- a) otto anni, per l'avanzamento a scelta;
- b) quattro anni, per l'avanzamento per concorso per titoli di servizio ed esami.

5. Il numero delle promozioni a primo maresciallo e' stabilito annualmente con decreto del Ministro della difesa in misura non superiore a un trentesimo della consistenza del personale appartenente a ciascuno dei ruoli marescialli determinata per l'anno precedente dal decreto di cui all'articolo 2207 e, per il Corpo delle capitanerie di porto, dall'articolo 814.

6. Il numero di promozioni non conferito con la procedura di avanzamento di cui al comma 1, lettera a), puo' essere devoluto in aumento al numero di promozioni da conferire con la procedura di avanzamento di cui al comma 1, lettera b), e viceversa.

7. I marescialli capi e gradi corrispondenti giudicati idonei e iscritti nel quadro di avanzamento o vincitori del concorso sono promossi al grado di primo maresciallo nell'ordine della graduatoria di merito, con decorrenza dal 1° gennaio dell'anno successivo a quello nel quale e' formata l'aliquota di avanzamento. I marescialli capo e gradi corrispondenti promossi ai sensi del comma 1, lettera a), precedono nel ruolo quelli di cui al comma 1, lettera b).

8. I marescialli capi e gradi corrispondenti inseriti nell'aliquota al 31 dicembre 2016 e non promossi, sono inclusi in un'aliquota straordinaria formata al 1° gennaio 2017 e sono promossi al grado di primo marescialli ai sensi dell'articolo 1277, comma 1, lettera a), nell'ordine di ruolo con le seguenti modalita':

- a) il primo terzo, con decorrenza 1° gennaio 2017. Essi seguono in ruolo i primi marescialli promossi in pari data secondo le previsioni del comma 5;
- b) il secondo terzo, con decorrenza 1° aprile 2017;
- c) il restante terzo, con decorrenza 1° luglio 2017.

))

### Art. 2251-bis. - Disposizioni transitorie per l'avanzamento al grado di primo maresciallo dell'Esercito italiano, della Marina militare e dell'Aeronautica militare

((...))

1. Fermo quanto previsto dall'articolo 2251, fino al conferimento delle promozioni relative all'anno 2021, l'avanzamento al grado di primo maresciallo avviene:

- a) a scelta;
- b) per concorso per titoli di servizio ed esami.

2. L'avanzamento per concorso per titoli di servizio ed esami e' riservato ai marescialli capi e gradi corrispondenti in possesso del diploma di istituto secondario di secondo grado. La partecipazione al concorso e' limitata a non piu' di due volte, elevate a quattro esclusivamente per i sottufficiali che siano risultati, in tutti i precedenti concorsi cui abbiano partecipato, idonei ma non utilmente collocati nelle relative graduatorie di merito.

3. Per l'inserimento nell'aliquota di avanzamento sono richiesti i periodi di permanenza minima nel grado di maresciallo capo e gradi corrispondenti di seguito indicati:

- a) otto anni, per l'avanzamento a scelta;
- b) per l'avanzamento per concorso per titoli di servizio ed esami: 1) cinque anni, per i marescialli capi con anzianita' di grado dal 1° gennaio 2013 al 31 dicembre 2013; 2) sei anni, per i marescialli capi con anzianita' di grado dal 1° gennaio 2014 al 31 dicembre 2014.

4. Le promozioni sono conferite:

- a) per l'avanzamento a scelta, secondo le modalita' di cui all'articolo 1273, comma 2;
- b) per l'avanzamento mediante concorso per titoli di servizio ed esami, nel numero massimo di seguito indicato: 1) Esercito italiano: n. 56; 2) Marina militare: n. 50, di cui n. 7 destinati al Corpo delle capitanerie di porto; 3) Aeronautica militare: n. 78.

5. I marescialli capi e gradi corrispondenti promossi ai sensi del comma 1, lettera a), precedono nel ruolo quelli di cui al comma 1, lettera b).

6. I marescialli capi e gradi corrispondenti inseriti nell'aliquota al 31 dicembre 2017 prendono posto nel ruolo dopo i primi marescialli promossi in pari data ai sensi dell'articolo 2251, comma 8, lettera c).

7. Fino al conferimento delle promozioni relative all'anno 2026, non si applica l'articolo 1274, comma 1-bis.

((

7-bis. Per la composizione delle aliquote di valutazione degli anni dal 2020 al 2029, in deroga all'articolo 1278, comma 1, lettera a), i requisiti di anzianita' richiesti per l'inserimento in aliquota di valutazione a scelta per la promozione al grado di primo maresciallo sono rispettivamente:

- a) 8 anni per i marescialli capi con anzianita' di grado tra il 1° gennaio 2012 e il 31 dicembre 2012;
- b) 7 anni per i marescialli capi con anzianita' di grado tra il 1° gennaio 2013 e il 31 dicembre 2013;
- c) 7 anni per i marescialli capi con anzianita' di grado tra il 1° gennaio 2014 e il 31 dicembre 2019;
- d) 7 anni per i marescialli capi con anzianita' di grado dal 1° gennaio 2020 al 31 dicembre 2020 di cui all'articolo 2251-sexies, comma 1, lettera a).

7-ter. Per il conferimento delle promozioni al grado di primo maresciallo per il 2020, al 31 dicembre 2020 sono formate due distinte aliquote di valutazione, rispettivamente per i marescialli capi sotto elencati:

a) con anzianita' nel grado fino al 31 dicembre 2012;

b) con anzianita' nel grado fino al 31 dicembre 2013.))

((

7-quater. Per gli anni 2020, 2021 e 2022 la decorrenza delle promozioni al grado di primo maresciallo e l'ordine di iscrizione in ruolo sono cosi' disciplinati:

- a) 1° luglio 2020, primi marescialli promossi in prima valutazione con l'aliquota 2020 di cui al comma 7-ter, lettera a);
- b) 2 luglio 2020, prima meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2019;
- c) 3 luglio 2020, seconda meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2018;
- d) 4 luglio 2020, primi marescialli promossi in prima valutazione con l'aliquota di cui al comma 7-ter, lettera b);
- e) 1° luglio 2021, prima meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2020 di cui al comma 7-ter, lettera a);
- f) 2 luglio 2021, seconda meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2019;
- g) 3 luglio 2021, primi marescialli promossi in prima valutazione con l'aliquota 2021;
- h) 4 luglio 2021, prima meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2020 di cui al comma 7-ter, lettera b);
- i) 1° luglio 2022, seconda meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2020 di cui al comma 7-ter, lettera a);
- l) 2 luglio 2022, primi marescialli promossi in prima valutazione con l'aliquota 2022;
- m) 3 luglio 2022, prima meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2021;
- n) 4 luglio 2022, seconda meta' dei marescialli capi non promossi in prima valutazione con l'aliquota 2020 di cui al comma 7-ter, lettera b).

7-quinquies. Per l'anno 2018, in deroga all'articolo 1273, comma 2, lettera a), per i marescialli di 1ª classe dell'Aeronautica militare con anzianita' 2010, la decorrenza delle promozioni a scelta al grado di primo maresciallo e' cosi' determinata:

- a) 1° gennaio 2018 per i marescialli di 1ª classe con anzianita' di grado dal 1° gennaio 2010 al 30 giugno 2010, promossi in prima valutazione;
- b) 1° luglio 2018 per i marescialli di 1ª classe con anzianita' di grado dal 1° luglio 2010 al 31 dicembre 2010, promossi in prima valutazione.

))

### Art. 2251-ter.

(Disposizioni transitorie per ((l'attribuzione)) del grado di luogotenente dell'Esercito italiano, della Marina militare e dell'Aeronautica militare).

1. Dal 1° gennaio 2017, i primi marescialli in servizio ((permanente, ovvero iscritti nel ruolo d'onore e richiamati in servizio,)) in possesso della qualifica di luogotenente assumono il grado di luogotenente in ordine di ruolo e con anzianita' di grado corrispondente all'anzianita' nella qualifica.

2. I primi marescialli inseriti nell'aliquota di valutazione al 31 dicembre 2016, ai quali non e' stata conferita la qualifica di luogotenente ai sensi dell'articolo 2253, commi 1, 1-bis e 1-ter, nonche' i primi marescialli, che alla data di entrata in vigore del presente articolo hanno una permanenza minima nel grado uguale o superiore a quella stabilita dall'articolo 1278, comma 1, lettera b), sono inclusi in un'aliquota straordinaria formata al 1° gennaio 2017 e valutati ai sensi ((dell'articolo 1056, comma 2)).

3. I primi marescialli, inseriti nell'aliquota straordinaria di cui al comma 2, se giudicati idonei, sono promossi al grado di luogotenente in ordine di ruolo con decorrenza giuridica e amministrativa al 1° gennaio 2017, prendendo posto dopo i pari grado promossi con l'aliquota del 31 dicembre 2016.

((

3-bis. Per la composizione delle aliquote di valutazione fino all'anno 2037, in deroga all'articolo 1278, comma 1, lettera b), i requisiti di anzianita' richiesti per l'inserimento in aliquota di valutazione per la promozione al grado di luogotenente, fatte salve le disposizioni di cui al comma 3-quinquies, sono rispettivamente:

- a) 8 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2010 e il 31 dicembre 2012;
- b) 7 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2013 e il 31 dicembre 2013;
- c) 6 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2014 e il 31 dicembre 2014;
- d) 5 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2015 e il 31 dicembre 2015;
- e) 4 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2016 e il 31 dicembre 2016;
- f) 3 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2017 e il 31 dicembre 2017, precedentemente marescialli capi giudicati idonei e promossi nell'aliquota di valutazione del 31 dicembre 2016;
- g) 4 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2017 e il 31 dicembre 2017 di cui all'articolo 2251, comma 8;
- h) 6 anni per i primi marescialli con anzianita' di grado tra il 1° luglio 2017 e il 31 dicembre 2017 di cui all'articolo 2251-bis, comma 6;
- i) 6 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2018 e il 31 dicembre 2021, con precedente anzianita' nel grado di maresciallo capo tra il 1° gennaio 2010 e il 31 dicembre 2011;
- l) 6 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2020 e il 31 dicembre 2022 di cui all'articolo 2251-bis, comma 7-bis, lettera a);
- m) 7 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2020 e il 31 dicembre 2022 di cui all'articolo 2251-bis, comma 7-bis, lettera b);
- n) 7 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2021 e il 31 dicembre 2028, precedentemente marescialli capi con anzianita' fino al 31 dicembre 2019;
- o) 7 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2027 e il 31 dicembre 2029, precedentemente marescialli ordinari promossi marescialli capi con anzianita' 2020 di cui all'articolo 2251-sexies, comma 1, lettera a);
- p) 8 anni per i primi marescialli con anzianita' di grado tra il 1° gennaio 2027 e il 31 dicembre 2029, precedentemente marescialli ordinari promossi marescialli capi con anzianita' 2020 di cui all'articolo 2251-sexies, comma 1, lettera b).

3-ter. Per il conferimento delle promozioni al grado di luogotenente per il 2020, sono formate sei distinte aliquote di valutazione, rispettivamente per i primi marescialli sotto elencati:

- a) con anzianita' di grado tra il 1° gennaio 2012 e il 31 dicembre 2012;
- b) con anzianita' di grado tra il 1° gennaio 2013 e il 31 dicembre 2013;
- c) con anzianita' di grado tra il 1° gennaio 2014 e il 31 dicembre 2014;
- d) con anzianita' di grado tra il 1° gennaio 2015 e il 31 dicembre 2015;
- e) con anzianita' di grado tra il 1° gennaio 2016 e il 31 dicembre 2016;
- f) con anzianita' di grado tra il 1° gennaio 2017 e il 31 dicembre 2017, precedentemente marescialli capi giudicati idonei e promossi con l'aliquota di valutazione del 31 dicembre 2016.

3-quater. Per il conferimento delle promozioni al grado di luogotenente dal 2019 al 2021, in deroga all'articolo 1050, commi 3 e 4, il personale e' incluso in una aliquota formata al 31 dicembre dell'anno solare precedente alla maturazione del requisito minimo di anzianita' stabilito al comma 3-bis.

3-quinquies. Per il conferimento delle promozioni al grado di luogotenente per il 2021, in deroga all'articolo 1050, commi 3 e 4, al 31 dicembre 2020, e' formata un'aliquota di valutazione per i primi marescialli aventi anzianita' dal 1° gennaio 2017 al 31 dicembre 2017 di cui al comma 3-bis, lettera g).

3-sexies. In deroga all'articolo 1282, i primi marescialli di cui al comma 3-bis, lettere a), b), c), d), e), f), e g) sono valutati ai sensi dell'articolo 1056.

3-septies. Per l'anno 2020 la decorrenza delle promozioni al grado di luogotenente e l'ordine di iscrizione in ruolo sono cosi' disciplinati:

- a) 1° gennaio 2020, primi marescialli di cui al comma 3-ter, lettera a);
- b) 2 gennaio 2020, primi marescialli di cui al comma 3-ter, lettera b);
- c) 3 gennaio 2020, primi marescialli di cui al comma 3-ter, lettera c);
- d) 4 gennaio 2020, primi marescialli di cui al comma 3-ter, lettera d);
- e) 5 gennaio 2020, primi marescialli di cui al comma 3-ter, lettera e);
- f) 6 gennaio 2020, primi marescialli di cui al comma 3-ter, lettera f).

3-octies. Per l'anno 2021 la decorrenza delle promozioni al grado di luogotenente e l'ordine di iscrizione in ruolo sono cosi' disciplinati:

- a) 1° gennaio 2021, primi marescialli con anzianita' di grado tra il 1° gennaio 2017 e il 31 marzo 2017 di cui all'articolo 2251, comma 8;
- b) 2 gennaio 2021, primi marescialli con anzianita' di grado tra il 1° aprile 2017 e il 30 giugno 2017 di cui all'articolo 2251, comma 8;
- c) 3 gennaio 2021, primi marescialli con anzianita' di grado tra il 1° luglio 2017 e il 31 dicembre 2017 di cui all'articolo 2251, comma 8.

))

4. Le promozioni di cui al presente articolo non sono comunque conferite al personale che si trova nelle condizioni di cui all'articolo 1051.

((

5. Dal 1° gennaio 2023 al 31 dicembre 2029, in deroga all'articolo 1282, comma 3, il numero di promozioni al grado di luogotenente e' pari al 75 per cento della rispettiva aliquota.

))

### Art. 2251-quater. - (Disposizioni transitorie per l'attribuzione della qualifica di primo luogotenente ai luogotenenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)

1. Il personale che ha assunto il grado di luogotenente, ai sensi dell'articolo 2251-ter, comma 1, e non si trovi nelle condizioni di cui all'articolo 1051 e' inserito in una aliquota straordinaria al 1° ottobre 2017. L'attribuzione della qualifica di primo luogotenente ha decorrenza 1° ottobre 2017.

2. Al personale promosso al grado di luogotenente ai sensi dell'art. 2251-ter, ((commi 2, 3 e 3-bis)), ai fini dell'attribuzione della qualifica di primo luogotenente, fermi restando gli altri requisiti, sono richiesti i periodi di permanenza minima nel grado di seguito indicati:

- a) un anno, per il personale che rivestiva il grado di primo maresciallo non oltre il 2006;
- b) due anni, per il personale che rivestiva il grado di primo maresciallo dal 1° gennaio 2007 al 31 dicembre 2007;
- c) tre anni, per il personale che rivestiva il grado di primo maresciallo dal 1° gennaio 2008 al ((31 dicembre 2009)).
- c-bis) due anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2018 e il 31 dicembre 2018;
- c-ter) un anno, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2019 e il 31 dicembre 2019;
- c-quater) un anno, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2020 e il 31 dicembre 2020, di cui all'articolo 2251-ter, comma 3-ter, lettera a);
- c-quinquies) due anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2020 e il 31 dicembre 2020, di cui all'articolo 2251-ter, comma 3-ter, lettera b);
- c-sexies) tre anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2020 e il 31 dicembre 2020, di cui all'articolo 2251-ter, comma 3-ter, lettera c);
- c-septies) quattro anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2020 e il 31 dicembre 2020, di cui all'articolo 2251-ter, comma 3-ter, lettera d);
- c-octies) cinque anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2020 e il 31 dicembre 2020, di cui all'articolo 2251-ter, comma 3-ter, lettera e);
- c-nonies) sei anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2020 e il 31 dicembre 2020, di cui all'articolo 2251-ter, comma 3-ter, lettera f);
- c-decies) sei anni, per i luogotenenti con anzianita' di grado compresa tra il 1° gennaio 2021 e il 31 dicembre 2021, di cui all'articolo 2251-ter, comma 3-bis, lettera g).

((

2-bis. Per le qualifiche da attribuire dal 2019 al 2027, in deroga alle disposizioni di cui all'articolo 1323, comma 1, i luogotenenti con anzianita' di grado 1° gennaio a cui attribuire la qualifica di primo luogotenente sono inclusi in una aliquota formata al 31 dicembre dell'anno solare precedente alla maturazione del requisito minimo di anzianita' stabilito dal comma 2.

2-ter. Ai luogotenenti esclusi dalle aliquote di cui ai commi 1, 2 e 2-bis per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del titolo VII, in materia di rinnovazione dei giudizi di avanzamento.

2-quater. I luogotenenti esclusi dalle aliquote cui ai commi 1, 2 e 2-bis per mancanza dei requisiti di cui all'articolo 1323, comma 1, lettere c) e d), sono inseriti nella prima aliquota successiva alla data di maturazione di tali requisiti e la qualifica speciale e' conferita a decorrere dal giorno successivo a tale data.

2-quinquies. Per l'anno 2020 la decorrenza della qualifica di primo luogotenente e l'ordine di iscrizione in ruolo sono cosi' disciplinati:

- a) 1° gennaio 2020, luogotenenti con anzianita' di grado dal 1° gennaio 2017 al 31 dicembre 2017, precedentemente primi marescialli con anzianita' 2008;
- b) 2 gennaio 2020, luogotenenti con anzianita' di grado dal 1° gennaio 2017 al 31 dicembre 2017, precedentemente primi marescialli con anzianita' 2009;
- c) 3 gennaio 2020, luogotenenti con anzianita' di grado dal 1° gennaio 2018 al 31 dicembre 2018, precedentemente primi marescialli con anzianita' 2010;
- d) 4 gennaio 2020, luogotenenti con anzianita' di grado dal 1° gennaio 2019 al 31 dicembre 2019, precedentemente primi marescialli con anzianita' 2011.

2-sexies. Per l'anno 2027 la decorrenza della qualifica di primo luogotenente e l'ordine di iscrizione in ruolo sono cosi' disciplinati:

- a) 1° gennaio 2027, luogotenenti con anzianita' di grado dal 1° gennaio 2021 al 31 marzo 2021, precedentemente primi marescialli con anzianita' di grado dal 1° gennaio 2017 al 31 marzo 2017;
- b) 2 gennaio 2027, luogotenenti con anzianita' di grado dal 1° aprile 2021 al 30 giugno 2021, precedentemente primi marescialli con anzianita' di grado dal 1° aprile 2017 al 30 giugno 2017;
- c) 3 gennaio 2027, luogotenenti con anzianita' di grado dal 1° luglio 2021 al 31 dicembre 2021, precedentemente primi marescialli con anzianita' di grado dal 1° luglio 2017 al 31 dicembre 2017;
- d) 1° luglio 2027, luogotenenti con anzianita' di grado dal 1° luglio 2023 al 31 dicembre 2023.

))

### Art. 2251-quinquies. - (Regime transitorio per le promozioni del ruolo dei musicisti)

1. I primi marescialli e gradi corrispondenti in possesso della qualifica di luogotenente, appartenenti al ruolo dei musicisti, in servizio alla data del 31 dicembre 2016, sono inseriti in una aliquota straordinaria formata al 1° gennaio 2017 e assumono il grado di luogotenente in ordine di ruolo e con anzianita' di grado corrispondente all'anzianita' nella qualifica.

2. I primi marescialli e gradi corrispondenti, appartenenti al ruolo dei musicisti, in servizio alla data del 31 dicembre 2016, sono inseriti in una aliquota straordinaria formata al 1° gennaio 2017 e se in possesso di anzianita' di grado uguale o superiore a quanto stabilito dall'articolo 1521, comma 2, lettera b-bis), sono valutati e promossi al grado di luogotenente con anzianita' 1° gennaio 2017.

3. I luogotenenti e gradi corrispondenti, promossi ai sensi del comma 1, ((...)) sono inseriti in una aliquota straordinaria al 1° ottobre 2017. L'attribuzione della qualifica di primo luogotenente ha decorrenza 1° ottobre 2017.

4. Per i luogotenenti e gradi corrispondenti, promossi ai sensi del comma 2, ai fini del compimento del periodo minimo di permanenza previsto dall'articolo 1522, e' computata la parte eccedente dell'anzianita' maturata nel precedente grado. Se da tale computo risulta una anzianita' uguale o superiore a quanto previsto dall'articolo 1522, detti sottufficiali sono inseriti in una aliquota straordinaria al 1° ottobre 2017. L'attribuzione della qualifica di primo luogotenente ha decorrenza 1° ottobre 2017, in ordine di ruolo dopo i primi luogotenenti di cui al comma 3.

5. Ai fini delle promozioni di cui al presente articolo non devono ricorrere le condizioni di cui all'articolo 1051.

### Art. 2251-sexies. - (( (Disposizioni transitorie per l'avanzamento al grado di maresciallo ordinario, maresciallo capo e gradi corrispondenti del personale dei ruoli dei marescialli dell'Esercito italiano, della Marina militare e dell'Aeronautica militare).))

((

1. Per la composizione delle aliquote di valutazione dell'anno 2020, in deroga all'articolo 1278, comma 3, lettera b), i requisiti di anzianita' richiesti per l'avanzamento ad anzianita' al grado di maresciallo capo e corrispondenti, sono rispettivamente:

- a) 7 anni per i marescialli ordinari con anzianita' di grado tra il 1° gennaio 2013 e il 31 dicembre 2013;
- b) 6 anni per i marescialli ordinari con anzianita' di grado tra il 1° gennaio 2014 e il 31 dicembre 2014.

2. Per il conferimento delle promozioni al grado di maresciallo capo dell'anno 2020, al 31 dicembre 2020 sono formate due aliquote, rispettivamente per i marescialli ordinari sotto elencati:

- a) con anzianita' di grado tra il 1° gennaio 2013 e il 31 dicembre 2013;
- b) con anzianita' di grado tra il 1° gennaio 2014 e il 31 dicembre 2014.

3. I marescialli capi di cui al comma 2, lettera b), sono promossi con decorrenza giuridica il giorno successivo ai marescialli capi di cui al comma 2, lettera a).

4. In deroga all'articolo 1050, commi 3 e 4, per l'avanzamento al grado di maresciallo ordinario e maresciallo capo, il personale di cui all'articolo 2197-ter, comma 4, lettera a), numero 1), avente decorrenza di grado 1° gennaio, e' incluso in un'aliquota di valutazione formata al 31 dicembre dell'anno solare precedente alla maturazione del requisito minimo di anzianita' stabilito dall'articolo 1278.

))

### Art. 2251-septies. - (( (Regime transitorio per le promozioni degli orchestrali e archivisti).))

((

1. Il personale appartenente al ruolo dei musicisti, comunque in servizio alla data del 1° gennaio 2020, che riveste il grado di maresciallo ordinario e maresciallo capo, in possesso di anzianita' di grado uguale o superiore a quanto stabilito dall'articolo 1521, comma 2, e' incluso in una aliquota straordinaria al 1° gennaio 2020 e promosso al grado superiore, previo giudizio di idoneita' espresso dalla commissione permanente di avanzamento.

2. Per il personale che alla data del 1° gennaio 2020 riveste il grado di maresciallo capo, primo maresciallo e luogotenente, e gradi corrispondenti, in relazione a quanto previsto dagli articoli 1521 e 1522, ai fini dell'avanzamento al grado superiore e' computata la parte eccedente di anzianita' maturata nei precedenti gradi.

3. Il personale che ha maturato l'anzianita' prevista per l'avanzamento al grado superiore o per l'attribuzione della qualifica speciale e' incluso in una aliquota straordinaria formata al 1° gennaio 2020 e valutato dalla relativa commissione di avanzamento.

))

### Art. 2252. - Regime transitorio dell'avanzamento al grado di maresciallo maggiore

((...))

1. I marescialli aiutanti sostituti ufficiali di pubblica sicurezza in servizio al 1° gennaio 2017 sono iscritti in ruolo con il grado di maresciallo maggiore mantenendo l'anzianita' di servizio e di grado.

2. I marescialli capo dell'Arma dei carabinieri iscritti nel quadro di avanzamento al 31 dicembre 2016 e non promossi, in deroga alle disposizioni sull'avanzamento del personale del ruolo ispettori dell'Arma dei carabinieri, sono promossi nell'ordine del proprio ruolo al grado superiore con le seguenti modalita':

- a) il primo terzo, con decorrenza 1° gennaio 2017, prendendo posto in ruolo dopo i parigrado promossi con l'aliquota formata al 31 dicembre 2016;
- b) il secondo terzo, con decorrenza 1° aprile 2017;
- c) il restante terzo, con decorrenza 1° luglio 2017.

((

3. In relazione alle promozioni di cui al comma 2 e al fine di garantire l'armonico sviluppo del ruolo, a parziale deroga di quanto previsto dall'articolo 1295-bis, comma 3, per gli anni 2020 e 2021 il numero delle promozioni annuali al grado di luogotenente e' stabilito in misura non superiore a 1/7 della dotazione organica del ruolo ispettori dell'Arma dei carabinieri di cui all'articolo 800, comma 2.

))

4. I marescialli capo e i periti capo dei ruoli forestali dell'Arma dei carabinieri con permanenza minima nel grado uguale o superiore a quella prevista dalla tabella 4, quadri VI e IX, allegata al presente codice, sono inclusi in un'aliquota straordinaria formata al 1° gennaio 2017, valutati ai sensi dell'articolo 1059 e promossi nell'ordine del proprio ruolo al grado superiore con le seguenti modalita':

- a) il primo terzo, con decorrenza 1° gennaio 2017;
- b) il secondo terzo, con decorrenza 1° aprile 2017;
- c) il restante terzo, con decorrenza 1° luglio 2017.

5. Il giudizio espresso dalla commissione di cui all'articolo 1047 in occasione della aliquota di avanzamento del 31 dicembre 2016 vale anche ai fini della promozione di cui al comma 2.

6. Il personale risultato idoneo nell'aliquota del 31 dicembre 2017 e promosso ai sensi dell'articolo 1295 comma 1, lettera a), prende posto nel ruolo dopo i militari promossi ai sensi del comma 2.

7. Il personale risultato idoneo nell'aliquota del 31 dicembre 2017 e promosso ai sensi dell'articolo 2247-duodecies comma 1, lettera a), prende posto nel ruolo dopo i militari promossi ai sensi del comma 4.

8. Le promozioni di cui ai commi 2 e 4 non sono comunque conferite al personale che si trovi nelle condizioni di cui all'articolo 1051.

9. Le promozioni disponibili al grado di maresciallo aiutante determinate nei limiti disponibili al 31 dicembre 2016, sono devolute interamente alla procedura di avanzamento a «scelta».

9-bis. Il periodo di comando valido ai fini dell'avanzamento previsto dall'articolo 1294 viene considerato compiuto per i marescialli capo del ruolo ispettori, con decorrenza del grado fino al 2016 compreso, e per il personale dei ruoli forestali.

9-ter. I marescialli capo dell'Arma dei carabinieri inclusi nell'aliquota formata al 31 dicembre 2016 e promossi marescialli aiutanti sostituti ufficiali di pubblica sicurezza nel novero delle promozioni disponibili, nonche', alla medesima data, i marescialli aiutanti sostituti ufficiali di pubblica sicurezza in servizio e i militari dei ruoli forestali dell'Arma dei carabinieri che rivestivano le corrispondenti qualifiche nel Corpo forestale dello Stato, i quali maturano il periodo di permanenza minimo nel grado per la promozione al grado di luogotenente e per la successiva attribuzione della qualifica di carica speciale con decorrenza 1° gennaio, sono inseriti nell'aliquota formata al 31 dicembre antecedente, ferme restando le modalita' e i termini previsti dagli articoli 1295-bis, 1325-bis, 2247-bis, 2247-decies, 2247-undecies, 2253-bis e 2253-ter.

((

9-quater. I marescialli capo dell'Arma dei carabinieri inclusi nell'aliquota di valutazione determinata al 31 dicembre 2019, giudicati idonei e non promossi perche' non utilmente ricompresi nei quadri di avanzamento, sono promossi, in ordine di ruolo, al grado di maresciallo maggiore, prendendo posto nel ruolo dopo i parigrado promossi nell'anno. A tal fine, il giudizio espresso dalla commissione di cui all'articolo 1047, in occasione della citata aliquota del 31 dicembre 2019, vale anche ai fini del conseguimento della promozione di cui al presente comma.

))

((

9-quinquies. I marescialli capi con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2012, avendo compiuto il periodo di permanenza minimo nel grado previsto dall'articolo 1293 e dalla tabella 4, quadri VI e IX, sono inclusi in una aliquota straordinaria formata al 1° gennaio 2020 e valutati dalla commissione di cui all'articolo 1047. Se giudicati idonei sono promossi, in ordine di ruolo, al grado di maresciallo maggiore, a decorrere dal 31 dicembre 2019, prendendo posto dopo il personale promosso ai sensi del comma 9-quater.

))

((

9-sexies. Al fine di assicurare l'armonico sviluppo del ruolo, i marescialli capi con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013, se giudicati idonei, sono promossi al grado di maresciallo maggiore, in deroga a quanto previsto dall'articolo 1295, in ordine di ruolo, a decorrere dal giorno successivo al compimento del periodo minimo, previsto dall'articolo 1293 e dalla tabella 4, quadri VI e IX.

))

((

9-septies. Per il personale che riveste il grado di maresciallo capo con anzianita' compresa fra il 1° gennaio 2014 e il 31 dicembre 2018, ovvero i marescialli ordinari che hanno conseguito il grado di maresciallo capo con l'aliquota del 31 dicembre 2019, fermi restando gli altri requisiti, la permanenza minima nel grado richiesta per la promozione al grado di maresciallo maggiore, in deroga a quanto indicato dall'articolo 1293 e dalla tabella 4, quadri VI e IX, e' di 6 anni.

))

### Art. 2252-bis. - (( (Regime transitorio dell'avanzamento al grado di maresciallo capo) ))

((

.

1. I marescialli ordinari con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013 avendo compiuto il periodo di permanenza minimo nel grado previsto dall'articolo 1293 e dalla tabella 4, quadri VI e IX, sono inclusi in una aliquota straordinaria formata al 1° gennaio 2020 e valutati dalla commissione di cui all'articolo 1047. Se giudicati idonei sono promossi in ordine di ruolo prendendo posto dopo l'ultimo dei promossi con l'aliquota del 31 dicembre 2019.

))

### Art. 2252-ter. - (( (Rivalutazione del personale giudicato non idoneo all'avanzamento) ))

((

.

1. I militari inclusi nell'aliquota di avanzamento del 31 dicembre 2019 e giudicati non idonei sono nuovamente valutati e a tal fine inclusi nell'aliquota del 31 dicembre 2020. I medesimi, se giudicati idonei, sono promossi con le stesse modalita' e decorrenze attribuite ai parigrado con i quali sono stati portati in avanzamento.

))

### Art. 2253. - Regime transitorio per l'attribuzione della qualifica di luogotenente

((

1. Ai primi marescialli, che fino al 2016 maturano quattordici anni di permanenza minima nel grado, puo' essere conferita la qualifica di luogotenente, previa valutazione secondo i criteri stabiliti dall'articolo 1059, secondo la graduatoria di merito a decorrere dal giorno successivo a quello di maturazione del periodo minimo di permanenza nel grado piu' un ulteriore anno.

))

((

1-bis. Con decreto dirigenziale sono determinate al 31 dicembre di ciascun anno le aliquote di valutazione dei primi marescialli da valutare per l'attribuzione della qualifica di cui al comma 1. In relazione alle esigenze funzionali e ordinative di ciascuna Forza armata, con decreto del Ministro della difesa e' stabilito il numero delle qualifiche da attribuire, che comunque non deve superare la misura di due ventiduesimi degli organici del medesimo grado stabiliti dal presente codice ovvero dal decreto adottato ai sensi dell'articolo 2207.

1-ter. Per i primi marescialli con anzianita' di grado compresa tra il 15 aprile 2001 ed il 31 dicembre 2005, ai fini dell'inclusione nell'aliquota di valutazione per l'attribuzione della qualifica di luogotenente di cui ai commi 1 e 1-bis, e' richiesto, in riferimento agli indicati periodi di conferimento della promozione al grado di primo maresciallo, il requisito di anzianita' nel grado di seguito riportato:

- a) dal 15 aprile 2001 al 31 dicembre 2002: otto anni;
- b) dal 1° gennaio 2003 al 31 dicembre 2003: nove anni;
- c) dal 1° gennaio 2004 al 31 dicembre 2004: dieci anni;
- d) dal 1° gennaio 2005 al 31 dicembre 2005: undici anni.

))

2. ((Fino al 2016)), allo scopo di assicurare l'armonico sviluppo del ruolo, il conferimento della qualifica di <<luogotenente>> per l'Esercito italiano, la Marina militare e l'Aeronautica militare avviene sulla base delle esigenze ordinativo-funzionali di ciascuna Forza armata e della trasformazione progressiva dello strumento militare in professionale.

3. ((COMMA ABROGATO DAL D.LGS. 29 MAGGIO 2017, N. 94)).

4. I marescialli aiutanti dell'Arma dei carabinieri, comunque in servizio al 1° gennaio 2005, che al 31 agosto 1995 rivestivano il grado di maresciallo maggiore, la qualifica di <<carica speciale>> o di <<aiutante>> del disciolto ruolo sottufficiali i quali alla medesima data del 1° gennaio 2005 non risultano in possesso dei requisiti di cui all'articolo 1324, comma 1, conseguono la qualifica di <<luogotenente>>, con decorrenza dal giorno successivo a quello di maturazione dei requisiti di cui allo stesso articolo 1324, comma 1, ferme restando le condizioni ivi previste.

5. Per il conferimento della qualifica di luogotenente riferito agli anni 2005, 2006, 2007 e 2008, in deroga ai requisiti di anzianita' previsti dall'articolo 1324, comma 1, e fermi restando gli altri requisiti e le condizioni di cui al medesimo articolo, ai marescialli aiutanti dell'Arma dei carabinieri e' richiesta una permanenza minima nel grado di sette anni per il personale con anzianita' di grado compresa tra il 1° settembre 1995 ed il 31 dicembre 1995 e di sette anni e sei mesi per il personale con anzianita' di grado compresa tra il 1° gennaio 1996 e il 14 aprile 2001.

6. Dal 2002 e fino al 2008, fermi restando i requisiti previsti dai commi 4 e 5, nonche' accertati quelli di cui all'articolo 1324, comma 1, la qualifica di <<luogotenente>> e' conferita ai marescialli aiutanti dell'Arma dei carabinieri di maggiore anzianita' in ordine di ruolo fino alla concorrenza dei posti annualmente disponibili.

7. Per i marescialli aiutanti con anzianita' di grado compresa tra il 15 aprile 2001 ed il ((31 dicembre 2005)), fermi restando gli altri requisiti e le condizioni previste dall'articolo 1324, comma 1, per l'ammissione alla procedura selettiva per il conseguimento della qualifica di luogotenente e' richiesto il requisito di anzianita' nel grado di maresciallo aiutante come di seguito indicato:

- a) dal 15 aprile 2001 al 31 dicembre 2002: 9 anni;
- b) dal 1° gennaio 2003 al 31 dicembre 2003: 10 anni;
- c) dal 1° gennaio 2004 al 31 dicembre 2004: 11 anni;
- d) dal 1° gennaio 2005 al 31 dicembre 2005: 12 anni;
- e) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95));
- f) ((LETTERA SOPPRESSA DAL D.LGS. 29 MAGGIO 2017, N. 95)).

### Art. 2253-bis. - (Promozione al grado di luogotenente e di perito superiore scelto)

((62))

1. I marescialli aiutanti luogotenenti in servizio al 1° gennaio 2017 sono iscritti in ruolo con il grado di luogotenente mantenendo l'anzianita' di servizio e con anzianita' di grado corrispondente all'anzianita' nella qualifica.

2. I periti superiori scelti in servizio al 1° gennaio 2017 sono iscritti in ruolo con il grado di perito superiore scelto mantenendo l'anzianita' di servizio e con anzianita' di grado corrispondente all'anzianita' nella qualifica.

3. I marescialli aiutanti iscritti nella graduatoria di merito per il conferimento della qualifica di luogotenente del 31 dicembre 2016 e non promossi, nonche' i marescialli aiutanti che al 1° gennaio 2017 hanno un periodo di permanenza minima nel grado uguale o superiore a quanto previsto dall'articolo 1293, comma 1, lettera b), sono inclusi in un aliquota straordinaria formata al 1° gennaio 2017 e valutati secondo quanto previsto dall'articolo 1295-bis, comma 4.

4. I marescialli aiutanti del ruolo forestale degli ispettori dell'Arma dei carabinieri che al 1° gennaio 2017 hanno un periodo di permanenza minima nel grado uguale o superiore a quanto previsto dalla tabella 4, quadro VI, sono inclusi in un aliquota straordinaria formata al 1° gennaio 2017 e valutati secondo quanto previsto dall'articolo 2247-decies.

5. I periti superiori che alla data del 1° gennaio 2017 hanno un periodo di permanenza minima nel grado uguale o superiore a quanto previsto dal comma 9-bis dell'articolo 2247-bis, sono inclusi in un aliquota straordinaria formata al 1° gennaio 2017 e valutati secondo quanto previsto dall'articolo 2247-undecies.

6. I militari giudicati idonei all'avanzamento nell'aliquota di cui al comma 3 sono promossi al grado di luogotenente ed iscritti in ruolo secondo l'ordine del grado di provenienza, con decorrenza giuridica e amministrativa il 1° gennaio 2017.

7. I militari giudicati idonei all'avanzamento nell'aliquota di cui al comma 4 sono promossi al grado perito superiore scelto, con decorrenza giuridica e amministrativa il 1° gennaio 2017.

8. I militari giudicati idonei all'avanzamento nell'aliquota di cui al comma 5 sono promossi al grado perito superiore scelto, con decorrenza giuridica e amministrativa il 1° gennaio 2017.

9. Il personale promosso ai sensi dei commi 6, 7 e 8 e' iscritto in ruolo prendendo posto dopo i militari promossi con l'aliquota del 31 dicembre 2016.

((

9-bis. Il personale in servizio alla data del 1° gennaio 2020, che al 31 dicembre 2016 rivestiva il grado di maresciallo aiutante, non compreso nell'aliquota straordinaria di cui ai commi 3, 4 e 5, consegue la promozione al grado di luogotenente, in deroga a quanto indicato dall'articolo 1293 e dalla tabella 4, quadri VI e IX, secondo le modalita' previste dagli articoli 1295-bis, 2247-decies e 2247-undecies, al compimento di cinque anni di servizio effettivo, maturati anche nella qualifica di ispettore superiore e di perito superiore del Corpo forestale dello Stato.

9-ter. I marescialli maggiori con anzianita' compresa fra il 1° gennaio 2013 e il 31 dicembre 2015, avendo compiuto il periodo di permanenza minimo nel grado previsto dal comma 9-bis, sono inclusi in una aliquota straordinaria formata al 1° gennaio 2020 e valutati dalla commissione di cui all'articolo 1047. Se giudicati idonei, sono promossi al grado di luogotenente, in deroga al comma 3 dell'articolo 1295-bis, in ordine di ruolo, a decorrere dal 1° gennaio 2020, prendendo posto dopo il personale promosso con l'aliquota del 31 dicembre 2019.

9-quater. Fermo restando quanto previsto dall'articolo 2253-ter, comma 4-quater, lettere e), f) e g), i marescialli maggiori promossi:

- a) con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016 e il personale promosso al grado di maresciallo aiutante perche' risultato compreso nel novero dei posti disponibili per l'aliquota del 31 dicembre 2016, sono inclusi in una aliquota straordinaria formata al 1° gennaio 2020 e valutati dalla commissione di cui all'articolo 1047. Se giudicati idonei, sono promossi al grado di luogotenente, in deroga al comma 3 dell'articolo 1295-bis, in ordine di ruolo, a decorrere dal 1° gennaio 2020, prendendo posto dopo il personale di cui al comma 9-ter;
- b) ai sensi dell'articolo 2252, commi 2 e 4 sono inclusi in una aliquota straordinaria formata al 1° gennaio 2021 e valutati dalla commissione di cui all'articolo 1047. Se giudicati idonei, sono promossi al grado di luogotenente, in deroga al comma 3 dell'articolo 1295-bis, in ordine di ruolo, a decorrere dal 1° gennaio 2021.

9-quinquies. Il personale promosso al grado di maresciallo maggiore ai sensi dell'articolo 2252, commi 6 e 7, ovvero promosso con le aliquote del 31 dicembre 2018 e del 31 dicembre 2019, consegue la promozione al grado di luogotenente, in deroga a quanto indicato dall'articolo 1293, al compimento di sei anni di servizio effettivo nel grado.

9-sexies. Per il personale che rivestiva il grado di maresciallo capo dal 1° gennaio al 31 dicembre 2012, promosso al grado di maresciallo maggiore ai sensi dell'articolo 2252, commi 9-quater e 9-quinquies, fermi restando gli altri requisiti, la permanenza minima nel grado richiesta, in deroga a quanto indicato dall'articolo 1293 e dalla tabella 4, quadri VI e IX, per il conseguimento del grado di luogotenente, e' di 7 anni.

9-septies. Per il personale che rivestiva il grado di maresciallo capo dal 1° gennaio al 31 dicembre 2013, fermi restando gli altri requisiti, la permanenza minima nel grado richiesta, in deroga a quanto indicato dall'articolo 1293 e dalla tabella 4, quadri VI e IX, per il conseguimento del grado di luogotenente, e' di 7 anni.

))

10. Le promozioni di cui al presente articolo non sono comunque conferite al personale che si trovi nelle condizioni di cui all'articolo 1051.

11. Ai fini dell'iscrizione in ruolo del personale di cui ai commi 1 e 2, nell'anzianita' di grado posseduta, non sono computati i periodi che hanno causato la rideterminazione, a qualsiasi titolo, dell'anzianita' nel grado di maresciallo aiutante sostituto ufficiale di pubblica sicurezza e gradi corrispondenti in data successiva al conferimento della qualifica di luogotenente e gradi corrispondenti.

((11-bis. I marescialli aiutanti iscritti nel ruolo d'onore e richiamati in servizio alla data del 1° gennaio 2017 sono inquadrati nel grado di luogotenente con l'anzianita' di grado posseduta.))

--------------- AGGIORNAMENTO (62) Il D.Lgs. 27 dicembre 2019, n. 172 ha disposto (con l'art. 25, comma 1, lettera o)) che "Al codice dell'ordinamento militare di cui al decreto legislativo 15 marzo 2010, n. 66, sono apportate le seguenti modificazioni:[...] o) all'articolo 2253-bis: 1) nella rubrica, le parole: «e perito superiore scelto» sono soppresse".

### Art. 2253-ter.

(Assunzione della qualifica di luogotenente carica speciale ((...)) ).

1. Al personale iscritto in ruolo con il grado di luogotenente ai sensi dell'articolo 2253-bis, comma 1, che non si trovi nelle condizioni di cui all'articolo 1051, in deroga al periodo minimo di permanenza indicato dall'articolo 1325-bis, comma 1 lettera a), e' attribuita la qualifica di carica speciale con decorrenza dal 1° ottobre 2017.

2. Al personale iscritto in ruolo con il grado di perito superiore scelto ai sensi dell'articolo 2253-bis, comma 2, che non si trovi nelle condizioni di cui all'articolo 1051, in deroga al periodo minimo di permanenza indicato dall'articolo 2247-bis, comma 8-bis, lettera a), e' attribuita la qualifica di primo perito superiore con decorrenza dal 1° ottobre 2017.

3. Al fine dell'accertamento dell'assenza di cause impeditive previste dall'articolo 1051, il personale di cui ai commi precedenti e' incluso nell'aliquota di valutazione straordinaria formata alla data del 30 settembre 2017.

4. Per il personale promosso al grado di luogotenente ai sensi dell'articolo 2253-bis, commi 3 e 4, fermi restando gli altri requisiti, la permanenza minima nel grado richiesta, in deroga a quanto indicato dall'articolo 1325-bis, comma 1, lettera a), per il conseguimento della carica speciale, e' la seguente:

- a) per il personale che rivestiva il grado di maresciallo aiutante non oltre il 2006: 1 anno;
- b) per il personale che rivestiva il grado di maresciallo aiutante dal 1° gennaio 2007 al 31 dicembre 2007: 2 anni;
- c) per il personale che rivestiva il grado di maresciallo aiutante dal 1° gennaio 2008 al 31 dicembre 2008: 3 anni.

((

4-bis. Alla data del 1° gennaio 2020, al fine di assicurare l'armonico sviluppo del ruolo per l'attribuzione della qualifica di carica speciale e' formata un'aliquota straordinaria nella quale sono inclusi:

- a) i luogotenenti con anzianita' 2017, che rivestivano il grado di maresciallo maggiore con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2009;
- b) i luogotenenti con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2018;
- c) i luogotenenti con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2019.

4-ter. Ai luogotenenti inclusi nell'aliquota straordinaria di cui al comma 4-bis e' attribuita la qualifica di carica speciale a decorrere dal 1° gennaio 2020, previa verifica del possesso dei requisiti di cui all'articolo 1325-bis, prendendo posto in ruolo dopo i pari grado promossi con l'aliquota del 31 dicembre 2019.

4-quater. Al fine di assicurare l'armonico sviluppo del ruolo, le aliquote di valutazione per l'attribuzione della qualifica di carica speciale, in deroga alla permanenza nel grado prevista dagli articoli 1325-bis e 2247-bis, sono le seguenti:

- a) per l'anno 2021, i marescialli maggiori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2012;
- b) per l'anno 2022, i marescialli maggiori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013;
- c) per l'anno 2023, i marescialli maggiori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014;
- d) per l'anno 2024, i marescialli maggiori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015;
- e) per l'anno 2025, i marescialli maggiori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016;
- f) per l'anno 2026, il personale promosso al grado di maresciallo aiutante perche' risultato compreso nel novero dei posti disponibili per l'aliquota del 31 dicembre 2016;
- g) per l'anno 2027, il personale promosso al grado di maresciallo maggiore, ai sensi dell'articolo 2252, commi 2 e 6.

))

5. Per il personale promosso al grado di perito superiore scelto ai sensi dell'art. 2253-bis, comma 5, fermi restando gli altri requisiti e le condizioni previste dall'articolo 2247-bis, comma 8-bis, la permanenza minima nel grado richiesta, in deroga a quanto indicato nel medesimo comma, e' la seguente:

- a) per il personale che rivestiva la qualifica di perito superiore non oltre il 2006: 1 anno;
- b) per il personale che rivestiva la qualifica di perito superiore dal 1° gennaio 2007 al 31 dicembre 2007: 2 anni;
- c) per il personale che rivestiva la qualifica di perito superiore dal 1° gennaio 2008 al 31 dicembre 2008: 3 anni.

((

5-bis. I commi 4-bis, 4-ter e 4-quater si applicano anche al personale dei corrispondenti ruoli forestali degli ispettori e dei periti dell'Arma dei carabinieri.

))

### Art. 2253-quater. - (Regime transitorio per le promozioni nei ruoli dei sovrintendenti e dei revisori dell'Arma dei carabinieri)

1. I brigadieri dell'Arma dei carabinieri inclusi nell'aliquota di valutazione determinata al 31 dicembre 2016, giudicati idonei e non promossi perche' non utilmente ricompresi nei quadri di avanzamento, sono promossi, in ordine di ruolo, al grado di brigadiere capo con decorrenza dal 1° gennaio 2017. A tal fine, il giudizio espresso dalla Commissione di cui all'articolo 1047, in occasione della citata aliquota del 31 dicembre 2016, vale anche ai fini del conseguimento della promozione di cui al presente comma.

2. I brigadieri capo promossi ai sensi del comma 1 prendono posto nel ruolo dopo i parigrado promossi con l'aliquota del 31 dicembre 2016.

3. I brigadieri e i revisori che alla data del 1° gennaio 2017 hanno un periodo di permanenza minima nel grado uguale o superiore a quanto previsto dall'articolo 1299 o dalla tabella 4, quadri VII e X, o che comunque hanno conseguito la promozione entro il 31 dicembre 2013 sono inclusi in un aliquota straordinaria formata al 1° gennaio 2017.

4. I brigadieri e i revisori risultati idonei nell'aliquota di cui al comma 3, conseguono la promozione rispettivamente a brigadiere capo e revisore capo con decorrenza giuridica e amministrativa il 1° gennaio 2017.

5. Il personale promosso ai sensi del comma 4 prende posto in ruolo dopo i militari promossi ai sensi del comma 1.

6. I vice brigadieri e i vice revisori che al 1° gennaio 2017 hanno un periodo di permanenza minima nel grado uguale o superiore a quanto previsto dall'articolo 1299 o dalla tabella 4, quadri VII e X, sono inclusi in un aliquota straordinaria formata al 1° gennaio 2017.

7. I vice brigadieri e i vice revisori risultati idonei nell'aliquota di cui al comma 6, conseguono la promozione rispettivamente a brigadiere e revisore con decorrenza giuridica e amministrativa il 1° gennaio 2017.

8. I vice brigadieri che hanno conseguito la nomina nel corso del 2012, promossi ai sensi dell'articolo 1298 o dalla tabella 4, quadro VII, per il ruolo forestale dell'Arma dei carabinieri, sono iscritti in ruolo prendendo posto dopo i sovrintendenti promossi ai sensi del comma 7.

9. I vice revisori che hanno conseguito la nomina nel corso del 2012, promossi ai sensi della tabella 4, quadro X, sono iscritti in ruolo prendendo posto dopo i pari grado promossi ai sensi del comma 7.

((

9-bis. I vice brigadieri che hanno conseguito la nomina nel grado tra il 1° gennaio e il 31 dicembre 2015, sono inclusi in un'aliquota straordinaria formata al 1° gennaio 2020.

9-ter. I vice brigadieri risultati idonei nell'aliquota di cui al comma 9-bis, conseguono la promozione a brigadiere con decorrenza giuridica e amministrativa al 1° gennaio 2020.

9-quater. Al fine di assicurare l'armonico sviluppo dei ruoli, l'aliquota di valutazione per l'anno 2020, sara' formata dai vice brigadieri con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016.

9-quinquies. I brigadieri promossi ai sensi del comma 9-quater sono iscritti in ruolo prendendo posto dopo quelli promossi ai sensi del comma 9-ter.

))

10. Effettuate le promozioni di cui ai commi precedenti, al fine di assicurare l'armonico sviluppo del ruolo e il graduale raggiungimento delle nuove dotazioni organiche, le aliquote di valutazione dei sovrintendenti e revisori sono fissate secondo i seguenti criteri:

- a) per l'avanzamento al grado di brigadiere capo, fermi restando gli altri requisiti, in deroga alla permanenza nel grado prevista dall'articolo 1299 e dalla tabella 4, quadro VII, sono inclusi in aliquota di avanzamento: 1) per l'anno 2017, i brigadieri con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014; 2) per l'anno 2018, i brigadieri con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015; 3) per l'anno 2019, i brigadieri con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016; 4) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 5) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172));
- b) per l'avanzamento al grado di brigadiere capo del ruolo forestale dei revisori dell'Arma dei carabinieri, fermi restando gli altri requisiti, in deroga alla permanenza nel grado prevista dalla tabella 4, quadro X, sono inclusi in aliquota di avanzamento: 1) per l'anno 2017, i revisori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014; 2) per l'anno 2018, i brigadieri, gia' revisori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015; 3) per l'anno 2019, i brigadieri, gia' revisori con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016; 4) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 5) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)).

((

10-bis. Al fine di assicurare l'armonico sviluppo del ruolo, alla data del 1° gennaio 2020 e' formata un'aliquota straordinaria per la promozione a brigadiere capo, nella quale sono inclusi i brigadieri che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2010. Gli stessi, se giudicati idonei, sono promossi in ordine di ruolo con decorrenza giuridica e amministrativa dal 1° gennaio 2020.

10-ter. Al fine di assicurare l'armonico sviluppo del ruolo, le aliquote di valutazione per l'avanzamento al grado di brigadiere capo, in deroga alla permanenza nel grado prevista dall'articolo 1299, sono cosi' formate:

- a) per l'anno 2020, i brigadieri che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2011, i quali, se promossi, prendono posto nel ruolo dopo i parigrado di cui al precedente comma 10-bis;
- b) per l'anno 2021, i brigadieri che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2012;
- c) per l'anno 2022, i brigadieri che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013;
- d) per l'anno 2023, i brigadieri che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014;
- e) per l'anno 2024, i brigadieri promossi ai sensi del comma 9-ter, che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015.

10-quater. Le disposizioni di cui ai commi 9-bis, 9-ter, 9-quater, 9-quinquies, 10-bis e 10-ter si applicano anche al personale dei corrispondenti ruoli forestali.

))

### Art. 2253-quinquies. - (Assunzione della qualifica di brigadiere capo qualifica speciale)

1. Ai brigadieri capo in servizio al 30 settembre 2017 che hanno maturato un periodo di permanenza minimo nel grado uguale o superiore a quello previsto dall'articolo 1325-ter, o conseguito la promozione entro il 31 dicembre 2012 e che non si trovino nelle condizioni di cui all'articolo 1051, e' attribuita la qualifica di qualifica speciale con decorrenza dal 1° ottobre 2017.

2. Ai revisori capo che al 30 settembre 2017 hanno maturato un periodo di permanenza minimo uguale o superiore a quello previsto dal comma 9-bis dell'articolo 2247-bis, o conseguito la promozione entro il 31 dicembre 2012 e che non si trovino nelle condizioni di cui all'articolo 1051, e' attribuita la qualifica di qualifica speciale con decorrenza dal 1° ottobre 2017.

3. Al fine dell'accertamento dell'assenza di cause impeditive previste dall'articolo 1051, il personale di cui ai commi precedenti e' incluso nell'aliquota di valutazione straordinaria formata alla data del 30 settembre 2017.

4. Attribuite le promozioni di cui ai commi precedenti, al fine di assicurare l'armonico sviluppo del ruolo e il graduale raggiungimento delle nuove dotazioni organiche, le aliquote di valutazione dei sovrintendenti e revisori sono fissate secondo i seguenti criteri:

- a) per il conseguimento della qualifica speciale, fermi restando gli altri requisiti in deroga alla permanenza nel grado prevista dall'articolo 1325-ter, sono inclusi in aliquota di avanzamento: 1) per l'anno 2017, i brigadieri capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013; 2) per l'anno 2018, i brigadieri capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014; 3) per l'anno 2019, i brigadieri capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015; 4) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 5) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 6) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 7) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 8)((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172));
- b) per il conseguimento della qualifica speciale, fermi restando gli altri requisiti in deroga alla permanenza nel grado prevista dall'articolo 2247-bis, comma 9-bis, sono inclusi in aliquota di avanzamento: 1) per l'anno 2017, i revisori capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013; 2) per l'anno 2018, i brigadieri capo, gia' revisori capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014; 3) per l'anno 2019, i brigadieri capo, gia' revisori capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015; 4) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 5) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 6) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 7) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172)); 8) ((NUMERO SOPPRESSO DAL D.LGS. 27 DICEMBRE 2019, N. 172));

5. Il personale che consegue la qualifica speciale ai sensi del comma 4, lettera a), numero 1) e lettera b), numero 1), prende posto in ruolo dopo i militari di cui ai commi 1 e 2.

((

5-bis. Alla data del 1° gennaio 2020, al fine di assicurare l'armonico sviluppo del ruolo per l'attribuzione della qualifica speciale, e' formata un'aliquota straordinaria, nella quale sono inclusi:

- a) i brigadieri capo del ruolo sovrintendenti e del ruolo forestale sovrintendenti: 1) con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016; 2) promossi ai sensi dell'articolo 2253-quater, comma 1; 3) che rivestivano il grado di brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2010 e fra il 1° gennaio e il 31 dicembre 2011;
- b) i brigadieri capo del ruolo forestale dei revisori: 1) gia' revisori capo con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016; 2) che rivestivano il grado di revisore con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2010 e fra il 1° gennaio e il 31 dicembre 2011.

))

((

5-ter. Ai brigadieri capo inclusi nell'aliquota straordinaria di cui al comma 5-bis, e' attribuita la qualifica speciale a decorrere dal 1° gennaio 2020, previa verifica del possesso dei requisiti di cui all'articolo 1325-ter.

))

((

5-quater. Attribuite le promozioni di cui al comma 5-bis, al fine di assicurare l'armonico sviluppo del ruolo, in deroga alla permanenza nel grado prevista dagli articoli 1325-ter e 2247-bis, sono inclusi in aliquota di valutazione per l'attribuzione della qualifica speciale:

- a) per l'anno 2020, i brigadieri capo che rivestivano il grado di brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2012, prendendo posto nel ruolo dopo i parigrado di cui al precedente comma 5-ter;
- b) per l'anno 2021, i brigadieri capo che rivestivano il grado di brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2013;
- c) per l'anno 2022, i brigadieri capo che rivestivano il grado di brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2014;
- d) per l'anno 2023, i brigadieri capo che rivestivano il grado di brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2015;
- e) per l'anno 2024, i brigadieri capo che rivestivano il grado di brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2016;
- f) per l'anno 2025, i brigadieri capo promossi ai sensi dell'articolo 2253-quater, comma 10-bis, che rivestivano il grado di vice brigadiere con anzianita' compresa fra il 1° gennaio e il 31 dicembre 2010.

))

((

5-quinquies. Le disposizioni di cui al comma 5-quater si applicano anche al personale dei corrispondenti ruoli forestali.

))

### Art. 2253-sexies. - (( (Promozione al grado di appuntato scelto). ))

((

1. Gli appuntati e i collaboratori che al 1° gennaio 2017 hanno un periodo di permanenza minima nel grado uguale o superiore a quanto previsto dall'articolo 1311 e dalla tabella 4, quadri VIII e XI, sono valutati dalla commissione di cui all'articolo 1047 e, se idonei, promossi con determinazione del Comandante generale dell'Arma dei carabinieri, o dell'autorita' da questi delegata, ed iscritti in ordine di ruolo rispettivamente al grado di appuntato scelto e collaboratore capo con decorrenza 1°gennaio 2017.

2. I militari di cui al comma 1 sono comunque promossi in data non anteriore a quella di promozione del pari grado che lo precede in ruolo.

))

### Art. 2253-septies. - (Assunzione della qualifica di appuntato scelto qualifica speciale)

1. Agli appuntati scelti che al 30 settembre 2017 hanno compiuto sette anni di permanenza nel grado, in deroga alla permanenza nel grado prevista dall'articolo 1325-quater, che non si trovino nelle condizioni di cui all'articolo 1051, con determinazione del Comandante generale dell'Arma dei carabinieri, o dell'autorita' da questi delegata, e' attribuita la qualifica di qualifica speciale, con decorrenza 1° ottobre 2017.

2. Ai collaboratori capo che al 30 settembre 2017 hanno compiuto sette anni di permanenza nella qualifica, in deroga alla permanenza nel grado prevista dall'articolo 2247-bis, che non si trovino nelle condizioni di cui all'articolo 1051, con determinazione del Comandante generale dell'Arma dei carabinieri, o dell'autorita' da questi delegata, e' attribuita la qualifica di qualifica speciale, con decorrenza 1° ottobre 2017.

3. Al fine dell'accertamento dell'assenza di cause impeditive previste dall'articolo 1051, il personale di cui ai commi precedenti e' valutato dalla commissione di cui all'articolo 1047 alla data del 30 settembre 2017.

4. Per il conseguimento della qualifica speciale, fermi restando gli altri requisiti, in deroga alla permanenza nel grado prevista dall'articolo 1325-quater, gli appuntati scelti non rientranti nella previsione di cui al comma 1 e in servizio il 31 dicembre 2016, sono portati in avanzamento dopo 7 anni di permanenza nel grado.

5. Per il conseguimento della qualifica speciale, fermi restando gli altri requisiti, in deroga alla permanenza nel grado prevista dall'articolo 1325-quater, gli appuntati scelti, gia' collaboratori capo non rientranti nella previsione di cui al comma 2 e in servizio il 31 dicembre 2016, sono portati in avanzamento dopo 7 anni di permanenza nel grado.

6. Il personale che consegue la qualifica speciale ai sensi dei commi 4 e 5 prende posto in ruolo dopo i militari di cui ai commi 1 e 2.

((

6-bis. Gli appuntati scelti in servizio al 31 dicembre 2019, in deroga al periodo di permanenza nel grado previsto dal comma 4 e dall'articolo 1325-quater, conseguiranno i requisiti temporali per l'avanzamento al grado superiore dopo:

- a) 4 anni di anzianita' nel grado, se sono stati promossi al grado di appuntato scelto entro e non oltre il 31 dicembre 2016 e non rientrano nella previsione di cui ai commi 1 e 2;
- b) 5 anni di anzianita' nel grado, se sono stati promossi al grado di appuntato scelto dal 1° gennaio 2017 al 31 dicembre 2019;

))

((

6-ter. Al personale di cui al comma 6-bis, lettera a), che alla data del 31 dicembre 2019 ha gia' compiuto 4 anni di permanenza nel grado, previa verifica del possesso dei requisiti previsti dall'articolo 1325-quater da parte dalla commissione di cui all'articolo 1047, viene conferita la qualifica di qualifica speciale con determinazione del Comandante generale dell'Arma dei carabinieri, o dell'autorita' da questi delegata, con decorrenza dal 1° gennaio 2020.

))

### Art. 2253-octies. - (( (Concorso per il personale in servizio presso il centro addestramento musicale). ))

((

1. Entro il 1°giugno 2018, e' bandito con decreto del Ministro della difesa, un concorso per l'inquadramento nella terza parte B, prescindendo dalla qualificazione strumentale e in soprannumero alle vacanze organiche esistenti nel ruolo dei musicisti della banda dell'Arma dei carabinieri, riservato ai militari dell'Arma dei carabinieri in servizio da almeno due anni presso il Centro di addestramento musicale.

2. Per l'ammissione a tale concorso si prescinde dai limiti di eta' e dal possesso dei titoli di studio previsti dalla normativa vigente.

3. Gli esami di concorso consistono nelle seguenti prove: esecuzione di un pezzo di concerto studiato, a scelta del concorrente, lettura a prima vista di un brano di musica, nozioni inerenti alla tecnica dello strumento suonato.

4. La commissione esaminatrice del concorso e' costituita ai sensi dell'articolo 950 del decreto del Presidente della Repubblica 15 marzo 2010, n. 90;

5. La commissione forma la graduatoria attribuendo a ciascun concorrente un punteggio da uno a venti per ciascuna prova. E' giudicato idoneo il concorrente che nella graduatoria raggiunge un punteggio non inferiore a 12 in ciascuna delle prove stabilite.

))

### Art. 2254. - Cause impeditive

1. Per il personale di cui all'articolo 2253, sospeso precauzionalmente dall'impiego, rinviato a giudizio o ammesso ai riti alternativi per delitto non colposo ovvero sottoposto a procedimento disciplinare di stato, l'attribuzione avviene, anche con effetto retroattivo e fermi restando gli ulteriori requisiti previsti nei medesimi articoli, al venir meno delle predette cause impeditive, salvo che le stesse non comportino la cessazione dal servizio permanente.

### Art. 2254-bis. - (Disposizioni transitorie per l'avanzamento al grado superiore del personale dei ruoli dei sergenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)

1. Fino al 31 dicembre 2016, per l'avanzamento al grado superiore del personale dei ruoli dei sergenti, sono richiesti i periodi di permanenza minima nel grado di seguito indicati:

- a) sette anni, per l'inserimento nell'aliquota di valutazione a scelta, per l'avanzamento al grado di sergente maggiore capo e gradi corrispondenti;
- b) sette anni, per la promozione ad anzianita' al grado di sergente maggiore e gradi corrispondenti.

((

1-bis. Per il conferimento delle promozioni relative alle aliquote di avanzamento fino al 31 dicembre 2019, nell'avanzamento a scelta al grado di sergente maggiore capo, le promozioni sono cosi' determinate:

- a) il primo terzo del personale iscritto nel quadro d'avanzamento a scelta e' promosso al grado superiore in ordine di ruolo con decorrenza dal giorno successivo a quello del compimento del periodo di permanenza prevista al comma 1-ter;
- b) il restante personale e' sottoposto a seconda valutazione per l'avanzamento all'epoca della formazione delle corrispondenti aliquote di scrutinio dell'anno successivo. Di essi: 1) la prima meta' e' promossa in ordine di ruolo, previa nuova valutazione, con un anno di ritardo rispetto al personale di cui alla lettera a), prendendo posto nel ruolo dopo il primo terzo del personale da promuovere in prima valutazione nello stesso anno ai sensi della medesima lettera a); 2) la seconda meta' e' promossa in ordine di ruolo, previa nuova valutazione, con due anni di ritardo rispetto al personale di cui alla lettera a), prendendo posto nel ruolo dopo il personale da promuovere in seconda valutazione nello stesso anno;
- c) ogni sottufficiale e' comunque promosso in data non anteriore a quella di promozione del pari grado che lo precede.

1-ter. Fino al 31 dicembre 2019 i requisiti di anzianita' richiesti per l'inserimento in aliquota per l'avanzamento al grado di sergente maggiore capo sono:

- a) 7 anni per i sergenti maggiori con anzianita' di grado tra il 1° gennaio 2003 e il 31 dicembre 2010;
- b) 6 anni per i sergenti maggiori con anzianita' di grado tra il 1° gennaio 2011 e il 31 dicembre 2011;
- c) 5 anni per i sergenti maggiori con anzianita' di grado tra il 1° gennaio 2012 e il 31 dicembre 2012;
- d) 4 anni per i sergenti maggiori con anzianita' di grado tra il 1° gennaio 2013 e il 31 dicembre 2015.

))

2. Per il conferimento delle promozioni al grado di sergente maggiore capo ((, al 31 dicembre 2017)) sono formate quattro aliquote, rispettivamente per i sergenti maggiori sotto elencati:

- a) con anzianita' nel grado 2010;
- b) con anzianita' nel grado 2011;
- c) con anzianita' nel grado 2012;
- d) con anzianita' nel grado 2013.

((

2-bis. Al 1° gennaio 2020, sono promossi al grado di sergente maggiore capo e corrispondenti i sergenti maggiori con anzianita' di grado 2014 e 2015, giudicati idonei ma non promossi nelle aliquote fino al 31 dicembre 2019, secondo il seguente ordine di iscrizione in ruolo:

- a) la prima meta' dei sergenti maggiori con anzianita' 2015 non promossi in prima valutazione;
- b) i sergenti maggiori con anzianita' 2014;
- c) la seconda meta' dei sergenti maggiori con anzianita' 2015 non promossi in prima valutazione.

2-ter. Per il conferimento delle promozioni ad anzianita' al grado di sergente maggiore capo, di cui all'articolo 1284, al 31 dicembre 2021 e' formata l'aliquota di valutazione per i sergenti maggiori con anzianita' nel grado 2016.

2-quater. Per il conferimento delle promozioni ad anzianita' al grado di sergente maggiore capo, di cui all'articolo 1284, al 31 dicembre 2022 sono formate le seguenti distinte aliquote di valutazione, rispettivamente per i sergenti maggiori:

- a) con anzianita' nel grado 1° gennaio 2017;
- b) con anzianita' nel grado 2 gennaio 2017;
- c) con anzianita' nel grado 3 gennaio 2017.

))

3. Le promozioni al grado di sergente maggiore capi e gradi corrispondenti ((, in deroga al comma 1-bis, per l'anno 2017,)) hanno le decorrenze giuridiche e amministrative di seguito indicate:

- a) per i sergenti maggiore e gradi corrispondenti gia' iscritti nel quadro di avanzamento al 31 dicembre 2016 e non promossi: 1) 1° gennaio 2017, per i sergenti maggiori e gradi corrispondenti con anzianita' di grado non oltre 2008; 2) 1° gennaio 2017 e 1° aprile 2017, rispettivamente per il secondo e il terzo terzo, per i sergenti maggiore e gradi corrispondenti con anzianita' di grado non oltre 2009;
- b) 1° gennaio 2017, 1° aprile 2017 e 1° luglio 2017, rispettivamente, per il primo, il secondo e il terzo terzo, per l'aliquota di cui al comma 2, lettera a);
- c) 1° aprile 2017, 1° luglio 2017 e 1° ottobre 2017, rispettivamente, per il primo, il secondo e il terzo terzo, per l'aliquota di cui al comma 2, lettera b);
- d) 1° luglio 2017 e 1° ottobre 2017, rispettivamente, per il primo e il secondo terzo, per l'aliquota di cui al comma 2, lettera c);
- e) 1° ottobre 2017, per il primo terzo, per l'aliquota di cui al comma 2, lettera d).

4. Per il conferimento delle promozioni al grado di sergente maggiore ((al 31 dicembre 2017)) sono formate tre aliquote, rispettivamente per i sergenti sotto elencati:

- a) con anzianita' nel grado 2010;
- b) con anzianita' nel grado 2011;
- c) con anzianita' nel grado 2012.

((

4-bis. Per la promozione al grado di sergente maggiore per il 2020, al 31 dicembre 2020 sono formate due distinte aliquote di valutazione, rispettivamente per sergenti e gradi corrispondenti, sotto elencati:

- a) con anzianita' nel grado dal 1° gennaio 2015 al 31 dicembre 2015;
- b) con anzianita' nel grado dal 1° gennaio 2016 al 31 dicembre 2016.

))

5. Le promozioni al grado di sergente maggiore e gradi corrispondenti hanno le decorrenze giuridiche e amministrative di seguito indicate:

- a) 1° gennaio 2017, per l'aliquota di cui al comma 4, lettera a);
- b) 2 gennaio 2017, per l'aliquota di cui al comma 4, lettera b);
- c) 3 gennaio 2017, per l'aliquota di cui al comma 4, lettera c).

((

5-bis. Per l'anno 2020, la decorrenza dell'attribuzione della promozione a sergente maggiore e gradi corrispondenti e' cosi' disciplinata:

- a) sergenti maggiori di cui al comma 4-bis, lettera a): il giorno successivo la maturazione dei requisiti previsti;
- b) sergenti maggiori di cui al comma 4-bis, lettera b): il giorno successivo al personale di cui alla lettera a).

))

### Art. 2254-ter.

(Disposizioni transitorie per il conferimento della qualifica ((di sergente maggiore aiutante o di secondo capo aiutante)) ai sergenti maggiore capo e gradi corrispondenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). 1. I sergenti maggiori capi e gradi corrispondenti, che alla data di entrata in vigore del presente articolo sono in possesso dei requisiti previsti dall'articolo 1323-bis, commi 1, lettere b), c) e d) con anzianita' nel grado fino al 31 dicembre 2014, sono inclusi in un'aliquota straordinaria di valutazione formata al 1° ottobre 2017 e conseguono l'attribuzione della qualifica ((di sergente maggiore aiutante e corrispondenti)) con decorrenza dal 1° ottobre 2017. 2. Per la composizione delle aliquote di valutazione degli anni dal 2017 al 2031, in deroga all'articolo 1323-bis, comma 1, lettera a), i requisiti di anzianita' richiesti per l'inserimento in aliquota per l'attribuzione della qualifica ((di sergente maggiore aiutante e corrispondenti)) sono rispettivamente: a) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2015 e il 31 dicembre 2016; b) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2017 e 30 marzo 2017; c) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° aprile 2017 e il 30 giugno 2017; d) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° luglio 2017 e il 30 settembre 2017; e) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° ottobre 2017 e il 31 dicembre 2017; f) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2018 e il 31 dicembre 2020; g) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2021 e il 31 dicembre 2021; h) 3 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2022 e il 31 dicembre 2022, di cui all'articolo 2254-bis, comma 2-quater, lettera a); i) 4 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2022 e il 31 dicembre 2022, di cui all'articolo 2254-bis, comma 2-quater, lettera b); l) 5 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2022 e il 31 dicembre 2022, di cui all'articolo 2254-bis, comma 2-quater, lettera c); m) 5 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2023 e il 31 dicembre 2024; n) 5 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2025 e il 31 dicembre 2025, precedentemente sergenti maggiori di cui all'articolo 2254-bis, comma 4-bis, lettera a); o) 6 anni per i sergenti maggiori capi con anzianita' di grado tra il 1° gennaio 2025 e il 31 dicembre 2025, precedentemente sergenti maggiori di cui all'articolo 2254-bis, comma 4-bis, lettera b). 2-bis. Ai sergenti maggiori capi esclusi dalle aliquote di cui ai commi 1 e 2 per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del titolo VII, in materia di rinnovazione dei giudizi di avanzamento. 2-ter. I sergenti maggiori capi esclusi dalle aliquote di cui ai commi 1, e 2 per mancanza dei requisiti di cui all'articolo 1323-bis, comma 1, lettere c) e d), sono inseriti nella prima aliquota successiva alla data di maturazione di tali requisiti e la qualifica ((di sergente maggiore aiutante e corrispondenti)) e' conferita a decorrere dal giorno successivo a tale data. 3. COMMA ABROGATO DAL D.LGS. 27 DICEMBRE 2019, N. 173.

### Art. 2254-quater. - (Disposizioni transitorie per l'attribuzione del parametro ai sergenti maggiori capi e gradi corrispondenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare)

1. Il parametro stipendiale previsto dalla tabella 2 di cui all'articolo 2, comma 1-bis, del decreto legislativo 30 maggio 2003, n. 193, per il grado di sergente maggiore capo con quattro anni di anzianita', e' attribuito con le seguenti modalita':

- a) per il personale che rivestiva il grado di sergente maggiore dal 1°gennaio 2010 al 31 dicembre 2010: all'atto della promozione a sergente maggiore capo ((e comunque non anteriormente al 1° ottobre 2017));
- b) per il personale che rivestiva il grado di sergente maggiore dal 1° gennaio 2011 al 31 dicembre 2011: dopo un anno di permanenza nel grado di sergente maggiore capo;
- c) per il personale che rivestiva il grado di sergente maggiore dal 1° gennaio 2012 al 31 dicembre 2012: dopo due anni di permanenza nel grado di sergente maggiore capo;
- d) per il personale che rivestiva il grado di sergente maggiore dal 1° gennaio 2013 al 31 dicembre 2013: dopo tre anni di permanenza nel grado di sergente maggiore capo.

### Art. 2255.

Avanzamento al grado di ((graduato)) e corrispondenti

1. Il grado di ((graduato)), o grado corrispondente, per i volontari in rafferma biennale, e' conseguito, ai sensi dell'articolo 1303, a decorrere dal 1° gennaio 2010.

### Art. 2255-bis.

(Disposizioni transitorie per l'avanzamento al grado di ((primo graduato)) e gradi corrispondenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare).

1. Per l'anno 2017, le promozioni al grado di ((primo graduato)) e gradi corrispondenti sono conferite ad anzianita', previo giudizio di idoneita' espresso dalle commissioni di avanzamento, con le decorrenze giuridiche e amministrative di seguito indicate in riferimento alle permanenze minime ((nel grado di graduato capo)) e gradi corrispondenti ivi richieste:

- a) 1° gennaio 2017, per i ((graduati capi)) e gradi corrispondenti con anzianita' di grado 2012 e almeno quattro anni e sei mesi di permanenza nel grado;
- b) 1° aprile 2017, per i restanti ((graduati capi)) e gradi corrispondenti con anzianita' di grado 2012;
- c) 1° luglio 2017, per i ((graduati capi)) e gradi corrispondenti con anzianita' di grado 2013 e almeno quattro anni di permanenza nel grado maturati nel primo semestre dell'anno 2017;
- d) 31 dicembre 2017, per i ((graduati capi)) e gradi corrispondenti con anzianita' di grado 2013 e almeno quattro anni di permanenza nel grado maturati nel secondo semestre dell'anno 2017.

2. I ((graduati capi e gradi corrispondenti)) sono comunque promossi in data non anteriore a quella di promozione dei pari grado che li precedono nel ruolo.

### Art. 2255-ter.

(Disposizioni transitorie per l'attribuzione della qualifica ((di graduato aiutante o di sottocapo aiutante)) ai ((primi graduati)) e gradi corrispondenti dell'Esercito italiano, della Marina militare e dell'Aeronautica militare). 1. I ((primi graduati)) e gradi corrispondenti, che al 31 dicembre 2016 hanno compiuto sette anni di permanenza nel grado e non si trovano nelle condizioni di cui all'articolo 1051, sono inseriti in un'aliquota straordinaria al 1° ottobre 2017. L'attribuzione della qualifica ((di graduato aiutante o di sottocapo aiutante)) ha decorrenza 1° ottobre 2017. 2. Dal 2018 al 31 dicembre 2023, in deroga all'articolo 1307-bis, comma 1, lettera a), i requisiti di anzianita' richiesti per l'inserimento in aliquota per l'attribuzione della qualifica ((di graduato aiutante o di sottocapo aiutante)) sono rispettivamente: a) 7 anni per i ((primi graduati, e gradi corrispondenti,)) con anzianita' di grado tra il 1° gennaio 2010 e il 31 dicembre 2013; b) 6 anni per i ((primi graduati, e gradi corrispondenti,)) con anzianita' di grado tra il 1° gennaio 2014 e il 31 dicembre 2014; c) 5 anni per i ((primi graduati, e gradi corrispondenti,)) con anzianita' di grado tra il 1° gennaio 2015 e il 31 dicembre 2015; d) 4 anni per i ((primi graduati, e gradi corrispondenti,)) con anzianita' di grado tra il 1° gennaio 2016 e il 31 dicembre 2016 e per quelli con anzianita' di grado tra il 1° gennaio 2017 e il 31 dicembre 2017, di cui all'articolo 2255-bis, comma 1, lettere a) e b); e) 5 anni per i ((primi graduati, e gradi corrispondenti,)) con anzianita' di grado tra il 1° gennaio 2017 e il 31 dicembre 2017, di cui all'articolo 2255-bis, comma 1, lettere c) e d). 2-bis. Ai ((primi graduati, e gradi corrispondenti,)) esclusi dalle aliquote di cui ai commi 1 e 2 per i motivi di cui all'articolo 1051, si applicano, in quanto compatibili, le disposizioni di cui al capo V del titolo VII, in materia di rinnovazione dei giudizi di avanzamento. 2-ter. I ((primi graduati, e gradi corrispondenti,)) esclusi dalle aliquote di cui ai commi 1 e 2 per mancanza dei requisiti di cui all'articolo 1307-bis, comma 1, lettere c) e d), sono inseriti nella prima aliquota successiva alla data di maturazione di tali requisiti e la qualifica ((di graduato aiutante o di sottocapo aiutante)) e' conferita a decorrere dal giorno successivo a tale data. 2-quater. Per il conferimento delle qualifiche ((di graduato aiutante e di sottocapo aiutante)) per il 2020, al 31 dicembre 2020 sono formate quattro distinte aliquote di valutazione, rispettivamente per i ((primi graduati)) e gradi corrispondenti, sotto elencati: a) con anzianita' nel grado dal 1° gennaio 2013 al 31 dicembre 2013; b) con anzianita' nel grado dal 1° gennaio 2014 al 31 dicembre 2014; c) con anzianita' nel grado dal 1° gennaio 2015 al 31 dicembre 2015; d) con anzianita' nel grado dal 1° gennaio 2016 al 31 dicembre 2016. 2-quinquies. Per l'anno 2020, la decorrenza dell'attribuzione della qualifica ((di graduato aiutante o di sottocapo aiutante)) e' cosi disciplinata: a) ((primi graduati, e gradi corrispondenti,)) di cui al comma 2-quater, lettera a): il giorno successivo la maturazione dei requisiti previsti; b) ((primi graduati, e gradi corrispondenti,)) di cui al comma 2-quater, lettera b): il giorno successivo al personale di cui alla lettera a); c) ((primi graduati, e gradi corrispondenti,)) di cui al comma 2-quater, lettera c): il giorno successivo al personale di cui alla lettera b); d) ((primi graduati, e gradi corrispondenti,)) di cui al comma 2-quater, lettera d): il giorno successivo al personale di cui alla lettera c).

### Art. 2256. - Condizioni particolari per l'avanzamento nella Marina militare

1. I periodi di imbarco ovvero in reparti operativi previsti dagli articoli 1280, 1287, 1308 e 1275 si applicano al personale reclutato con le norme a regime ai sensi degli articoli 8 e seguenti del decreto legislativo 12 maggio 1995, n. 196.

2. Per il restante personale compreso quello reclutato ai sensi delle disposizioni transitorie di cui agli articoli 34 e seguenti del decreto legislativo 12 maggio 1995, n. 196, i periodi di imbarco ovvero in reparti operativi, di cui agli 1280, 1287, 1308 e 1275 si considerano ridotti alla meta'.

## Parte VII ((Disciplina militare ed esercizio dei diritti))

### Art. 2257. - (( (Durata del mandato degli organi della rappresentanza militare). ))

((

1. I delegati della rappresentanza militare di cui all'articolo 2257-bis, il cui mandato era in corso alla data del 27 maggio 2022, restano in carica e proseguono l'attivita' di competenza, compresa la partecipazione alle procedure di concertazione per il rinnovo del contenuto del rapporto di impiego del personale delle Forze armate e delle Forze di polizia a ordinamento militare, se in corso, ai sensi del decreto legislativo 12 maggio 1995, n. 195, fino alla data di cui all'articolo 19, comma 2, della legge 28 aprile 2022, n. 46.

2. Fino alla data di cui al comma 1, continuano ad essere svolte dagli organi della rappresentanza militare di cui all'articolo 2257-bis le funzioni attribuite alle associazioni professionali a carattere sindacale tra militari dagli articoli 286, comma 3-bis, 287, comma 3, 294, commi 1 e 2, 296, comma 1, 297, comma 4, 546, comma 5, 980, 2188-quinquies, comma 5, 2209-octies, comma 1, del decreto legislativo n. 66 del 2010 nonche' dall'articolo 8, commi 1 e 2, della legge 1° dicembre 1986, n. 831, dall'articolo 9, comma 3, del decreto legislativo 9 marzo 2001, n. 68, dall'articolo 3, comma 2, del decreto legislativo 9 aprile 2008, n. 81, dall'articolo 19, comma 3, della legge 4 novembre 2010, n. 183 e dall'articolo 9, comma 2, della legge 5 agosto 2022, n. 119.

3. A decorrere dalla data di cui al comma 1, gli organi della rappresentanza militare e i delegati che li compongono cessano di svolgere le relative funzioni.

))

### Art. 2257-bis. - (( (Disposizioni transitorie in materia di rappresentanza militare).))

((

1. Gli organi di rappresentanza di militari, le cui competenze sono indicate dal presente articolo, si distinguono:

- a) in un organo centrale, a carattere nazionale e interforze, articolato in relazione alle esigenze, in commissioni interforze di categoria - A) ufficiali, B) marescialli/ispettori, C) sergenti/sovrintendenti e D) graduati/militari di truppa, fermo restando il numero complessivo dei rappresentanti - e in sezioni di Forza armata o di Corpo armato - Esercito italiano, Marina militare, Aeronautica militare, Carabinieri e Guardia di finanza;
- b) in un organo intermedio presso gli alti comandi;
- c) in un organo di base presso le unita' a livello minimo compatibile con la struttura di ciascuna Forza armata o Corpo armato.

2. L'organo centrale e quelli intermedi sono costituiti da un numero fisso di delegati di ciascuna delle seguenti categorie: A) ufficiali, B) marescialli/ispettori, C) sergenti/sovrintendenti e D) graduati/militari di truppa, fermo restando il numero complessivo dei rappresentanti. L'organo di base e' costituito dai rappresentanti delle suddette categorie presenti al livello considerato. Nell'organo centrale la rappresentanza di ciascuna Forza armata o Corpo e' proporzionale alla rispettiva consistenza numerica.

3. Per la elezione dei rappresentanti nei diversi organi di base si procede con voto diretto, nominativo e segreto. All'elezione dei rappresentanti negli organi intermedi provvedono i rappresentanti eletti negli organi di base, scegliendoli nel proprio ambito con voto diretto, nominativo e segreto. Ciascuno dei rappresentanti di base esprime non piu' di due terzi dei voti rispetto al numero dei delegati da eleggere. Con la stessa procedura i rappresentanti degli organi intermedi eleggono i delegati all'organo centrale.

4. Gli eletti, militari di carriera, durano in carica quattro anni, sono rieleggibili due sole volte, e se cessano anticipatamente dal mandato sono sostituiti, per il periodo residuo, dai militari che nelle votazioni effettuate, di primo o secondo grado, seguono immediatamente nella graduatoria l'ultimo degli eletti.

5. In deroga al divieto di cui all'articolo 1470, comma 1, sono previste riunioni per il funzionamento degli organi di rappresentanza che, in ogni caso, devono essere concordate con i comandi competenti. Normalmente l'organo centrale della rappresentanza si riunisce in sessione congiunta di tutte le sezioni costituite, per formulare pareri e proposte e per avanzare richieste, nell'ambito delle competenze attribuite. Tale sessione si aduna almeno una volta all'anno per formulare un programma di lavoro e per verificarne l'attuazione. Le riunioni delle sezioni costituite all'interno dell'organo centrale della rappresentanza sono convocate ogni qualvolta i pareri e le proposte da formulare e le richieste da avanzare riguardino esclusivamente le singole Forze armate o i Corpi armati. Le riunioni delle commissioni costituite all'interno dell'organo centrale della rappresentanza sono convocate ogni qualvolta i pareri e le proposte da formulare e le richieste da avanzare riguardino le singole categorie. Gli organi di rappresentanza sono convocati dalla presidenza, per iniziativa della stessa o a richiesta di un quinto dei loro componenti, compatibilmente con le esigenze di servizio.

6. Le competenze dell'organo centrale di rappresentanza riguardano la formulazione di pareri, di proposte e di richieste su tutte le materie che formano oggetto di norme legislative o regolamentari circa la condizione, il trattamento, la tutela - di natura giuridica, economica, previdenziale, sanitaria, culturale e morale - dei militari. Se i pareri, le proposte, le richieste riguardano materie inerenti al servizio di leva devono essere sentiti i militari di leva eletti negli organi intermedi. Tali pareri, proposte e richieste sono comunicati al Ministro della difesa che li trasmette per conoscenza alle Commissioni permanenti competenti per materia delle due Camere, a richiesta delle medesime. L'organo centrale della rappresentanza militare puo' essere ascoltato, a sua richiesta, dalle Commissioni permanenti competenti per materia delle due Camere, sulle materie di competenza e secondo le procedure previste dai regolamenti parlamentari. Gli organi della rappresentanza militare, intermedi e di base, concordano con i comandi e gli organi dell'amministrazione militare, le forme e le modalita' per trattare materie di competenza. In materia di contenuti del rapporto di impiego del personale militare si applicano le disposizioni del decreto legislativo 12 maggio 1995, n. 195, vigenti fino alla data di adozione del primo decreto del Ministro per la pubblica amministrazione di cui all'articolo 1478, comma 5, del decreto legislativo n. 66 del 2010.

7. Dalle competenze degli organi rappresentativi sono comunque escluse le materie concernenti l'ordinamento, l'addestramento, le operazioni, il settore logistico-operativo, il rapporto gerarchico-funzionale e l'impiego del personale.

8. Gli organi rappresentativi hanno inoltre la funzione di prospettare le istanze di carattere collettivo, relative ai seguenti campi di interesse:

- a) conservazione dei posti di lavoro durante il servizio militare, qualificazione professionale, inserimento nell'attivita' lavorativa di coloro che cessano dal servizio militare;
- b) provvidenze per gli infortuni subiti e per le infermita' contratte in servizio e per causa di servizio;
- c) integrazione del personale militare femminile;
- d) attivita' assistenziali, culturali, ricreative e di promozione sociale, anche a favore dei familiari del personale militare;
- e) organizzazione delle sale convegno e delle mense;
- f) condizioni igienico-sanitarie;
- g) alloggi.

9. Per i provvedimenti da adottare in materia di attivita' assistenziale, culturale, ricreativa, di promozione sociale, anche a favore dei familiari del personale militare, l'amministrazione militare competente puo' avvalersi dell'apporto degli organi di rappresentanza intermedi o di base, per i rapporti con le regioni, le province, i comuni.

10. Sono vietati gli atti diretti comunque a condizionare o limitare l'esercizio del mandato dei componenti degli organi della rappresentanza. I trasferimenti ad altre sedi di militari di carriera o di leva eletti negli organi di rappresentanza, se pregiudicano l'esercizio del mandato, devono essere concordati con l'organo di rappresentanza a cui il militare, del quale si chiede il trasferimento, appartiene.

11. Le disposizioni del regolamento concernenti l'organizzazione e il funzionamento della rappresentanza militare nonche' il collegamento con i rappresentanti dei militari delle categorie in congedo e dei pensionati delegati dalle rispettive associazioni, sono adottate dall'organo centrale a maggioranza assoluta dei componenti.

))

### Art. 2257-ter. - (Disposizioni transitorie in materia di associazioni professionali a carattere sindacale tra militari)

1. Le associazioni professionali a carattere sindacale tra militari, che alla data del 27 maggio 2022 avevano gia' conseguito l'assenso del Ministro competente, si adeguano alle disposizioni del libro quarto, titolo IX, capo III entro novanta giorni. Decorso tale termine, il Ministro competente effettua sulle predette associazioni gli accertamenti previsti dall'articolo 1477.

((

2. Le quote percentuali di iscritti previste dall'articolo 1478, commi 1 e 2, ai fini del riconoscimento della rappresentativita' a livello nazionale, sono ridotte:

- a) di 2 punti percentuali, per il triennio negoziale 2022-2024;
- b) di 1 punto percentuale, per il triennio negoziale 2025-2027.

))

### Art. 2258. - Ordine militare di Savoia

1. L'Ordine militare d'Italia raccoglie e custodisce tutte le documentazioni relative ai decreti dell'Ordine militare di Savoia.

2. I decorati dell'Ordine Militare di Savoia, sono trasferiti nell'Ordine Militare d'Italia, si fregiano dei distintivi di questo e mantengono le loro decorazioni, assegnazioni e anzianita' di classe e i diritti che ne derivano.

### SEZIONE V - PERSONALE AUSILIARIO DELLE FORZE ARMATE

#### Art. 2259. - Disposizioni provvisorie per i cappellani militari

1. I cappellani militari di complemento e della riserva in servizio alla data del 31 dicembre 1997 sono iscritti in un apposito ruolo a esaurimento.

2. Nel limite delle vacanze esistenti nell'organico complessivo dei cappellani militari addetti e dei cappellani militari capi, i cappellani militari di cui al comma 1 sono immessi annualmente in servizio permanente, se hanno svolto almeno due anni di servizio in qualita' di cappellani militari addetti, previo giudizio di idoneita' dell'Ordinario militare da emettersi sulla base della documentazione caratteristica e del fascicolo matricolare del personale interessato. Dalla data di immissione nel predetto ruolo essi cessano di appartenere alla categoria del congedo e transitano in quella del servizio permanente.

3. Il limite di eta' per la cessazione dal servizio permanente dei cappellani militari di cui al comma 1 e' di 62 anni, fermo restando quanto disposto dall'articolo 1539.

((

3-bis. Fino al collocamento in congedo dei terzi cappellani militari capo in servizio al 22 maggio 2021 e al raggiungimento del numero complessivo di unita' dei secondi cappellani militari capo fissato dall'articolo 1546, comma 1, lettera a), le immissioni dei cappellani militari sono determinate nel limite dell'onere finanziario complessivo teorico a regime.

3-ter. A decorrere dal 22 maggio 2021 e fino al raggiungimento del numero complessivo di unita' dei secondi cappellani militari capo, fissato dall'articolo 1546, comma 1, lettera a), non ha luogo l'avanzamento dei primi cappellani militari capo.

3-quater. A decorrere dal 22 maggio 2021 cessano le promozioni a terzo cappellano militare capo.

3-quinquies. A decorrere dal 22 maggio 2021 ai cappellani militari non sono attribuite le maggiorazioni delle indennita' di impiego operativo di cui alla legge 23 marzo 1983, n. 78, a esclusione di quelle di cui all'articolo 4, e delle indennita' per servizio d'istituto di cui alla legge 23 dicembre 1970, n. 1054, e successive modificazioni. Ai cappellani militari in servizio alla data del 21 maggio 2021, che percepiscono l'indennita' di impiego operativo ovvero l'indennita' per servizio di istituto superiore, di importo superiore all'indennita' di cui all'articolo 2 della legge 23 marzo 1983, n. 78, la differenza e' attribuita sotto forma di assegno ad personam riassorbibile con i futuri incrementi dell'indennita' di impiego operativo di base.

))

### ((SEZIONE VBIS PERSONALE CIVILE))

#### Art. 2259-bis. - (Assunzioni di personale negli arsenali e stabilimenti militari).

1. Al fine di consentire l'attuazione dei processi di ristrutturazione e di incremento dell'efficienza degli arsenali e degli stabilimenti militari, in ciascuno degli anni del triennio 2012-2014, il Ministero della difesa riserva alle assunzioni del personale degli arsenali e degli stabilimenti militari appartenente ai profili professionali tecnici il sessanta per cento delle assunzioni di cui all'articolo 3, comma 102, della legge 24 dicembre 2007, n. 244, e successive modificazioni, e all'articolo 66, comma 9, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, e successive modificazioni. Per le assunzioni di cui al presente comma non si applica l'articolo 30, comma 2-bis, del decreto legislativo 30 marzo 2001, n. 165, e successive modificazioni.

1-bis. Le disposizioni di cui al comma 1 sono prorogate fino all'anno ((2020)).

#### Art. 2259-ter. - (Riduzione graduale delle dotazioni organiche del personale civile.)

1. Ai fini del graduale conseguimento della dotazione organica complessiva del personale civile del Ministero della difesa fissata in 20.000 unita' al 1° gennaio 2025, ovvero al diverso termine stabilito ai sensi dell'articolo 5, comma 2, della legge 31 dicembre 2012, n. 244, a decorrere dal 1° gennaio 2016, in aderenza al processo di revisione dell'assetto strutturale e organizzativo del Ministero della difesa, con decreto del Presidente del Consiglio dei ministri su proposta del Ministro della difesa di concerto con il Ministro per la pubblica amministrazione e la semplificazione e il Ministro dell'economia e delle finanze, previa informazione alle organizzazioni sindacali, si provvede, con cadenza triennale, alla progressiva rideterminazione della dotazione organica complessiva di cui alla tabella 1, allegata al decreto del Presidente del Consiglio dei ministri 22 gennaio 2013, pubblicato nella Gazzetta Ufficiale n. 87 del 13 aprile 2013.

2. Con decreto del Ministro della difesa, su proposta del Capo di stato maggiore della difesa, d'intesa con il Segretario generale della difesa ((e il Direttore nazionale degli armamenti per le aree)) di relativa competenza, previa informazione alle organizzazioni sindacali, si provvede a ripartire la dotazione organica complessiva, suddivisa per profili professionali, nelle strutture centrali e periferiche in cui si articola l'amministrazione.

3. In riferimento alla dotazione organica complessiva come ripartita dal decreto del Ministro della difesa, il Capo di Stato maggiore della difesa, su proposta del Segretario generale della difesa, ((del Direttore nazionale degli armamenti,)) dei Capi di stato maggiore di Forza armata e del Comandante generale dell'Arma dei carabinieri, ciascuno per l'area di rispettiva competenza, predispone il piano di riassorbimento delle unita' di personale risultanti in eccedenza, da attuare prima dell'adozione del successivo decreto del Presidente del Consiglio dei ministri di rideterminazione degli organici. Il piano, adottato dal Ministro della difesa previo esame entro trenta giorni con le organizzazioni sindacali, individua:

- a) le unita' di personale risultanti complessivamente in eccedenza ovvero carenti, suddivise per area funzionale e profilo professionale;
- b) nell'ambito delle unita' risultanti in eccedenza, le unita' riassorbibili nel triennio in applicazione dei seguenti criteri: 1) cessazione dal servizio per collocamento in pensione secondo le vigenti disposizioni; 2) riconversione professionale, nell'ambito dell'area funzionale di appartenenza, secondo i criteri e le procedure fissati in sede di contrattazione decentrata di amministrazione prevista dal vigente contratto collettivo nazionale di lavoro del personale del comparto Ministeri, mediante specifici percorsi di formazione; 3) attuazione di procedure di mobilita' interna anche attraverso l'adozione di misure che agevolano il reimpiego del personale in ambito comunale e provinciale, sentiti gli interessati, nei limiti dei posti disponibili; 4) trasformazione del rapporto di lavoro da tempo pieno a tempo parziale, secondo le modalita' previste dalle vigenti disposizioni, anche oltre il limite percentuale di cui all'articolo 22, comma 20, della legge 23 dicembre 1994, n. 724; 5) a decorrere dall'anno 2016 avvio di processi di trasferimento presso altre amministrazioni pubbliche, di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, entro i contingenti e le misure percentuali e con i criteri stabiliti con decreti del Presidente del Consiglio dei Ministri, di concerto con il Ministro dell'economia e delle finanze e con il Ministro per la pubblica amministrazione e la semplificazione, in misura non inferiore al 15 per cento delle complessive facolta' assunzionali delle predette amministrazioni e fatto salvo quanto disposto dall'articolo 30, comma 2-ter, del decreto legislativo n. 165 del 2001, previo esame, entro trenta giorni, con le organizzazioni sindacali; i posti eventualmente non coperti dal personale civile sono devoluti a favore del personale militare secondo le modalita' di cui all'articolo 2209-quinquies. I trasferimenti presso le regioni e gli enti locali sono disposti nella misura percentuale stabilita con intesa in sede di Conferenza unificata, di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, con il consenso dell'amministrazione ricevente, previa verifica della rispondenza tra i requisiti culturali e professionali richiesti per l'accesso al profilo da ricoprire e i requisiti posseduti dallo stesso personale da trasferire.

4. Le misure di attuazione del piano sono adottate sentite le organizzazioni sindacali.

5. Il personale in eccedenza non riassorbibile nei tempi e con le modalita' definiti dal piano e' collocato in disponibilita'. Il periodo di ventiquattro mesi di cui al comma 8 dell'articolo 33 del decreto legislativo n. 165 del 2001 puo' essere aumentato fino a sessanta mesi, laddove il personale collocato in disponibilita' maturi entro il predetto arco temporale i requisiti per il trattamento pensionistico.

6. Ai fini della periodica revisione del piano di cui al comma 3, con decreto del Ministro della difesa si provvede alla ricognizione annuale delle dotazioni organiche effettive del personale civile.

7. A decorrere dall'anno 2021, quota parte dei risparmi derivanti dalla progressiva riduzione del personale civile, pari a 20 milioni di euro annui, e' destinata ad alimentare il fondo risorse decentrate del personale civile del Ministero della difesa e un'ulteriore quota parte, pari a 30 milioni di euro annui, e' destinata ad aumentare per il medesimo personale l'indennita' di amministrazione, le cui misure sono determinate in sede di contrattazione collettiva per il triennio 2019-2021. L'utilizzo delle predette risorse e' subordinato alla progressiva riduzione, sino al raggiungimento del numero di 20.000 unita', della dotazione organica complessiva del personale civile del Ministero della difesa fissata dalla tabella 1 allegata al decreto del Presidente del Consiglio dei ministri 22 gennaio 2013, pubblicato nella Gazzetta Ufficiale n. 87 del 13 aprile 2013, da operare in sede di programmazione triennale del fabbisogno di personale, ai sensi degli articoli 6 e seguenti del decreto legislativo 30 marzo 2001, n. 165.

#### Art. 2259-quater. - Piani di miglioramento individuale della professionalita' del personale civile).

1. In aderenza al processo di revisione dell'assetto strutturale e organizzativo del Ministero della difesa, al fine di conseguire, nel rispetto delle disposizioni vigenti in materia di progressioni di carriera, il migliore impiego delle risorse umane disponibili, nell'ottica della valorizzazione delle relative professionalita', nonche' di agevolare l'adozione delle misure di attuazione dei piani di riassorbimento del personale eventualmente in eccedenza, a decorrere dall'anno 2016 e fino all'anno 2024 ovvero al diverso termine stabilito ai sensi dell'articolo 5, comma 2, della legge 31 dicembre 2012, n. 244, nell'ambito delle risorse finanziarie disponibili a legislazione vigente, nel «Piano triennale di formazione dei dirigenti e dei funzionari» adottato dal Ministero della difesa, di cui all'articolo 8 del decreto del Presidente della repubblica 16 aprile 2013, n. 70, e' inserita una sezione dedicata alla rappresentazione delle esigenze straordinarie e urgenti di formazione del personale civile appartenente all'area terza connesse con:

- a) l'ampliamento dei settori di impiego, compresi i procedimenti di approvvigionamento di mezzi, materiali, armamenti, beni, servizi e lavori, in campo nazionale e internazionale;
- b) la riconversione professionale, ai fini del reimpiego nell'ambito del Ministero della difesa ovvero del trasferimento presso altre amministrazioni pubbliche, di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, d'intesa con le amministrazioni di destinazione;

2. Le esigenze di formazione di cui al comma 1 devono essere assolte entro i corrispondenti anni del «Programma triennale delle attivita' di formazione dei dirigenti e funzionari pubblici», di cui all'articolo 8 del decreto del Presidente della Repubblica 16 aprile 2013, n. 70. ((Le esigenze straordinarie e urgenti di formazione di cui al comma 1 possono essere assolte dal Polo di formazione unico di cui all'articolo 1013, comma 5-bis e dagli enti di formazione della Difesa nonche' dalla Scuola nazionale dell'amministrazione.))

3. ((Per le medesime finalita' di cui al comma 1, il Capo di stato maggiore della difesa approva, entro il 31 gennaio di ciascun anno, un programma annuale di formazione, da attuare tramite i centri di formazione di cui al comma 2, anche attraverso strutture decentrate, che individua in particolare:))

- a) moduli formativi dedicati alla riconversione professionale del personale civile appartenente all'area seconda, ai fini del reimpiego nell'ambito del Ministero della difesa ovvero del trasferimento presso altre amministrazioni pubbliche, di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, d'intesa con le amministrazioni di destinazione;
- b) moduli formativi di base e di specializzazione, per ottimizzare l'impiego del personale civile assegnato agli arsenali, agli stabilimenti, ai poli di mantenimento, ai centri tecnici e polifunzionali e agli enti e reparti della Difesa;
- c) moduli formativi destinati al personale militare di grado corrispondente alle qualifiche funzionali delle aree seconda e terza, al fine di agevolare l'attuazione del piano di programmazione triennale scorrevole dei transiti nei ruoli del personale civile delle amministrazioni pubbliche, di cui all'articolo 2209-quater, d'intesa con le amministrazioni di destinazione.

4. I moduli formativi di cui al comma 3 si concludono con un esame finale che attesta il possesso delle conoscenze relative alle materie oggetto del corso, d'intesa con le amministrazioni di destinazione.

((

5. Il Capo di stato maggiore della difesa, d'intesa con il Segretario generale, sentite le organizzazioni sindacali, stabilisce annualmente il numero dei posti da riservare a favore del personale civile per la partecipazione ai corsi svolti presso i centri di formazione militare, con esclusione dei corsi di cui all'articolo 715, comma 2, nonche' agli articoli 716, 717, 720, 722, 723, 725, 728, 731, 734, 736, 737, 739, 743, 750, 754, 755, 756, 757, 758, 760, 765, 773, 775, 776, 781, 783 e 786 e di altri corsi la cui partecipazione e' riservata al solo personale militare. La percentuale dei posti da riservare e' pari a non meno del 20 per cento dei posti disponibili.

))

6. Alla formazione del personale civile del Ministero della difesa e' annualmente destinata quota parte dei risparmi derivanti dalla riduzione del personale civile, accertati secondo quanto previsto dall'articolo 4, comma 1, lettera d), della legge 31 dicembre 2012, n. 244, in deroga a quanto previsto dall'articolo 6, comma 13, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122, in misura non inferiore al 2 per cento e non superiore al 5 per cento, sentite le organizzazioni sindacali.

#### Art. 2259-quinquies. - (( (Accesso alla dirigenza). ))

((

1. Fino al 31 dicembre 2024, ovvero al diverso termine stabilito ai sensi dell'articolo 5, comma 2, della legge 31 dicembre 2012, n. 244, nei concorsi banditi per l'accesso alla qualifica di dirigente di seconda fascia del Ministero della difesa, nei limiti delle relative facolta' assunzionali, il 50 per cento dei posti e' riservato a favore del personale civile appartenente all'area terza dello stesso Ministero in possesso dei prescritti requisiti.

))

#### Art. 2259-sexies. - (Enti dipendenti dai comandi logistici di Forza armata).

1. Fino al 31 dicembre 2024, ovvero al diverso termine stabilito ai sensi dell'articolo 5, comma 2, della legge 31 dicembre 2012, n. 244, in deroga all'articolo 51 del presente codice, le dotazioni organiche di ciascuno degli enti dipendenti dai comandi logistici di Forza armata, di cui all'articolo 47, comma 1, lettera c), sono stabilite con il decreto del Ministro della difesa di cui all'articolo 2259-ter, comma 2. In coerenza con i piani di riduzione graduale del personale, nonche' con gli obiettivi di efficienza e di gestione economica, da conseguire anche attraverso l'avvio di un processo di internalizzazione di servizi e lavori, per ciascun ente, in relazione alle esigenze connesse con i compiti istituzionali e con i programmi di lavoro, con decreto del Ministro della difesa, su proposta del Capo di Stato maggiore di Forza armata per il tramite del Capo di stato maggiore della difesa, sentite le organizzazioni sindacali per le materie di competenza, si provvede alla ricognizione annuale dell'organico effettivo di personale militare e civile e ad apportare le coerenti modifiche ordinative, anche rimodulando la ripartizione interna di compiti e funzioni. Con il medesimo decreto puo' essere rideterminato il grado dell'ufficiale preposto a ricoprire la carica di direttore dell'ente ((, nonche', nei casi di perdurante vacanza di una o piu' cariche apicali, il personale, con i relativi requisiti di grado o qualifica, idoneo a ricoprire le cariche stesse in seno all'ente)).

2. Allo scopo di razionalizzare l'attivita' produttiva degli enti di cui al comma 1, i Capi di stato maggiore di Forza armata, annualmente, adottano piani di ricognizione dei servizi e dei lavori esternalizzati, nonche' di analisi, individuazione e classificazione di settori di spesa improduttiva, volti, rispettivamente, alla definizione di quote crescenti di lavorazioni da effettuare con risorse interne e alla riqualificazione complessiva della spesa.

3. I risparmi derivanti dal processo di internalizzazione di servizi e lavori, realizzati ai sensi dei commi 1 e 2 e accertati secondo quanto previsto dall'articolo 4, comma 1, lettera d), della legge 31 dicembre 2012, n. 244, sono destinati al sostegno delle attivita' produttive e all'efficientamento degli enti di cui comma 1.

#### Art. 2259-septies. - (( (Regime transitorio per il transito nei ruoli civili della Difesa del personale in ferma volontaria dell'Arma dei carabinieri). ))

((

1. L'articolo 952, comma 3-bis, si applica anche al personale in ferma volontaria appartenente ai ruoli degli ispettori e degli appuntati e carabinieri dell'Arma dei carabinieri giudicato non idoneo al servizio militare incondizionato per lesioni dipendenti o meno da causa di servizio, che ha conseguito la nomina a carabiniere di cui agli articoli 768 e 783, collocato in congedo dalla data di entrata in vigore del presente codice.

2. Per il personale di cui al comma 1, le domande di transito nelle qualifiche funzionali del personale civile del Ministero della difesa sono presentate, a pena di decadenza, entro il 31 dicembre 2017 all'amministrazione di appartenenza.

))

### SEZIONE VI - TRATTAMENTO ECONOMICO, ASSISTENZA E BENESSERE

#### Art. 2260. - Trattamento economico dei volontari in ferma breve

1. Fino a esaurimento del ruolo dei volontari in ferma breve, anche trattenuti in servizio, si applicano nei confronti dei medesimi le disposizioni in materia di retribuzione base e accessoria previste per i volontari in ferma prefissata dagli articoli 1791 e 1792.

#### Art. 2261.

((ARTICOLO ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190))

#### Art. 2262. - Premi residuali al personale dell'Esercito italiano, della Marina militare e dell'Aeronautica militare addetto al controllo del traffico aereo

1. Gli ufficiali e i sottufficiali dell'Esercito italiano, della Marina militare e dell'Aeronautica militare, gia' titolari di abilitazione di controllore del traffico aereo, in periodo antecedente al 2004, sono ammessi, al compimento di dieci anni di servizio e dopo aver acquisito il massimo grado di abilitazione previsto, alle ferme volontarie di cui all'articolo 970 entro il quarantacinquesimo anno di eta', con corresponsione dei relativi premi.

2. ((COMMA ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190)).((92))

3. ((COMMA ABROGATO DALLA L. 23 DICEMBRE 2014, N. 190)).((92))

--------------- AGGIORNAMENTO (92) Successivamente la Corte Costituzionale, con sentenza 9 giugno - 5 luglio 2022, n. 169 (in G.U. 1ª s.s. 06/07/2022, n. 27), ha dichiarato l'illegittimita' costituzionale dell'art. 1, comma 261 della legge 23 dicembre 2014, n. 190 (che ha abrogato i commi 2 e 3 del presente articolo) "nella parte in cui ha disposto l'abrogazione dell'art. 2262, commi 2 e 3, del decreto legislativo 15 marzo 2010, n. 66 (Codice dell'ordinamento militare)".

#### Art. 2262-bis. - Disposizioni transitorie e di coordinamento in tema di riordino

1. Al personale militare che a seguito dell'emanazione del decreto legislativo in attuazione della delega di cui all'articolo 1, comma 5, secondo periodo, della legge 31 dicembre 2012, n. 244, percepisce un trattamento fisso e continuativo inferiore a quello precedentemente in godimento, e' attribuito un assegno ad personam riassorbibile con i successivi incrementi della componente di retribuzione fissa e continuativa, non cumulabile con l'assegno funzionale di cui all'articolo 8, comma 3, del decreto del Presidente della Repubblica 16 aprile 2009, n. 52. Per gli ufficiali, l'assegno ad personam di cui al presente comma non e' cumulabile con l'assegno funzionale di cui all'articolo 8, comma 3, del decreto del Presidente della Repubblica 16 aprile 2009, n. 52, ma e' cumulabile con l'assegno funzionale di cui all'articolo 10, comma 11 del decreto legislativo di cui al primo periodo.

2. Ai fini del comma 1 si intende per «trattamento fisso e continuativo» quello composto, a seconda dei ruoli di appartenenza, da: stipendio, indennita' integrativa speciale, assegno pensionabile, indennita' di impiego operativo di base, indennita' dirigenziale, importo aggiuntivo pensionabile, assegno funzionale, assegno di valorizzazione dirigenziale, indennita' perequativa.

3. Agli ufficiali in servizio alla data del 1° gennaio 2018 e a decorrere da tale data, e' corrisposto un assegno personale di riordino, di importo lordo mensile pari a euro 650,00, per tredici mensilita' dal compimento del tredicesimo anno di servizio dalla nomina ad ufficiale o dalla qualifica di aspirante fino al conseguimento del grado di maggiore e gradi corrispondenti. Il predetto assegno non e' cumulabile con l'assegno funzionale di cui all'articolo 8, comma 3, del decreto del Presidente della Repubblica. n. 52 del 2009, ma e' cumulabile con l'assegno funzionale di cui all'articolo 10, comma 11 del decreto legislativo di cui al comma 1, primo periodo.

4. Agli ufficiali in servizio alla data del 1° gennaio 2018 che non abbiano maturato a tale data un'anzianita' pari a quindici anni di servizio dal conseguimento della nomina ad ufficiale o dalla qualifica di aspirante, e' corrisposto un assegno personale di riordino pari a euro 180,00 mensili lordi dal compimento del quindicesimo anno di servizio dalla nomina ad ufficiale o dalla qualifica di aspirante fino al raggiungimento del grado di maggiore e gradi corrispondenti.

5. Gli assegni di cui ai commi 1, 3 e 4 hanno effetto sulla tredicesima mensilita', sul trattamento ordinario di quiescenza, normale e privilegiato, sulla indennita' di buonuscita, sull'assegno alimentare, sull'equo indennizzo, sulle ritenute previdenziali ed assistenziali e i relativi contributi e i contributi di riscatto.

6. Per il personale di cui al comma 4 del presente articolo le maggiorazioni dell'indennita' di impiego operativo fondamentali e supplementari sono calcolate sull'indennita' di impiego operativo di base di euro 550,02. Le maggiorazioni di cui agli articoli 3, 4, 5, 6 e 7 della legge 28 marzo 1983, n. 78, e all'articolo 4 del decreto del Presidente della Repubblica 10 maggio 1998, n. 360, calcolate su tale importo, assorbono l'assegno di riordino di cui al comma 4 del presente articolo.

7. Il personale ufficiale fino al grado di capitano che alla data del 31 dicembre 2017 abbia maturato un'anzianita' pari a 15 anni dalla nomina ad ufficiale con attribuzione del relativo trattamento economico, mantiene l'indennita' di impiego operativo di base in godimento a tale data fino al raggiungimento del grado di maggiore.

8. Agli ufficiali appartenenti ai ruoli del servizio permanente per i quali e' previsto il diretto conseguimento del grado di tenente o corrispondente che alla data del 1° gennaio 2018 rivestono il grado di maggiore e gradi corrispondenti, o gradi superiori, la determinazione dello stipendio e la relativa progressione economica, in deroga agli articoli 1811, comma 3, e 1811-bis, comma 2, decorrono dalla maturazione del ventitreesimo anno dal conseguimento della nomina diretta a tenente o corrispondente, ove piu' favorevole.

8-bis. Ai ((graduati aiutanti, ai sergenti maggiori aiutanti)) e ai primi luogotenenti e ((qualifiche)) corrispondenti, con anzianita' di qualifica non successiva al 31 dicembre 2019, e' corrisposto un assegno lordo una tantum negli importi di seguito stabiliti:

- a) euro 250,00 ai ((graduati aiutanti e)) corrispondenti;
- b) euro 350,00 ai ((sergenti maggiori aiutanti)) e corrispondenti;
- c) euro 450,00 ai primi luogotenenti.

8-ter. L'assegno di cui al comma 8-bis e' altresi' corrisposto al personale che consegue la qualifica ((di graduato aiutante, di sergente maggiore aiutante e qualifiche corrispondenti)) ovvero la qualifica di primo luogotenente nell'anno 2020, negli importi di seguito specificati:

- a) euro 250,00 ai ((primi graduati)) e gradi corrispondenti, con decorrenza nel grado non successiva al 31 dicembre 2013;
- b) euro 350,00 ai sergenti maggiori capi e corrispondenti con decorrenza nel grado di sergente maggiore non successiva al 31 dicembre 2010;
- c) euro 450,00 ai luogotenenti con decorrenza nel grado di primo maresciallo e gradi corrispondenti non successiva al 31 dicembre 2008.

8-quater. Ai sergenti maggiori e gradi corrispondenti promossi al grado di sergente maggiore capo ai sensi dell'articolo 1273, comma 2, lettera b), numeri 1 e 2, vigente anteriormente all'entrata in vigore del presente comma e' corrisposto un assegno una tantum pari a euro 250,00.

8-quinquies. Al personale di cui ai commi 8-bis e 8-ter e' corrisposto un ulteriore assegno lordo una tantum negli importi di seguito stabiliti:

- a) al personale di cui alla lettera a), euro 65,00 nell'anno 2020;
- b) al personale di cui alla lettera b), euro 80,00 nell'anno 2020;
- c) al personale di cui alla lettera c), euro 90,00 nell'anno 2020.

#### Art. 2262-ter. - (( (Disposizioni transitorie in materia di trattamento economico dei volontari in ferma prefissata di un anno o in rafferma). ))

((

1. Ai volontari in ferma prefissata di un anno e in rafferma annuale:

- a) fino al 31 dicembre 2022, e' corrisposta una paga netta giornaliera determinata nelle seguenti misure percentuali riferite al valore giornaliero dello stipendio iniziale lordo e dell'indennita' integrativa speciale costituenti la retribuzione mensile del grado iniziale dei volontari in servizio permanente: 1) pari al 64 per cento, per i volontari in ferma prefissata di un anno; 2) pari al 74 per cento, per i volontari in rafferma annuale;
- b) a decorrere dal 1° gennaio 2023, e' attribuito il trattamento economico di cui agli articoli 1791, comma 1, e 1792, comma 1;
- c) si applica l'articolo 1791, comma 2, se prestano servizio nei reparti alpini;
- d) si applica l'articolo 1792, comma 4, per le indennita' di impiego operativo;
- e) durante la licenza straordinaria di convalescenza, se l'infermita' non dipende da causa di servizio, esclusi i periodi di ricovero in luogo di cura, la paga e' dovuta in misura intera per i primi due mesi, in misura ridotta alla meta' per il mese successivo e, a decorrere dal quarto mese, non e' piu' dovuta.

2. Ai volontari di cui al presente articolo si applicano le disposizioni del presente codice in materia di trattamento economico riferite ai volontari in ferma prefissata senza ulteriori specificazioni.

))

#### Art. 2262-quater. - (( (Disposizioni transitorie in materia di trattamento economico dei volontari in ferma prefissata quadriennale o in rafferma). ))

((

1. Ai volontari in ferma prefissata quadriennale:

- a) fino al 31 dicembre 2025: 1) e' corrisposta una paga netta giornaliera determinata nella misura percentuale pari al 74 per cento del valore giornaliero dello stipendio iniziale lordo e dell'indennita' integrativa speciale costituenti la retribuzione mensile del grado iniziale dei volontari in servizio permanente; 2) per compensare l'attivita' effettuata oltre il normale orario di servizio, fatta salva la previsione di adeguati turni di riposo per il recupero psico-fisico disciplinati dalla normativa vigente in materia per le singole Forze armate, e' corrisposta un'indennita' pari a euro 103,29 mensili, a far data dal 1° gennaio 2005. Se il volontario in ferma prefissata quadriennale decede senza aver fruito dei turni di riposo di cui al primo periodo, ferma restando la corresponsione dell'indennita' di cui al medesimo primo periodo, l'attivita' effettuata oltre il normale orario di servizio e' integralmente remunerata a favore degli eredi nella misura pari al compenso per lavoro straordinario previsto per il grado di graduato e gradi corrispondenti; 3) si applica l'articolo 1792, comma 3, per i compensi forfetari di guardia e di impiego; 4) si applica l'articolo 1792, comma 4, per le indennita' di impiego operativo;
- b) a decorrere dal 1° gennaio 2026: 1) e' attribuito il trattamento economico di cui all'articolo 1791, comma 3; 2) per compensare l'attivita' effettuata oltre il normale orario di servizio, si applica l'articolo 1792, comma 2; 3) cessa la corresponsione dell'indennita' di cui alla lettera a), numero 2); 4) si applica l'articolo 1792, comma 3, per i compensi forfetari di guardia e di impiego; 5) si applica l'articolo 1792, comma 5, per le indennita' di impiego operativo;
- c) durante la licenza straordinaria di convalescenza, di cui all'articolo 1503, comma 6, se l'infermita' non dipende da causa di servizio, esclusi i periodi di ricovero in luogo di cura, la paga di cui alla lettera a), numero 1), ovvero il trattamento economico di cui alla lettera b), numero 1), sono dovuti in misura intera per i primi sei mesi, in misura ridotta alla meta' per i successivi tre mesi e, a decorrere dal decimo mese, non sono piu' dovuti.

2. Ai volontari in ferma prefissata quadriennale in rafferma biennale ovvero annuale sono attribuiti il parametro stipendiale e gli assegni a carattere fisso e continuativo spettanti al grado iniziale dei volontari in servizio permanente. Dalla data di attribuzione del trattamento economico di cui al primo periodo cessa la corresponsione dell'indennita' di cui al comma 1, lettera a), numero 2).

3. Ai volontari di cui al presente articolo si applicano le disposizioni del presente codice in materia di trattamento economico riferite ai volontari in ferma prefissata senza ulteriori specificazioni))

#### Art. 2262-quinquies. - (( (Disposizioni transitorie in materia di soppressione dell'assegno speciale per gli ufficiali dell'Esercito italiano e dell'Arma dei carabinieri) ))

((

1. Al personale che, alla data del 31 dicembre 2022, e' percettore dell'assegno speciale di cui all'articolo 1915 e' riconosciuto il diritto di optare, in sostituzione dello stesso, per una maggiorazione dell'indennita' supplementare di cui all'articolo 1914, calcolata moltiplicando il 60 per cento dell'importo annuo dell'assegno speciale in godimento per i coefficienti corrispondenti al sesso e all'eta' dell'avente diritto di cui alla tavola di mortalita' elaborata dall'Istituto nazionale di statistica, riferita alla popolazione italiana residente per l'anno 2019, e calcolata al 1° dicembre dell'anno nel quale e' esercitata l'opzione.

2. Al personale che, alla data del 31 dicembre 2022, e' cessato dal servizio con diritto a pensione, ma non e' ancora percettore dell'assegno speciale di cui all'articolo 1915, e' riconosciuto il diritto di optare tra lo stesso assegno speciale e una maggiorazione dell'indennita' supplementare di cui all'articolo 1914, calcolata moltiplicando il 50 per cento dell'importo annuo dell'assegno speciale previsto per il grado rivestito all'atto della cessazione dal servizio alla data del 31 dicembre 2022, per i seguenti fattori:

- a) il coefficiente di cui alla tavola di mortalita' dell'Istituto nazionale di statistica, riferita alla popolazione italiana residente per l'anno 2019, corrispondente al sesso e all'eta' dell'avente diritto, indicato al 1° dicembre dell'anno in cui l'interessato compira' un'eta' pari a quella posseduta al congedo aumentata di otto anni e comunque non inferiore a sessantacinque;
- b) l'anzianita' contributiva al fondo previdenziale di cui all'articolo 1913, comma 1, lettera a), posseduta al 31 dicembre 2022, con un massimo di quaranta anni, rapportata a 40. L'eventuale anzianita' maturata in altri fondi non e' considerata utile al calcolo della maggiorazione.

3. Al personale in servizio al 31 dicembre 2022, in luogo dell'assegno speciale di cui all'articolo 1915, e' riconosciuta una maggiorazione dell'indennita' supplementare di cui all'articolo 1914, calcolata ai sensi del comma 2.

4. Il diritto alle opzioni di cui ai commi 1 e 2 e' esercitato entro il mese di settembre di ogni anno ed e' irrevocabile. La maggiorazione dell'indennita' supplementare di cui all'articolo 1914 e' liquidata e corrisposta agli interessati entro il 31 dicembre dell'anno nel quale il diritto di opzione e' esercitato. Le maggiorazioni dell'indennita' supplementare, di cui ai commi 1, 2 e 3, sono reversibili))

((99))

-------------- AGGIORNAMENTO (99) La L. 29 dicembre 2022, n. 197 ha disposto (con l'art. 1, comma 654) che "Le disposizioni di cui ai commi da 651 a 653 si applicano anche a coloro per i quali, alla data di entrata in vigore della presente legge, risulta ancora pendente un giudizio o e' stata emessa sentenza non ancora passata in giudicato".

### SEZIONE VII - TRATTAMENTO PREVIDENZIALE E PER LE INVALIDITA' DI SERVIZIO

#### Art. 2263. - Ritenuta INPDAP per i volontari in ferma breve

1. Fino ad esaurimento del ruolo dei volontari in ferma breve, anche trattenuti in servizio, l'Amministrazione della difesa provvede al versamento dei contributi previdenziali e assistenziali previsti dalla normativa vigente.

#### Art. 2264. - Norma di interpretazione autentica in materia di assicurazione obbligatoria contro gli infortuni sul lavoro e le malattie professionali

1. Al personale militare si applica l'articolo 12-bis del decreto-legge 23 febbraio 2009, n. 11, convertito dalla legge 23 aprile 2009, n. 38.

#### Art. 2264-bis. - (( (Limiti per la costituzione della posizione assicurativa). ))

((

1. Gli articoli 1861 e 1862 trovano applicazione per le posizioni assicurative costituite per il servizio prestato fino al 30 luglio 2010, agli effetti dell'articolo 12, comma 12-undecies, del decreto-legge 31 maggio 2010, n. 78, convertito, con modificazioni, dalla legge 30 luglio 2010, n. 122.

))

### SEZIONE VIII - SERVIZIO MILITARE E SERVIZIO DEGLI OBIETTORI DI COSCIENZA IN TEMPO DI GUERRA O DI GRAVE CRISI INTERNAZIONALE

#### Art. 2265. - Cancellazione della nota di renitenza

1. I renitenti alla leva appartenenti alle classi 1985 e precedenti, presentandosi ai comandi militari Esercito italiano e agli altri organi di cui all'articolo 1930, comma 3, possono ottenere la cancellazione della nota di renitenza, fornendo un giustificato motivo del proprio comportamento omissivo.

#### Art. 2266. - Attivita' connesse con la sospensione della leva obbligatoria

1. Fatte salve le decisioni di competenza dell'autorita' giudiziaria, durante la sospensione della leva obbligatoria per gli appartenenti alle classi 1985 e precedenti, i comandi ((interregionale)) territorialmente competenti, i comandi militari Esercito italiano, ovvero gli altri organismi di cui all'articolo 1930, comma 3, su istanza degli interessati:

- a) definiscono le posizioni rimaste in sospeso, concernenti l'accertamento dell'idoneita' al servizio militare incondizionato;
- b) pronunciano la revoca delle riforme, qualora si accerti il venire meno delle cause che le hanno determinate;
- c) provvedono alla cancellazione delle note di renitenza, qualora ne ricorrano i presupposti;
- d) definiscono i procedimenti pendenti connessi con la cittadinanza;
- e) provvedono alla compilazione e alla consegna dei fogli di congedo per fine ferma e dei fogli matricolari agli arruolati con visita e senza visita, nonche' ai dispensati a seguito dell'accoglimento di ricorso giurisdizionale o amministrativo.

## TITOLO III DISPOSIZIONI FINALI

### Art. 2267. - Abrogazione per nuova regolamentazione della materia

1. Alla data di approvazione definitiva del codice e del regolamento, sono abrogate, ai sensi dell'articolo 15 delle disposizioni sulla legge in generale, tutte le disposizioni incompatibili o comunque afferenti alle materie indicate nell'articolo 1, commi 1 e 3, a eccezione di quelle richiamate dal codice o dal regolamento. ((Alla data di entrata in vigore del codice, le abrogazioni previste all'articolo 2268, comma 1, aventi ad oggetto le leggi di conversione di decreti-legge con approvazione complessiva, si riferiscono esclusivamente ai rispettivi decreti-legge abrogati ai medesimi numeri.))

2. Ai sensi dell'articolo 13-bis, comma 4, della legge 23 agosto 1988, n. 400, le disposizioni del presente codice e del regolamento possono essere abrogate, derogate, sospese, modificate, coordinate o implementate solo in modo esplicito, e mediante intervento avente ad oggetto le disposizioni contenute nel codice o nel regolamento.

### Art. 2268. - Abrogazione espressa di norme primarie

1. A decorrere dall'entrata in vigore del codice e del regolamento, sono o restano abrogati i seguenti atti normativi primari e le successive modificazioni: 1) regio decreto 2 aprile 1885, n. 3095: articoli 1 e 3; 2) legge 14 luglio 1907, n. 470; 3) legge 22 giugno 1913, n. 693; 4) regio decreto legge 26 luglio 1917, n. 1513, e legge di conversione 7 giugno 1923, n. 1310; 5) decreto legislativo luogotenenziale 23 giugno 1918, n. 896; 6) decreto legislativo luogotenenziale 6 aprile 1919, n. 495; 7) regio decreto 2 ottobre 1919, n. 1802 e legge di conversione 21 marzo 1926, n. 597; 8) regio decreto legge 23 ottobre 1919, n. 1970 e legge di conversione 21 agosto 1921, n. 1144; 9) regio decreto 18 novembre 1920, n. 1626; 10) regio decreto 4 agosto 1921, n. 1215; 11) regio decreto 30 settembre 1922, n. 1290; 12) regio decreto 27 ottobre 1922, n. 1427; 13) regio decreto 27 ottobre 1922, n. 1462, esclusi articoli 6 e 23; 14) regio decreto legge 29 ottobre 1922, n. 1386; 15) regio decreto 18 dicembre 1922, n. 1637; 16) regio decreto 24 gennaio 1923, n. 62; 17) regio decreto 18 marzo 1923, n. 590; 18) regio decreto 28 marzo 1923, n. 645; 19) legge 7 giugno 1923, n. 1310; 20) regio decreto 11 novembre 1923, n. 2395; 21) regio decreto 15 novembre 1923, n. 2506, articoli: 6; 16; 17, comma 2, limitatamente alle parole «per decreto del Ministro della guerra se trattisi di strade da iscriversi alla 5- classe»; 17, comma 3, limitatamente alle parole «e l'obbligo del contributo dei comuni per la manutenzione delle strade di 5- classe»; 22) regio decreto 18 novembre 1923, n. 2440: articolo 5-bis; 23) regio decreto 31 dicembre 1923, n. 3225; 24) regio decreto 23 maggio 1924, n. 827: articolo 4, comma 2; 25) regio decreto 21 dicembre 1924, «Approvazione del testo unico delle norme e disposizioni riguardanti la concessione della medaglia mauriziana pel merito militare di dieci lustri». 26) regio decreto legge 2 aprile 1925, n. 382 e legge di conversione 21 marzo 1926, n. 597; 27) regio decreto legge 4 maggio 1925, n. 775 e legge di conversione 21 marzo 1926, n. 597; 28) regio decreto legge 24 maggio 1925, n. 1032; 29) regio decreto 21 giugno 1925, n. 1943; 30) regio decreto legge 4 settembre 1925, n. 1576 e legge di conversione 18 marzo 1926, n. 562; 31) regio decreto legge 15 ottobre 1925, n. 1909 e legge di conversione 18 marzo 1926, n. 562; 32) regio decreto legge 14 gennaio 1926, n. 143 e legge di conversione legge 25 novembre 1926, n. 2150; 33) regio decreto legge 14 gennaio 1926, n. 196 e legge di conversione 25 giugno 1926, n. 1262; 34) regio decreto 31 gennaio 1926, n. 452; 35) regio decreto legge 9 febbraio 1926, n. 202 e legge di conversione 25 novembre 1926, n. 2149; 36) legge 11 marzo 1926, n. 416; 37) legge 11 marzo 1926, n. 417; 38) regio decreto legge 16 maggio 1926, n. 855 e legge di conversione 21 novembre 1926, n. 2147; 39) legge 8 luglio 1926, n. 1178; 40) regio decreto legge 15 luglio 1926, n. 1345 e legge di conversione 5 agosto 1927, n. 1835; 41) regio decreto legge 9 dicembre 1926, n. 2352 e legge di conversione 12 febbraio 1928, n. 261; 42) regio decreto legge 6 gennaio 1927, n. 27; 43) regio decreto legge 13 febbraio 1927, n. 285 e legge di conversione 18 dicembre 1927, n. 2431; 44) regio decreto legge 27 marzo 1927, n. 755 e legge di conversione 29 dicembre 1927, n. 2763; 45) regio decreto legge 23 giugno 1927, n. 1429; 46) regio decreto 12 agosto 1927, n. 1613; 47) regio decreto legge 19 dicembre 1927, n. 2317 e legge di conversione 15 novembre 1928, n. 2792; 48) legge 12 gennaio 1928, n. 93; 49) regio decreto 2 febbraio 1928, n. 263; 50) regio decreto legge 14 giugno 1928, n. 1446 e legge di conversione 9 dicembre 1928, n. 3327; 51) regio decreto legge 6 settembre 1928, n. 2167 e legge di conversione 20 dicembre 1928, n. 3204; 52) regio decreto legge 4 ottobre 1928, n. 2327 e legge di conversione 6 dicembre 1928, n. 3240; 53) regio decreto legge 4 ottobre 1928, n. 2380 e legge di conversione 20 dicembre 1928, n. 3091; 54) regio decreto legge 8 novembre 1928, n. 2482 e legge di conversione 27 dicembre 1928, n. 3328; 55) legge 24 dicembre 1928, n. 3241; 56) regio decreto 31 dicembre 1928, n. 3458, esclusi articoli 11 e 115; 57) legge 10 gennaio 1929, n. 59; 58) regio decreto legge 26 luglio 1929, n. 1413 e legge di conversione 23 dicembre 1929, n. 2294; 59) legge 27 marzo 1930, n. 460; 60) legge 17 aprile 1930, n. 479; 61) regio decreto 23 giugno 1930, n. 983; 62) legge 3 luglio 1930, n. 1079; 63) legge 10 luglio 1930, n. 1140; 64) regio decreto 23 ottobre 1930, n. 1563; 65) regio decreto 23 ottobre 1930, n. 1571; 66) regio decreto legge 30 ottobre 1930, n. 1510 e legge di conversione 6 gennaio 1931, n. 32; 67) regio decreto legge 30 novembre 1930, n. 2508; 68) legge 29 dicembre 1930, n. 1712; 69) legge 1° giugno 1931, n. 886; 70) legge 12 giugno 1931, n. 877; 71) regio decreto 18 giugno 1931, n. 876; 72) regio decreto 18 giugno 1931, n. 914; 73) legge 24 marzo 1932, n. 453; 74) regio decreto 31 marzo 1932, n. 867; 75) regio decreto 16 maggio 1932, n. 819; 76) legge 23 maggio 1932, n. 739; 77) regio decreto 28 luglio 1932, n. 1365; 78) regio decreto 15 settembre 1932, n. 1514; 79) regio decreto 4 novembre 1932, n. 1423; 80) legge 20 dicembre 1932, n. 1613; 81) legge 20 dicembre 1932, n. 1694; 82) legge 22 dicembre 1932, n. 1958; 83) regio decreto legge 11 maggio 1933, n. 431 e legge di conversione 8 giugno 1933, n. 788; 84) regio decreto legge 22 giugno 1933, n. 930 e legge di conversione 28 dicembre 1933, n. 1890; 85) regio decreto legge 29 luglio 1933, n. 997 e legge di conversione 11 gennaio 1934, n. 34; 86) regio decreto 24 agosto 1933, n. 2423: articolo 2; 87) regio decreto legge 7 settembre 1933, n. 1295 e legge di conversione 28 dicembre 1933, n. 1941; 88) legge 28 dicembre 1933, n. 1954; 89) regio decreto legge 8 gennaio 1934, n. 46 e legge di conversione 4 giugno 1934, n. 938; 90) legge 22 gennaio 1934, n. 115; 91) legge 22 gennaio 1934, n. 121; 92) regio decreto legge 5 febbraio 1934, n. 264 e legge di conversione 4 giugno 1934, n. 940; 93) regio decreto legge 16 aprile 1934, n. 781 e legge di conversione 4 giugno 1934, n. 946; 94) regio decreto legge 19 aprile 1934, n. 730 e legge di conversione 4 giugno 1934, n. 1043; 95) regio decreto legge 30 aprile 1934, n. 795; 96) legge 4 giugno 1934, n. 950; 97) legge 7 giugno 1934, n. 899; 98) legge 14 giugno 1934, n. 1015; 99) legge 21 giugno 1934, n. 1093; 100) regio decreto legge 28 settembre 1934, n. 1635; 101) regio decreto legge 18 ottobre 1934, n. 1858 e legge di conversione 27 dicembre 1934, n. 2223; 102) legge 27 dicembre 1934, n. 2250; 103) regio decreto legge 28 gennaio 1935, n. 314 e legge di conversione 13 giugno 1935, n. 1297; 104) regio decreto legge 23 febbraio 1935, n. 115 e legge di conversione 11 aprile 1935, n. 845; 105) regio decreto 24 aprile 1935, n. 1376; 106) legge 6 maggio 1935, n. 747; 107) regio decreto legge 31 maggio 1935, n. 752 e legge di conversione 9 gennaio 1936, n. 132; 108) legge 3 giugno 1935, n. 1018; 109) legge 3 giugno 1935, n. 1095; 110) legge 6 giugno 1935, n. 1097; 111) legge 6 giugno 1935, n. 1098; 112) regio decreto legge 27 giugno 1935, n. 1300; 113) regio decreto legge 4 ottobre 1935, n. 1902 e legge di conversione 20 gennaio 1936, n. 215; 114) regio decreto legge 28 novembre 1935, n. 2397 e legge di conversione 6 aprile 1936, n. 1826; 115) regio decreto 2 dicembre 1935, n. 2342; 116) regio decreto legge 5 dicembre 1935, n. 2353 e legge di conversione 6 aprile 1936, n. 731; 117) regio decreto legge 16 dicembre 1935, n. 2430 e legge di conversione 4 giugno 1936, n. 1143; 118) regio decreto legge 13 gennaio 1936, n. 229 e legge di conversione 4 giugno 1936, n. 1145: articolo 4; 119) regio decreto legge 27 gennaio 1936, n. 303 e legge di conversione 6 aprile 1936, n. 744; 120) regio decreto 10 febbraio 1936, n. 484; 121) regio decreto legge 12 marzo 1936, n. 1030 e legge di conversione 1° febbraio 1937, n. 455; 122) regio decreto legge 20 aprile 1936, n. 913 e legge di conversione 10 febbraio 1937, n. 326; 123) regio decreto legge 27 aprile 1936, n. 1119 e legge di conversione 31 dicembre 1936, n. 2416; 124) legge 2 giugno 1936, n. 1225; 125) legge 2 giugno 1936, n. 1226; 126) regio decreto 16 luglio 1936, n. 1444; 127) regio decreto legge 22 ottobre 1936, n. 2134 e legge di conversione 28 aprile 1937, n. 753; 128) regio decreto legge 19 dicembre 1936, n. 2509 e legge di conversione 3 giugno 1937, n. 1318; 129) legge 31 dicembre 1936, n. 2416; 130) legge 4 gennaio 1937, n. 35; 131) regio decreto legge 15 febbraio 1937, n. 245; 132) regio decreto legge 22 febbraio 1937, n. 220 e legge di conversione 25 giugno 1937, n. 1501; 133) regio decreto legge 28 aprile 1937, n. 707 e legge di conversione 23 dicembre 1937, n. 2334; 134) regio decreto 29 aprile 1937, n. 894; 135) legge 3 giugno 1937, n. 1166; 136) regio decreto legge 21 ottobre 1937, n. 2179; 137) regio decreto legge 27 ottobre 1937, n. 2117 e legge di conversione 4 aprile 1938, n. 468; 138) legge 23 dicembre 1937, n. 2334; 139) legge 4 gennaio 1938, n. 23; 140) regio decreto legge 3 febbraio 1938, n. 744 e legge di conversione 16 febbraio 1939, n. 468; 141) regio decreto legge 17 febbraio 1938, n. 89 e legge di conversione 28 aprile 1938, n. 638; 142) regio decreto 24 febbraio 1938, n. 329; 143) regio decreto legge 14 marzo 1938, n. 882 e legge di conversione 22 dicembre 1938, n. 2229; 144) regio decreto 14 marzo 1938, n. 596; 145) regio decreto 14 marzo 1938, n. 964; 146) regio decreto legge 17 marzo 1938, n. 891 e legge di conversione 24 febbraio 1939, n. 492; 147) regio decreto legge 19 maggio 1938, n. 782 e legge di conversione 9 gennaio 1939, n. 248; 148) regio decreto legge 1 luglio 1938, n. 1368 e legge di conversione 9 gennaio 1939, n. 216; 149) regio decreto 1 luglio 1938, n. 1496; 150) regio decreto 8 luglio 1938, n. 1415: articolo 133; 151) regio decreto 15 luglio 1938, n. 1156, esclusi articoli 5 ((...)) e 19; 152) regio decreto legge 5 settembre 1938, n. 1519 e legge di conversione 22 dicembre 1938, n. 2168; 153) regio decreto legge 5 settembre 1938, n. 1525 e legge di conversione 24 febbraio 1939, n. 490; 154) regio decreto legge 4 ottobre 1938, n. 1741; 155) regio decreto legge 11 novembre 1938, n. 1902 e legge di conversione legge 2 giugno 1939, n. 739; 156) legge 22 dicembre 1938, n. 2235; 157) legge 19 gennaio 1939, n. 340; 158) regio decreto legge 25 gennaio 1939, n. 204; 159) legge 19 maggio 1939, n. 894; 160) legge 25 maggio 1939, n. 781; 161) legge 6 giugno 1939, n. 985; 162) legge 13 luglio 1939, n. 1154; 163) legge 22 luglio 1939, n. 1180; 164) legge 22 luglio 1939, n. 1225; 165) legge 18 dicembre 1939, n. 2109; 166) legge 22 dicembre 1939, n. 2183; 167) legge 22 dicembre 1939, n. 2185; 168) legge 22 dicembre 1939, n. 2207; 169) legge 6 giugno 1940, n. 730; 170) legge 4 aprile 1940, n. 336; 171) legge 9 maggio 1940, n. 368; 172) legge 9 maggio 1940, n. 371; 173) legge 13 maggio 1940, n. 690: articolo 13; 174) legge 23 maggio 1940, n. 649; 175) legge 6 giugno 1940, n. 595; 176) legge 6 giugno 1940, n. 733; 177) legge 14 giugno 1940, n. 863; 178) regio decreto 29 giugno 1940, n. 1227; 179) legge 1 luglio 1940, n. 935; 180) legge 6 luglio 1940, n. 1040; 181) legge 6 luglio 1940, n. 1082: articolo 5; 182) legge 12 luglio 1940, n. 1139; 183) regio decreto 18 agosto 1940, n. 1741; 184) legge 25 agosto 1940, n. 1302; 185) legge 25 agosto 1940, n. 1382; 186) legge 4 settembre 1940, n. 1422; 187) regio decreto 13 settembre 1940, n. 1669; 188) legge 14 ottobre 1940, n. 1549; 189) legge 21 novembre 1940, n. 1735; 190) legge 28 novembre 1940, n. 1773; 191) legge 2 dicembre 1940, n. 1848; 192) legge 27 gennaio 1941, n. 285; 193) regio decreto-legge 19 maggio 1941, n. 583 e legge di conversione 10 maggio 1943, n. 507; 194) legge 19 maggio 1941, n. 626; 195) regio decreto 21 giugno 1941, n. 688; 196) regio decreto 11 luglio 1941 n. 1161; 197) legge 25 luglio 1941, n. 1136; 198) legge 25 luglio 1941, n. 883; 199) legge 29 agosto 1941, n. 1052; 200) regio decreto 9 settembre 1941, n. 1022: articolo 1 e testo allegato, parte prima e parte terza; 201) regio decreto legge 2 dicembre 1941, n. 1670 e legge di conversione 3 dicembre 1942, n. 1819; 202) regio decreto 22 dicembre 1941, n. 1601; 203) legge 27 dicembre 1941, n. 1570: articolo 22, comma 3; 204) legge 22 gennaio 1942, n. 104; 205) legge 24 marzo 1942, n. 370; 206) legge 24 marzo 1942, n. 479; 207) legge 26 marzo 1942, n. 371; 208) legge 12 maggio 1942, n. 797; 209) regio decreto 12 maggio 1942, n. 918: articolo 68; 210) legge 27 giugno 1942, n. 897; 211) legge 27 giugno 1942, n. 924; 212) legge 27 giugno 1942, n. 976; 213) legge 9 ottobre 1942, n. 1229; 214) legge 9 ottobre 1942, n. 1356; 215) legge 9 ottobre 1942, n. 1357; 216) legge 3 dicembre 1942, n. 1547; 217) legge 14 dicembre 1942, n. 1690; 218) legge 14 dicembre 1942, n. 1717; 219) legge 24 dicembre 1942, n. 1755; 220) legge 11 gennaio 1943, n. 36; 221) regio decreto 2 febbraio 1943, n. 127; 222) regio decreto legge 8 febbraio 1943, n. 38; 223) legge 15 marzo 1943, n. 187; 224) regio decreto 29 marzo 1943, n. 437; 225) legge 31 maggio 1943, n. 614; 226) regio decreto legge 13 marzo 1944, n. 85 e legge di conversione 5 maggio 1949, n. 178; 227) decreto legislativo luogotenenziale 8 luglio 1944, n. 286; 228) decreto legislativo luogotenenziale 3 agosto 1944, n. 165; 229) decreto legislativo luogotenenziale 3 agosto 1944, n. 193; 230) decreto legislativo luogotenenziale 26 ottobre 1944, n. 571; 231) decreto legislativo luogotenenziale 1 novembre 1944, n. 385; 232) decreto legislativo luogotenenziale 16 novembre 1944, n. 409; 233) decreto legislativo luogotenenziale 23 novembre 1944, n. 401; 234) decreto legislativo luogotenenziale 11 gennaio 1945, n. 30; 235) decreto legislativo luogotenenziale 1 febbraio 1945, n. 53; 236) decreto legislativo luogotenenziale 1 febbraio 1945, n. 81; 237) decreto legislativo luogotenenziale 15 febbraio 1945, n. 43; 238) decreto legislativo luogotenenziale 22 marzo 1945, n. 244; 239) decreto legislativo luogotenenziale 31 maggio 1945, n. 346; 240) decreto legislativo luogotenenziale 31 maggio 1945, n. 567; 241) decreto legislativo luogotenenziale 28 giugno 1945, n. 497; 242) decreto legislativo luogotenenziale 7 giugno 1945, n. 568; 243) decreto legislativo luogotenenziale 5 luglio 1945, n. 429; 244) decreto legislativo luogotenenziale 3 agosto 1945, n. 663; 245) decreto legislativo luogotenenziale 10 agosto 1945, n. 618; 246) decreto legislativo luogotenenziale 21 agosto 1945, n. 535; 247) decreto legislativo luogotenenziale 31 agosto 1945, n. 603; 248) decreto legislativo luogotenenziale 7 settembre 1945, n. 41; 249) decreto legislativo luogotenenziale 7 settembre 1945, n. 580; 250) decreto legislativo luogotenenziale 7 settembre 1945, n. 615; 251) decreto legislativo luogotenenziale 7 settembre 1945, n. 772; 252) decreto legislativo luogotenenziale 19 ottobre 1945, n. 1372; 253) decreto legislativo luogotenenziale 23 novembre 1945, n. 890; 254) decreto legislativo luogotenenziale 25 gennaio 1946, n. 73; 255) decreto legislativo luogotenenziale 22 febbraio 1946, n. 379; 256) decreto legislativo luogotenenziale 29 marzo 1946, n. 348; 257) decreto legislativo luogotenenziale 12 aprile 1946, n. 319; 258) decreto legislativo luogotenenziale 12 aprile 1946, n. 320; 259) decreto legislativo luogotenenziale 12 aprile 1946, n. 585; 260) decreto legislativo luogotenenziale 12 aprile 1946, n. 588; 261) decreto legislativo luogotenenziale 12 aprile 1946, n. 605; 262) regio decreto legislativo 24 maggio 1946, n. 530; 263) regio decreto legislativo 31 maggio 1946, n. 616; 264) decreto legislativo del Capo provvisorio dello Stato 6 settembre 1946, n. 86; 265) decreto legislativo del Capo provvisorio dello Stato 6 settembre 1946, n. 238; 266) decreto legislativo del Capo provvisorio dello Stato 13 settembre 1946, n. 303; 267) decreto legislativo del Capo provvisorio dello Stato 13 settembre 1946, n. 358; 268) NUMERO SOPPRESSO DAL D.LGS. 24 FEBBRAIO 2012, N. 20; 269) decreto legislativo del Capo provvisorio dello Stato 30 novembre 1946, n. 736; 270) decreto legislativo del Capo provvisorio dello Stato 23 dicembre 1946, n. 533; 271) decreto legislativo del Capo provvisorio dello Stato 2 gennaio 1947, n. 4; 272) decreto legislativo del Capo provvisorio dello Stato 18 gennaio 1947, n. 66; 273) decreto legislativo del Capo provvisorio dello Stato 18 gennaio 1947, n. 129; 274) decreto legislativo del Capo provvisorio dello Stato 18 gennaio 1947, n. 150; 275) decreto legislativo del Capo provvisorio dello Stato 18 gennaio 1947, n. 165; 276) decreto legislativo del Capo provvisorio dello Stato 18 marzo 1947, n. 168; 277) decreto legislativo del Capo provvisorio dello Stato 26 aprile 1947, n. 264; 278) decreto legislativo del Capo provvisorio dello Stato 10 maggio 1947, n. 306; 279) decreto legislativo del Capo provvisorio dello Stato 10 luglio 1947, n. 697; 280) decreto legislativo del Capo provvisorio dello Stato 31 luglio 1947, n. 810, ratificato con legge 5 gennaio 1953, n. 30; 281) decreto legislativo del Capo provvisorio dello Stato 13 agosto 1947, n. 833, ratificato con legge 17 aprile 1956, n. 561; 282) decreto legislativo del Capo provvisorio dello Stato 20 agosto 1947, n. 1115; 283) decreto legislativo del Capo provvisorio dello Stato 20 agosto 1947, n. 1136; 284) decreto legislativo del Capo provvisorio dello Stato 20 agosto 1947, n. 1205; 285) decreto legislativo del Capo provvisorio dello Stato 21 agosto 1947, n. 1060; 286) decreto legislativo del Capo provvisorio dello Stato 5 settembre 1947, ratificato con legge 31 gennaio 1953, n. 72; 287) decreto legislativo del Capo provvisorio dello Stato 24 ottobre 1947, n. 1428; 288) decreto legislativo del Capo provvisorio dello Stato 25 ottobre 1947, n. 1152; 289) decreto legislativo del Capo provvisorio dello Stato 29 ottobre 1947, n. 1354; 290) decreto legislativo del Capo provvisorio dello Stato 1 novembre 1947, n. 1605; 291) decreto legislativo del Capo provvisorio dello Stato 1 novembre 1947, n. 1768; 292) decreto legislativo del Capo provvisorio dello Stato 9 novembre 1947, n. 1305; 293) decreto legislativo del Capo provvisorio dello Stato 28 dicembre 1947, n. 1627; 294) decreto legislativo 20 gennaio 1948, n. 45; 295) decreto legislativo 24 gennaio 1948, n. 196; 296) decreto legislativo 26 gennaio 1948, n. 74, ratificato dalla legge 5 gennaio 1953, n. 30; 297) NUMERO SOPPRESSO DAL D.LGS. 24 FEBBRAIO 2012, N. 20; (27) 298) decreto del Presidente della Repubblica 20 febbraio 1948, n. 1116; 299) decreto legislativo 11 marzo 1948, n. 409; 300) decreto legislativo 19 marzo 1948, n. 249, ratificato con legge 18 dicembre 1951, n. 1574; 301) decreto legislativo 14 aprile 1948, n. 1011; 302) decreto legislativo 17 aprile 1948, n. 611; 303) decreto legislativo 17 aprile 1948, n. 1181; 304) decreto legislativo 21 aprile 1948, n. 955; 305) decreto legislativo 21 aprile 1948, n. 1054; 306) decreto legislativo 27 aprile 1948, n. 614; 307) decreto legislativo 3 maggio 1948, n. 543; 308) decreto legislativo 3 maggio 1948, n. 1037; 309) decreto legislativo 5 maggio 1948, n. 814; 310) decreto legislativo 7 maggio 1948, n. 770; 311) decreto legislativo 7 maggio 1948, n. 1147; 312) legge 2 ottobre 1948, n. 1247; 313) decreto legislativo 5 ottobre 1948, n. 668; 314) legge 26 gennaio 1949, n. 20; 315) legge 29 marzo 1949, n. 164; 316) legge 21 aprile 1949, n. 185; 317) legge 21 aprile 1949, n. 257; 318) legge29 aprile 1949, n. 221; 319) legge 16 giugno 1949, n. 332; 320) legge 29 luglio 1949, n. 839; 321) legge 26 ottobre 1949, n. 915; 322) legge 23 dicembre 1949, n. 949; 323) legge 5 gennaio 1950, n. 44; 324) legge19 maggio 1950, n. 433; 325) legge 9 giugno 1950, n. 449; 326) legge 9 giugno 1950, n. 519; 327) legge 8 luglio 1950, n. 688; 328) legge 8 luglio 1950, n. 728; 329) legge 28 luglio 1950, n. 540; 330) legge 28 luglio 1950, n. 624; 331) legge 10 agosto 1950, n. 667; 332) decreto del Presidente della Repubblica 11 settembre 1950, n. 807; 333) legge 10 ottobre 1950, n. 877: articolo 4; 334) legge 21 ottobre 1950,n. 990; 335) legge 4 novembre 1950, n. 976; 336) legge 9 novembre 1950, n. 977; 337) legge 14 dicembre 1950, n. 1097; 338) legge 9 gennaio 1951, n. 167; 339) legge 9 gennaio 1951, n. 204; 340) legge 2 aprile 1951, n. 299; 341) legge 10 aprile 1951 n. 287: articolo 12, lettera b), limitatamente alle parole «alle forze armate dello Stato ed»; 342) legge 4 maggio 1951, n. 306; 343) legge 4 maggio 1951, n. 570; 344) legge 4 maggio 1951, n. 571; 345) legge 21 maggio 1951, n. 513; 346) legge 26 maggio 1951, n. 404; 347) legge 5 luglio 1951, n. 626; 348) legge 24 luglio 1951, n. 625: articoli 1 e 2; 349) legge 10 agosto 1951, n. 475; 350) legge 22 agosto 1951, n. 1064; 351) legge 27 ottobre 1951, n. 1616; 352) legge 7 dicembre 1951, n. 1565; 353) legge 18 dicembre 1951, n. 1666; 354) legge 24 dicembre 1951, n. 1638; 355) legge 8 gennaio 1952, n. 15; 356) legge 8 gennaio 1952, n. 27; 357) legge 18 gennaio 1952, n. 43; 358) legge 1 marzo 1952, n. 157; 359) legge 29 marzo 1952, n. 337; 360) legge 29 marzo 1952, n. 338; 361) legge 29 marzo 1952, n. 667; 362) legge 5 maggio 1952, n. 521; 363) legge 27 maggio 1952, n. 648; 364) legge 13 giugno 1952, n. 698; 365) decreto del Presidente della Repubblica 20 giugno 1952, n. 1021; 366) legge 1 luglio 1952, n. 878; 367) legge 5 luglio 1952, n. 989; 368) legge 25 luglio 1952, n. 1113; 369) legge 30 luglio 1952, n. 1116; 370) legge 26 ottobre 1952, n. 1785; 371) legge 3 novembre 1952, n. 1789; 372) legge 18 dicembre 1952, n. 2386; 373) legge 18 dicembre 1952, n. 3084; 374) legge 18 dicembre 1952, n. 3085; 375) legge 18 dicembre 1952, n. 3089; 376) legge 18 dicembre 1952, n. 3099; 377) legge 22 dicembre 1952, n. 4414; 378) legge 30 gennaio 1953, n. 141; 379) legge 31 gennaio 1953, n. 72; 380) legge 31 gennaio 1953, n. 78; 381) legge 24 febbraio 1953, n. 108; 382) legge 24 febbraio 1953, n. 109; 383) legge 6 marzo 1953, n. 178; 384) legge 27 marzo 1953, n. 259; 385) legge 17 dicembre 1953, n. 953; 386) legge 27 dicembre 1953, n. 946; 387) legge 27 dicembre 1953, n. 993; 388) legge 20 marzo 1954, n. 72; 389) legge 8 aprile 1954, n. 124; 390) legge 10 aprile 1954, n. 113 , escluso l'articolo 68; 391) legge 10 aprile 1954, n. 114; 392) legge 7 maggio 1954, n. 203; 393) legge 15 maggio 1954, n. 266; 394) legge 15 maggio 1954, n. 267; 395) legge 15 maggio 1954, n. 277; 396) legge 19 maggio 1954, n. 275; 397) legge 25 maggio 1954, n. 329; 398) legge 22 giugno 1954, n. 391; 399) legge 17 luglio 1954, n. 522: articolo 19; 400) legge 31 luglio 1954, n. 599 , escluso l'articolo 32; 401) legge 9 agosto 1954, n. 659; 402) legge 16 ottobre 1954, n. 1015; 403) legge 5 gennaio 1955, n. 14; 404) legge 9 marzo 1955, n. 286; 405) decreto del Presidente della Repubblica 19 marzo 1955, n. 520: articolo 16; 406) legge 3 maggio 1955, n. 370; 407) decreto del Presidente della Repubblica 28 giugno 1955, n. 1106; 408) legge 30 ottobre 1955, n. 1061; 409) legge 9 novembre 1955, n. 1176; 410) legge 12 novembre 1955, n. 1137; 411) legge 5 dicembre 1955, n. 1305; 412) legge 9 gennaio 1956, n. 25; 413) decreto del Presidente della Repubblica 11 gennaio 1956, n. 19; 414) legge 23 febbraio 1956, n. 118; 415) legge 25 febbraio 1956, n. 121; 416) legge 23 marzo 1956, n. 185; 417) legge 3 maggio 1956, n. 487; 418) legge 16 maggio 1956, n. 496; 419) legge 14 giugno 1956, n. 610; 420) legge 20 giugno 1956, n. 612; 421) legge 31 luglio 1956, n. 917; 422) legge 8 novembre 1956, n. 1327; 423) legge 27 novembre 1956, n. 1368; 424) legge 23 dicembre 1956, n. 1448; 425) legge 3 gennaio 1957, n. 1; 426) decreto del Presidente della Repubblica 10 gennaio 1957, n. 3: articolo 352; 427) legge 3 febbraio 1957, n. 34; 428) legge 14 marzo 1957, n. 108; 429) NUMERO SOPPRESSO DAL D.LGS. 31 DICEMBRE 2012, N. 248; 430) legge 4 aprile 1957, n. 229; 431) legge 4 aprile 1957, n. 238; 432) legge 11 aprile 1957, n. 246; 433) legge 25 aprile 1957, n. 308; 434) legge 25 aprile 1957, n. 313; 435) NUMERO ESPUNTO CON AVVISO DI RETTIFICA IN G.U. 7/9/2010; 436) decreto del Presidente della Repubblica 4 agosto 1957, n. 918: articoli 6 e 8; 437) legge 7 ottobre 1957, n. 968; 438) legge 7 ottobre 1957, n. 969; 439) legge 3 dicembre 1957, n. 1197; 440) legge 10 dicembre 1957, n. 1248; 441) legge 18 febbraio 1958, n. 112; 442) legge 18 febbraio 1958, n. 160; 443) legge 27 febbraio 1958, n. 166; 444) legge 27 febbraio 1958, n. 205; 445) legge 27 febbraio 1958, n. 295; 446) legge 4 marzo 1958, n. 168; 447) legge 6 marzo 1958, n. 192; 448) legge 6 marzo 1958, n. 247; 449) legge 8 marzo 1958, n. 233, escluso articolo 6; 450) legge 13 marzo 1958, n. 203; 451) legge 18 marzo 1958, n. 311: articolo 8, comma 2; 452) legge 3 aprile 1958, n. 472; 453) legge 3 aprile 1958, n. 473; 454) legge 2 febbraio 1959, n. 49; 455) legge 3 aprile 1959, n. 154; 456) legge 15 maggio 1959, n. 367; 457) legge 15 maggio 1959, n. 368: articolo 1; 458) legge 22 maggio 1959, n. 397; 459) legge 3 giugno 1959, n. 403; 460) legge 11 giugno 1959, n. 353; 461) legge 30 giugno 1959, n. 488; 462) legge 7 luglio 1959, n. 479; 463) legge 14 luglio 1959, n. 494; 464) legge 24 luglio 1959, n. 698; 465) legge 24 luglio 1959, n. 701; 466) legge 30 luglio 1959, n. 694; 467) legge 19 ottobre 1959, n. 946; 468) legge 7 dicembre 1959, n. 1037; 469) legge 15 dicembre 1959, n. 1095; 470) legge 26 febbraio 1960, n. 165; 471) legge 16 settembre 1960, n. 1015; 472) legge 22 settembre 1960, n. 1031; 473) legge 14 ottobre 1960, n. 1191; 474) legge 20 ottobre 1960, n. 1189: articoli da 1 a 20; 475) legge 6 dicembre 1960, n. 1479; 476) legge 12 dicembre 1960, n. 1597; 477) legge 15 dicembre 1960, n. 1577; 478) legge 2 febbraio 1961, n. 30; 479) legge 5 marzo 1961, n. 212; 480) legge 9 marzo 1961, n. 202; 481) legge 14 marzo 1961, n. 131; 482) legge 14 marzo 1961, n. 132; 483) legge 28 maggio 1961, n. 458; 484) legge 1 giugno 1961, n. 512; 485) legge 8 giugno 1961, n. 509; 486) legge 27 giugno 1961, n. 550; 487) legge 29 giugno 1961, n. 575; 488) legge 29 giugno 1961, n. 577; 489) legge 8 luglio 1961, n. 642; 490) legge 8 luglio 1961, n. 643; 491) legge 8 luglio 1961, n. 645; 492) legge 13 ottobre 1961, n. 1163; 493) legge 18 ottobre 1961, n. 1168; 494) legge 22 ottobre 1961, n. 1143: articolo 8; 495) legge 22 novembre 1961, n. 1291; 496) legge 24 novembre 1961, n. 1298; 497) legge 29 novembre 1961, n. 1300, esclusi articoli 4, 5 e 6; 498) legge 25 gennaio 1962, n. 24; 499) legge 25 gennaio 1962, n. 26; 500) legge 12 aprile 1962, n. 183; 501) legge 24 aprile 1962, n. 192; 502) legge 24 aprile 1962, n. 193; 503) legge 25 maggio 1962, n. 417; 504) legge 23 giugno 1962, n. 882; 505) legge 23 giugno 1962, n. 883; 506) legge 18 luglio 1962, n. 1112; 507) legge 2 agosto 1962, n. 1331; 508) legge 16 agosto 1962, n. 1303; 509) legge 27 settembre 1962, n. 1419; 510) legge 29 settembre 1962, n. 1483; 511) legge 18 ottobre 1962, n. 1499; 512) legge 5 novembre 1962, n. 1695; 513) legge 14 novembre 1962, n. 1591; 514) legge 16 novembre 1962, n. 1622; 515) legge 3 dicembre 1962, n. 1699; 516) legge 12 dicembre 1962, n. 1862; 517) legge 31 dicembre 1962, n. 1841; 518) legge 26 gennaio 1963, n. 41; 519) legge 26 gennaio 1963, n. 52; 520) legge 30 gennaio 1963, n. 43; 521) legge 3 febbraio 1963, n. 101; 522) legge 4 febbraio 1963, n. 95; 523) legge 9 febbraio 1963, n. 248; 524) legge 18 febbraio 1963, n. 165; 525) legge 21 febbraio 1963, n. 249; 526) legge 21 febbraio 1963, n. 326; 527) legge 21 febbraio 1963, n. 356; 528) legge 21 febbraio 1963, n. 358; 529) legge 2 marzo 1963, n. 308; 530) legge 5 marzo 1963, n. 284; 531) decreto del Presidente della Repubblica 18 marzo 1963, n. 679; 532) legge 27 ottobre 1963, n. 1431; 533) legge 3 novembre 1963, n. 1543, escluso l'articolo 6; 534) legge 14 febbraio 1964, n. 47; 535) decreto legislativo di cui al decreto del Presidente della Repubblica 14 febbraio 1964, n. 237; 536) legge 23 marzo 1964, n. 151; 537) legge 19 maggio 1964, n. 345; 538) legge 10 giugno 1964, n. 447; 539) legge 5 luglio 1964, n. 626; 540) legge 29 settembre 1964, n. 860; 541) legge 18 novembre 1964, 1249; 542) legge 9 ottobre 1964, n. 1058; 543) legge 16 ottobre 1964, n. 1148; 544) legge 18 novembre 1964, n. 1250; 545) legge 18 novembre 1964, n. 1251; 546) legge 18 dicembre 1964, n. 1414; 547) legge 5 febbraio 1965, n. 26; 548) legge 1 marzo 1965, n. 122; 549) legge 30 marzo 1965, n. 331; 550) legge 6 aprile 1965, n. 235; 551) legge 14 maggio 1965, n. 497; 552) NUMERO SOPPRESSO DAL D.LGS. 24 FEBBRAIO 2012, N. 20; 553) legge 26 giugno 1965, n. 807; 554) legge 26 giugno 1965, n. 808; 555) legge 26 giugno 1965, n. 809; 556) legge 26 giugno 1965, n. 810; 557) legge 26 giugno 1965, n. 813; 558) legge 5 luglio 1965, n. 811; 559) legge 5 luglio 1965, n. 814; 560) legge 14 luglio 1965, n. 900; 561) legge 21 luglio 1965, n. 934; 562) decreto del Presidente della Repubblica 18 novembre 1965, n. 1478; 563) decreto del Presidente della Repubblica 18 novembre 1965, n. 1479; 564) decreto del Presidente della Repubblica 18 novembre 1965, n. 1480; 565) decreto del Presidente della Repubblica 18 novembre 1965, n. 1481; 566) decreto del Presidente della Repubblica 18 novembre 1965, n. 1482; 567) decreto del Presidente della Repubblica 18 novembre 1965, n. 1483; 568) decreto del Presidente della Repubblica 18 novembre 1965, n. 1484; 569) legge 31 gennaio 1966, n. 30; 570) legge 31 marzo 1966, n. 172; 571) legge 31 marzo 1966, n. 259; 572) legge 8 giugno 1966, n. 433; 573) legge 11 maggio 1966, n. 334; 574) legge 11 maggio 1966, n. 367; 575) legge 1 luglio 1966, n. 532; 576) legge 1 luglio 1966, n. 537; 577) legge 6 agosto 1966, n. 647; 578) legge 4 dicembre 1966, n. 1066; 579) legge 13 dicembre 1966, n. 1111; 580) legge 11 aprile 1967, n. 233; 581) legge 19 maggio 1967, n. 378, articoli: 7; 8, comma 3; 582) decreto del Presidente della Repubblica 10 giugno 1967, n. 850; 583) legge 21 giugno 1967, n. 470; 584) legge 27 giugno 1967, n. 534; 585) legge 9 luglio 1967, n. 564; 586) legge 9 ottobre 1967, n. 913; 587) legge 31 ottobre 1967, n. 1080; 588) legge 15 dicembre 1967, n. 1250; 589) legge 15 dicembre 1967, n. 1261; 590) legge 15 dicembre 1967, n. 1262; 591) legge 27 gennaio 1968, n. 37, esclusi gli articoli 9 e 10; 592) legge 2 febbraio 1968, n. 63; 593) legge 12 marzo 1968, n. 290; 594) legge 14 marzo 1968, n. 272; 595) legge 14 marzo 1968, n. 273; 596) NUMERO SOPPRESSO DAL D.LGS. 24 FEBBRAIO 2012, N. 20; 597) legge 18 marzo 1968, n. 275; 598) legge 18 marzo 1968, n. 276; 599) legge 18 marzo 1968, n. 353; 600) legge 18 marzo 1968, n. 356; 601) legge 28 marzo 1968, n. 371; 602) legge 2 aprile 1968, n. 485; 603) legge 2 aprile 1968, n. 486; 604) legge 2 aprile 1968, n. 487; 605) legge 24 gennaio 1969, n. 1; 606) legge 10 marzo 1969, n. 79; 607) legge 21 marzo 1969, n. 97; 608) legge 21 marzo 1969, n. 98; 609) legge 2 maggio 1969, n. 304; 610) legge 22 maggio 1969, n. 240: articolo 2; 611) legge 26 maggio 1969, n. 260; 612) legge 26 maggio 1969, n. 310; 613) legge 10 giugno 1969, n. 309; 614) legge 20 giugno 1969, n. 333; 615) legge 25 giugno 1969, n. 334; 616) legge 10 luglio 1969, n. 375; 617) legge 1 ottobre 1969, n. 697; 618) legge 1 ottobre 1969, n. 698; 619) legge 13 ottobre 1969, n. 744; 620) legge 30 ottobre 1969, n. 831: articoli 3 e 6; 621) legge 30 ottobre 1969, n. 943; 622) legge 7 novembre 1969, n. 832; 623) legge 26 novembre 1969, n. 934; 624) legge 26 novembre 1969, n. 937; 625) legge 26 novembre 1969, n. 938; 626) legge 12 dicembre 1969, n. 1017; 627) legge 15 dicembre 1969, n. 1021; 628) legge 15 dicembre 1969, n. 1022; 629) legge 15 dicembre 1969, n. 1023; 630) legge 22 dicembre 1969, n. 967 , escluso l'articolo 1; 631) legge 24 dicembre 1969, n. 1014; 632) legge 24 dicembre 1969, n. 1015; 633) legge 11 febbraio 1970, n. 56; 634) legge 10 maggio 1970, n. 288; 635) legge 10 maggio 1970, n. 316; 636) legge 11 maggio 1970, n. 289; 637) legge 25 maggio 1970, n. 363; 638) legge 3 ottobre 1970, n. 741; 639) legge 28 ottobre 1970, n. 822; 640) legge 30 novembre 1970, n. 953; 641) legge 3 dicembre 1970, n. 995; 642) legge 23 dicembre 1970, n. 1094; 643) decreto del Presidente della Repubblica 28 dicembre 1970, n. 1079: articolo 30; 644) legge 25 febbraio 1971, n. 111, articoli: 2, comma 2; 5; 645) legge 3 marzo 1971, n. 96; 646) legge 25 marzo 1971, n. 185; 647) legge 31 marzo 1971, n. 214; 648) legge 3 maggio 1971, n. 301; 649) legge 11 maggio 1971, n. 421; 649-bis) legge 22 maggio 1971, n. 368; 650) legge 18 giugno 1971, n. 449; 651) legge 22 luglio 1971, n. 536; 652) legge 9 ottobre 1971, n. 908; 653) legge 20 ottobre 1971, n. 915; 654) legge 26 ottobre 1971, n. 916; 655) legge 29 ottobre 1971, n. 881; 656) legge 6 dicembre 1971, n. 1082; 657) legge 6 dicembre 1971, n. 1098; 658) legge 11 dicembre 1971, n. 1090; 659) legge 20 dicembre 1971, n. 1155; 660) legge 6 dicembre 1972, n. 786; 661) legge 15 dicembre 1972, n. 772; 662) legge 5 marzo 1973, n. 29; 663) legge 5 marzo 1973, n. 60; 664) legge 19 marzo 1973, n. 70; 665) legge 16 aprile 1973, n. 174; 666) legge 16 aprile 1973, n. 175; 667) legge 5 giugno 1973, n. 299; 668) legge 5 giugno 1973, n. 319; 669) legge 5 giugno 1973, n. 320; 670) legge 5 giugno 1973, n. 339; 671) legge 6 giugno 1973, n. 313; 672) legge 6 giugno 1973, n. 324; 673) legge 6 giugno 1973, n. 325; 674) legge 14 giugno 1973, n. 404; 675) legge 30 luglio 1973, n. 489; 676) legge 4 agosto 1973, n. 520; 677) legge 22 ottobre 1973, n. 678; 678) NUMERO SOPPRESSO DAL D.LGS. 31 DICEMBRE 2012, N. 248; 679) legge 22 novembre 1973, n. 816; 680) legge 22 novembre 1973, n. 872, articoli: 1, 2, 3; 681) legge 22 novembre 1973 n. 873; 682) legge 10 dicembre 1973, n. 804; 683) legge 18 dicembre 1973, n. 855; 684) legge 18 dicembre 1973, n. 857; 685) legge 18 dicembre 1973, n. 858; 686) legge 20 dicembre 1973, n. 824; 687) legge 22 dicembre 1973, n. 825; 688) legge 27 dicembre 1973, n. 838; 689) legge 27 dicembre 1973, n. 875; 690) legge 27 dicembre 1973, n. 934; 691) decreto del Presidente della Repubblica 29 dicembre 1973, n. 1092, articoli: 8, commi 2, secondo periodo, 3, lettera a), limitatamente alle parole «nonche' dai militari in aspettativa per motivi privati ovvero in licenza senza assegni concessa a domanda in qualita' di richiamati senza assegni», e 4; 22; 31; 55; 56; 57; 59; 60; 93, commi da 6 a 8; 128; 141; 165; 172; 692) legge 30 gennaio 1974, n. 12; 693) legge 27 febbraio 1974, n. 68: articoli 2 e 4; 694) legge 27 febbraio 1974, n. 69; 695) legge 6 aprile 1974, n. 113; 696) legge 16 aprile 1974, n. 173; 697) legge 21 maggio 1974, n. 249; 698) legge 18 giugno 1974, n. 257; 699) legge 26 luglio 1974, n. 330; 700) legge 21 dicembre 1974, n. 699; 701) legge 21 dicembre 1974, n. 703; 702) legge 2 agosto 1974, n. 389; 703) legge 24 dicembre 1974, n. 695; 704) legge 29 gennaio 1975, n. 14; 705) legge 22 marzo 1975, n. 57; 706) legge 2 aprile 1975, n. 108; 707) legge 27 maggio 1975, n. 178; 708) legge 31 maggio 1975, n. 191; 709) legge 15 luglio 1975, n. 390; 710) legge 26 luglio 1975, n. 385; 711) legge 29 luglio 1975, n. 392; 712) decreto-legge 13 agosto 1975, n. 376 e legge di conversione 16 ottobre 1975, n. 492: articolo 7, comma 3; 713) legge 20 ottobre 1975, n. 528; 714) legge 15 novembre 1975, n. 609: articolo 1, comma 1, limitatamente alle parole «dal Corpo delle capitanerie di porto, dal Corpo equipaggi militari marittimi - ruolo servizi portuali e categoria nocchieri di porto, dall'Arma dei carabinieri e»; 715) legge 18 novembre 1975, n. 590; 716) legge 26 novembre 1975, n. 622; 717) legge 28 novembre 1975, n. 624; 718) legge 2 dicembre 1975, n. 626; 719) legge 5 dicembre 1975, n. 704; 720) legge 5 dicembre 1975, n. 719; 721) legge 22 dicembre 1975, n. 685, articoli: 88; 89; 89-bis; 89-ter; 89-quater; 89-quinquies; 99, comma 4, limitatamente alle parole «armate e»; 722) legge 29 aprile 1976, n. 177, articolo 18; 723) legge 5 maggio 1976, n. 187 esclusi gli articoli 18 e 26, quest'ultimo limitatamente al personale delle Forze armate e di polizia ad ordinamento militare, nonche' 27, secondo comma; 724) legge 10 maggio 1976, n. 347; 725) decreto-legge 19 maggio 1976, n. 266 e legge di conversione 22 maggio 1976, n. 392; 726) decreto-legge 18 settembre 1976, n. 648 e legge di conversione 30 ottobre 1976, n. 730: articolo 3; 727) legge 24 dicembre 1976, n. 898; 728) legge 16 febbraio 1977, n. 38; 729) legge 21 aprile 1977, n. 163; 730) legge 2 maggio 1977, n. 186; 731) legge 2 maggio 1977, n. 189; 732) legge 16 maggio 1977, n. 228; 733) legge 1 giugno 1977, n. 337; 734) legge 9 giugno 1977, n. 338; 735) legge 16 giugno 1977, n. 372; 736) lege 24 settembre 1977, n. 717; 737) legge 28 settembre 1977, n. 736; 738) legge 22 novembre 1977, n. 890; 739) legge 1 dicembre 1977, n. 907; 740) legge 20 dicembre 1977, n. 965; 741) decreto del Presidente della Repubblica 23 dicembre 1977, n. 1006; 742) legge 27 aprile 1978, n. 181; 743) legge 27 aprile 1978, n. 183; 744) legge 11 luglio 1978, n. 382; 745) legge 18 agosto 1978, n. 497; 746) legge 5 dicembre 1978, n. 786; 747) decreto-legge 23 dicembre 1978, n. 814 e legge di conversione 19 febbraio 1979, n. 52; 748) legge 23 dicembre 1978, n. 833: articoli: 6, lettera v) e lettera z), limitatamente alle parole «le Forze armate ed»; 32, comma 4; 47, comma 11; 749) legge 21 dicembre 1978, n. 861: articoli 1 e 2; 750) legge 8 gennaio 1979, n. 4; 751) legge 8 gennaio 1979, n. 5; 752) legge 26 ottobre 1979, n. 560; 753) legge 24 dicembre 1979, n. 671; 754) legge 24 dicembre 1979, n. 674; 755) legge 10 gennaio 1980, n. 1; 756) legge 22 gennaio 1980, n. 12; 757) legge 11 febbraio 1980, n. 22; 758) legge 19 marzo 1980, n. 79; 759) legge 22 maggio 1980, n. 210; 760) legge 23 maggio 1980, n. 242, articoli: 3, lettera b); 5; 761) legge 4 luglio 1980, n. 318; 762) legge 11 luglio 1980, n. 312: articoli da 136 a 151; 763) decreto del Presidente della Repubblica 11 luglio 1980, n. 382: articolo 105; 764) legge 8 agosto 1980, n. 435; 765) legge 20 settembre 1980, n. 574; 766) decreto-legge 26 novembre 1980, n. 776 e legge di conversione 22 dicembre 1980, n. 874: articolo 14-decies; 767) legge 22 dicembre 1980, n. 912; 768) legge 22 dicembre 1980, n. 913; 769) legge 20 febbraio 1981, n. 30; 770) legge 20 febbraio 1981, n. 31; 771) legge 25 febbraio 1981, n. 63; 772) legge 28 febbraio 1981, n. 47; 773) legge 30 marzo 1981, n. 122; 774) legge 23 aprile 1981, n. 154: articolo 2, n. 3; 775) legge 27 aprile 1981, n. 191; 776) legge 7 maggio 1981, n. 180; 777) legge 11 maggio 1981, n. 192; 778) legge 14 maggio 1981, n. 219: articolo 68; 779) decreto-legge 22 maggio 1981, n. 233 e legge di conversione 13 luglio 1981, n. 380; 780) legge 25 maggio 1981, n. 280; 781) legge 28 maggio 1981, n. 286; 782) legge 3 giugno 1981, n. 308; 783) decreto-legge 6 giugno 1981, n. 283 e legge di conversione 6 agosto 1981, n. 432: articoli 1; da 16 a 20; 21, comma 2; 22; 784) decreto-legge 26 giugno 1981, n. 335, e legge di conversione 6 agosto 1981, n. 458; 785) legge 4 luglio 1981, n. 418; 786) legge 20 luglio 1981, n. 382; 786-bis) decreto del Presidente della Repubblica 27 luglio 1981, n. 484, articoli: 4, 5, 6, 7 e 8; 787) legge 5 agosto 1981, n. 440; 788) legge 4 dicembre 1981, n. 720: articolo 4; 789) legge 6 ottobre 1981, n. 560; 790) legge 22 dicembre 1981, n. 773: articolo 2; 791) legge 22 gennaio 1982, n. 6; 792) legge 26 gennaio 1982, n. 21; 793) legge 9 febbraio 1982, n. 106: articolo 93; 794) decreto-legge 27 febbraio 1982, n. 57 e legge di conversione 29 aprile 1982, n. 187: articolo 23-ter; 795) NUMERO ABROGATO DAL D.L. 6 LUGLIO 2010, N. 102, CONVERTITO CON MODIFICAZIONI DALLA L. 3 AGOSTO 2010, N. 126; 796) decreto-legge 27 settembre 1982, n. 686; 797) decreto-legge 1 ottobre 1982, n. 696 e legge di conversione 29 novembre 1982, n. 883: articolo 3-octies; 798) legge 23 marzo 1983, n. 78, articoli: 18; 19; 20; 21; 799) legge 28 aprile 1983, n. 173; 800) legge 10 maggio 1983, n. 186; 801) legge 10 maggio 1983, n. 187; 802) legge 10 maggio 1983, n. 188; 803) legge 10 maggio 1983, n. 212, articoli: da 2 a 22; da 24 a 30; 34; da 36 a 43; 45; 46; 47; 50; 51; da 53 a 79; tabelle allegate; 804) legge 20 febbraio 1984, n. 11; 805) decreto-legge 28 febbraio 1984, n. 19 e legge di conversione 18 aprile 1984, n. 80: articolo 1, comma 8; 806) legge 3 aprile 1984, n. 63; 807) legge 12 aprile 1984, n. 66; 808) legge 12 aprile 1984, n. 67; 809) legge 11 maggio 1984, n. 134; 810) legge 4 luglio 1984, n. 324; 811) legge 18 luglio 1984, n. 349; 812) legge 4 agosto 1984, n. 429; 813) legge 6 agosto 1984, n. 456; 814) legge 1 ottobre 1984, n. 637; 815) legge 8 ottobre 1984, n. 693; 816) NUMERO SOPPRESSO DAL D.LGS. 31 DICEMBRE 2012, N. 248; 817) decreto-legge 19 dicembre 1984, n. 857 e legge di conversione 17 febbraio 1985, n. 18; 818) legge 22 dicembre 1984, n. 873; 819) legge 6 febbraio 1985, n. 16; 820) legge 2 marzo 1985, n. 60; 821) legge 4 aprile 1985, n. 123; 822) legge 25 giugno 1985, n. 342; 823) legge 4 luglio 1985, n. 353; 824) legge 24 luglio 1985, n. 410; 825) legge 23 dicembre 1985, n. 783; 826) decreto del Presidente della Repubblica 23 gennaio 1986, n. 94; 827) legge 24 gennaio 1986, n. 17; 828) legge 28 febbraio 1986, n. 41: articolo 13, comma 6; 829) legge 24 marzo 1986, n. 90: articolo 3; 830) legge 25 marzo 1986, n. 83; 831) legge 19 maggio 1986, n. 224; 832) legge 6 giugno 1986, n. 254; 833) legge 21 giugno 1986, n. 304; 834) legge 2 luglio 1986, n. 332; 835) legge 5 luglio 1986, n. 342, articoli: 1, comma 2; 2; 3; 836) legge 4 ottobre 1986, n. 724; 837) legge 7 ottobre 1986, n. 654; 838) legge 10 ottobre 1986, n. 668: articolo 56; 839) decreto-legge 27 ottobre 1986, n. 700 e legge di conversione 23 dicembre 1986, n. 897; 840) legge 24 dicembre 1986, n. 958; 841) legge 26 febbraio 1987, n. 49: articolo 35; 842) legge 10 marzo 1987, n. 100; 843) decreto-legge 4 agosto 1987, n. 325 e legge di conversione 3 ottobre 1987, n. 402; 844) decreto-legge 16 settembre 1987, n. 379 e legge di conversione 14 novembre 1987, n. 468: articolo 1, commi 1, 2, 2-bis, 3, 4, 5, 6 e 7; 845) decreto-legge 21 settembre 1987, n. 387 e legge di conversione 20 novembre 1987, n. 472, articolo 9, comma 1, limitatamente alle parole «, dell'Arma dei carabinieri», «, il Ministro della difesa di concerto con quello dell'interno», «, il Comando generale dell'Arma dei carabinieri», comma 2, limitatamente alle parole «, con decreto del Ministro della difesa di concerto con quello dell'interno per il personale dell'Arma dei carabinieri», comma 3, limitatamente alle parole «, al Comando generale dell'Arma dei carabinieri»; 846) decreto-legge 22 gennaio 1988, n. 13 e legge di conversione 11 marzo 1988, n. 74; 847) decreto-legge 28 giugno 1988, n. 238 e legge di conversione 5 agosto 1988, n. 332; 848) legge 30 settembre 1988, n. 425; 849) legge 4 ottobre 1988, n. 436; 850) legge 16 dicembre 1988, n. 538; 851) legge 27 dicembre 1988, n. 557; 852) legge 27 dicembre 1988, n. 558; 853) legge 30 dicembre 1988 n. 561; 854) legge 1 febbraio 1989, n. 36: articolo 5, comma 1; 855) legge 1 febbraio 1989, n. 53: articoli 3; 4; 5; 6;12; 14; 15; 27; tabella A; 856) legge 3 febbraio 1989, n. 38; 857) legge 27 febbraio 1989, n. 79; 858) legge 27 febbraio 1989, n. 82; 859) legge 3 maggio 1989, n. 167; 860) decreto-legge 23 settembre 1989, n. 325 e legge di conversione 15 novembre 1989, n. 374; 861) legge 22 dicembre 1989, n. 419; 862) legge 13 febbraio 1990, n. 23; 863) legge 13 febbraio 1990, n. 25; 864) legge 19 marzo 1990, n. 50; 865) legge 9 aprile 1990, n. 88; 866) legge 9 aprile 1990, n. 89; 867) legge 2 maggio 1990, n. 104; 868) legge 25 maggio 1990, n. 131; 869) legge 7 giugno 1990, n. 144; 870) legge 23 giugno 1990, n. 169; 871) legge 9 luglio 1990, n. 185, articoli: 3; 4; 17; 31, commi 2 e 3; 872) legge 8 agosto 1990, n. 231, esclusi articoli 4; 5, commi 1 e 2; 7; 9 e 10; 873) decreto-legge 23 agosto 1990, n. 247 e legge di conversione 19 ottobre 1990, n. 298, esclusi gli articoli 1 e 2; 874) decreto del Presidente della Repubblica 9 ottobre 1990, n. 309: articoli 107, 108, 109, 110, 111, 112, 124, comma 4, limitatamente alle parole «armate e»; 875) legge 6 novembre 1990, n. 325; 876) legge 27 dicembre 1990, n. 404; 877) decreto-legge 19 gennaio 1991, n. 17 e legge di conversione 20 marzo 1991, n. 88; 878) decreto legislativo 27 febbraio 1991, n. 78; 879) legge 10 aprile 1991, n. 124; 880) legge 12 aprile 1991, n. 131; 881) legge 27 maggio 1991, n. 168; 882) legge 27 giugno 1991, n. 199; 883) legge 6 agosto 1991, n. 255; 884) legge 11 agosto 1991, n. 269; 885) legge 11 agosto 1991, n. 270; 886) legge 14 agosto 1991, n. 280: articoli 1, 2, 4; 887) legge 30 dicembre 1991, n. 412: articolo 7; 888) legge 31 dicembre 1991, n. 437; 889) legge 31 gennaio 1992, n. 64; 890) legge 31 gennaio 1992, n. 159; 891) legge 14 febbraio 1992, n. 189; 892) legge 17 febbraio 1992, n. 190; 893) decreto legislativo 30 aprile 1992, n. 285, articoli: 2, comma 5, ultimo periodo; 5, comma 3, ultimo periodo; 6, commi 3 e 5, lettera e); 13, comma 1, primo periodo, limitatamente alle parole «ad eccezione di quelle di esclusivo uso militare»; 26, comma 4, limitatamente alle parole «e, se trattasi di strade militari, di concerto con il Ministro della difesa.»; 35, comma 1, primo periodo, limitatamente alle parole «, eccetto quelle di esclusivo uso militare, in ordine alle quali e' competente il comando militare territoriale»; 38, comma 11; 894) decreto-legge 25 luglio 1992, n. 349 e legge di conversione 23 settembre 1992, n. 386; 895) decreto-legge 4 dicembre 1992, n. 469 e legge di conversione 2 febbraio 1993, n. 23, articoli: 1, 2 e 3; 896) decreto legislativo 30 dicembre 1992, n. 502: articolo 8-quinquies, commi 2-bis e 2-ter; 897) decreto legge 27 agosto 1993, n. 325 e legge di conversione 27 ottobre 1993, n. 424; 898) legge 23 dicembre 1993, n. 559: articolo 5, comma 3, limitatamente alle parole «militare e civile delle Forze armate,»; 899) legge 23 dicembre 1993, n. 577; 900) legge 24 dicembre 1993, n. 537, articoli: 3, comma 65; 9, comma 7; 901) decreto-legge 30 dicembre 1993, n. 551 e legge di conversione 22 febbraio 1994, n. 125; 902) decreto-legge 11 gennaio 1994, n. 16 e legge di conversione 22 febbraio 1994, n. 151; 903) decreto-legge 16 maggio 1994, n. 290 e legge di conversione 15 luglio 1994, n. 443 ; 904) decreto-legge 10 giugno 1994, n. 354 e legge di conversione 16 luglio 1994, n. 455: articolo 1, commi 3 e 4; 905) decreto-legge 20 giugno 1994, n. 397 e legge di conversione 3 agosto 1994, n. 482; 906) decreto-legge 29 agosto 1994, n. 521 e legge di conversione 27 ottobre 1994, n. 599; 907) decreto-legge 24 novembre 1994, n. 646 e legge di conversione 21 gennaio 1995, n. 22: articolo 12; 908) decreto legislativo 19 dicembre 1994, n. 758: articolo 9; 909) legge 23 dicembre 1994, n. 724: articolo 43, commi 1 e 2; 910) decreto-legge 7 aprile 1995, n. 107 e legge di conversione 7 giugno 1995, n. 222: articoli 5, 6, 7; 911) decreto legislativo 12 maggio 1995, n. 196; 912) decreto legislativo 12 maggio 1995, n. 198; 913) decreto-legge 19 maggio 1995, n. 180 e legge di conversione 13 luglio 1995, n. 285; 914) legge 8 agosto 1995, n. 350; 915) legge 28 dicembre 1995, n. 549: articolo 1, commi 1, 2 e 3; 916) legge 28 dicembre 1995, n. 551: articolo 13, comma 13. 917) decreto-legge 11 giugno 1996, n. 313 e legge di conversione 8 agosto 1996, n. 416; 918) decreto-legge 29 giugno 1996, n. 341 e legge di conversione 8 agosto 1996, n. 427, articoli: 1; 1-bis; 1-ter; 2, comma 1; 4-bis; 919) decreto-legge 6 settembre 1996, n. 467 e legge di conversione 7 novembre 1996, n. 569: articolo 4; 920) decreto-legge 1° ottobre 1996, n. 510 e legge di conversione 28 novembre 1996, n. 608: articolo 9-bis, comma 14; 921) legge 10 ottobre 1996, n. 525: articolo 2; 922) decreto-legge 23 ottobre 1996, n. 554 e legge di conversione 23 dicembre 1996, n. 653; 923) decreto-legge 12 novembre 1996, n. 576 e legge di conversione 31 dicembre 1996, n. 677: articolo 3-bis; 924) legge 23 dicembre 1996, n. 662, articoli: 1, commi 101, 102, 104, 105, 106, 107, 108, 109, 110, 115, 118; 2, commi 93 e 94; 3, comma 112; 3, comma 114, limitatamente alle dismissioni della difesa; 925) decreto legge 31 dicembre 1996, n. 669 e legge di conversione 28 febbraio 1997, n. 30: articolo 10, comma 3; 926) decreto legge 31 gennaio 1997, n. 12 e legge di conversione 25 marzo 1997, n. 72; 927) legge 18 febbraio 1997, n. 25; 928) legge 28 marzo 1997, n. 85, esclusi gli articoli 5 e 6; 929) decreto-legge 24 aprile 1997, n. 108 e legge di conversione 20 giugno 1997, n. 174, con esclusione dell'articolo 6-bis; 930) decreto legislativo 30 aprile 1997, n. 165: articolo 3, commi 1, 2, 3, 4 e 5; 931) decreto-legge. 5 giugno 1997, n. 144 e legge di conversione 25 luglio 1997, n. 239; 932) decreto-legge 14 luglio 1997, n. 214 e legge di conversione 31 luglio 1997, n. 260; 933) decreto-legge 14 luglio 1997, n. 215 e legge di conversione 28 agosto 1997, n. 282; 934) decreto legislativo 16 luglio 1997, n. 264; 935) decreto legislativo 16 luglio 1997, n. 265; 936) decreto-legge 27 ottobre 1997, n. 364 e legge di conversione 17 dicembre 1997, n. 434: articolo 1-ter; 937) legge 29 ottobre 1997, n. 374: articolo 5, commi 2 e 3; 938) decreto legislativo 28 novembre 1997, n. 459, a esclusione del comma 5 dell'articolo 4; 939) decreto legislativo 28 novembre 1997, n. 464; 940) legge 18 dicembre 1997, n. 439; 941) legge 27 dicembre 1997, n. 449, articoli: 14, comma 15; 17, comma 36; 39, comma 24; 45; 54, commi 10 e 11; 942) decreto legislativo 30 dicembre 1997, n. 490; 943) decreto legislativo 30 dicembre 1997, n. 498; 944) decreto legislativo 30 dicembre 1997, n. 504; 945) decreto legislativo 30 dicembre 1997, n. 505; 946) decreto-legge 13 gennaio 1998, n. 1 e legge di conversione 13 marzo 1998, n. 42; 947) legge 13 marzo 1998, n. 50; 948) legge 24 giugno 1998, n. 206; 949) legge 11 giugno 1998, n. 205; 950) legge 26 giugno 1998, n. 199; 951) legge 8 luglio 1998, n. 230, a esclusione degli articoli 8, 10, 19 e 20; 952) legge 22 luglio 1998, n. 254; 953) legge 3 agosto 1998, n. 270; 954) legge 23 dicembre 1998 n. 448, articoli: 44; 50, comma 1, lettera h); 955) decreto legislativo 28 dicembre 1998, n. 496; 956) decreto-legge 28 gennaio 1999, n. 12 e legge di conversione 29 marzo 1999, n. 77; 957) legge 12 marzo 1999 n. 68: articolo 3, comma 4, limitatamente alle parole «e della difesa nazionale»; 958) decreto-legge 21 aprile 1999, n. 110 e legge di conversione 18 giugno 1999, n. 186, a esclusione degli articoli 6, 6- bis e 6- ter; 959) decreto-legge 13 maggio 1999, n. 132 e legge di conversione 13 luglio 1999, n. 226: articolo 2-bis; 960) legge 17 maggio 1999, n. 144: articolo 62; 961) decreto-legge 17 giugno 1999, n. 180 e legge di conversione 2 agosto 1999, n. 269; 962) legge 28 luglio 1999, n. 266: articoli 14, commi 1, 2, 3, 4, 6, escluso l'ultimo periodo, 7, 8, 9, 10; 14, comma 5, limitatamente alle parole «delle Forze armate, incluso quello dell'Arma dei carabinieri e», «del personale civile del Ministero della difesa e, per la Guardia di finanza,» e «dei Ministri interessati,»; 15; 16, commi da 1 a 9 compresi; 17, comma 1, limitatamente alle parole «di cui alla legge 19 maggio 1986, n. 224,»; 963) legge 2 agosto 1999, n. 276; 964) legge 2 agosto 1999, n. 277; 965) legge 17 agosto 1999, n. 301; 966) decreto legislativo 17 agosto 1999, n. 368, articoli: 35, comma 3, limitatamente alle parole «d'intesa con il Ministro della difesa, una riserva di posti complessivamente non superiore al 5 per cento per le esigenze della sanita' militare e,» e alle parole «sentito, per gli aspetti relativi alla sanita' militare, il Ministro della difesa»; 42; 967) legge 14 ottobre 1999, n. 365; 968) legge 20 ottobre 1999, n. 380; 969) decreto-legge 25 ottobre 1999, n. 371 e legge di conversione 22 dicembre 1999, n. 487; 970) legge 21 dicembre 1999, n. 513: articolo 3, comma 1, secondo periodo; 971) legge 23 dicembre 1999 n. 488: articolo 4, comma 12; 972) decreto-legge 7 gennaio 2000, n. 1 e legge di conversione 7 marzo 2000, n. 44; 973) legge 11 gennaio 2000, n. 4; 974) decreto legislativo 31 gennaio 2000 n. 24; 975) legge 28 febbraio 2000, n. 42; 976) legge 31 marzo 2000, n. 78, articoli: 1; 2; 6, comma 4, limitatamente alle parole «delle Forze armate»; 6, comma 5, lettere a), c), d) ed e); 7; 9; 977) decreto-legge 19 giugno 2000, n. 163 e legge di conversione 10 agosto 2000, n. 228; 978) decreto legislativo 27 giugno 2000, n. 214; 979) decreto legislativo 28 giugno 2000, n. 216; 980) decreto legislativo 18 agosto 2000, n. 267: articoli 60, comma 1, numero 3); 60, comma 3, numero 3); 78, comma 6, terzo periodo dalle parole «Nell'assegnazione» sino alla fine; 79, commi 2 e 3, ultimo periodo; 981) decreto legislativo 5 ottobre 2000, n. 297, ad eccezione degli articoli 3, commi 1, 3 e 5; 16; 982) decreto legislativo 5 ottobre 2000, n. 298; 983) decreto-legge 12 ottobre 2000, n. 279 e legge di conversione 11 dicembre 2000, n. 365: articolo 5, commi 1, 2, 3, 4; 984) legge 14 novembre 2000, n. 331; 985) legge 23 dicembre 2000, n. 388, articoli: 43, commi 7, 8, 9, 10, 11, 14, 16; 49, comma 2, limitatamente alla parole «decreto del Ministro della difesa o» e alle parole «delle Forze armate,»; 63, comma 2, limitatamente alle parole «del Ministro della difesa o»; 63, comma 3, limitatamente alle parole «delle Forze armate»; 145, comma 4; 986) decreto-legge 29 dicembre 2000, n. 393 e legge di conversione 28 febbraio 2001, n. 27, a esclusione dell'articolo 4-bis; 987) legge 29 dicembre 2000, n. 400: articolo 5; 988) legge 29 dicembre 2000, n. 422: articolo 17; 989) legge 8 gennaio 2001, n. 2; 990) decreto legislativo 28 febbraio 2001, n. 82; 991) decreto legislativo 28 febbraio 2001, n. 83; 992) legge 7 marzo 2001, n. 61; 993) NUMERO SOPPRESSO DAL D.LGS. 24 FEBBRAIO 2012, N. 20; 994) decreto legislativo 26 marzo 2001, n. 151: articoli 10 e 58; 995) legge 29 marzo 2001, n. 86: articoli 5 e 6; 996) legge 2 aprile 2001, n. 136: articoli 1, comma 3; 3; 997) decreto legislativo 3 maggio 2001, n. 186; 998) decreto legislativo 8 maggio 2001, n. 215; 999) decreto-legge 19 luglio 2001, n. 294 e legge di conversione 29 agosto 2001, n. 339; 1000) decreto-legge 18 settembre 2001, n. 348 e legge di conversione 16 novembre 2001, n. 406; 1001) decreto-legge 25 settembre 2001 n. 351 e legge di conversione 23 novembre 2001 n. 410: articolo 3, comma 15-ter; 1002) decreto-legge 1° dicembre 2001, n. 421, e legge di conversione 31 gennaio 2002, n. 6, escluso l'articolo 9; 1003) legge 28 dicembre 2001, n. 448: articolo 21; 1004) decreto-legge 28 dicembre 2001, n. 451, e legge di conversione 27 febbraio 2002, n. 15, a esclusione degli articoli 2, commi 2 e 3; 3; 4; 5; 7; 13; 14; 1005) legge 28 dicembre 2001, n. 484; 1006) legge 15 marzo 2002, n. 37; 1007) decreto-legge 16 aprile 2002, n. 64 e legge di conversione 15 giugno 2002, n. 116; 1008) legge 31 luglio 2002, n. 179: articolo 2; 1009) legge 6 novembre 2002, n. 267; 1010) legge 27 dicembre 2002, n. 289: articolo 34, comma 8; 1011) legge 30 dicembre 2002, n. 295; 1012) legge 16 gennaio 2003, n. 3, articoli: 30; 32; 33; 37, comma 2; 1013) decreto-legge 20 gennaio 2003, n. 4 e legge di conversione 18 marzo 2003, n. 42; 1014) decreto legislativo 30 maggio 2003, n. 193: articolo 14; 1015) decreto-legge 10 luglio 2003, n. 165 e legge di conversione 1 agosto 2003, n. 219, a esclusione degli articoli 2, 3 e 4; 1016) decreto legislativo 31 luglio 2003, n. 236; 1017) legge 11 agosto 2003, n. 231, a esclusione dell'articolo 14; 1018) decreto-legge 30 settembre 2003, n. 269 e legge di conversione 24 novembre 2003, n. 326, articoli: 26, commi 11-quater, 11-quinquies, 11-sexies; 27, commi 13, 13-bis, 13-ter, 13-ter.1, 13-ter.2, 13-ter.3, 13-quater; 1019) legge 24 ottobre 2003, n. 321: articoli 3 e 4; 1020) legge 22 dicembre 2003, n. 365; 1021) legge 24 dicembre 2003, n. 350, articoli: 3, comma 70; 4, comma 179; 1022) decreto-legge 20 gennaio 2004, n. 9 e legge di conversione 12 marzo 2004, n. 68, a esclusione dell'articolo 1-bis; 1023) legge 2 marzo 2004, n. 62; 1024) decreto legislativo 26 maggio 2004, n. 154: articolo 14, comma 7; 1025) decreto-legge 28 maggio 2004, n. 136 e legge di conversione 27 luglio 2004, n. 186: articolo 8; 1026) decreto-legge 24 giugno 2004, n. 160 e legge di conversione 30 luglio 2004, n. 207; 1027) legge 14 luglio 2004, n. 178; 1028) legge 30 luglio 2004, n. 208, a esclusione dell'articolo 10; 1029) legge 23 agosto 2004, n. 226; 1030) decreto-legge 10 settembre 2004, n. 238 e legge di conversione 5 novembre 2004, n. 263: articolo 5-quater; 1031) decreto-legge 19 novembre 2004, n. 276 e legge di conversione 19 gennaio 2005, n. 1: articolo 2; 1032) legge 2 dicembre 2004, n. 299; 1033) legge 30 dicembre 2004, n. 311: articolo 1, commi 90, 443, 541, quest'ultimo limitatamente alle parole «e del carabiniere» e «e di 1.400 carabinieri»; 1034) decreto-legge 19 gennaio 2005, n. 3 e legge di conversione 18 marzo 2005, n. 37, a esclusione dell'articolo 4-bis, comma 2; 1035) decreto-legge 31 gennaio 2005, n. 7 e legge di conversione 31 marzo 2005, n. 43: articolo 7-vicies; 1036) legge 21 marzo 2005, n. 39; 1037) decreto-legge 31 marzo 2005, n. 45 e legge di conversione 31 maggio 2005, n. 89, articoli: 2; 2-bis; 8-ter; 8-quater; 1038) legge 31 marzo 2005, n. 48; 1039) decreto-legge 17 giugno 2005 n. 106 e legge di conversione 31 luglio 2005 n. 156: articolo 3, comma 2, lettere 0a) e b); 1040) decreto-legge 28 giugno 2005, n. 111 e legge di conversione 31 luglio 2005, n. 157; 1041) decreto-legge 28 giugno 2005, n. 112 e legge di conversione 31 luglio 2005, n. 158, a esclusione degli articoli da 1 a 4; 1042) decreto-legge 30 giugno 2005, n. 115 e legge di conversione 17 agosto 2005, n. 168: articolo 12; 1043) decreto-legge 27 luglio 2005, n. 144 e legge di conversione 31 luglio 2005, n. 155: articolo 18-bis; 1044) decreto legislativo 19 agosto 2005, n. 197; 1045) decreto legislativo 8 settembre 2005, n. 200; 1046) decreto-legge 1 ottobre 2005, n. 202 e legge di conversione 30 novembre 2005, n. 244: articolo 3; 1047) decreto legislativo 6 ottobre 2005, n. 216; 1048) legge 21 ottobre 2005, n. 219: articolo 24; 1049) decreto legislativo 28 novembre 2005, n. 253; 1050) legge 23 dicembre 2005, n. 266, articolo 1, commi: 29; 40 dalle parole «la restante parte...» fino alla fine del periodo; 482; 568; 569; 570; 571; 1051) decreto-legge 30 dicembre 2005, n. 273 e legge di conversione 23 febbraio 2006, n. 51, articoli: 4; 4-bis; 4-quater, commi 1, 2 e 3, dalle parole «la restante parte...» fino alla fine del periodo; 39-vicies bis; 39-vicies semel, commi 38, 40 e 42; 1052) legge 6 febbraio 2006, n. 34; 1053) legge 20 febbraio 2006, n. 79; 1054) legge 20 febbraio 2006, n. 92: articoli 1 e 3; 1055) decreto legislativo 11 aprile 2006, n. 198: articoli 32, 33 e 34; 1056) legge 4 agosto 2006, n. 247, a esclusione dell'articolo 1; 1057) decreto-legge 28 agosto 2006, n. 253 e legge di conversione 20 ottobre 2006, n. 270, a esclusione degli articoli 1 e 3; 1058) decreto legislativo 6 ottobre 2006, n. 275; 1059) legge 27 dicembre 2006, n. 296, articolo 1, commi: 216, ultimo periodo; 262, nella parte relativa all'inserimento del comma 15-ter nell'articolo 3, decreto-legge n. 351 del 2001; 263, lettere a) e b); 264; 515; 570; 571; 574; 896; 897; 898; 899; 900; 901; 902; 1238; 1239; 1241; 1270; 1330; 1060) decreto legge 31 gennaio 2007, n. 4 e legge di conversione 29 marzo 2007, n. 38, a esclusione degli articoli 1 e 2; 1061) decreto legislativo 6 febbraio 2007, n. 52: articolo 1, comma 2, lettera c); 1062) decreto-legge 2 luglio 2007, n. 81 e legge di conversione 3 agosto 2007, n. 127: articoli 6, comma 4; 9; 1063) legge 2 agosto 2007, n. 130; 1064) NUMERO ESPUNTO CON AVVISO DI RETTIFICA IN G.U. 30/9/2010, N. 229; 1065) decreto-legge 1 ottobre 2007, n. 159 e legge di conversione 29 novembre 2007, n. 222, articoli: 2-ter; 2-quater; 2-quinques; 2-sexies; 1066) legge 24 dicembre 2007, n. 244, articoli: 1, commi 181, 320; 2, commi 71, 72, 73, 74, 78, 79, 80, 81, 230, 387, 458, 459, 460, da 603 a 611, 627, 628, 629, 630, 631; 3, comma 93; 1067) decreto-legge 31 dicembre 2007, n. 248 e legge di conversione 28 febbraio 2008, n. 31, articoli: 1, comma 2; 2, comma 4; 34-bis; 1068) decreto-legge 31 gennaio 2008, n. 8 e legge di conversione 13 marzo 2008, n. 45, a esclusione degli articoli 1 e 2; 1069) decreto legislativo 30 maggio 2008, n. 118: articolo 6; 1070) decreto-legge 3 giugno 2008, n. 97 e legge di conversione 2 agosto 2008, n. 129: articolo 4-septies, comma 4, 3°, 4°, 5° e 6° periodo; 1071) decreto-legge 25 giugno 2008, n. 112 e legge di conversione 6 agosto 2008, n. 133, articoli: 14-bis; 60, commi 8-bis e 12; 65; 1072) decreto-legge 22 settembre 2008, n. 147 e legge di conversione 20 novembre 2008, n. 183, a esclusione dell'articolo 2; 1073) decreto-legge 2 ottobre 2008, n. 151 e legge di conversione 28 novembre 2008, n. 186: articolo 2; 1074) decreto-legge 6 novembre 2008, n. 172 e legge di conversione 30 dicembre 2008, n. 210: articolo 5, comma 1; 1075) decreto-legge 30 dicembre 2008, n. 207 e legge di conversione 27 febbraio 2009, n. 14, articoli: 13; 14; 26, comma 1, secondo periodo; 1076) decreto-legge 30 dicembre 2008, n. 209, e legge di conversione 24 febbraio 2009, n. 12, ad esclusione degli articoli: 01; 1; 2 ; 5; 1077) decreto-legge 23 febbraio 2009, n. 11, e legge di conversione 23 aprile 2009, n. 38, articolo 6-bis; 1078) decreto-legge 1° luglio 2009, n. 78, e legge di conversione 3 agosto 2009, n. 102, articoli: 16, comma 2-bis; 23, commi 17, 18 e 19; 1079) legge 10 luglio 2009, n. 93; 1080) legge 23 luglio 2009, n. 99, articoli: 27, comma 5; 39, commi 1, 3, 4, 5, 6, 7; 1081) legge 3 agosto 2009, n. 108, articoli: 3, comma 10, 4, 5, 6, 7 e 8; 1082) decreto-legge 4 novembre 2009, n. 152, e legge di conversione 29 dicembre 2009, n. 197, articoli: 2; 3, commi 1, 2, 3, 3-bis, 5, 7, 7-bis, 7-ter; 4, comma 1; 1083) legge 23 dicembre 2009, n. 191, articolo 2, commi: 27, 31, primo periodo, 32, 33, 34, 35, 36, 47, 189, 190, 191, 192, 193 e 194; 1084) decreto-legge 30 dicembre 2009, n. 194, e legge di conversione 26 febbraio 2010, n. 25, articolo 4 commi 1, 1-bis, 3, 4, 5, 6 e 7; 1085) decreto-legge 1° gennaio 2010, n. 1, e legge di conversione 5 marzo 2010, n. 30, articoli: 6, comma 3; 7; 8, comma 1; 9, commi 1-bis, 2, 2-bis, 3-bis, 3-ter, 3-quater, 3-quinquies, 5. 1085-bis) decreto-legge 31 maggio 2010, n. 78, e legge di conversione 30 luglio 2010, n. 122: articoli 6, commi 21-ter e 21-quater, e 55, commi 5-bis, 5-ter, 5-quater, 5-quinquies e 5-sexies; 1085-ter) legge 4 novembre 2010, n. 183, articoli: 27, commi 1, 2, 3 e 5; 28, comma 1, limitatamente alle parole: "delle Forze armate,". 1085-quater) legge 12 novembre 2011, n. 183: articolo 4, commi 57 e 96; 1085-quinquies) decreto-legge 29 dicembre 2011, n. 215 e legge di conversione 24 febbraio 2012, n. 13, articoli: 4, commi 1-bis e 1-ter, e 5, commi 1, 1-bis, 3 e 4; 1085-sexies) decreto-legge 24 gennaio 2012, n. 1, e legge di conversione 24 marzo 2012, n. 27: articolo 81.

------------- AGGIORNAMENTO (27) La Corte Costituzionale, con sentenza 15 - 23 gennaio 2014, n. 5 (in G.U. 1a s.s. 29/1/2014, n. 5), ha dichiarato "l'illegittimita' costituzionale dell'art. 2268 del decreto legislativo 15 marzo 2010, n. 66 (Codice dell'ordinamento militare), nella parte in cui, al numero 297) del comma 1, abroga il decreto legislativo 14 febbraio 1948, n. 43 (Divieto delle associazioni di carattere militare)".

### Art. 2269. - Abrogazione espressa di norme secondarie

1. A decorrere dall'entrata in vigore del codice e del regolamento, sono o restano abrogati i seguenti atti normativi secondari e le successive modificazioni: 1) regie patenti 13 luglio 1814, «Istituzione del Corpo dei carabinieri reali»; 2) regio decreto 1° aprile 1861 «Istituzione della Regia marina»; 3) regio decreto 9 dicembre 1866, n. 3486; 4) regio decreto 14 luglio 1887, n. 4758; 5) regio decreto 13 dicembre 1871, n. 571; 6) regio decreto 27 ottobre 1872, n. 1084; 7) regio decreto 26 dicembre 1872, n. 1205; 8) regio decreto 25 febbraio 1894, «Bandiera dell'Arma dei carabinieri»; 9) regio decreto 15 settembre 1897, n. 421; 10) regio decreto 25 giugno 1899, n. 310; 11) regio decreto 8 novembre 1900, n. 358; 12) regio decreto 29 luglio 1906, n. 470; 13) regio decreto 10 gennaio 1907, n. 71; 14) regio decreto 28 febbraio 1907, n. 48; 15) regio decreto 9 maggio 1907, n. 331; 16) regio decreto 14 maggio 1908, n. 232; 17) regio decreto 27 novembre 1910, n. 871; 18) regio decreto 6 ottobre 1911, n. 1326; 19) regio decreto 24 dicembre 1911, n. 1517; 20) regio decreto 15 giugno 1912, n. 822; 21) regio decreto 5 marzo 1914, n. 247; 22) regio decreto 18 aprile 1915, n. 662; 23) decreto luogotenenziale 27 giugno 1915, n. 1022; 24) regio decreto 21 maggio 1916, n. 640; 25) decreto luogotenenziale 3 settembre 1916, n. 1191; 26) decreto ministeriale 16 novembre 1916, «Norme per l'applicazione dello speciale distintivo d'onore per i mutilati nell'attuale guerra»; 27) regio decreto 24 luglio 1917, n. 1221; 28) regio decreto 19 gennaio 1918, n. 205; 29) regio decreto 10 marzo 1918, n. 356; 30) regio decreto 30 maggio 1918, n. 813; 31) decreto luogotenenziale 27 ottobre 1918, n. 201; 32) regio decreto 24 maggio 1919, n. 800; 33) regio decreto 27 febbraio 1921, n. 285; 34) regio decreto 24 marzo 1921, n. 447; 35) regio decreto 7 gennaio 1922, n. 195; 36) regio decreto 19 ottobre 1923, n. 2316; 37) regio decreto 30 dicembre 1923, n. 2903; 38) regio decreto 30 dicembre 1923, n. 2982; 39) regio decreto 4 settembre 1925, n. 1576; 40) regio decreto 29 aprile 1926, n. 866; 41) regio decreto 9 agosto 1926, n. 1493; 42) regio decreto 7 ottobre 1926, n. 2410; 43) regio decreto 16 dicembre 1926, n. 2354; 44) regio decreto 16 gennaio 1927, n. 374; 45) regio decreto 10 febbraio 1927, n. 443; 46) regio decreto 24 aprile 1927, n. 1065; 47) regio decreto 27 novembre 1927, n. 1224; 48) regio decreto 27 novembre 1927, n. 2297; 49) regio decreto 11 dicembre 1927, n. 2598; 50) regio decreto 19 gennaio 1928, n. 150; 51) regio decreto 15 aprile 1928, n. 1024: articoli 19 e 21; 52) regio decreto 7 giugno 1928, n. 1823; 53) regio decreto 30 dicembre 1929, n. 2245; 54) regio decreto 13 gennaio 1930, n. 35; 55) regio decreto 1 maggio 1930, n. 726; 56) regio decreto 3 luglio 1930, n. 1209; 57) regio decreto 23 giugno 1930, n. 983; 58) regio decreto 10 luglio 1930, n. 974: articolo 4; 59) regio decreto 26 settembre 1930, n. 1401; 60) regio decreto 13 novembre 1930, n. 1642; 61) regio decreto 14 agosto 1931, n. 1249; 62) regio decreto 19 novembre 1931, «Norme per l'applicazione della legge 29 dicembre 1930, n. 1712, relativa all'indennita' supplementare degli ufficiale del regio Esercito»; 63) regio decreto 26 dicembre 1931, «Computo del servizio aeronavigante ai fini della concessione della medaglia mauriziana»; 64) regio decreto 24 marzo 1932, n. 433; 65) regio decreto 16 maggio 1932, n. 595; 66) regio decreto 16 giugno 1932, n. 840; 67) regio decreto 7 luglio 1932, n. 375; 68) regio decreto 20 ottobre 1932, n. 1960; 69) regio decreto 4 novembre 1932, n. 1423; 70) regio decreto 17 novembre 1932, «Regolamento sul servizio sanitario militare territoriale»; 71) regio decreto 21 novembre 1932, n. 2051; 72) regio decreto 26 dicembre 1932, «Computo del servizio aeronavigante agli effetti della concessione della medaglia mauriziana al merito militare di dieci lustri»; 73) regio decreto 23 gennaio 1933, n. 8; 74) regio decreto 30 marzo 1933, n. 422; 75) regio decreto 6 aprile 1933, n.729; 76) decreto ministeriale 6 aprile 1933; 77) regio decreto 8 maggio 1933, n. 695; 78) regio decreto 29 giugno 1933, n. 944; 79) regio decreto 27 novembre 1933, «Norme per l'applicazione del regio decreto-legge 22 giugno 1933, n. 930, relativo all'istituzione del fondo di previdenza sottufficiali dell'Esercito»; 80) regio decreto 28 dicembre 1933, n. 1918; 81) regio decreto 14 giugno 1934, n. 1169, ad eccezione degli articoli 2, 7, 9, 51, 62, 63, 64, 65, 66, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81 e 82; 82) regio decreto 14 giugno 1934, n. 1181; 83) regio decreto 28 settembre 1934, n. 1587; 84) regio decreto 28 settembre 1934, n. 1820; 85) regio decreto 18 ottobre 1934, n. 2111; 86) regio decreto 3 dicembre 1934, n. 20; 87) regio decreto 14 febbraio 1935, «Regolamento della cassa ufficiali della Marina militare»; 88) regio decreto 13 maggio 1935, n. 908; 89) regio decreto 26 luglio 1935, n. 1658; 90) regio decreto 10 ottobre 1935, n. 1919; 91) regio decreto 24 ottobre 1935, n. 2075; 92) regio decreto 19 dicembre 1935, n. 2364; 93) regio decreto 8 gennaio 1936, n. 46; 94) regio decreto 27 aprile 1936, n. 1040; 95) regio decreto 2 luglio 1936, n. 1712; 96) regio decreto 9 luglio 1936, n. 1546; 97) regio decreto 7 agosto 1936, «Approvazione del regolamento della cassa sottufficiali della Marina militare» ; 98) regio decreto 1 ottobre 1936, n. 2145; 99) regio decreto 15 ottobre 1936, n. 2135; 100) regio decreto 1 febbraio 1937, n. 264; 101) regio decreto 28 aprile 1937, n. 1118; 102) regio decreto 28 aprile 1937, n. 1825; 103) regio decreto 8 luglio 1937, n. 1826; 104) regio decreto 21 agosto 1937, n. 1585; 105) regio decreto 25 novembre 1937, n. 2616; 106) regio decreto 14 marzo 1938, n. 964; 107) regio decreto 21 marzo 1938, n. 538; 108) regio decreto 12 maggio 1938, n. 747; 109) regio decreto 3 giugno 1938, n. 1562; 110) regio decreto 12 luglio 1938, n. 1324; 111) ((NUMERO SOPPRESSO DAL D.LGS. 26 APRILE 2016, N. 91)); 112) decreto del Capo del Governo 10 agosto 1938 «Determinazione delle zone di province di confine alle quali si applicano le disposizioni della legge 3 giugno 1935, n. 1095»; 113) regio decreto 14 ottobre 1938, n. 1759; 114) NUMERO ESPUNTO CON AVVISO DI RETTIFICA IN G.U. 7/9/2010; 115) regio decreto 12 maggio 1939, n. 708; 116) regio decreto 25 maggio 1939, n. 1126; 117) regio decreto 27 giugno 1939, n. 1108; 118) regio decreto 13 luglio 1939, n. 1260; 119) regio decreto 13 luglio 1939, n. 1674; 120) regio decreto 20 ottobre 1939, n. 1848; 121) regio decreto 26 ottobre 1939, n. 1995; 122) regio decreto 26 ottobre 1939, n. 2002; 123) regio decreto 19 febbraio 1940, n. 194; 124) regio decreto 7 marzo 1940, n. 339; 125) regio decreto 2 maggio 1940, n. 902; 126) regio decreto 6 giugno 1940, n. 1220; 127) regio decreto 6 giugno 1940, n. 1481; 128) regio decreto 29 giugno 1940, n. 1118; 129) regio decreto 29 giugno 1940, n. 1227; 130) regio decreto 29 giugno 1940, n. 1478; 131) regio decreto 5 settembre 1940, n. 1478; 132) regio decreto 26 ottobre 1940, n. 1809; 133) regio decreto 30 dicembre 1940, n. 2024; 134) regio decreto 25 marzo 1941, n. 472; 135) regio decreto 27 marzo 1941, n. 428; 136) regio decreto 15 maggio 1941, n. 611; 137) regio decreto 15 maggio 1941, n. 616; 138) regio decreto 24 agosto 1941, n. 1236; 139) regio decreto 17 ottobre 1941, n. 1480; 140) regio decreto 31 ottobre 1941, n. 1495; 141) regio decreto 14 novembre 1941, n. 1674; 142) regio decreto 20 novembre 1941, n. 1523; 143) regio decreto 20 novembre 1941, n. 1550; 144) regio decreto 16 dicembre 1941, n. 1633; 145) regio decreto 12 gennaio 1942, n. 233; 146) regio decreto 26 febbraio 1942, n. 238; 147) regio decreto 3 aprile 1942, n. 1133; 148) regio decreto 12 maggio 1942, n. 650; 149) regio decreto 12 maggio 1942, n. 918; 150) regio decreto 5 settembre 1942, n. 1273; 151) regio decreto 7 novembre 1942, n. 1515; 152) regio decreto 14 dicembre 1942, n. 1729; 153) regio decreto 10 febbraio 1943, n. 306; 154) regio decreto 23 febbraio 1943, n. 316; 155) regio decreto 10 maggio 1943, n. 629; 156) regio decreto 31 maggio 1943, n. 656; 157) regio decreto 7 giugno 1943, n. 652; 158) regio decreto 3 gennaio 1944, n. 15; 159) decreto luogotenenziale 1° marzo 1945, n. 127; 160) decreto luogotenenziale 26 aprile 1945, n. 230; 161) decreto luogotenenziale 2 novembre 1945, n. 900; 162) decreto luogotenenziale 16 novembre 1945; 163) decreto luogotenenziale 8 febbraio 1946, n. 162; 164) decreto ministeriale 25 ottobre 1946 «Elenco dei Comuni ai quali si applicano le disposizioni della legge 3 giugno 1935, n. 1095»; 165) decreto del Capo provvisorio dello Stato 3 gennaio 1947, n. 100; 166) decreto del Capo provvisorio dello Stato 4 febbraio 1947, n. 17; 167) decreto del Capo provvisorio dello Stato 5 agosto 1947, n. 931; 168) decreto del Capo provvisorio dello Stato 3 dicembre 1947, n. 1799; 169) decreto del Presidente della Repubblica 14 aprile 1948, n. 580; 170) decreto del Presidente della Repubblica 14 ottobre 1948, n. 1646; 171) decreto del Presidente della Repubblica 8 settembre 1949, n. 773; 172) decreto del Presidente della Repubblica 21 ottobre 1950, n. 1081; 173) decreto del Presidente della Repubblica 27 ottobre 1951, n. 1838; 174) decreto del Presidente della Repubblica 30 agosto 1952, n. 1337; 175) decreto del Presidente della Repubblica 10 febbraio 1953, n. 277; 176) decreto del Presidente della Repubblica 10 febbraio 1953, n. 331; 177) decreto del Presidente della Repubblica 22 marzo 1954, n. 586; 178) decreto del Presidente della Repubblica 19 marzo 1955, n. 470; 179) decreto del Presidente della Repubblica 3 giugno 1955, n. 679; 180) decreto del Presidente della Repubblica 20 giugno 1956, n. 950; 181) decreto del Presidente della Repubblica 23 ottobre 1956, n. 1672; 182) decreto del Presidente della Repubblica 14 settembre 1957, n. 1110; 183) decreto del Presidente del Consiglio dei Ministri 30 settembre 1957 recante «Cessazione della facolta' del Ministro per la difesa di requisire naviglio mercantile per il dragaggio delle mine e di militarizzare il personale da imbarcarsi su detto naviglio»; 184) decreto del Presidente della Repubblica 12 novembre 1958, n. 1211; 185) decreto del Presidente della Repubblica 30 luglio 1959, n. 859; 186) decreto del Presidente della Repubblica 12 febbraio 1960; 187) decreto del Presidente della Repubblica 22 giugno 1960, n. 1099; 188) decreto del Presidente della Repubblica 9 aprile 1962, n. 962; 189) decreto del Presidente della Repubblica 7 febbraio 1963, n. 790; 190) decreto del Presidente della Repubblica 24 aprile 1963, n. 931; 191) decreto del Presidente della Repubblica 21 agosto 1963, n. 1537; 192) decreto del Presidente della Repubblica 14 febbraio 1964, n. 199; 193) decreto del Presidente della Repubblica 18 maggio 1964, n. 628; 194) decreto del Presidente della Repubblica 28 maggio 1964, n. 496; 195) decreto del Presidente della Repubblica 28 maggio 1964, n. 670; 196) decreto del Presidente della Repubblica 26 maggio 1965, n. 1040; 197) decreto del Presidente della Repubblica 9 agosto 1966, n. 922; 198) decreto del Presidente della Repubblica 4 gennaio 1968, n. 678; 199) decreto del Presidente della Repubblica 13 agosto 1968, n. 1512; 200) decreto del Presidente della Repubblica 9 maggio 1969, n. 397; 201) decreto del Presidente della Repubblica 9 maggio 1969, n. 582; 202) decreto del Presidente della Repubblica 7 gennaio 1970, n. 98; 203) decreto del Presidente della Repubblica 14 agosto 1971, n. 1302; 204) decreto ministeriale 20 dicembre 1971 «Conferimento di incarichi e docenti civili per l'insegnamento di materie non militari presso scuole, istituti ed enti della Marina e dell'Aeronautica»; 205) decreto del Presidente della Repubblica 10 maggio 1972, n. 403; 206) decreto del Presidente della Repubblica 10 maggio 1972, n. 553; 207) decreto del Presidente della Repubblica 10 maggio 1972, n. 971; 208) decreto del Presidente della Repubblica 30 giugno 1972, n. 748: articoli 43 e 44; 209) decreto ministeriale 12 agosto 1972, «Criteri e modalita' per la scelta e la retribuzione del personale civile insegnante presso gli istituti, le scuole e gli enti dell'Esercito»; 210) decreto del Presidente della Repubblica 12 settembre 1972, n. 985; 211) decreto del Presidente della Repubblica 16 febbraio 1973, n. 183; 212) decreto ministeriale 19 maggio 1973, «Atto di approvazione del regolamento sul servizio territoriale e di presidio»; 213) decreto del Presidente della Repubblica 12 agosto 1973, n. 613; 213-bis) decreto del Presidente della Repubblica 26 settembre 1973, n. 966; 214) decreto del Presidente della Repubblica 31 dicembre 1973, n. 1076; 215) decreto del Presidente della Repubblica 31 dicembre 1973, n. 1199; 216) decreto del Presidente della Repubblica 7 marzo 1975, n. 210; 217) decreto del Presidente della Repubblica 9 marzo 1976, n. 471; 218) decreto del Presidente della Repubblica 29 maggio 1976, n. 658; 219) decreto del Presidente della Repubblica 5 giugno 1976, n. 636; 220) decreto del Presidente della Repubblica 30 dicembre 1976, n. 1015; 221) decreto del Presidente della Repubblica 8 gennaio 1977, n. 64; 222) decreto del Presidente della Repubblica 23 febbraio 1977, n. 240; 223) decreto del Presidente della Repubblica 10 giugno 1977, n. 490; 224) decreto del Presidente della Repubblica 16 giugno 1977, n. 1132; 225) decreto ministeriale 20 agosto 1977 «Estensione a taluni comuni delle province di Udine, Gorizia e Trieste del regime sui trapassi immobiliari previsti dalla legge 3 giugno 1935, n. 1095»; 226) decreto del Presidente della Repubblica 7 ottobre 1977, n. 895; 227) decreto del Presidente della Repubblica 28 novembre 1977, n. 1139; 228) decreto del Presidente della Repubblica 3 maggio 1978, n. 345; 229) decreto ministeriale 18 agosto 1978 «Applicazione del decreto del Presidente della Repubblica 31 dicembre 1973 n. 1199, concernente la disciplina per l'iscrizione nel quadro del naviglio militare di Stato»; 230) decreto del Presidente della Repubblica 29 settembre 1979, n. 601; 231) decreto del Presidente della Repubblica 4 novembre 1979, n. 691; 232) decreto del Presidente della Repubblica 17 dicembre 1979, n. 780; 233) decreto interministeriale 16 aprile 1980, che in applicazione dell'articolo 13, legge n. 497 del 1978 determina il canone per gli alloggi ASIR-ASI e per gli alloggi AST; 234) decreto del Presidente della Repubblica 31 luglio 1980, n. 613, articoli: 2, numero 2), lettere a) e b); 10; 235) decreto ministeriale 25 settembre 1980, recante norme attuative del decreto del Presidente della Repubblica n. 1015 del 1976 e del decreto del Presidente della Repubblica n. 345 del 1978; 236) decreto del Presidente della Repubblica 27 giugno 1981, «Tabelle annesse relative agli organici della magistratura militare»; 237) decreto del Presidente della Repubblica 1 luglio 1981, n. 735; 238) NUMERO ABROGATO DAL D.LGS. 31 DICEMBRE 2012, N. 248; 239) decreto del Presidente della Repubblica 17 maggio 1982, n. 459; 240) decreto del Presidente della Repubblica 17 maggio 1982, n. 1171; 241) decreto ministeriale 5 agosto 1982, «Norme di collegamento della rappresentanza militare con i rappresentanti dei militari delle categorie in congedo e dei pensionati»; 242) decreto del Presidente della Repubblica 18 marzo 1983, n. 290; 243) decreto del Presidente della Repubblica 14 settembre 1983, «Organici della magistratura militare»; 244) decreto ministeriale 1 ottobre 1983, «Inserimento dell'associazione nazionale dei decorati della medaglia mauriziana nell'elenco allegato al decreto ministeriale 5 agosto 1982, concernente norme di collegamento della rappresentanza militare con i rappresentanti militari delle categorie in congedo e dei pensionati»; 245) decreto del Presidente della Repubblica 31 ottobre 1983, n. 811; 246) decreto del Presidente della Repubblica 10 gennaio 1984, n. 23; 247) decreto del Presidente della Repubblica 6 febbraio 1984, n. 49; 248) decreto del Presidente della Repubblica 30 ottobre 1984, n. 912; 249) decreto del Presidente della Repubblica 30 ottobre 1984 n. 913; 250) decreto del Presidente della Repubblica 6 novembre 1984, n. 850; 251) decreto del Presidente della Repubblica 6 febbraio 1985, n. 804; 252) decreto del Presidente della Repubblica 5 aprile 1985, n. 229; 253) decreto del Presidente della Repubblica 2 settembre 1985, n. 1008; 254) decreto ministeriale 9 ottobre 1985, «Approvazione del regolamento per l'organizzazione e il funzionamento della rappresentanza militare»; 255) decreto ministeriale 25 novembre 1985, «Cancellazione di tre associazioni e inserimento di una nuova associazione nell'elenco allegato al decreto ministeriale 5 agosto 1982, concernente norme di collegamento della rappresentanza militare con i rappresentanti dei militari delle categorie in congedo e dei pensionati»; 256) decreto del Presidente della Repubblica 23 gennaio 1986, n. 94; 257) decreto del Presidente della Repubblica 28 marzo 1986, n. 136; 258) decreto ministeriale 12 maggio 1986, «Inserimento dell'associazione nazionale veterani e reduci garibaldini nell'elenco allegato al decreto ministeriale 5 agosto 1982, concernente norme di collegamento della rappresentanza militare con i rappresentanti militari delle categorie in congedo e dei pensionati»; 259) decreto del Presidente della Repubblica 18 luglio 1986, n. 545; 260) decreto ministeriale 30 ottobre 1986, «Iscrizione della Federazione italiana dei combattenti alleati e dell'associazione nazionale ufficiali provenienti dal servizio attivo nell'elenco allegato al decreto ministeriale 5 agosto 1982, concernente norme di collegamento della rappresentanza militare con i rappresentanti militari delle categorie in congedo e dei pensionati»; 261) decreto ministeriale 15 gennaio 1987, n. 136; 262) decreto del Presidente della Repubblica 29 gennaio 1987, n. 98; 263) decreto del Presidente della Repubblica 13 aprile 1987, «Tabelle annesse relative agli organici della magistratura militare»; 264) decreto del Presidente del Consiglio dei Ministri 22 luglio 1987, n. 411: articolo 2; 265) decreto del Presidente della Repubblica 13 ottobre 1987, n. 579; 266) decreto del Presidente della Repubblica 4 febbraio 1988, n. 37; 267) decreto ministeriale 11 febbraio 1988, n. 62; 268) decreto del Presidente della Repubblica 18 novembre 1988, n. 566: articolo 27, comma 1, limitatamente alle parole «o presso uno degli istituti medico - legali dell'Aeronautica militare»; 269) decreto ministeriale 20 febbraio 1989, «Integrazione dell'elenco allegato al decreto ministeriale 5 agosto 1982, concernente norme di collegamento della rappresentanza militare con i rappresentanti militari delle categorie in congedo e dei pensionati»; 270) decreto del Presidente della Repubblica 24 marzo 1989, n. 158; 271) decreto interministeriale 3 giugno 1989 relativo agli alloggi di servizio gratuiti connessi all'incarico (ASGI) dell'Arma dei carabinieri; 272) decreto ministeriale 3 luglio 1989, «Iscrizione dell'associazioni lagunari truppe anfibie e dell'associazione nazionale volontari di guerra all'albo previsto dall'articolo 1 decreto ministeriale 5 agosto 1982»; 273) decreto del Presidente della Repubblica 10 novembre 1989, «Tabelle annesse relative agli organici della magistratura militare»; 274) decreto ministeriale 15 gennaio 1990, «Modificazioni all'articolo 14 del regolamento interno per l'organizzazione e il funzionamento della rappresentanza militare; 275) decreto del Presidente della Repubblica 21 febbraio 1990, n. 68; 276) decreto ministeriale 15 maggio 1990 «Dichiarazione d'importanza militare per alcune zone del territorio nazionale»; 277) decreto interministeriale 12 luglio 1990, n. 616; 278) decreto del Presidente della Repubblica 25 luglio 1990, n. 433; 279) decreto del Presidente della Repubblica 4 agosto 1990, n. 251; 280) decreto ministeriale 19 febbraio 1991, n. 95; 281) decreto ministeriale 28 febbraio 1991, n. 96; 282) decreto ministeriale 28 marzo 1991, «Integrazione all'elenco allegato al decreto ministeriale 5 agosto 1982, concernente norme di collegamento della rappresentanza militare con i rappresentanti militari delle categorie in congedo e dei pensionati»; 283) decreto ministeriale 4 settembre 1991, «Tabelle annesse relative agli organici della magistratura militare»; 284) decreto del Presidente della Repubblica 14 ottobre 1991, n. 355; 285) decreto ministeriale 19 febbraio 1992, n. 308; 286) decreto ministeriale 24 febbraio 1992, n. 337; 287) decreto del Presidente del Consiglio dei Ministri 4 maggio 1992, n. 389; 288) decreto del Presidente della Repubblica 27 novembre 1992, n. 520; 289) decreto del Presidente della Repubblica 12 agosto 1993, n. 351; 290) decreto ministeriale 16 settembre 1993, n. 603; 291) decreto ministeriale 2 novembre 1993, n. 571; 292) decreto ministeriale 24 novembre 1993, «Modalita' di attuazione delle norme previste dagli articoli 1 e 3 del decreto-legge 27 agosto 1993, n. 325, convertito, con modificazioni dalla legge 27 ottobre 1993, n. 424, recante elargizione a favore dei cittadini vittime di incidenti occorsi durante attivita' operative ed addestrative delle Forze armate»; 293) decreto interministeriale 7 marzo 1994 che modifica l'allegato A) al decreto interministeriale 3 giugno 1989 relativo agli alloggi di servizio dell'Arma dei carabinieri 294) decreto del Presidente della Repubblica 8 agosto 1994, n. 568; 295) decreto ministeriale 3 gennaio 1995, n. 167; 296) decreto ministeriale 3 gennaio 1995, n. 168; 297) decreto ministeriale 14 giugno 1995, n. 519; 298) decreto ministeriale 27 giugno 1995, n. 570; 299) decreto del Presidente della Repubblica 14 luglio 1995, n. 419; 300) decreto interministeriale 12 ottobre 1995, che in applicazione dell'articolo 13, legge n. 497 del 1978 determina il canone per gli alloggi AST; 301) decreto ministeriale 24 novembre 1995, che in applicazione dell'articolo 13, legge n. 497 del 1978 determina il canone per gli alloggi AST; 302) decreto ministeriale 24 novembre 1995 che in applicazione dell'articolo 13, legge n. 497 del 1978 determina il canone per gli alloggi, determina il canone per gli alloggi ASIR-ASI; 303) decreto ministeriale 29 novembre 1995, «Approvazione del nuovo elenco delle imperfezioni e delle infermita' che sono causa di non idoneita' al servizio militare»; 304) decreto ministeriale 28 dicembre 1995, n. 586; 305) decreto ministeriale 8 agosto 1996, n. 690; 306) decreto del Presidente della Repubblica 17 ottobre 1996, n. 616; 307) decreto ministeriale 25 marzo 1997, n. 138; 308) decreto ministeriale 24 giugno 1997, n. 269; 309) decreto del Presidente della Repubblica 16 luglio 1997, n. 289: articolo 5; 310) decreto del Presidente della Repubblica 16 luglio 1997, n. 361; 311) decreto del Presidente della Repubblica 2 settembre 1997, n. 332; 312) decreto ministeriale 27 febbraio 1998, n. 86,; 313) decreto del Presidente della Repubblica 13 luglio 1998, n. 367: articolo 7, comma 6; 314) decreto ministeriale 31 dicembre 1998, n. 521; 315) decreto ministeriale 31 dicembre 1998, n. 522; 316) decreto ministeriale 1 febbraio 1999, n. 71; 317) decreto ministeriale 12 marzo 1999, n. 125; 318) decreto ministeriale 26 marzo 1999, «Approvazione del nuovo elenco delle imperfezioni e delle infermita' che sono causa di non idoneita' al servizio militare»; 319) decreto ministeriale 22 aprile 1999, n. 188; 320) decreto ministeriale 3 giugno 1999, n. 244; 321) decreto ministeriale 12 giugno 1999, n. 245; 322) decreto ministeriale 19 ottobre 1999, n. 459; 323) decreto del Presidente della Repubblica 25 ottobre 1999, n. 556; 324) decreto ministeriale 3 novembre 1999, n. 486; 325) decreto ministeriale 8 marzo 2000, «Criteri per l'individuazione dei livelli di reddito e degli altri elementi obiettivi utili per il riconoscimento dei titoli previsti per la concessione della dispensa dalla ferma di leva per l'anno 2000»; 326) decreto del Presidente del Consiglio dei ministri 16 marzo 2000, n. 112; 327) decreto ministeriale 4 aprile 2000, n. 114; 328) decreto ministeriale 14 giugno 2000, n. 284; 329) decreto ministeriale 30 giugno 2000, n. 292; 330) decreto ministeriale 4 agosto 2000, n. 302; 331) decreto ministeriale 11 settembre 2000, n. 330; 332) decreto del Presidente della Repubblica 15 novembre 2000, n. 424; 333) decreto ministeriale 7 marzo 2001 «Criteri per l'individuazione dei livelli di reddito e degli altri elementi obiettivi utili per il riconoscimento dei titoli previsti per la concessione della dispensa dalla ferma di leva per l'anno 2001»; 334) decreto del Presidente della Repubblica 21 marzo 2001, n. 169; 335) decreto del Presidente della Repubblica 21 marzo 2001, n. 172; 336) decreto del Presidente della Repubblica 15 maggio 2001, n. 300; 337) decreto ministeriale 8 giugno 2001, n. 323; 338) decreto ministeriale 8 ottobre 2001, n. 412; 339) decreto ministeriale 30 novembre 2001, «Alienazione, cessione di materiale e mezzi eccedenti le esigenze delle Forze armate»; 340) decreto del Presidente della Repubblica 10 dicembre 2001, n. 479; 341) decreto ministeriale 19 marzo 2002 «Criteri per l'individuazione dei livelli di reddito e degli altri elementi obiettivi utili per il riconoscimento dei titoli previsti per la concessione della dispensa dalla ferma di leva per l'anno 2002»; 342) decreto ministeriale 28 giugno 2002 «Modalita' e procedure per l'acquisizione in economia di beni e servizi da parte di organismi dell'Amministrazione della difesa»; 343) decreto del Presidente della Repubblica 8 agosto 2002, n. 213; 344) decreto del Presidente della Repubblica 26 settembre 2002, n. 252; 345) decreto ministeriale 22 ottobre 2002, n. 274; 346) decreto ministeriale 22 novembre 2002, n. 299; 347) decreto ministeriale 10 febbraio 2003, n. 64; 348) decreto ministeriale 25 febbraio 2003, «Criteri per l'individuazione dei livelli di reddito e degli altri elementi obiettivi utili per il riconoscimento dei titoli previsti per la concessione della dispensa dalla ferma di leva per l'anno 2003»; 349) decreto ministeriale 31 marzo 2003, n. 117; 350) decreto ministeriale 3 maggio 2003, n. 161; 351) decreto ministeriale 13 giugno 2003, n. 187; 352) decreto ministeriale 30 dicembre 2003, «Determinazione delle condizioni per la concessione della dispensa dagli obblighi di leva, ai sensi dell'articolo 7, comma 3, lettera a) del decreto legislativo 30 dicembre 1997, n. 504»; 353) decreto ministeriale 23 gennaio 2004, n. 88; 354) decreto del Presidente della Repubblica 6 febbraio 2004, n. 83; 355) decreto ministeriale 10 marzo 2004, «Sostituzione dell'allegato A, al d.m. 30 novembre 2001, concernente alienazione, cessione di materiale e mezzi eccedenti le esigenze delle Forze armate»; 356) decreto ministeriale 11 marzo 2004, «Criteri per l'individuazione dei livelli di reddito e degli altri elementi obiettivi utili per il riconoscimento dei titoli previsti per la concessione della dispensa dalla ferma di leva per l'anno 2004»; 357) decreto del Presidente del Consiglio dei Ministri 18 ottobre 2004 «Individuazione delle regioni maggiormente oberate dai vincoli e dalle attivita' militari per il quinquennio 2000-2004, ai fini della corresponsione di un contributo annuo dello Stato - Articolo 4, comma 2, della legge 2 maggio 1990, n. 104»; 358) decreto ministeriale 24 novembre 2004, n. 326; 359) decreto del Presidente della Repubblica 6 aprile 2005, n. 83; 360) decreto del Presidente della Repubblica 19 aprile 2005, n. 113; 361) decreto del Presidente della Repubblica 19 aprile 2005, n. 170: articolo 2, comma 10; 362) decreto del Presidente del Consiglio dei Ministri 6 maggio 2005, n. 97: articoli 9, comma 2, numeri 1) e 2); 14; 33; 363) decreto del Presidente del Consiglio dei ministri 24 giugno 2005, n. 183; 364) decreto ministeriale 8 luglio 2005, n. 165; 365) decreto ministeriale 26 luglio 2005, n. 172; 366) decreto ministeriale 27 luglio 2005, «Modifiche al decreto ministeriale 5 agosto 1982 del Ministro della difesa, recante norme di collegamento della rappresentanza militare con i rappresentanti militari delle categorie in congedo e dei pensionati»; 367) decreto ministeriale 28 luglio 2005, n. 180; 368) decreto ministeriale 21 settembre 2005, n. 235; 369) decreto del Presidente della Repubblica 28 novembre 2005, n. 300; 370) decreto del Presidente della Repubblica 21 febbraio 2006, n. 167: tranne gli articoli 14 e 15; 371) decreto del Presidente della Repubblica 24 febbraio 2006, n. 162; 372) decreto ministeriale 13 aprile 2006, n. 203; 373) decreto ministeriale 10 maggio 2006, n. 232; 374) decreto ministeriale 15 maggio 2006, n. 212; 375) decreto del Presidente della Repubblica 11 luglio 2006, n. 255; 376) decreto ministeriale 27 settembre 2006, «Modalita' attuative delle cessioni di beni mobili a titolo gratuito nell'ambito di missioni internazionali»; 377) decreto interministeriale 14 novembre 2006, «Aggiornamento, a decorrere dal 1° luglio 2005, delle paghe nette giornaliere spettanti ai graduati e militari di truppa nonche' al personale equiparato»; 378) decreto ministeriale 29 dicembre 2006, n. 317; 379) decreto ministeriale 29 dicembre 2006, «Disciplina delle condizioni e delle modalita' per i contratti di permuta di materiali o prestazioni da stipulare tra il Ministero della difesa e soggetti pubblici e privati, in attuazione dell'articolo 1, commi 568 e 569, della legge 23 dicembre 2005, n. 266»; 380) decreto ministeriale 23 febbraio 2007, n. 53; 381) decreto del Presidente della Repubblica 14 maggio 2007, n. 88; 382) decreto del Presidente della Repubblica 28 gennaio 2008, n. 52; 383) decreto ministeriale 29 aprile 2008, «Aggiornamento dell'elenco delle associazioni militari»; 384) decreto del Presidente della Repubblica 15 ottobre 2008, n. 164; 385) decreto del Presidente della Repubblica 3 marzo 2009, n. 37; 386) decreto del Presidente della Repubblica 22 giugno 2009, n. 105; 387) decreto del Presidente della Repubblica 22 giugno 2009, n. 136; 388) decreto ministeriale 3 luglio 2009, n. 125; 389) decreto del Presidente della Repubblica 3 agosto 2009, n. 145; 390) decreto del Presidente della Repubblica 12 novembre 2009, n. 203; 391) decreto del Presidente della Repubblica 12 novembre 2009, n. 205; 392) decreto del Presidente della Repubblica 12 novembre 2009, n. 209; 393) decreto del Presidente della Repubblica 4 dicembre 2009, n. 211; 394) decreto del Presidente della Repubblica 23 dicembre 2009, n. 215. 394-bis) decreto del Presidente della Repubblica 30 aprile 2010, n. 117; 394-ter) decreto del Presidente della Repubblica 14 maggio 2010, n. 115; 394-quater) decreto del Ministro della difesa 18 maggio 2010, n. 112.

### Art. 2270. - Norme che rimangono in vigore

1. In attuazione dell'articolo 14, comma 14, legge 28 novembre 2005, n. 246, restano in vigore i seguenti atti normativi primari, e le relative successive modificazioni: 1) regio decreto 27 ottobre 1922, n. 1462: articoli 6 e 23; 2) regio decreto 3 giugno 1926, n. 941; 3) regio decreto 31 dicembre 1928, n. 3458: articoli 11 e 115; 4) regio decreto-legge 20 luglio 1934, n. 1302 e legge di conversione 4 aprile 1935, n. 808: articoli 3, 7, 9, 10 e 11; 5) regio decreto legge 21 agosto 1937, n. 1542, convertito dalla legge 3 gennaio 1939, n. 1: articolo 22; 6) regio decreto-legge 14 ottobre 1937, n. 2707, convertito dalla legge 3 giugno 1938, n. 1176; 7) legge 2 maggio 1938, n. 735; 8) legge 3 giugno 1938, n. 1176, di conversione in legge del regio decreto-legge 14 ottobre 1937, n. 2707; 9) regio decreto 8 luglio 1938, n. 1415, a esclusione dell'articolo 133; 10) regio decreto 15 luglio 1938, n. 1156: ((articoli 5 e 19;)) 11) regio decreto legge 5 settembre 1938, n. 1628, convertito dalla legge 22 dicembre 1938, n. 2196; 12) legge 21 maggio 1940, n. 415; 13) legge 25 agosto 1940, n. 1304; 14) legge 1 novembre 1940, n. 1610; 15) legge 16 dicembre 1940, n. 1902; 16) legge 27 gennaio 1941, n. 73; 17) regio decreto legge 6 marzo 1941, n. 219, convertito dalla legge 4 luglio 1941, n. 872; 18) regio decreto legge 14 giugno 1941, n. 878; 19) regio decreto legge 22 aprile 1941, n. 445, convertito dalla legge 24 agosto 1941, n. 1075; 20) legge 4 luglio 1941, n. 872, di conversione in legge del regio decreto legge 6 marzo 1941, n. 219, 21) legge 25 luglio 1941, n. 902; 22) legge 24 agosto 1941 n. 1075, di conversione in legge del regio decreto-legge 22 aprile 1941, n. 445; 23) legge 29 novembre 1941, n. 1571; 24) legge 9 dicembre 1941, n. 1383; 25) regio decreto legge 19 gennaio 1942, n. 87, convertito in legge 7 maggio 1942, n. 562; 26) legge 23 aprile 1942, n. 456; 27) legge 7 maggio 1942, n. 562, di conversione in legge, con modificazioni del regio decreto-legge 19 gennaio 1942, n. 87; 28) regio decreto 31 ottobre 1942, n. 1611; 29) regio decreto legge 30 marzo 1943, n. 123; 30) legge 2 aprile 1943, n. 260; 30-bis) legge 10 aprile 1954, n. 113: articolo 68; 30-ter) legge 31 luglio 1954. n. 599: articolo 32; 31) decreto del Presidente della Repubblica 17 agosto 1955, n. 767: articolo 7; 32) legge 8 marzo 1958, n. 233: articolo 6; 33) legge 29 novembre 1961, n. 1300: articoli 4, 5 e 6; 33-bis) legge 18 marzo 1968, n. 263; 33-ter) legge 5 maggio 1976, n. 187: articoli 18 e 26, quest'ultimo limitatamente al personale delle Forze armate e di polizia ad ordinamento militare, nonche' 27, secondo comma; 34) legge 14 aprile 1977, n. 112: articolo 6; 35) legge 6 marzo 1992, n. 216, a esclusione dell'articolo 2, comma 5; 36) decreto legislativo 12 maggio 1995, n. 195.

2. Restano in vigore i seguenti atti normativi secondari e successive modificazioni: 1) regio decreto 5 settembre 1938, n. 1823; 2) regio decreto 12 ottobre 1939, n. 1725; 3) regio decreto 12 ottobre 1939, n. 2248; 4) regio decreto 16 giugno 1940, n. 656; 5) regio decreto 16 giugno 1940, n. 765; 6) regio decreto 16 luglio 1940, n. 1056; 7) regio decreto 25 novembre 1940, n. 1886; 8) regio decreto 29 maggio 1941, n. 401; 9) regio decreto 14 giugno 1941, n. 878; 10) regio decreto 31 ottobre 1942, n. 1612; 11) decreto luogotenenziale 9 novembre 1945, n. 731; 12) decreto del Presidente della Repubblica 2 dicembre 1956, n. 1666. 12-bis) decreto del Presidente della Repubblica 3 maggio 1957, n. 686, articoli da 42 a 47, limitatamente a quanto disposto dall'articolo 1, comma 555, della legge 27 dicembre 2006, n. 296.

### Art. 2271. - Norma finanziaria

1. Dall'attuazione del codice non devono derivare nuovi o maggiori oneri a carico della finanza pubblica.

### Art. 2272. - Entrata in vigore

1. Il codice e il regolamento entrano in vigore cinque mesi dopo la pubblicazione nella Gazzetta Ufficiale della Repubblica Italiana del codice.

